(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2822017,     109176]*)
(*NotebookOutlinePosition[   2822761,     109201]*)
(*  CellTagsIndexPosition[   2822717,     109197]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["FOCUSING IN FRONT OF A NEGATIVE DELTA-FUNCTION \
NONHOMOGENEITY", "Text",
  CellFrame->True,
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  v[x]  ",
    FontSize->12],
  StyleBox["is a delta-function of strength  c0, positive or negative, \
located at  x=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  The potential has one bound state if  c0<0  and no bound states \
if  c0>0.\n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" <0, is in front of  the nonhomogeneity and needs to be \
specified. ",
    FontSize->12],
  StyleBox["\n\nThe transmission coefficient, left reflection coefficient, \
and right reflection coefficient, respectively, are denoted by  T[k],  L[k],  \
R[k].\n\nThe tail of the wave is denoted by  g[x,t].\n\nThe focusing moment \
is chosen as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(Clear[v, T, L, R, c0, x0, g];\)\), "\[IndentingNewLine]", 
    \(\(v[x_] = \ c0\ \ DiracDelta[x]\ ;\)\), "\n", 
    \(\(T[k_] = k/\((k + I\ \ c0/2)\);\)\), "\n", 
    \(\(L[k_] = \((\(-I\)\ c0/2)\)/\((k + I\ \ c0/2)\);\)\), "\n", 
    \(\(R[k_] = \((\(-I\)\ c0/2)\)/\((k + I\ \ c0/2)\);\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the strength of the potential, c0, a negative number;
also specify the focusing location  x0, a negative number, next:\
\>", "Text",\

  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(c0 = \(-1\)\)\(;\)\(\ \ \)\(\(x0 = \(-1\)\) \)\(;\)\(\ \)\)\)], \
"Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(\n\)\(g[x_, 
          t_] = \ \(-\ \((c0/
                2)\)\)\ \((UnitStep[
                  x]\ \ UnitStep[\(-x\) + x0 + 
                    t]\ E^\((c0 \((x - x0 - t)\)/2)\) + 
              UnitStep[\(-x\)]\ UnitStep[
                  x + x0 + 
                    t]\ \ E^\((\(-c0\) \((x + x0 + t)\)/
                        2)\))\);\)\)\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-3\), \ 
              3}, \ PlotRange -> {\(-0.2\), 2.5}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-3\), \ 3}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-0.2\), 
                2.5}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-3\), \ 3}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-0.2\), 
                2.5}]}, \[IndentingNewLine]\ {t, \ \(-1.9\), \ 3.9, 0.05}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.02846 .04578 L
.03279 .04578 L
.03523 .04578 L
.03754 .04578 L
.03881 .04578 L
.03953 .04578 L
s
.03953 .04578 m
.0397 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool01@000?ooooooooooool0V@03oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo000Goooo00?o09Woooooool0MOooo`030000oooooooo
08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo
07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool0
01Ooool00ol0VOooooooo`1eoooo0P0008ooool001Ooool00ol0VOooooooo`1eoooo00<0003ooooo
ool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Wooooo
ool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_oo
o`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOoo
o`80002?oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOoo
ooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>
oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1e
oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool20000Soooo`005oooo`03o`2I
oooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo
08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo
07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool0
01Ooool00ol0VOooooooo`1eoooo0P0008ooool001Ooool00ol0VOooooooo`1eoooo00<0003ooooo
ool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Wooooo
ool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1Roooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo067oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0HOoo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`005oooo`03o`2Ioooooooo
067oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool001Ooool00ol0VOoo
ooooo`1Qoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
01Ooool00ol0VOooooooo`1Roooo0P0000[oool300001?ooo`030000oooooooo08koool001Ooool0
0ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?oo
ooooo`2>oooo000Goooo00?o09Woooooool0MOooo`80002?oooo000Goooo00?o09Woooooool0MOoo
o`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005ooo
o`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000
oooooooo08koool001Ooool00ol0VOooooooo`1eoooo0P0008ooool001Ooool00ol0VOooooooo`1e
oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000G
oooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0
003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o
09Woooooool0MOooo`80002?oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool0
01Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool0
0`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool0
0ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool20000Sooo
o`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOoo
o`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005ooo
o`03o`2Ioooooooo06goool500000oooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1_
oooo00<0003oooooool00oooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1_oooo00<0
003oooooool00oooo`<0002>oooo000Goooo00?o09Woooooool0Koooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo000Goooo00?o09Woooooool0Koooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Goooo00?o09Woooooool0K_ooo`800005oooo00<0003oooooool0S_ooo`005ooo
o`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000
oooooooo08koool001Ooool00ol0VOooooooo`1eoooo0P0008ooool001Ooool00ol0VOooooooo`1e
oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000G
oooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0
003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o
09Woooooool0MOooo`80002?oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool0
01Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool0
0`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool0
0ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool20000Sooo
o`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOoo
o`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005ooo
o`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000
oooooooo08koool001Ooool00ol0VOooooooo`1eoooo0P0008ooool001Ooool00ol0VOooooooo`1e
oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000G
oooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1Qoooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo06?oool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`005oooo`03o`2I
oooooooo06?oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Goooo00?o
09Woooooool0Hoooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool001Ooool0
0ol0VOooooooo`1Soooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo000Goooo00?o09Woooooool0H_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000G
oooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0
003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool20000Soooo`005oooo`03o`2Ioooooooo
07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool0
01Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool0
0`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool0
0ol0VOooooooo`1eoooo0P0008ooool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_oo
o`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOoo
o`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005ooo
o`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`80002?
oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1e
oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000G
oooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0
003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool20000Soooo`005oooo`03o`2Ioooooooo
07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool0
01Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo06goool4
00001?ooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1]oooo00<0003oooooool01Ooo
o`030000oooooooo08koool001Ooool00ol0VOooooooo`1^oooo00<0003oooooool01?ooo`<0002>
oooo000Goooo00?o09Woooooool0Koooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000G
oooo00?o09Woooooool0KOooo`040000oooooooo00001?ooo`030000oooooooo08koool001Ooool0
0ol0VOooooooo`1^oooo0P0000Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOoo
o`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005ooo
o`03o`2Ioooooooo07Goool20000Soooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>
oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1e
oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000G
oooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo0P00
08ooool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo
07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool0
01Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo07Goool0
0`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOooo`80002?oooo000Goooo00?o09Wooooo
ool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_oo
o`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0MOoo
o`030000oooooooo08koool001Ooool00ol0VOooooooo`1eoooo00<0003oooooool0S_ooo`005ooo
o`03o`2Ioooooooo07Goool20000Soooo`005oooo`03o`2Ioooooooo07Goool00`000?ooooooo`2>
oooo000Goooo00?o09Woooooool0MOooo`030000oooooooo08koool001Ooool00ol0VOooooooo`1e
oooo00<0003oooooool0S_ooo`005oooo`03o`2Ioooooooo067oool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0HOooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Goooo00?o09Woooooool0H_ooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool0
0`000?ooooooo`08oooo0`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
01Coool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000001Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{79.5625, 308.938}, {290.125, 148.813}} -> {-0.349561, \
1.05307, 0.00349883, 0.00566123}, {{79.875, 308.563}, {290.125, 148.813}} -> \
{-5.8905, 2.92371, 0.0242634, 0.0168253}, {{79.875, 308.563}, {290.125, \
148.813}} -> {-5.8905, 2.92371, 0.0242634, 0.0168253}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.03279 .04578 L
.04262 .04578 L
.04517 .04578 L
.04642 .04578 L
.04758 .04578 L
s
.04758 .04578 m
.04774 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`03oooo00?o09Woool000002?ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool0
01Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool0
0`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool0
0ol0VOooooooo`1coooo0P0008ooool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_oo
o`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Looo
o`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Ooo
o`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`80002?
oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1c
oooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000I
oooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0
003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool20000Soooo`006Oooo`03o`2Ioooooooo
07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool0
01Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool0
0`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool0
0ol0VOooooooo`1coooo0P0008ooool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_oo
o`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Looo
o`030000oooooooo08koool001Woool00ol0VOooooooo`1Poooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo05ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Goooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`006Oooo`03o`2Ioooooooo05ooool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool001Woool00ol0VOooooooo`1O
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool001Woool0
0ol0VOooooooo`1Poooo0P0000[oool300001?ooo`030000oooooooo08koool001Woool00ol0VOoo
ooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>
oooo000Ioooo00?o09Woooooool0Loooo`80002?oooo000Ioooo00?o09Woooooool0Loooo`030000
oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2I
oooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo
08koool001Woool00ol0VOooooooo`1coooo0P0008ooool001Woool00ol0VOooooooo`1coooo00<0
003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o
09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003ooooo
ool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Wooooo
ool0Loooo`80002?oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool0
0ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?oo
ooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOoo
ooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool20000Soooo`006Ooo
o`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000
oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2I
oooooooo06_oool500000oooo`030000oooooooo08koool001Woool00ol0VOooooooo`1]oooo00<0
003oooooool00oooo`030000oooooooo08koool001Woool00ol0VOooooooo`1]oooo00<0003ooooo
ool00oooo`<0002>oooo000Ioooo00?o09Woooooool0KOooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Ioooo00?o09Woooooool0KOooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000Ioooo00?o09Woooooool0K?ooo`800005oooo00<0003oooooool0S_ooo`006Oooo`03o`2I
oooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo
08koool001Woool00ol0VOooooooo`1coooo0P0008ooool001Woool00ol0VOooooooo`1coooo00<0
003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o
09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003ooooo
ool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Wooooo
ool0Loooo`80002?oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool0
0ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?oo
ooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOoo
ooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool20000Soooo`006Ooo
o`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000
oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2I
oooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo
08koool001Woool00ol0VOooooooo`1coooo0P0008ooool001Woool00ol0VOooooooo`1coooo00<0
003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o
09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1Ooooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo067oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo
067oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Ioooo00?o09Wooooo
ool0HOooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool001Woool00ol0VOoo
ooooo`1Qoooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000I
oooo00?o09Woooooool0H?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Ioooo00?o
09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003ooooo
ool0S_ooo`006Oooo`03o`2Ioooooooo07?oool20000Soooo`006Oooo`03o`2Ioooooooo07?oool0
0`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool0
0ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?oo
ooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOoo
ooooo`1coooo0P0008ooool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Ooo
o`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000
oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2I
oooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`80002?oooo000I
oooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0
003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o
09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003ooooo
ool0S_ooo`006Oooo`03o`2Ioooooooo07?oool20000Soooo`006Oooo`03o`2Ioooooooo07?oool0
0`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool0
0ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo06_oool400001?oo
o`030000oooooooo08koool001Woool00ol0VOooooooo`1[oooo00<0003oooooool01Oooo`030000
oooooooo08koool001Woool00ol0VOooooooo`1/oooo00<0003oooooool01?ooo`<0002>oooo000I
oooo00?o09Woooooool0KOooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000Ioooo00?o
09Woooooool0Joooo`040000oooooooo00001?ooo`030000oooooooo08koool001Woool00ol0VOoo
ooooo`1/oooo0P0000Goool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000
oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2I
oooooooo07?oool20000Soooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000I
oooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0
003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o
09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo0P0008ooool0
01Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool0
0`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool0
0ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2Ioooooooo07?oool00`000?oo
ooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`80002?oooo000Ioooo00?o09Woooooool0Looo
o`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Ooo
o`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Loooo`030000
oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0003oooooool0S_ooo`006Oooo`03o`2I
oooooooo07?oool20000Soooo`006Oooo`03o`2Ioooooooo07?oool00`000?ooooooo`2>oooo000I
oooo00?o09Woooooool0Loooo`030000oooooooo08koool001Woool00ol0VOooooooo`1coooo00<0
003oooooool0S_ooo`006Oooo`03o`2Ioooooooo05ooool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0Goooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000Ioooo00?o09Woooooool0H?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001Oooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001Coool00`000?oo
ooooo`08oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`00000Goooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_oo
o`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.03279 .04578 L
.04262 .04578 L
.04758 .04578 L
.0503 .04578 L
.05288 .04578 L
.05405 .04578 L
.05528 .04578 L
s
.05528 .04578 m
.05544 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool0
01_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool0
0`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool0
0ol0VOooooooo`1aoooo0P0008ooool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_oo
o`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOoo
o`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006ooo
o`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`80002?
oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1a
oooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000K
oooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0
003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool20000Soooo`006oooo`03o`2Ioooooooo
077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool0
01_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool0
0`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool0
0ol0VOooooooo`1aoooo0P0008ooool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_oo
o`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOoo
o`030000oooooooo08koool001_oool00ol0VOooooooo`1Noooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo05goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0GOooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`006oooo`03o`2Ioooooooo05goool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool001_oool00ol0VOooooooo`1M
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool001_oool0
0ol0VOooooooo`1Noooo0P0000[oool300001?ooo`030000oooooooo08koool001_oool00ol0VOoo
ooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>
oooo000Koooo00?o09Woooooool0LOooo`80002?oooo000Koooo00?o09Woooooool0LOooo`030000
oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2I
oooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo
08koool001_oool00ol0VOooooooo`1aoooo0P0008ooool001_oool00ol0VOooooooo`1aoooo00<0
003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o
09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003ooooo
ool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Wooooo
ool0LOooo`80002?oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool0
0ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?oo
ooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOoo
ooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool20000Soooo`006ooo
o`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000
oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2I
oooooooo06Woool500000oooo`030000oooooooo08koool001_oool00ol0VOooooooo`1[oooo00<0
003oooooool00oooo`030000oooooooo08koool001_oool00ol0VOooooooo`1[oooo00<0003ooooo
ool00oooo`<0002>oooo000Koooo00?o09Woooooool0Joooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Koooo00?o09Woooooool0Joooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000Koooo00?o09Woooooool0J_ooo`800005oooo00<0003oooooool0S_ooo`006oooo`03o`2I
oooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo
08koool001_oool00ol0VOooooooo`1aoooo0P0008ooool001_oool00ol0VOooooooo`1aoooo00<0
003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o
09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003ooooo
ool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Wooooo
ool0LOooo`80002?oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool0
0ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?oo
ooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOoo
ooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool20000Soooo`006ooo
o`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000
oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2I
oooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo
08koool001_oool00ol0VOooooooo`1aoooo0P0008ooool001_oool00ol0VOooooooo`1aoooo00<0
003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o
09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1Moooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo05ooool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo
05ooool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Koooo00?o09Wooooo
ool0Goooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool001_oool00ol0VOoo
ooooo`1Ooooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000K
oooo00?o09Woooooool0G_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Koooo00?o
09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003ooooo
ool0S_ooo`006oooo`03o`2Ioooooooo077oool20000Soooo`006oooo`03o`2Ioooooooo077oool0
0`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool0
0ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?oo
ooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOoo
ooooo`1aoooo0P0008ooool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006ooo
o`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000
oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2I
oooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`80002?oooo000K
oooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0
003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o
09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003ooooo
ool0S_ooo`006oooo`03o`2Ioooooooo077oool20000Soooo`006oooo`03o`2Ioooooooo077oool0
0`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool0
0ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo06Woool400001?oo
o`030000oooooooo08koool001_oool00ol0VOooooooo`1Yoooo00<0003oooooool01Oooo`030000
oooooooo08koool001_oool00ol0VOooooooo`1Zoooo00<0003oooooool01?ooo`<0002>oooo000K
oooo00?o09Woooooool0Joooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000Koooo00?o
09Woooooool0JOooo`040000oooooooo00001?ooo`030000oooooooo08koool001_oool00ol0VOoo
ooooo`1Zoooo0P0000Goool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000
oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2I
oooooooo077oool20000Soooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000K
oooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0
003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o
09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo0P0008ooool0
01_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool0
0`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool0
0ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2Ioooooooo077oool00`000?oo
ooooo`2>oooo000Koooo00?o09Woooooool0LOooo`80002?oooo000Koooo00?o09Woooooool0LOoo
o`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006ooo
o`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0LOooo`030000
oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0003oooooool0S_ooo`006oooo`03o`2I
oooooooo077oool20000Soooo`006oooo`03o`2Ioooooooo077oool00`000?ooooooo`2>oooo000K
oooo00?o09Woooooool0LOooo`030000oooooooo08koool001_oool00ol0VOooooooo`1aoooo00<0
003oooooool0S_ooo`006oooo`03o`2Ioooooooo05goool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000Koooo00?o09Woooooool0GOooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000Koooo00?o09Woooooool0G_ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0001Coool00`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.04262 .04578 L
.0522 .04578 L
.05746 .04578 L
.06005 .04578 L
.06119 .04578 L
.06244 .04578 L
s
.06244 .04578 m
.06276 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003ooooo09T01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool0
01goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool0
0`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool0
0ol0VOooooooo`1_oooo0P0008ooool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_oo
o`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Kooo
o`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Ooo
o`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`80002?
oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_
oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000M
oooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0
003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool20000Soooo`007Oooo`03o`2Ioooooooo
06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool0
01goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool0
0`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool0
0ol0VOooooooo`1_oooo0P0008ooool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_oo
o`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Kooo
o`030000oooooooo08koool001goool00ol0VOooooooo`1Loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo05_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Foooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`007Oooo`03o`2Ioooooooo05_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool001goool00ol0VOooooooo`1K
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool001goool0
0ol0VOooooooo`1Loooo0P0000[oool300001?ooo`030000oooooooo08koool001goool00ol0VOoo
ooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>
oooo000Moooo00?o09Woooooool0Koooo`80002?oooo000Moooo00?o09Woooooool0Koooo`030000
oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2I
oooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo
08koool001goool00ol0VOooooooo`1_oooo0P0008ooool001goool00ol0VOooooooo`1_oooo00<0
003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o
09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003ooooo
ool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Wooooo
ool0Koooo`80002?oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool0
0ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?oo
ooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOoo
ooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool20000Soooo`007Ooo
o`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000
oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2I
oooooooo06Ooool500000oooo`030000oooooooo08koool001goool00ol0VOooooooo`1Yoooo00<0
003oooooool00oooo`030000oooooooo08koool001goool00ol0VOooooooo`1Yoooo00<0003ooooo
ool00oooo`<0002>oooo000Moooo00?o09Woooooool0JOooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Moooo00?o09Woooooool0JOooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000Moooo00?o09Woooooool0J?ooo`800005oooo00<0003oooooool0S_ooo`007Oooo`03o`2I
oooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo
08koool001goool00ol0VOooooooo`1_oooo0P0008ooool001goool00ol0VOooooooo`1_oooo00<0
003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o
09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003ooooo
ool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Wooooo
ool0Koooo`80002?oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool0
0ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?oo
ooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOoo
ooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool20000Soooo`007Ooo
o`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000
oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2I
oooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo
08koool001goool00ol0VOooooooo`1_oooo0P0008ooool001goool00ol0VOooooooo`1_oooo00<0
003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o
09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1Koooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo05goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo
05goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Moooo00?o09Wooooo
ool0GOooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool001goool00ol0VOoo
ooooo`1Moooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000M
oooo00?o09Woooooool0G?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Moooo00?o
09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003ooooo
ool0S_ooo`007Oooo`03o`2Ioooooooo06ooool20000Soooo`007Oooo`03o`2Ioooooooo06ooool0
0`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool0
0ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?oo
ooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOoo
ooooo`1_oooo0P0008ooool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Ooo
o`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000
oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2I
oooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`80002?oooo000M
oooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0
003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o
09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003ooooo
ool0S_ooo`007Oooo`03o`2Ioooooooo06ooool20000Soooo`007Oooo`03o`2Ioooooooo06ooool0
0`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool0
0ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06Ooool400001?oo
o`030000oooooooo08koool001goool00ol0VOooooooo`1Woooo00<0003oooooool01Oooo`030000
oooooooo08koool001goool00ol0VOooooooo`1Xoooo00<0003oooooool01?ooo`<0002>oooo000M
oooo00?o09Woooooool0JOooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000Moooo00?o
09Woooooool0Ioooo`040000oooooooo00001?ooo`030000oooooooo08koool001goool00ol0VOoo
ooooo`1Xoooo0P0000Goool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000
oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2I
oooooooo06ooool20000Soooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000M
oooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0
003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o
09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo0P0008ooool0
01goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool0
0`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool0
0ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2Ioooooooo06ooool00`000?oo
ooooo`2>oooo000Moooo00?o09Woooooool0Koooo`80002?oooo000Moooo00?o09Woooooool0Kooo
o`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Ooo
o`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Koooo`030000
oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0003oooooool0S_ooo`007Oooo`03o`2I
oooooooo06ooool20000Soooo`007Oooo`03o`2Ioooooooo06ooool00`000?ooooooo`2>oooo000M
oooo00?o09Woooooool0Koooo`030000oooooooo08koool001goool00ol0VOooooooo`1_oooo00<0
003oooooool0S_ooo`007Oooo`03o`2Ioooooooo05_oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000Moooo00?o09Woooooool0Foooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000Moooo00?o09Woooooool0G?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001Oooo`030000
oooooooo00;oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Woool0
1@000?ooooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0003ooooo
ool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002Oooo`@00003oooo0`00
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.04262 .04578 L
.0522 .04578 L
.06244 .04578 L
.06525 .04578 L
.0679 .04578 L
.06905 .04578 L
.07027 .04578 L
.07091 .04578 L
s
.07091 .04578 m
.07109 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00D0003ooooooooooooo09T01?ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo
08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo
06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool0
01ooool00ol0VOooooooo`1]oooo0P0008ooool001ooool00ol0VOooooooo`1]oooo00<0003ooooo
ool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Wooooo
ool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_oo
o`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOoo
o`80002?oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOoo
ooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>
oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]
oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool20000Soooo`007oooo`03o`2I
oooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo
08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo
06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool0
01ooool00ol0VOooooooo`1]oooo0P0008ooool001ooool00ol0VOooooooo`1]oooo00<0003ooooo
ool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Wooooo
ool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1Joooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo05Woool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0FOoo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`007oooo`03o`2Ioooooooo
05Woool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool001ooool00ol0VOoo
ooooo`1Ioooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
01ooool00ol0VOooooooo`1Joooo0P0000[oool300001?ooo`030000oooooooo08koool001ooool0
0ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?oo
ooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`80002?oooo000Ooooo00?o09Woooooool0KOoo
o`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007ooo
o`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000
oooooooo08koool001ooool00ol0VOooooooo`1]oooo0P0008ooool001ooool00ol0VOooooooo`1]
oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000O
oooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0
003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o
09Woooooool0KOooo`80002?oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool0
01ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool0
0`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool0
0ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool20000Sooo
o`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOoo
o`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007ooo
o`03o`2Ioooooooo06Goool500000oooo`030000oooooooo08koool001ooool00ol0VOooooooo`1W
oooo00<0003oooooool00oooo`030000oooooooo08koool001ooool00ol0VOooooooo`1Woooo00<0
003oooooool00oooo`<0002>oooo000Ooooo00?o09Woooooool0Ioooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0Ioooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Ooooo00?o09Woooooool0I_ooo`800005oooo00<0003oooooool0S_ooo`007ooo
o`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000
oooooooo08koool001ooool00ol0VOooooooo`1]oooo0P0008ooool001ooool00ol0VOooooooo`1]
oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000O
oooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0
003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o
09Woooooool0KOooo`80002?oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool0
01ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool0
0`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool0
0ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool20000Sooo
o`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOoo
o`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007ooo
o`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000
oooooooo08koool001ooool00ol0VOooooooo`1]oooo0P0008ooool001ooool00ol0VOooooooo`1]
oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000O
oooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1Ioooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo05_oool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`007oooo`03o`2I
oooooooo05_oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Ooooo00?o
09Woooooool0Foooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool001ooool0
0ol0VOooooooo`1Koooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo000Ooooo00?o09Woooooool0F_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000O
oooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0
003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool20000Soooo`007oooo`03o`2Ioooooooo
06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool0
01ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool0
0`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool0
0ol0VOooooooo`1]oooo0P0008ooool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_oo
o`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOoo
o`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007ooo
o`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`80002?
oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]
oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000O
oooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0
003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool20000Soooo`007oooo`03o`2Ioooooooo
06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool0
01ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06Goool4
00001?ooo`030000oooooooo08koool001ooool00ol0VOooooooo`1Uoooo00<0003oooooool01Ooo
o`030000oooooooo08koool001ooool00ol0VOooooooo`1Voooo00<0003oooooool01?ooo`<0002>
oooo000Ooooo00?o09Woooooool0Ioooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000O
oooo00?o09Woooooool0IOooo`040000oooooooo00001?ooo`030000oooooooo08koool001ooool0
0ol0VOooooooo`1Voooo0P0000Goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOoo
o`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007ooo
o`03o`2Ioooooooo06goool20000Soooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>
oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]
oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000O
oooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo0P00
08ooool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo
06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool0
01ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo06goool0
0`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOooo`80002?oooo000Ooooo00?o09Wooooo
ool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_oo
o`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0KOoo
o`030000oooooooo08koool001ooool00ol0VOooooooo`1]oooo00<0003oooooool0S_ooo`007ooo
o`03o`2Ioooooooo06goool20000Soooo`007oooo`03o`2Ioooooooo06goool00`000?ooooooo`2>
oooo000Ooooo00?o09Woooooool0KOooo`030000oooooooo08koool001ooool00ol0VOooooooo`1]
oooo00<0003oooooool0S_ooo`007oooo`03o`2Ioooooooo05Woool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0FOooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Ooooo00?o09Woooooool0F_ooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool05Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?oo
o`030000oooooooo00D0000Doooo00<0003oooooool02_ooo`050000oooooooooooo000007[oool0
07Soool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000Woool400000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.04262 .04578 L
.06244 .04578 L
.06747 .04578 L
.07286 .04578 L
.07547 .04578 L
.07675 .04578 L
.07793 .04578 L
.07901 .04578 L
s
.07901 .04578 m
.07929 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool00oooo`04o`2Ioooooooo00001oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool0027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_oo
o`008Oooo`03o`2Ioooooooo06_oool00`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Jooo
o`030000oooooooo08koool0027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Ooo
o`03o`2Ioooooooo06_oool20000Soooo`008Oooo`03o`2Ioooooooo06_oool00`000?ooooooo`2>
oooo000Qoooo00?o09Woooooool0Joooo`030000oooooooo08koool0027oool00ol0VOooooooo`1[
oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo06_oool00`000?ooooooo`2>oooo000Q
oooo00?o09Woooooool0Joooo`030000oooooooo08koool0027oool00ol0VOooooooo`1[oooo0P00
08ooool0027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo
06_oool00`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`030000oooooooo08koool0
027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo06_oool0
0`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`80002?oooo000Qoooo00?o09Wooooo
ool0Joooo`030000oooooooo08koool0027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_oo
o`008Oooo`03o`2Ioooooooo06_oool00`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Jooo
o`030000oooooooo08koool0027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Ooo
o`03o`2Ioooooooo06_oool20000Soooo`008Oooo`03o`2Ioooooooo06_oool00`000?ooooooo`2>
oooo000Qoooo00?o09Woooooool0Joooo`030000oooooooo08koool0027oool00ol0VOooooooo`1[
oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo05Soool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Eoooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo08koool0027oool00ol0VOooooooo`1Goooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<0002>oooo000Qoooo00?o09Woooooool0Eooo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo
05Ooool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`008Ooo
o`03o`2Ioooooooo05Soool200002_ooo`<00004oooo00<0003oooooool0S_ooo`008Oooo`03o`2I
oooooooo06_oool00`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`030000oooooooo
08koool0027oool00ol0VOooooooo`1[oooo0P0008ooool0027oool00ol0VOooooooo`1[oooo00<0
003oooooool0S_ooo`008Oooo`03o`2Ioooooooo06_oool00`000?ooooooo`2>oooo000Qoooo00?o
09Woooooool0Joooo`030000oooooooo08koool0027oool00ol0VOooooooo`1[oooo00<0003ooooo
ool0S_ooo`008Oooo`03o`2Ioooooooo06_oool20000Soooo`008Oooo`03o`2Ioooooooo06_oool0
0`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`030000oooooooo08koool0027oool0
0ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo06_oool00`000?oo
ooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`030000oooooooo08koool0027oool00ol0VOoo
ooooo`1[oooo0P0008ooool0027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Ooo
o`03o`2Ioooooooo06_oool00`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`030000
oooooooo08koool0027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Oooo`03o`2I
oooooooo06_oool00`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`80002?oooo000Q
oooo00?o09Woooooool0Joooo`030000oooooooo08koool0027oool00ol0VOooooooo`1[oooo00<0
003oooooool0S_ooo`008Oooo`03o`2Ioooooooo06_oool00`000?ooooooo`2>oooo000Qoooo00?o
09Woooooool0Hoooo`D00003oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo06Goool0
0`000?ooooooo`03oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo06Goool00`000?oo
ooooo`03oooo0`0008koool0027oool00ol0VOooooooo`1Uoooo00<0003oooooool00oooo`030000
oooooooo08koool0027oool00ol0VOooooooo`1Uoooo00<0003oooooool00oooo`030000oooooooo
08koool0027oool00ol0VOooooooo`1Toooo0P0000Goool00`000?ooooooo`2>oooo000Qoooo00?o
09Woooooool0Joooo`030000oooooooo08koool0027oool00ol0VOooooooo`1[oooo00<0003ooooo
ool0S_ooo`008Oooo`03o`2Ioooooooo06_oool20000Soooo`008Oooo`03o`2Ioooooooo06_oool0
0`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`030000oooooooo08koool0027oool0
0ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Oooo`03o`2Ioooooooo06_oool00`000?oo
ooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`030000oooooooo08koool0027oool00ol0VOoo
ooooo`1[oooo0P0008ooool0027oool00ol0VOooooooo`1[oooo00<0003oooooool0S_ooo`008Ooo
o`03o`2Ioooooooo06_oool00`000?ooooooo`2>oooo000Qoooo00?o09Woooooool0Joooo`030000
oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2I
oooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`80002?oooo000R
oooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0
003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o
09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003ooooo
ool0S_ooo`008_ooo`03o`2Ioooooooo06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool0
0`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo05Koool500000_oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0F?ooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Roooo00?o09Wooooo
ool0F?ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0008koool002;oool00ol0VOoo
ooooo`1Hoooo00<0003oooooool02?ooo`800005oooo00<0003oooooool0S_ooo`008_ooo`03o`2I
oooooooo05Soool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo08koool0
02;oool00ol0VOooooooo`1Goooo0P0000[oool300001?ooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool00`000?oo
ooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`80002?oooo000Roooo00?o09Woooooool0J_oo
o`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_oo
o`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`030000
oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2I
oooooooo06[oool20000Soooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000R
oooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0
003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o
09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo0P0008ooool0
02;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool0
0`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool00`000?oo
ooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`80002?oooo000Roooo00?o09Woooooool0J_oo
o`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_oo
o`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0H_ooo`@00004
oooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`05oooo00<0
003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06?oool00`000?ooooooo`04oooo0`0008koool0
02;oool00ol0VOooooooo`1Toooo00<0003oooooool00oooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Roooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`008_ooo`03o`2I
oooooooo06?oool200001Oooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0
003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o
09Woooooool0J_ooo`80002?oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool0
02;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool0
0`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool0
0ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool20000Sooo
o`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_oo
o`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_oo
o`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o09Woooooool0J_ooo`030000
oooooooo08koool002;oool00ol0VOooooooo`1Zoooo0P0008ooool002;oool00ol0VOooooooo`1Z
oooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000R
oooo00?o09Woooooool0J_ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Zoooo00<0
003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool00`000?ooooooo`2>oooo000Roooo00?o
09Woooooool0J_ooo`80002?oooo000Roooo00?o09Woooooool0J_ooo`030000oooooooo08koool0
02;oool00ol0VOooooooo`1Zoooo00<0003oooooool0S_ooo`008_ooo`03o`2Ioooooooo06[oool0
0`000?ooooooo`2>oooo000Roooo00?o09Woooooool0E_ooo`@00003oooo0P0000Coool200001Ooo
o`030000oooooooo08koool002;oool00ol0VOooooooo`1Foooo00<0003oooooool02Oooo`040000
oooooooo00001?ooo`030000oooooooo08koool002;oool00ol0VOooooooo`1Goooo00<0003ooooo
ool02oooo`030000oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_oo
o`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOoo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo0`00
00Coool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003ooooo
ool00_ooo`030000oooooooo01Goool00`000?ooooooo`07oooo00@0003oooooool00005oooo00<0
003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000
oooooooo00Ooool300001?ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooo
oooo000001Ooool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0`0000?oool300000_oo
o`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.04262 .04578 L
.06244 .04578 L
.07216 .04578 L
.0775 .04578 L
.08255 .04578 L
.08542 .04578 L
.0862 .04578 L
.08703 .04578 L
s
.08703 .04578 m
.08721 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool0
02Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool0
0`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool0
0ol0VOooooooo`1Xoooo0P0008ooool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_oo
o`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?oo
o`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`80002?
oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1X
oooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000T
oooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo
06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool0
02Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool0
0`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool0
0ol0VOooooooo`1Xoooo0P0008ooool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_oo
o`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?oo
o`030000oooooooo08koool002Coool00ol0VOooooooo`1Eoooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo05Coool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0E?ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`009?ooo`03o`2Ioooooooo05Coool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool002Coool00ol0VOooooooo`1D
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool002Coool0
0ol0VOooooooo`1Eoooo0P0000[oool300001?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>
oooo000Toooo00?o09Woooooool0J?ooo`80002?oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo
08koool002Coool00ol0VOooooooo`1Xoooo0P0008ooool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o
09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003ooooo
ool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Wooooo
ool0J?ooo`80002?oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool0
0ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?oo
ooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo063oool500000oooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Roooo00<0
003oooooool00oooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Roooo00<0003ooooo
ool00oooo`<0002>oooo000Toooo00?o09Woooooool0H_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Toooo00?o09Woooooool0H_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000Toooo00?o09Woooooool0HOooo`800005oooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo
08koool002Coool00ol0VOooooooo`1Xoooo0P0008ooool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o
09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003ooooo
ool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Wooooo
ool0J?ooo`80002?oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool0
0ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?oo
ooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo
08koool002Coool00ol0VOooooooo`1Xoooo0P0008ooool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o
09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Doooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo05Koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo
05Koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Toooo00?o09Wooooo
ool0E_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Foooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000T
oooo00?o09Woooooool0EOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Toooo00?o
09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003ooooo
ool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool0
0`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool0
0ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?oo
ooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Xoooo0P0008ooool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`80002?oooo000T
oooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o
09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003ooooo
ool0S_ooo`009?ooo`03o`2Ioooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool0
0`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool0
0ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo063oool400001?oo
o`030000oooooooo08koool002Coool00ol0VOooooooo`1Poooo00<0003oooooool01Oooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Qoooo00<0003oooooool01?ooo`<0002>oooo000T
oooo00?o09Woooooool0H_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000Toooo00?o
09Woooooool0H?ooo`040000oooooooo00001?ooo`030000oooooooo08koool002Coool00ol0VOoo
ooooo`1Qoooo0P0000Goool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000T
oooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o
09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo0P0008ooool0
02Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool0
0`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool0
0ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2Ioooooooo06Soool00`000?oo
ooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`80002?oooo000Toooo00?o09Woooooool0J?oo
o`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?oo
o`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0J?ooo`030000
oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0003oooooool0S_ooo`009?ooo`03o`2I
oooooooo06Soool20000Soooo`009?ooo`03o`2Ioooooooo06Soool00`000?ooooooo`2>oooo000T
oooo00?o09Woooooool0J?ooo`030000oooooooo08koool002Coool00ol0VOooooooo`1Xoooo00<0
003oooooool0S_ooo`009?ooo`03o`2Ioooooooo05Coool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000Toooo00?o09Woooooool0E?ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000Toooo00?o09Woooooool0EOooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000oooo`<00004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0001Coool00`000?ooooooo`07oooo0`0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000005oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.04262 .04578 L
.06244 .04578 L
.08255 .04578 L
.08806 .04578 L
.09109 .04578 L
.09258 .04578 L
.09324 .04578 L
.09396 .04578 L
s
.09396 .04578 m
.09428 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000o`2Ioooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool0
02Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool0
0ol0VOooooooo`1Woooo0P0008ooool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_oo
o`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Iooo
o`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Ooo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`80002?
oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1W
oooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000U
oooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0
003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool20000Soooo`009Oooo`03o`2Ioooooooo
06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool0
02Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool0
0ol0VOooooooo`1Woooo0P0008ooool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_oo
o`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Iooo
o`030000oooooooo08koool002Goool00ol0VOooooooo`1Doooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo05?oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Doooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`009Oooo`03o`2Ioooooooo05?oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool002Goool00ol0VOooooooo`1C
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool002Goool0
0ol0VOooooooo`1Doooo0P0000[oool300001?ooo`030000oooooooo08koool002Goool00ol0VOoo
ooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>
oooo000Uoooo00?o09Woooooool0Ioooo`80002?oooo000Uoooo00?o09Woooooool0Ioooo`030000
oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2I
oooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo
08koool002Goool00ol0VOooooooo`1Woooo0P0008ooool002Goool00ol0VOooooooo`1Woooo00<0
003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o
09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003ooooo
ool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Wooooo
ool0Ioooo`80002?oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool0
0ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?oo
ooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOoo
ooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool20000Soooo`009Ooo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000
oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2I
oooooooo05ooool500000oooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Qoooo00<0
003oooooool00oooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Qoooo00<0003ooooo
ool00oooo`<0002>oooo000Uoooo00?o09Woooooool0HOooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Uoooo00?o09Woooooool0HOooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000Uoooo00?o09Woooooool0H?ooo`800005oooo00<0003oooooool0S_ooo`009Oooo`03o`2I
oooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo
08koool002Goool00ol0VOooooooo`1Woooo0P0008ooool002Goool00ol0VOooooooo`1Woooo00<0
003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o
09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003ooooo
ool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Wooooo
ool0Ioooo`80002?oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool0
0ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?oo
ooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOoo
ooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool20000Soooo`009Ooo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000
oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2I
oooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo
08koool002Goool00ol0VOooooooo`1Woooo0P0008ooool002Goool00ol0VOooooooo`1Woooo00<0
003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o
09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Coooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo05Goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo
05Goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Uoooo00?o09Wooooo
ool0EOooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool002Goool00ol0VOoo
ooooo`1Eoooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000U
oooo00?o09Woooooool0E?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Uoooo00?o
09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003ooooo
ool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool20000Soooo`009Oooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool0
0ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?oo
ooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOoo
ooooo`1Woooo0P0008ooool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Ooo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000
oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2I
oooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`80002?oooo000U
oooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0
003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o
09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003ooooo
ool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool20000Soooo`009Oooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool0
0ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo05ooool400001?oo
o`030000oooooooo08koool002Goool00ol0VOooooooo`1Ooooo00<0003oooooool01Oooo`030000
oooooooo08koool002Goool00ol0VOooooooo`1Poooo00<0003oooooool01?ooo`<0002>oooo000U
oooo00?o09Woooooool0HOooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000Uoooo00?o
09Woooooool0Goooo`040000oooooooo00001?ooo`030000oooooooo08koool002Goool00ol0VOoo
ooooo`1Poooo0P0000Goool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000
oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2I
oooooooo06Ooool20000Soooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000U
oooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0
003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o
09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo0P0008ooool0
02Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool0
0`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool0
0ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2Ioooooooo06Ooool00`000?oo
ooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`80002?oooo000Uoooo00?o09Woooooool0Iooo
o`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Ooo
o`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Ioooo`030000
oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0003oooooool0S_ooo`009Oooo`03o`2I
oooooooo06Ooool20000Soooo`009Oooo`03o`2Ioooooooo06Ooool00`000?ooooooo`2>oooo000U
oooo00?o09Woooooool0Ioooo`030000oooooooo08koool002Goool00ol0VOooooooo`1Woooo00<0
003oooooool0S_ooo`009Oooo`03o`2Ioooooooo05?oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0Doooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000Uoooo00?o09Woooooool0E?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Eoooo00<0003oooooool02_ooo`030000oooooooo00?oool00`000?oo
ooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0003ooooo
ool02?ooo`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool0
00005oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool300000oooo`<00002oooo00<0
003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.04262 .04578 L
.06244 .04578 L
.08255 .04578 L
.08806 .04578 L
.09396 .04578 L
.09682 .04578 L
.09952 .04578 L
.1007 .04578 L
.10195 .04578 L
.1026 .04578 L
s
.1026 .04578 m
.10278 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`050000ooooooooooooo`2I00?oool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo
08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo
06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Toooo0P0008ooool002Soool00ol0VOooooooo`1Toooo00<0003ooooo
ool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Wooooo
ool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_oo
o`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?oo
o`80002?oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOoo
ooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>
oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1T
oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2I
oooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo
08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo
06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Toooo0P0008ooool002Soool00ol0VOooooooo`1Toooo00<0003ooooo
ool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Wooooo
ool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Aoooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo053oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0D?oo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00:?ooo`03o`2Ioooooooo
053oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool002Soool00ol0VOoo
ooooo`1@oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Aoooo0P0000[oool300001?ooo`030000oooooooo08koool002Soool0
0ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?oo
ooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`80002?oooo000Xoooo00?o09Woooooool0I?oo
o`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000
oooooooo08koool002Soool00ol0VOooooooo`1Toooo0P0008ooool002Soool00ol0VOooooooo`1T
oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0
003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o
09Woooooool0I?ooo`80002?oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool0
0`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool0
0ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Sooo
o`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?oo
o`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?oo
o`03o`2Ioooooooo05coool500000oooo`030000oooooooo08koool002Soool00ol0VOooooooo`1N
oooo00<0003oooooool00oooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Noooo00<0
003oooooool00oooo`<0002>oooo000Xoooo00?o09Woooooool0G_ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0G_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Xoooo00?o09Woooooool0GOooo`800005oooo00<0003oooooool0S_ooo`00:?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000
oooooooo08koool002Soool00ol0VOooooooo`1Toooo0P0008ooool002Soool00ol0VOooooooo`1T
oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0
003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o
09Woooooool0I?ooo`80002?oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool0
0`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool0
0ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Sooo
o`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?oo
o`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000
oooooooo08koool002Soool00ol0VOooooooo`1Toooo0P0008ooool002Soool00ol0VOooooooo`1T
oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1@oooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo05;oool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00:?ooo`03o`2I
oooooooo05;oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Xoooo00?o
09Woooooool0D_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool002Soool0
0ol0VOooooooo`1Boooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo000Xoooo00?o09Woooooool0DOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0
003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo
06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool0
0`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool0
0ol0VOooooooo`1Toooo0P0008ooool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_oo
o`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?oo
o`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?oo
o`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`80002?
oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1T
oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0
003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo
06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo05coool4
00001?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Loooo00<0003oooooool01Ooo
o`030000oooooooo08koool002Soool00ol0VOooooooo`1Moooo00<0003oooooool01?ooo`<0002>
oooo000Xoooo00?o09Woooooool0G_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0G?ooo`040000oooooooo00001?ooo`030000oooooooo08koool002Soool0
0ol0VOooooooo`1Moooo0P0000Goool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?oo
o`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?oo
o`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>
oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1T
oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000X
oooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo0P00
08ooool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo
06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool0
02Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo06Coool0
0`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?ooo`80002?oooo000Xoooo00?o09Wooooo
ool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_oo
o`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0I?oo
o`030000oooooooo08koool002Soool00ol0VOooooooo`1Toooo00<0003oooooool0S_ooo`00:?oo
o`03o`2Ioooooooo06Coool20000Soooo`00:?ooo`03o`2Ioooooooo06Coool00`000?ooooooo`2>
oooo000Xoooo00?o09Woooooool0I?ooo`030000oooooooo08koool002Soool00ol0VOooooooo`1T
oooo00<0003oooooool0S_ooo`00:?ooo`03o`2Ioooooooo053oool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0D?ooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Xoooo00?o09Woooooool0DOooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00[oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Doooo00<0003oooooool02?ooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000001Ooool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.0932 .04578 L
.09905 .04578 L
.10458 .04578 L
.10708 .04578 L
.10972 .04578 L
.11039 .04578 L
.1111 .04578 L
s
.1111 .04578 m
.1113 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00?oool00ol0VOoo
o`000007oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool0
02[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo0P0008ooool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_oo
o`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_oo
o`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_oo
o`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`80002?
oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1R
oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Z
oooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0
003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo
06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool0
02[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo0P0008ooool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_oo
o`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_oo
o`030000oooooooo08koool002[oool00ol0VOooooooo`1?oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo04koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0C_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00:_ooo`03o`2Ioooooooo04koool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool002[oool00ol0VOooooooo`1>
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1?oooo0P0000[oool300001?ooo`030000oooooooo08koool002[oool00ol0VOoo
ooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>
oooo000Zoooo00?o09Woooooool0H_ooo`80002?oooo000Zoooo00?o09Woooooool0H_ooo`030000
oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2I
oooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo
08koool002[oool00ol0VOooooooo`1Roooo0P0008ooool002[oool00ol0VOooooooo`1Roooo00<0
003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003ooooo
ool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Wooooo
ool0H_ooo`80002?oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?oo
ooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOoo
ooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_oo
o`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000
oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2I
oooooooo05[oool500000oooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Loooo00<0
003oooooool00oooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Loooo00<0003ooooo
ool00oooo`<0002>oooo000Zoooo00?o09Woooooool0G?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000Zoooo00?o09Woooooool0G?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000Zoooo00?o09Woooooool0Foooo`800005oooo00<0003oooooool0S_ooo`00:_ooo`03o`2I
oooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo
08koool002[oool00ol0VOooooooo`1Roooo0P0008ooool002[oool00ol0VOooooooo`1Roooo00<0
003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003ooooo
ool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Wooooo
ool0H_ooo`80002?oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?oo
ooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOoo
ooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_oo
o`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000
oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2I
oooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo
08koool002[oool00ol0VOooooooo`1Roooo0P0008ooool002[oool00ol0VOooooooo`1Roooo00<0
003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1>oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo053oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo
053oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000Zoooo00?o09Wooooo
ool0D?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool002[oool00ol0VOoo
ooooo`1@oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000Z
oooo00?o09Woooooool0Coooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003ooooo
ool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?oo
ooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOoo
ooooo`1Roooo0P0008ooool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_oo
o`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000
oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2I
oooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`80002?oooo000Z
oooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0
003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003ooooo
ool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo05[oool400001?oo
o`030000oooooooo08koool002[oool00ol0VOooooooo`1Joooo00<0003oooooool01Oooo`030000
oooooooo08koool002[oool00ol0VOooooooo`1Koooo00<0003oooooool01?ooo`<0002>oooo000Z
oooo00?o09Woooooool0G?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0F_ooo`040000oooooooo00001?ooo`030000oooooooo08koool002[oool00ol0VOoo
ooooo`1Koooo0P0000Goool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000
oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2I
oooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Z
oooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0
003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o
09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo0P0008ooool0
02[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool0
0ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo06;oool00`000?oo
ooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`80002?oooo000Zoooo00?o09Woooooool0H_oo
o`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_oo
o`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0H_ooo`030000
oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0003oooooool0S_ooo`00:_ooo`03o`2I
oooooooo06;oool20000Soooo`00:_ooo`03o`2Ioooooooo06;oool00`000?ooooooo`2>oooo000Z
oooo00?o09Woooooool0H_ooo`030000oooooooo08koool002[oool00ol0VOooooooo`1Roooo00<0
003oooooool0S_ooo`00:_ooo`03o`2Ioooooooo04koool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0C_ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000Zoooo00?o09Woooooool0Coooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001Oooo`<00002
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`0:oooo00@0003ooooo
ool00002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Eoooo00<0003oooooool01oooo`D00004oooo00<0003oooooool00_ooo`030000oooooooo
07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Goooo00<0
003oooooool02?ooo`030000oooo000000?oool00`000?ooooooo`03oooo00<0003oooooool0MOoo
o`00M_ooo`030000oooooooo01Ooool200002oooo`800003oooo0`0000;oool00`000?ooooooo`1f
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.0932 .04578 L
.10458 .04578 L
.11009 .04578 L
.1128 .04578 L
.11531 .04578 L
.11758 .04578 L
.11872 .04578 L
s
.11872 .04578 m
.11904 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool0
02coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool0
0`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool0
0ol0VOooooooo`1Poooo0P0008ooool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_oo
o`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?oo
o`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?oo
o`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`80002?
oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1P
oooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/
oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo
063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool0
02coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool0
0`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool0
0ol0VOooooooo`1Poooo0P0008ooool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_oo
o`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?oo
o`030000oooooooo08koool002coool00ol0VOooooooo`1=oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo04coool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0C?ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00;?ooo`03o`2Ioooooooo04coool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool002coool00ol0VOooooooo`1<
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool002coool0
0ol0VOooooooo`1=oooo0P0000[oool300001?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>
oooo000/oooo00?o09Woooooool0H?ooo`80002?oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo
08koool002coool00ol0VOooooooo`1Poooo0P0008ooool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o
09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003ooooo
ool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Wooooo
ool0H?ooo`80002?oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool0
0ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?oo
ooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?oo
o`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo05Soool500000oooo`030000oooooooo08koool002coool00ol0VOooooooo`1Joooo00<0
003oooooool00oooo`030000oooooooo08koool002coool00ol0VOooooooo`1Joooo00<0003ooooo
ool00oooo`<0002>oooo000/oooo00?o09Woooooool0F_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000/oooo00?o09Woooooool0F_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000/oooo00?o09Woooooool0FOooo`800005oooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo
08koool002coool00ol0VOooooooo`1Poooo0P0008ooool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o
09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003ooooo
ool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Wooooo
ool0H?ooo`80002?oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool0
0ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?oo
ooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?oo
o`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo
08koool002coool00ol0VOooooooo`1Poooo0P0008ooool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o
09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1<oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo04koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo
04koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000/oooo00?o09Wooooo
ool0C_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1>oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000/
oooo00?o09Woooooool0COooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000/oooo00?o
09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003ooooo
ool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool0
0`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool0
0ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?oo
ooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1Poooo0P0008ooool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?oo
o`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`80002?oooo000/
oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o
09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003ooooo
ool0S_ooo`00;?ooo`03o`2Ioooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool0
0`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool0
0ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo05Soool400001?oo
o`030000oooooooo08koool002coool00ol0VOooooooo`1Hoooo00<0003oooooool01Oooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Ioooo00<0003oooooool01?ooo`<0002>oooo000/
oooo00?o09Woooooool0F_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000/oooo00?o
09Woooooool0F?ooo`040000oooooooo00001?ooo`030000oooooooo08koool002coool00ol0VOoo
ooooo`1Ioooo0P0000Goool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/
oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o
09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo0P0008ooool0
02coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool0
0`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool0
0ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo063oool00`000?oo
ooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`80002?oooo000/oooo00?o09Woooooool0H?oo
o`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?oo
o`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0H?ooo`030000
oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0003oooooool0S_ooo`00;?ooo`03o`2I
oooooooo063oool20000Soooo`00;?ooo`03o`2Ioooooooo063oool00`000?ooooooo`2>oooo000/
oooo00?o09Woooooool0H?ooo`030000oooooooo08koool002coool00ol0VOooooooo`1Poooo00<0
003oooooool0S_ooo`00;?ooo`03o`2Ioooooooo04coool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000/oooo00?o09Woooooool0C?ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000/oooo00?o09Woooooool0COooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001Oooo`<00002
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02_ooo`050000oooooooooooo0000
07[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Ooool5
00000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?ooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00005oooo`030000oooooooo00Soool00`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo01Ooool200002oooo`800002oooo00<0003oooooool0NOooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.10458 .04578 L
.11448 .04578 L
.11992 .04578 L
.1226 .04578 L
.12377 .04578 L
.12507 .04578 L
.12627 .04578 L
s
.12627 .04578 m
.12655 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ool0V@05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool0
02koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool0
0`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool0
0ol0VOooooooo`1Noooo0P0008ooool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_oo
o`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_oo
o`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_oo
o`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`80002?
oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1N
oooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^
oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo
05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool0
02koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool0
0`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool0
0ol0VOooooooo`1Noooo0P0008ooool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_oo
o`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_oo
o`030000oooooooo08koool002koool00ol0VOooooooo`1;oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo04[oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0B_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00;_ooo`03o`2Ioooooooo04[oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool002koool00ol0VOooooooo`1:
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool002koool0
0ol0VOooooooo`1;oooo0P0000[oool300001?ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>
oooo000^oooo00?o09Woooooool0G_ooo`80002?oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo
08koool002koool00ol0VOooooooo`1Noooo0P0008ooool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o
09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003ooooo
ool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Wooooo
ool0G_ooo`80002?oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool0
0ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?oo
ooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_oo
o`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05Koool500000oooo`030000oooooooo08koool002koool00ol0VOooooooo`1Hoooo00<0
003oooooool00oooo`030000oooooooo08koool002koool00ol0VOooooooo`1Hoooo00<0003ooooo
ool00oooo`<0002>oooo000^oooo00?o09Woooooool0F?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000^oooo00?o09Woooooool0F?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000^oooo00?o09Woooooool0Eoooo`800005oooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo
08koool002koool00ol0VOooooooo`1Noooo0P0008ooool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o
09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003ooooo
ool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Wooooo
ool0G_ooo`80002?oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool0
0ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?oo
ooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_oo
o`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo
08koool002koool00ol0VOooooooo`1Noooo0P0008ooool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o
09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1:oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo04coool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo
04coool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000^oooo00?o09Wooooo
ool0C?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1<oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000^
oooo00?o09Woooooool0Boooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000^oooo00?o
09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003ooooo
ool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool0
0`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool0
0ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?oo
ooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1Noooo0P0008ooool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_oo
o`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`80002?oooo000^
oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o
09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003ooooo
ool0S_ooo`00;_ooo`03o`2Ioooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool0
0`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool0
0ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05Koool400001?oo
o`030000oooooooo08koool002koool00ol0VOooooooo`1Foooo00<0003oooooool01Oooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Goooo00<0003oooooool01?ooo`<0002>oooo000^
oooo00?o09Woooooool0F?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000^oooo00?o
09Woooooool0E_ooo`040000oooooooo00001?ooo`030000oooooooo08koool002koool00ol0VOoo
ooooo`1Goooo0P0000Goool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^
oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o
09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo0P0008ooool0
02koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool0
0`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool0
0ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo05koool00`000?oo
ooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`80002?oooo000^oooo00?o09Woooooool0G_oo
o`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_oo
o`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0G_ooo`030000
oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0003oooooool0S_ooo`00;_ooo`03o`2I
oooooooo05koool20000Soooo`00;_ooo`03o`2Ioooooooo05koool00`000?ooooooo`2>oooo000^
oooo00?o09Woooooool0G_ooo`030000oooooooo08koool002koool00ol0VOooooooo`1Noooo00<0
003oooooool0S_ooo`00;_ooo`03o`2Ioooooooo04[oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000^oooo00?o09Woooooool0B_ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000^oooo00?o09Woooooool0Boooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Eoooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0003ooooo
ool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.10458 .04578 L
.11448 .04578 L
.11992 .04578 L
.12507 .04578 L
.12986 .04578 L
.13117 .04578 L
.13256 .04578 L
.13375 .04578 L
s
.13375 .04578 m
.13408 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool01@000?oo
ooooooooool0V@03oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo
08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo
05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`1Loooo0P0008ooool0033oool00ol0VOooooooo`1Loooo00<0003ooooo
ool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Wooooo
ool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_oo
o`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?oo
o`80002?oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOoo
ooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>
oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1L
oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2I
oooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo
08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo
05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`1Loooo0P0008ooool0033oool00ol0VOooooooo`1Loooo00<0003ooooo
ool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Wooooo
ool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`19oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo04Soool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0B?oo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00<?ooo`03o`2Ioooooooo
04Soool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool0033oool00ol0VOoo
ooooo`18oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`19oooo0P0000[oool300001?ooo`030000oooooooo08koool0033oool0
0ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?oo
ooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`80002?oooo000`oooo00?o09Woooooool0G?oo
o`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?oo
o`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000
oooooooo08koool0033oool00ol0VOooooooo`1Loooo0P0008ooool0033oool00ol0VOooooooo`1L
oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0
003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o
09Woooooool0G?ooo`80002?oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool0
0`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool0
0ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Sooo
o`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?oo
o`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?oo
o`03o`2Ioooooooo05Coool500000oooo`030000oooooooo08koool0033oool00ol0VOooooooo`1F
oooo00<0003oooooool00oooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Foooo00<0
003oooooool00oooo`<0002>oooo000`oooo00?o09Woooooool0E_ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo000`oooo00?o09Woooooool0E_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000`oooo00?o09Woooooool0EOooo`800005oooo00<0003oooooool0S_ooo`00<?oo
o`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000
oooooooo08koool0033oool00ol0VOooooooo`1Loooo0P0008ooool0033oool00ol0VOooooooo`1L
oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0
003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o
09Woooooool0G?ooo`80002?oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool0
0`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool0
0ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Sooo
o`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?oo
o`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?oo
o`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000
oooooooo08koool0033oool00ol0VOooooooo`1Loooo0P0008ooool0033oool00ol0VOooooooo`1L
oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`18oooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00<?ooo`03o`2I
oooooooo04[oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000`oooo00?o
09Woooooool0B_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool0033oool0
0ol0VOooooooo`1:oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo000`oooo00?o09Woooooool0BOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0
003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo
05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool0
0`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool0
0ol0VOooooooo`1Loooo0P0008ooool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_oo
o`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?oo
o`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?oo
o`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`80002?
oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1L
oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0
003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo
05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05Coool4
00001?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Doooo00<0003oooooool01Ooo
o`030000oooooooo08koool0033oool00ol0VOooooooo`1Eoooo00<0003oooooool01?ooo`<0002>
oooo000`oooo00?o09Woooooool0E_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0E?ooo`040000oooooooo00001?ooo`030000oooooooo08koool0033oool0
0ol0VOooooooo`1Eoooo0P0000Goool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?oo
o`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?oo
o`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>
oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1L
oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`
oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo0P00
08ooool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo
05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0
033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo05coool0
0`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?ooo`80002?oooo000`oooo00?o09Wooooo
ool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_oo
o`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0G?oo
o`030000oooooooo08koool0033oool00ol0VOooooooo`1Loooo00<0003oooooool0S_ooo`00<?oo
o`03o`2Ioooooooo05coool20000Soooo`00<?ooo`03o`2Ioooooooo05coool00`000?ooooooo`2>
oooo000`oooo00?o09Woooooool0G?ooo`030000oooooooo08koool0033oool00ol0VOooooooo`1L
oooo00<0003oooooool0S_ooo`00<?ooo`03o`2Ioooooooo04Soool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0B?ooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000`oooo00?o09Woooooool0BOooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Ooo
o`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Doooo00<0003oooooool02_ooo`050000oooooooooooo000007[oool007Soool0
1@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.10458 .04578 L
.11448 .04578 L
.12507 .04578 L
.1302 .04578 L
.13506 .04578 L
.13942 .04578 L
.14061 .04578 L
.14188 .04578 L
s
.14188 .04578 m
.14215 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`03oooo00?o09Woool000001oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool0
03;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo0P0008ooool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_oo
o`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_oo
o`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_oo
o`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`80002?
oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1J
oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000b
oooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0
003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo
05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool0
03;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo0P0008ooool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_oo
o`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_oo
o`030000oooooooo08koool003;oool00ol0VOooooooo`17oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo04Koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0A_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00<_ooo`03o`2Ioooooooo04Koool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool003;oool00ol0VOooooooo`16
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`17oooo0P0000[oool300001?ooo`030000oooooooo08koool003;oool00ol0VOoo
ooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>
oooo000boooo00?o09Woooooool0F_ooo`80002?oooo000boooo00?o09Woooooool0F_ooo`030000
oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo
08koool003;oool00ol0VOooooooo`1Joooo0P0008ooool003;oool00ol0VOooooooo`1Joooo00<0
003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003ooooo
ool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Wooooo
ool0F_ooo`80002?oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?oo
ooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOoo
ooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_oo
o`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000
oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2I
oooooooo05;oool500000oooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Doooo00<0
003oooooool00oooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Doooo00<0003ooooo
ool00oooo`<0002>oooo000boooo00?o09Woooooool0E?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000boooo00?o09Woooooool0E?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000boooo00?o09Woooooool0Doooo`800005oooo00<0003oooooool0S_ooo`00<_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo
08koool003;oool00ol0VOooooooo`1Joooo0P0008ooool003;oool00ol0VOooooooo`1Joooo00<0
003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003ooooo
ool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Wooooo
ool0F_ooo`80002?oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?oo
ooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOoo
ooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_oo
o`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000
oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo
08koool003;oool00ol0VOooooooo`1Joooo0P0008ooool003;oool00ol0VOooooooo`1Joooo00<0
003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`16oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo04Soool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo
04Soool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000boooo00?o09Wooooo
ool0B?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool003;oool00ol0VOoo
ooooo`18oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000b
oooo00?o09Woooooool0Aoooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003ooooo
ool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?oo
ooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOoo
ooooo`1Joooo0P0008ooool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_oo
o`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000
oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2I
oooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`80002?oooo000b
oooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0
003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003ooooo
ool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05;oool400001?oo
o`030000oooooooo08koool003;oool00ol0VOooooooo`1Boooo00<0003oooooool01Oooo`030000
oooooooo08koool003;oool00ol0VOooooooo`1Coooo00<0003oooooool01?ooo`<0002>oooo000b
oooo00?o09Woooooool0E?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0D_ooo`040000oooooooo00001?ooo`030000oooooooo08koool003;oool00ol0VOoo
ooooo`1Coooo0P0000Goool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000
oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2I
oooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000b
oooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0
003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o
09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo0P0008ooool0
03;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool0
0ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo05[oool00`000?oo
ooooo`2>oooo000boooo00?o09Woooooool0F_ooo`80002?oooo000boooo00?o09Woooooool0F_oo
o`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_oo
o`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0F_ooo`030000
oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0003oooooool0S_ooo`00<_ooo`03o`2I
oooooooo05[oool20000Soooo`00<_ooo`03o`2Ioooooooo05[oool00`000?ooooooo`2>oooo000b
oooo00?o09Woooooool0F_ooo`030000oooooooo08koool003;oool00ol0VOooooooo`1Joooo00<0
003oooooool0S_ooo`00<_ooo`03o`2Ioooooooo04Koool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000boooo00?o09Woooooool0A_ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000boooo00?o09Woooooool0Aoooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000oooo`@00003
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00<0003ooooo
ool00oooo`040000oooooooo00000oooo`030000oooooooo07Goool007Coool00`000?ooooooo`02
oooo00<0003oooooool05Oooo`030000oooooooo00Soool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.12507 .04578 L
.13506 .04578 L
.14415 .04578 L
.14635 .04578 L
.14868 .04578 L
.1499 .04578 L
.15059 .04578 L
s
.15059 .04578 m
.15076 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool0
03Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool0
0`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool0
0ol0VOooooooo`1Hoooo0P0008ooool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_oo
o`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?oo
o`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?oo
o`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`80002?
oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1H
oooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000d
oooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo
05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool0
03Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool0
0`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool0
0ol0VOooooooo`1Hoooo0P0008ooool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_oo
o`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?oo
o`030000oooooooo08koool003Coool00ol0VOooooooo`15oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo04Coool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0A?ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00=?ooo`03o`2Ioooooooo04Coool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool003Coool00ol0VOooooooo`14
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool003Coool0
0ol0VOooooooo`15oooo0P0000[oool300001?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>
oooo000doooo00?o09Woooooool0F?ooo`80002?oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo
08koool003Coool00ol0VOooooooo`1Hoooo0P0008ooool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o
09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003ooooo
ool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Wooooo
ool0F?ooo`80002?oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool0
0ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?oo
ooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?oo
o`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo053oool500000oooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Boooo00<0
003oooooool00oooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Boooo00<0003ooooo
ool00oooo`<0002>oooo000doooo00?o09Woooooool0D_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000doooo00?o09Woooooool0D_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000doooo00?o09Woooooool0DOooo`800005oooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo
08koool003Coool00ol0VOooooooo`1Hoooo0P0008ooool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o
09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003ooooo
ool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Wooooo
ool0F?ooo`80002?oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool0
0ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?oo
ooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?oo
o`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo
08koool003Coool00ol0VOooooooo`1Hoooo0P0008ooool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o
09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`14oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo
04Koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000doooo00?o09Wooooo
ool0A_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`16oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000d
oooo00?o09Woooooool0AOooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000doooo00?o
09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003ooooo
ool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool0
0`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool0
0ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?oo
ooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`1Hoooo0P0008ooool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?oo
o`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`80002?oooo000d
oooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o
09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003ooooo
ool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool0
0`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool0
0ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo053oool400001?oo
o`030000oooooooo08koool003Coool00ol0VOooooooo`1@oooo00<0003oooooool01Oooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Aoooo00<0003oooooool01?ooo`<0002>oooo000d
oooo00?o09Woooooool0D_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000doooo00?o
09Woooooool0D?ooo`040000oooooooo00001?ooo`030000oooooooo08koool003Coool00ol0VOoo
ooooo`1Aoooo0P0000Goool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000d
oooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o
09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo0P0008ooool0
03Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool0
0`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool0
0ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo05Soool00`000?oo
ooooo`2>oooo000doooo00?o09Woooooool0F?ooo`80002?oooo000doooo00?o09Woooooool0F?oo
o`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?oo
o`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0F?ooo`030000
oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0003oooooool0S_ooo`00=?ooo`03o`2I
oooooooo05Soool20000Soooo`00=?ooo`03o`2Ioooooooo05Soool00`000?ooooooo`2>oooo000d
oooo00?o09Woooooool0F?ooo`030000oooooooo08koool003Coool00ol0VOooooooo`1Hoooo00<0
003oooooool0S_ooo`00=?ooo`03o`2Ioooooooo04Coool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000doooo00?o09Woooooool0A?ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000doooo00?o09Woooooool0AOooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000oooo`@00003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`030000oooooooo00Coool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?oo
ooooo`08oooo00<0003oooooool01?ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005?ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000001Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.12507 .04578 L
.13506 .04578 L
.14415 .04578 L
.14868 .04578 L
.1536 .04578 L
.15586 .04578 L
.15709 .04578 L
.15825 .04578 L
s
.15825 .04578 m
.1585 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003ooooo09T01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool0
03Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool0
0`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool0
0ol0VOooooooo`1Foooo0P0008ooool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_oo
o`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_oo
o`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_oo
o`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`80002?
oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1F
oooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000f
oooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo
05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool0
03Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool0
0`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool0
0ol0VOooooooo`1Foooo0P0008ooool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_oo
o`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_oo
o`030000oooooooo08koool003Koool00ol0VOooooooo`13oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo04;oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0@_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00=_ooo`03o`2Ioooooooo04;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool003Koool00ol0VOooooooo`12
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool003Koool0
0ol0VOooooooo`13oooo0P0000[oool300001?ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>
oooo000foooo00?o09Woooooool0E_ooo`80002?oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo
08koool003Koool00ol0VOooooooo`1Foooo0P0008ooool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o
09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003ooooo
ool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Wooooo
ool0E_ooo`80002?oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool0
0ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?oo
ooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_oo
o`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo04koool500000oooo`030000oooooooo08koool003Koool00ol0VOooooooo`1@oooo00<0
003oooooool00oooo`030000oooooooo08koool003Koool00ol0VOooooooo`1@oooo00<0003ooooo
ool00oooo`<0002>oooo000foooo00?o09Woooooool0D?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000foooo00?o09Woooooool0D?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000foooo00?o09Woooooool0Coooo`800005oooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo
08koool003Koool00ol0VOooooooo`1Foooo0P0008ooool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o
09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003ooooo
ool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Wooooo
ool0E_ooo`80002?oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool0
0ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?oo
ooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_oo
o`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo
08koool003Koool00ol0VOooooooo`1Foooo0P0008ooool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o
09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`12oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo04Coool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo
04Coool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000foooo00?o09Wooooo
ool0A?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`14oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000f
oooo00?o09Woooooool0@oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000foooo00?o
09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003ooooo
ool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool0
0`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool0
0ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?oo
ooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`1Foooo0P0008ooool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_oo
o`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`80002?oooo000f
oooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o
09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003ooooo
ool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool0
0`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool0
0ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo04koool400001?oo
o`030000oooooooo08koool003Koool00ol0VOooooooo`1>oooo00<0003oooooool01Oooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1?oooo00<0003oooooool01?ooo`<0002>oooo000f
oooo00?o09Woooooool0D?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000foooo00?o
09Woooooool0C_ooo`040000oooooooo00001?ooo`030000oooooooo08koool003Koool00ol0VOoo
ooooo`1?oooo0P0000Goool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000f
oooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o
09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo0P0008ooool0
03Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool0
0`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool0
0ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo05Koool00`000?oo
ooooo`2>oooo000foooo00?o09Woooooool0E_ooo`80002?oooo000foooo00?o09Woooooool0E_oo
o`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_oo
o`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0E_ooo`030000
oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0003oooooool0S_ooo`00=_ooo`03o`2I
oooooooo05Koool20000Soooo`00=_ooo`03o`2Ioooooooo05Koool00`000?ooooooo`2>oooo000f
oooo00?o09Woooooool0E_ooo`030000oooooooo08koool003Koool00ol0VOooooooo`1Foooo00<0
003oooooool0S_ooo`00=_ooo`03o`2Ioooooooo04;oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000foooo00?o09Woooooool0@_ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000foooo00?o09Woooooool0@oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000oooo`D00002
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`09oooo00D0003ooooo
ooooool000000_ooo`050000oooooooooooo000007Ooool007Coool00`000?ooooooo`02oooo00<0
003oooooool05Oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`030000oooooooo07Coool007Goool00`000?ooooooo`0500005?ooo`030000oooooooo00Woool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool0
00005oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000
oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?ooo`<00002oooo00<0
003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.12507 .04578 L
.14415 .04578 L
.1536 .04578 L
.15825 .04578 L
.16254 .04578 L
.16494 .04578 L
.16615 .04578 L
s
.16615 .04578 m
.16632 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00D0003ooooooooooooo09T00oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo
08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`1Doooo0P0008ooool003Soool00ol0VOooooooo`1Doooo00<0003ooooo
ool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Wooooo
ool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_oo
o`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?oo
o`80002?oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOoo
ooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>
oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1D
oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2I
oooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo
08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`1Doooo0P0008ooool003Soool00ol0VOooooooo`1Doooo00<0003ooooo
ool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Wooooo
ool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`11oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo043oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0@?oo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00>?ooo`03o`2Ioooooooo
043oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool003Soool00ol0VOoo
ooooo`10oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`11oooo0P0000[oool300001?ooo`030000oooooooo08koool003Soool0
0ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?oo
ooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`80002?oooo000hoooo00?o09Woooooool0E?oo
o`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000
oooooooo08koool003Soool00ol0VOooooooo`1Doooo0P0008ooool003Soool00ol0VOooooooo`1D
oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0
003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o
09Woooooool0E?ooo`80002?oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool0
0`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool0
0ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Sooo
o`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?oo
o`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?oo
o`03o`2Ioooooooo04coool500000oooo`030000oooooooo08koool003Soool00ol0VOooooooo`1>
oooo00<0003oooooool00oooo`030000oooooooo08koool003Soool00ol0VOooooooo`1>oooo00<0
003oooooool00oooo`<0002>oooo000hoooo00?o09Woooooool0C_ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo000hoooo00?o09Woooooool0C_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000hoooo00?o09Woooooool0COooo`800005oooo00<0003oooooool0S_ooo`00>?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000
oooooooo08koool003Soool00ol0VOooooooo`1Doooo0P0008ooool003Soool00ol0VOooooooo`1D
oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0
003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o
09Woooooool0E?ooo`80002?oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool0
0`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool0
0ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Sooo
o`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?oo
o`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000
oooooooo08koool003Soool00ol0VOooooooo`1Doooo0P0008ooool003Soool00ol0VOooooooo`1D
oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`10oooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo04;oool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00>?ooo`03o`2I
oooooooo04;oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000hoooo00?o
09Woooooool0@_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool003Soool0
0ol0VOooooooo`12oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo000hoooo00?o09Woooooool0@Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0
003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool0
0`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool0
0ol0VOooooooo`1Doooo0P0008ooool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_oo
o`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?oo
o`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?oo
o`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`80002?
oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1D
oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0
003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo04coool4
00001?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1<oooo00<0003oooooool01Ooo
o`030000oooooooo08koool003Soool00ol0VOooooooo`1=oooo00<0003oooooool01?ooo`<0002>
oooo000hoooo00?o09Woooooool0C_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0C?ooo`040000oooooooo00001?ooo`030000oooooooo08koool003Soool0
0ol0VOooooooo`1=oooo0P0000Goool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?oo
o`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?oo
o`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>
oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1D
oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000h
oooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo0P00
08ooool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo
05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool0
03Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo05Coool0
0`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?ooo`80002?oooo000hoooo00?o09Wooooo
ool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_oo
o`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0E?oo
o`030000oooooooo08koool003Soool00ol0VOooooooo`1Doooo00<0003oooooool0S_ooo`00>?oo
o`03o`2Ioooooooo05Coool20000Soooo`00>?ooo`03o`2Ioooooooo05Coool00`000?ooooooo`2>
oooo000hoooo00?o09Woooooool0E?ooo`030000oooooooo08koool003Soool00ol0VOooooooo`1D
oooo00<0003oooooool0S_ooo`00>?ooo`03o`2Ioooooooo043oool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0@?ooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000hoooo00?o09Woooooool0@Oooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000ooo
o`D00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool0
0`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500005?ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000001Ooool00`000?ooooooo`09oooo00<0003oooooool00_oo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.12507 .04578 L
.14415 .04578 L
.16254 .04578 L
.16783 .04578 L
.17044 .04578 L
.17158 .04578 L
.17284 .04578 L
.17396 .04578 L
s
.17396 .04578 m
.17423 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool00oooo`03o`2Ioooo000000Soool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool0
03[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool0
0`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo0P0008ooool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_oo
o`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_oo
o`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_oo
o`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?
oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1B
oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000j
oooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0
003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool20000Soooo`00>_ooo`03o`2Ioooooooo
05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool0
03[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool0
0`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo0P0008ooool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_oo
o`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_oo
o`030000oooooooo08koool003[oool00ol0VOooooooo`0ooooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo03koool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0?_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00>_ooo`03o`2Ioooooooo03koool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool003[oool00ol0VOooooooo`0n
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`0ooooo0P0000[oool300001?ooo`030000oooooooo08koool003[oool00ol0VOoo
ooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>
oooo000joooo00?o09Woooooool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_ooo`030000
oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2I
oooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo
08koool003[oool00ol0VOooooooo`1Boooo0P0008ooool003[oool00ol0VOooooooo`1Boooo00<0
003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003ooooo
ool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Wooooo
ool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?oo
ooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOoo
ooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool20000Soooo`00>_oo
o`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000
oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2I
oooooooo04[oool500000oooo`030000oooooooo08koool003[oool00ol0VOooooooo`1<oooo00<0
003oooooool00oooo`030000oooooooo08koool003[oool00ol0VOooooooo`1<oooo00<0003ooooo
ool00oooo`<0002>oooo000joooo00?o09Woooooool0C?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000joooo00?o09Woooooool0C?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000joooo00?o09Woooooool0Boooo`800005oooo00<0003oooooool0S_ooo`00>_ooo`03o`2I
oooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo
08koool003[oool00ol0VOooooooo`1Boooo0P0008ooool003[oool00ol0VOooooooo`1Boooo00<0
003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003ooooo
ool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Wooooo
ool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?oo
ooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOoo
ooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool20000Soooo`00>_oo
o`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000
oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2I
oooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo
08koool003[oool00ol0VOooooooo`1Boooo0P0008ooool003[oool00ol0VOooooooo`1Boooo00<0
003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`0noooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo043oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo
043oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000joooo00?o09Wooooo
ool0@?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool003[oool00ol0VOoo
ooooo`10oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000j
oooo00?o09Woooooool0?oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003ooooo
ool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool20000Soooo`00>_ooo`03o`2Ioooooooo05;oool0
0`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?oo
ooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOoo
ooooo`1Boooo0P0008ooool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_oo
o`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000
oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2I
oooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?oooo000j
oooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0
003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003ooooo
ool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool20000Soooo`00>_ooo`03o`2Ioooooooo05;oool0
0`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo04[oool400001?oo
o`030000oooooooo08koool003[oool00ol0VOooooooo`1:oooo00<0003oooooool01Oooo`030000
oooooooo08koool003[oool00ol0VOooooooo`1;oooo00<0003oooooool01?ooo`<0002>oooo000j
oooo00?o09Woooooool0C?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000joooo00?o
09Woooooool0B_ooo`040000oooooooo00001?ooo`030000oooooooo08koool003[oool00ol0VOoo
ooooo`1;oooo0P0000Goool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000
oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2I
oooooooo05;oool20000Soooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000j
oooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0
003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o
09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo0P0008ooool0
03[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool0
0`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool0
0ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo05;oool00`000?oo
ooooo`2>oooo000joooo00?o09Woooooool0D_ooo`80002?oooo000joooo00?o09Woooooool0D_oo
o`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_oo
o`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0D_ooo`030000
oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0003oooooool0S_ooo`00>_ooo`03o`2I
oooooooo05;oool20000Soooo`00>_ooo`03o`2Ioooooooo05;oool00`000?ooooooo`2>oooo000j
oooo00?o09Woooooool0D_ooo`030000oooooooo08koool003[oool00ol0VOooooooo`1Boooo00<0
003oooooool0S_ooo`00>_ooo`03o`2Ioooooooo03koool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000joooo00?o09Woooooool0?_ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000joooo00?o09Woooooool0?oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001Oooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001Coool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.16408 .04578 L
.17277 .04578 L
.17735 .04578 L
.17986 .04578 L
.18109 .04578 L
.18221 .04578 L
s
.18221 .04578 m
.18251 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool0
03coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool0
0`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo0P0008ooool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_oo
o`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?oo
o`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??oo
o`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?
oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@
oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000l
oooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0
003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool20000Soooo`00??ooo`03o`2Ioooooooo
053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool0
03coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool0
0`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo0P0008ooool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_oo
o`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?oo
o`030000oooooooo08koool003coool00ol0VOooooooo`0moooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo03coool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0??ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00??ooo`03o`2Ioooooooo03coool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool003coool00ol0VOooooooo`0l
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`0moooo0P0000[oool300001?ooo`030000oooooooo08koool003coool00ol0VOoo
ooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>
oooo000loooo00?o09Woooooool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?ooo`030000
oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2I
oooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo
08koool003coool00ol0VOooooooo`1@oooo0P0008ooool003coool00ol0VOooooooo`1@oooo00<0
003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o
09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003ooooo
ool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Wooooo
ool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?oo
ooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOoo
ooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool20000Soooo`00??oo
o`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000
oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2I
oooooooo04Soool500000oooo`030000oooooooo08koool003coool00ol0VOooooooo`1:oooo00<0
003oooooool00oooo`030000oooooooo08koool003coool00ol0VOooooooo`1:oooo00<0003ooooo
ool00oooo`<0002>oooo000loooo00?o09Woooooool0B_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000loooo00?o09Woooooool0B_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000loooo00?o09Woooooool0BOooo`800005oooo00<0003oooooool0S_ooo`00??ooo`03o`2I
oooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo
08koool003coool00ol0VOooooooo`1@oooo0P0008ooool003coool00ol0VOooooooo`1@oooo00<0
003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o
09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003ooooo
ool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Wooooo
ool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?oo
ooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOoo
ooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool20000Soooo`00??oo
o`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000
oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2I
oooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo
08koool003coool00ol0VOooooooo`1@oooo0P0008ooool003coool00ol0VOooooooo`1@oooo00<0
003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o
09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`0loooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo03koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo
03koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000loooo00?o09Wooooo
ool0?_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool003coool00ol0VOoo
ooooo`0noooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000l
oooo00?o09Woooooool0?Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000loooo00?o
09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003ooooo
ool0S_ooo`00??ooo`03o`2Ioooooooo053oool20000Soooo`00??ooo`03o`2Ioooooooo053oool0
0`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?oo
ooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOoo
ooooo`1@oooo0P0008ooool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??oo
o`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000
oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2I
oooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?oooo000l
oooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0
003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o
09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003ooooo
ool0S_ooo`00??ooo`03o`2Ioooooooo053oool20000Soooo`00??ooo`03o`2Ioooooooo053oool0
0`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo04Soool400001?oo
o`030000oooooooo08koool003coool00ol0VOooooooo`18oooo00<0003oooooool01Oooo`030000
oooooooo08koool003coool00ol0VOooooooo`19oooo00<0003oooooool01?ooo`<0002>oooo000l
oooo00?o09Woooooool0B_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000loooo00?o
09Woooooool0B?ooo`040000oooooooo00001?ooo`030000oooooooo08koool003coool00ol0VOoo
ooooo`19oooo0P0000Goool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000
oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2I
oooooooo053oool20000Soooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000l
oooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0
003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o
09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo0P0008ooool0
03coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool0
0`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool0
0ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2Ioooooooo053oool00`000?oo
ooooo`2>oooo000loooo00?o09Woooooool0D?ooo`80002?oooo000loooo00?o09Woooooool0D?oo
o`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??oo
o`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0D?ooo`030000
oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0003oooooool0S_ooo`00??ooo`03o`2I
oooooooo053oool20000Soooo`00??ooo`03o`2Ioooooooo053oool00`000?ooooooo`2>oooo000l
oooo00?o09Woooooool0D?ooo`030000oooooooo08koool003coool00ol0VOooooooo`1@oooo00<0
003oooooool0S_ooo`00??ooo`03o`2Ioooooooo03coool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000loooo00?o09Woooooool0??ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000loooo00?o09Woooooool0?Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400001Oooo`030000oooooooo00Soool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`09oooo00<0003oooooool0N_oo
o`00Noooo`030000oooooooo00D0000Doooo00<0003oooooool02?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000Goooo00<0003oooooool02?ooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Goooo0P0000Woool00`000?ooooooo`1loooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.16408 .04578 L
.17277 .04578 L
.18221 .04578 L
.18475 .04578 L
.18744 .04578 L
.18855 .04578 L
.18974 .04578 L
s
.18974 .04578 m
.19006 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000ooooo`2I00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool0
03koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool0
0`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo0P0008ooool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_oo
o`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_oo
o`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_oo
o`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?
oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>
oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000n
oooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0
003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool20000Soooo`00?_ooo`03o`2Ioooooooo
04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool0
03koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool0
0`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo0P0008ooool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_oo
o`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_oo
o`030000oooooooo08koool003koool00ol0VOooooooo`0koooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo03[oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0>_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00?_ooo`03o`2Ioooooooo03[oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool003koool00ol0VOooooooo`0j
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`0koooo0P0000[oool300001?ooo`030000oooooooo08koool003koool00ol0VOoo
ooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>
oooo000noooo00?o09Woooooool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_ooo`030000
oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2I
oooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo
08koool003koool00ol0VOooooooo`1>oooo0P0008ooool003koool00ol0VOooooooo`1>oooo00<0
003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o
09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003ooooo
ool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Wooooo
ool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?oo
ooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOoo
ooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool20000Soooo`00?_oo
o`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000
oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2I
oooooooo04Koool500000oooo`030000oooooooo08koool003koool00ol0VOooooooo`18oooo00<0
003oooooool00oooo`030000oooooooo08koool003koool00ol0VOooooooo`18oooo00<0003ooooo
ool00oooo`<0002>oooo000noooo00?o09Woooooool0B?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo000noooo00?o09Woooooool0B?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo000noooo00?o09Woooooool0Aoooo`800005oooo00<0003oooooool0S_ooo`00?_ooo`03o`2I
oooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo
08koool003koool00ol0VOooooooo`1>oooo0P0008ooool003koool00ol0VOooooooo`1>oooo00<0
003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o
09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003ooooo
ool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Wooooo
ool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?oo
ooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOoo
ooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool20000Soooo`00?_oo
o`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000
oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2I
oooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo
08koool003koool00ol0VOooooooo`1>oooo0P0008ooool003koool00ol0VOooooooo`1>oooo00<0
003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o
09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`0joooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo03coool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo
03coool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo000noooo00?o09Wooooo
ool0??ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool003koool00ol0VOoo
ooooo`0loooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo000n
oooo00?o09Woooooool0>oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo000noooo00?o
09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003ooooo
ool0S_ooo`00?_ooo`03o`2Ioooooooo04koool20000Soooo`00?_ooo`03o`2Ioooooooo04koool0
0`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?oo
ooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOoo
ooooo`1>oooo0P0008ooool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_oo
o`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000
oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2I
oooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?oooo000n
oooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0
003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o
09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003ooooo
ool0S_ooo`00?_ooo`03o`2Ioooooooo04koool20000Soooo`00?_ooo`03o`2Ioooooooo04koool0
0`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04Koool400001?oo
o`030000oooooooo08koool003koool00ol0VOooooooo`16oooo00<0003oooooool01Oooo`030000
oooooooo08koool003koool00ol0VOooooooo`17oooo00<0003oooooool01?ooo`<0002>oooo000n
oooo00?o09Woooooool0B?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo000noooo00?o
09Woooooool0A_ooo`040000oooooooo00001?ooo`030000oooooooo08koool003koool00ol0VOoo
ooooo`17oooo0P0000Goool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000
oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2I
oooooooo04koool20000Soooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000n
oooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0
003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o
09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo0P0008ooool0
03koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool0
0`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool0
0ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo04koool00`000?oo
ooooo`2>oooo000noooo00?o09Woooooool0C_ooo`80002?oooo000noooo00?o09Woooooool0C_oo
o`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_oo
o`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0C_ooo`030000
oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0003oooooool0S_ooo`00?_ooo`03o`2I
oooooooo04koool20000Soooo`00?_ooo`03o`2Ioooooooo04koool00`000?ooooooo`2>oooo000n
oooo00?o09Woooooool0C_ooo`030000oooooooo08koool003koool00ol0VOooooooo`1>oooo00<0
003oooooool0S_ooo`00?_ooo`03o`2Ioooooooo03[oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo000noooo00?o09Woooooool0>_ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo000noooo00?o09Woooooool0>oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`<00004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool01@000?oo
ooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool0
0`000?ooooooo`0Coooo00@0003oooooool00009oooo0`0000Goool00`000?ooooooo`02oooo00<0
003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0003oooooool00008oooo00@0
003oooooool00003oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool0
00005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0`0000?oool300000_oo
o`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.16408 .04578 L
.18221 .04578 L
.18703 .04578 L
.19227 .04578 L
.19467 .04578 L
.19598 .04578 L
.19721 .04578 L
.19826 .04578 L
s
.19826 .04578 m
.19854 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`050000ooooooooooooo`2I00Coool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo
08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo
04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0
043oool00ol0VOooooooo`1<oooo0P0008ooool0043oool00ol0VOooooooo`1<oooo00<0003ooooo
ool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Wooooo
ool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_oo
o`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?oo
o`80002?oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOoo
ooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>
oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<
oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool20000Soooo`00@?ooo`03o`2I
oooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo
08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo
04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0
043oool00ol0VOooooooo`1<oooo0P0008ooool0043oool00ol0VOooooooo`1<oooo00<0003ooooo
ool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Wooooo
ool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`0ioooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo03Soool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0>?oo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00@?ooo`03o`2Ioooooooo
03Soool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool0043oool00ol0VOoo
ooooo`0hoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
043oool00ol0VOooooooo`0ioooo0P0000[oool300001?ooo`030000oooooooo08koool0043oool0
0ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?oo
ooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?oo
o`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?oo
o`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`030000
oooooooo08koool0043oool00ol0VOooooooo`1<oooo0P0008ooool0043oool00ol0VOooooooo`1<
oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010
oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0
003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o
09Woooooool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0
043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool0
0`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool0
0ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool20000Sooo
o`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?oo
o`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?oo
o`03o`2Ioooooooo04Coool500000oooo`030000oooooooo08koool0043oool00ol0VOooooooo`16
oooo00<0003oooooool00oooo`030000oooooooo08koool0043oool00ol0VOooooooo`16oooo00<0
003oooooool00oooo`<0002>oooo0010oooo00?o09Woooooool0A_ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo0010oooo00?o09Woooooool0A_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo0010oooo00?o09Woooooool0AOooo`800005oooo00<0003oooooool0S_ooo`00@?oo
o`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o09Woooooool0C?ooo`030000
oooooooo08koool0043oool00ol0VOooooooo`1<oooo0P0008ooool0043oool00ol0VOooooooo`1<
oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010
oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0043oool00ol0VOooooooo`1<oooo00<0
003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool00`000?ooooooo`2>oooo0010oooo00?o
09Woooooool0C?ooo`80002?oooo0010oooo00?o09Woooooool0C?ooo`030000oooooooo08koool0
043oool00ol0VOooooooo`1<oooo00<0003oooooool0S_ooo`00@?ooo`03o`2Ioooooooo04coool0
0`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool0
0ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04_oool20000Sooo
o`00@Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Booo
o`030000oooooooo08koool0047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Ooo
o`03o`2Ioooooooo04_oool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Boooo`030000
oooooooo08koool0047oool00ol0VOooooooo`1;oooo0P0008ooool0047oool00ol0VOooooooo`1;
oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`2>oooo0011
oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool00ol0VOooooooo`0goooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00@Oooo`03o`2I
oooooooo03Woool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo0011oooo00?o
09Woooooool0>Oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool0047oool0
0ol0VOooooooo`0ioooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo0011oooo00?o09Woooooool0>?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo0011
oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool00ol0VOooooooo`1;oooo00<0
003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04_oool20000Soooo`00@Oooo`03o`2Ioooooooo
04_oool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Boooo`030000oooooooo08koool0
047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04_oool0
0`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool0
0ol0VOooooooo`1;oooo0P0008ooool0047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_oo
o`00@Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Booo
o`030000oooooooo08koool0047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Ooo
o`03o`2Ioooooooo04_oool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Boooo`80002?
oooo0011oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool00ol0VOooooooo`1;
oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`2>oooo0011
oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool00ol0VOooooooo`1;oooo00<0
003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04_oool20000Soooo`00@Oooo`03o`2Ioooooooo
04_oool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Boooo`030000oooooooo08koool0
047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04?oool4
00001?ooo`030000oooooooo08koool0047oool00ol0VOooooooo`13oooo00<0003oooooool01Ooo
o`030000oooooooo08koool0047oool00ol0VOooooooo`14oooo00<0003oooooool01?ooo`<0002>
oooo0011oooo00?o09Woooooool0AOooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0011
oooo00?o09Woooooool0@oooo`040000oooooooo00001?ooo`030000oooooooo08koool0047oool0
0ol0VOooooooo`14oooo0P0000Goool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Booo
o`030000oooooooo08koool0047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Ooo
o`03o`2Ioooooooo04_oool20000Soooo`00@Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`2>
oooo0011oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool00ol0VOooooooo`1;
oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`2>oooo0011
oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool00ol0VOooooooo`1;oooo0P00
08ooool0047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo
04_oool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Boooo`030000oooooooo08koool0
047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo04_oool0
0`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Boooo`80002?oooo0011oooo00?o09Wooooo
ool0Boooo`030000oooooooo08koool0047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_oo
o`00@Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0Booo
o`030000oooooooo08koool0047oool00ol0VOooooooo`1;oooo00<0003oooooool0S_ooo`00@Ooo
o`03o`2Ioooooooo04_oool20000Soooo`00@Oooo`03o`2Ioooooooo04_oool00`000?ooooooo`2>
oooo0011oooo00?o09Woooooool0Boooo`030000oooooooo08koool0047oool00ol0VOooooooo`1;
oooo00<0003oooooool0S_ooo`00@Oooo`03o`2Ioooooooo03Ooool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0=oooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo0011oooo00?o09Woooooool0>?ooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000ooo
o`<00004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002Oooo`<00004oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo
00D0000Boooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.19227 .04578 L
.19721 .04578 L
.20178 .04578 L
.20433 .04578 L
.20562 .04578 L
s
.20562 .04578 m
.2058 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00?oool01?l0VOooooooo`0000Ooool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_oo
o`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_oo
o`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo04[oool20000Soooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>
oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:
oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012
oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo0P00
08ooool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo
04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool0
04;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o09Wooooo
ool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_oo
o`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_oo
o`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo04[oool20000Soooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>
oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:
oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo03Ooool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0=_ooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`030000oooooooo08koool004;oool00ol0VOooooooo`0foooo00@0
003oooooool0000;oooo00<0003oooooool00_ooo`<0002>oooo0012oooo00?o09Woooooool0=_oo
o`040000oooooooo00002Oooo`800005oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo
03Koool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo03Ooool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00@_ooo`03o`2I
oooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo
08koool004;oool00ol0VOooooooo`1:oooo0P0008ooool004;oool00ol0VOooooooo`1:oooo00<0
003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o
09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003ooooo
ool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool20000Soooo`00@_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?oo
ooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOoo
ooooo`1:oooo0P0008ooool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000
oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2I
oooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012
oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0
003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o
09Woooooool0@_ooo`D00003oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04Coool0
0`000?ooooooo`03oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04Coool00`000?oo
ooooo`03oooo0`0008koool004;oool00ol0VOooooooo`14oooo00<0003oooooool00oooo`030000
oooooooo08koool004;oool00ol0VOooooooo`14oooo00<0003oooooool00oooo`030000oooooooo
08koool004;oool00ol0VOooooooo`13oooo0P0000Goool00`000?ooooooo`2>oooo0012oooo00?o
09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003ooooo
ool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool20000Soooo`00@_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?oo
ooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOoo
ooooo`1:oooo0P0008ooool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000
oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2I
oooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012
oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0
003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o
09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003ooooo
ool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool20000Soooo`00@_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo03Koool500000_oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0>?ooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo0012oooo00?o09Wooooo
ool0>?ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0008koool004;oool00ol0VOoo
ooooo`0hoooo00<0003oooooool02?ooo`800005oooo00<0003oooooool0S_ooo`00@_ooo`03o`2I
oooooooo03Soool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo08koool0
04;oool00ol0VOooooooo`0goooo0P0000[oool300001?ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?oo
ooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_oo
o`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000
oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2I
oooooooo04[oool20000Soooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012
oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0
003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o
09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo0P0008ooool0
04;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?oo
ooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_oo
o`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0@_ooo`@00004
oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04;oool00`000?ooooooo`05oooo00<0
003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04?oool00`000?ooooooo`04oooo0`0008koool0
04;oool00ol0VOooooooo`14oooo00<0003oooooool00oooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`12oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00@_ooo`03o`2I
oooooooo04?oool200001Oooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0
003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o
09Woooooool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool0
04;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool0
0ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool20000Sooo
o`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_oo
o`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_oo
o`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o09Woooooool0B_ooo`030000
oooooooo08koool004;oool00ol0VOooooooo`1:oooo0P0008ooool004;oool00ol0VOooooooo`1:
oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012
oooo00?o09Woooooool0B_ooo`030000oooooooo08koool004;oool00ol0VOooooooo`1:oooo00<0
003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool00`000?ooooooo`2>oooo0012oooo00?o
09Woooooool0B_ooo`80002?oooo0012oooo00?o09Woooooool0B_ooo`030000oooooooo08koool0
04;oool00ol0VOooooooo`1:oooo00<0003oooooool0S_ooo`00@_ooo`03o`2Ioooooooo04[oool0
0`000?ooooooo`2>oooo0012oooo00?o09Woooooool0=_ooo`@00003oooo0P0000Coool200001Ooo
o`030000oooooooo08koool004;oool00ol0VOooooooo`0foooo00<0003oooooool02Oooo`040000
oooooooo00001?ooo`030000oooooooo08koool004;oool00ol0VOooooooo`0goooo00<0003ooooo
ool02oooo`030000oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_oo
o`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOoo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800004oooo0P00
00Coool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?ooo`040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Goool007Coool00`000?oo
ooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo00001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool0
10000?ooooooo`0000Woool200001?ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20178 .04578 L
.20742 .04578 L
.21019 .04578 L
.2114 .04578 L
.21274 .04578 L
.21394 .04578 L
s
.21394 .04578 m
.21422 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool0
04Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool0
0`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool0
0ol0VOooooooo`17oooo0P0008ooool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_oo
o`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aooo
o`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOoo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`80002?
oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17
oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015
oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0
003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool20000Soooo`00AOooo`03o`2Ioooooooo
04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool0
04Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool0
0`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool0
0ol0VOooooooo`17oooo0P0008ooool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_oo
o`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aooo
o`030000oooooooo08koool004Goool00ol0VOooooooo`0doooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo03?oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0<oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00AOooo`03o`2Ioooooooo03?oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool004Goool00ol0VOooooooo`0c
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004Goool0
0ol0VOooooooo`0doooo0P0000[oool300001?ooo`030000oooooooo08koool004Goool00ol0VOoo
ooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>
oooo0015oooo00?o09Woooooool0Aoooo`80002?oooo0015oooo00?o09Woooooool0Aoooo`030000
oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2I
oooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo
08koool004Goool00ol0VOooooooo`17oooo0P0008ooool004Goool00ol0VOooooooo`17oooo00<0
003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o
09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003ooooo
ool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Wooooo
ool0Aoooo`80002?oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool0
0ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOoo
ooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool20000Soooo`00AOoo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000
oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2I
oooooooo03ooool500000oooo`030000oooooooo08koool004Goool00ol0VOooooooo`11oooo00<0
003oooooool00oooo`030000oooooooo08koool004Goool00ol0VOooooooo`11oooo00<0003ooooo
ool00oooo`<0002>oooo0015oooo00?o09Woooooool0@Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo0015oooo00?o09Woooooool0@Oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo0015oooo00?o09Woooooool0@?ooo`800005oooo00<0003oooooool0S_ooo`00AOooo`03o`2I
oooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo
08koool004Goool00ol0VOooooooo`17oooo0P0008ooool004Goool00ol0VOooooooo`17oooo00<0
003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o
09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003ooooo
ool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Wooooo
ool0Aoooo`80002?oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool0
0ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOoo
ooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool20000Soooo`00AOoo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000
oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2I
oooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo
08koool004Goool00ol0VOooooooo`17oooo0P0008ooool004Goool00ol0VOooooooo`17oooo00<0
003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o
09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`0coooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo
03Goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo0015oooo00?o09Wooooo
ool0=Oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool004Goool00ol0VOoo
ooooo`0eoooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo0015
oooo00?o09Woooooool0=?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo0015oooo00?o
09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003ooooo
ool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool20000Soooo`00AOooo`03o`2Ioooooooo04Ooool0
0`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool0
0ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOoo
ooooo`17oooo0P0008ooool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOoo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000
oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2I
oooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`80002?oooo0015
oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0
003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o
09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003ooooo
ool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool20000Soooo`00AOooo`03o`2Ioooooooo04Ooool0
0`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool0
0ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo03ooool400001?oo
o`030000oooooooo08koool004Goool00ol0VOooooooo`0ooooo00<0003oooooool01Oooo`030000
oooooooo08koool004Goool00ol0VOooooooo`10oooo00<0003oooooool01?ooo`<0002>oooo0015
oooo00?o09Woooooool0@Oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0015oooo00?o
09Woooooool0?oooo`040000oooooooo00001?ooo`030000oooooooo08koool004Goool00ol0VOoo
ooooo`10oooo0P0000Goool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000
oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2I
oooooooo04Ooool20000Soooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015
oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0
003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o
09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo0P0008ooool0
04Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool0
0`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool0
0ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2Ioooooooo04Ooool00`000?oo
ooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`80002?oooo0015oooo00?o09Woooooool0Aooo
o`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOoo
o`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0Aoooo`030000
oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0003oooooool0S_ooo`00AOooo`03o`2I
oooooooo04Ooool20000Soooo`00AOooo`03o`2Ioooooooo04Ooool00`000?ooooooo`2>oooo0015
oooo00?o09Woooooool0Aoooo`030000oooooooo08koool004Goool00ol0VOooooooo`17oooo00<0
003oooooool0S_ooo`00AOooo`03o`2Ioooooooo03?oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo0015oooo00?o09Woooooool0<oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo0015oooo00?o09Woooooool0=?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Boooo00@0003oooooool00009oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool200000oooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20178 .04578 L
.20742 .04578 L
.21274 .04578 L
.21753 .04578 L
.21884 .04578 L
.22022 .04578 L
.22141 .04578 L
s
.22141 .04578 m
.22174 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?l0VOooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool0
04Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool0
0`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool0
0ol0VOooooooo`16oooo0P0008ooool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_oo
o`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_oo
o`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_oo
o`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`80002?
oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16
oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016
oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0
003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool20000Soooo`00A_ooo`03o`2Ioooooooo
04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool0
04Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool0
0`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool0
0ol0VOooooooo`16oooo0P0008ooool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_oo
o`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_oo
o`030000oooooooo08koool004Koool00ol0VOooooooo`0coooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo03;oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0<_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00A_ooo`03o`2Ioooooooo03;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool004Koool00ol0VOooooooo`0b
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004Koool0
0ol0VOooooooo`0coooo0P0000[oool300001?ooo`030000oooooooo08koool004Koool00ol0VOoo
ooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>
oooo0016oooo00?o09Woooooool0A_ooo`80002?oooo0016oooo00?o09Woooooool0A_ooo`030000
oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2I
oooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo
08koool004Koool00ol0VOooooooo`16oooo0P0008ooool004Koool00ol0VOooooooo`16oooo00<0
003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o
09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003ooooo
ool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Wooooo
ool0A_ooo`80002?oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool0
0ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOoo
ooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool20000Soooo`00A_oo
o`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000
oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2I
oooooooo03koool500000oooo`030000oooooooo08koool004Koool00ol0VOooooooo`10oooo00<0
003oooooool00oooo`030000oooooooo08koool004Koool00ol0VOooooooo`10oooo00<0003ooooo
ool00oooo`<0002>oooo0016oooo00?o09Woooooool0@?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo0016oooo00?o09Woooooool0@?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo0016oooo00?o09Woooooool0?oooo`800005oooo00<0003oooooool0S_ooo`00A_ooo`03o`2I
oooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo
08koool004Koool00ol0VOooooooo`16oooo0P0008ooool004Koool00ol0VOooooooo`16oooo00<0
003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o
09Woooooool0A_ooo`030000oooooooo08koool004Koool00ol0VOooooooo`16oooo00<0003ooooo
ool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?ooooooo`2>oooo0016oooo00?o09Wooooo
ool0A_ooo`80002?oooo0016oooo00?o09Woooooool0A_ooo`030000oooooooo08koool004Koool0
0ol0VOooooooo`16oooo00<0003oooooool0S_ooo`00A_ooo`03o`2Ioooooooo04Koool00`000?oo
ooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOoo
ooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool20000Soooo`00Aooo
o`03o`2Ioooooooo04Goool00`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000
oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2I
oooooooo04Goool00`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000oooooooo
08koool004Ooool00ol0VOooooooo`15oooo0P0008ooool004Ooool00ol0VOooooooo`15oooo00<0
003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool00`000?ooooooo`2>oooo0017oooo00?o
09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOooooooo`0aoooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo03?oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo
03?oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo0017oooo00?o09Wooooo
ool0<oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool004Ooool00ol0VOoo
ooooo`0coooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo0017
oooo00?o09Woooooool0<_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo0017oooo00?o
09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0003ooooo
ool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool20000Soooo`00Aoooo`03o`2Ioooooooo04Goool0
0`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000oooooooo08koool004Ooool0
0ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool00`000?oo
ooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOoo
ooooo`15oooo0P0008ooool004Ooool00ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aooo
o`03o`2Ioooooooo04Goool00`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000
oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2I
oooooooo04Goool00`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`80002?oooo0017
oooo00?o09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0
003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool00`000?ooooooo`2>oooo0017oooo00?o
09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0003ooooo
ool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool20000Soooo`00Aoooo`03o`2Ioooooooo04Goool0
0`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000oooooooo08koool004Ooool0
0ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo03goool400001?oo
o`030000oooooooo08koool004Ooool00ol0VOooooooo`0moooo00<0003oooooool01Oooo`030000
oooooooo08koool004Ooool00ol0VOooooooo`0noooo00<0003oooooool01?ooo`<0002>oooo0017
oooo00?o09Woooooool0?oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0017oooo00?o
09Woooooool0?Oooo`040000oooooooo00001?ooo`030000oooooooo08koool004Ooool00ol0VOoo
ooooo`0noooo0P0000Goool00`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000
oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2I
oooooooo04Goool20000Soooo`00Aoooo`03o`2Ioooooooo04Goool00`000?ooooooo`2>oooo0017
oooo00?o09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0
003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool00`000?ooooooo`2>oooo0017oooo00?o
09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOooooooo`15oooo0P0008ooool0
04Ooool00ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool0
0`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000oooooooo08koool004Ooool0
0ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo04Goool00`000?oo
ooooo`2>oooo0017oooo00?o09Woooooool0AOooo`80002?oooo0017oooo00?o09Woooooool0AOoo
o`030000oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aooo
o`03o`2Ioooooooo04Goool00`000?ooooooo`2>oooo0017oooo00?o09Woooooool0AOooo`030000
oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0003oooooool0S_ooo`00Aoooo`03o`2I
oooooooo04Goool20000Soooo`00Aoooo`03o`2Ioooooooo04Goool00`000?ooooooo`2>oooo0017
oooo00?o09Woooooool0AOooo`030000oooooooo08koool004Ooool00ol0VOooooooo`15oooo00<0
003oooooool0S_ooo`00Aoooo`03o`2Ioooooooo037oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo0017oooo00?o09Woooooool0<Oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo0017oooo00?o09Woooooool0<_ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`030000
oooooooo00;oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`00001goooo001doooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0
003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`800009oooo1000
00?oool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20342 .04578 L
.21345 .04578 L
.22272 .04578 L
.22738 .04578 L
.22852 .04578 L
.22974 .04578 L
s
.22974 .04578 m
.22991 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool01@000?ooooooooooool0V@03
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo0019oooo00?o09Woooooool0@oooo`030000oooooooo
08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo
04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool0
04Woool00ol0VOooooooo`13oooo0P0008ooool004Woool00ol0VOooooooo`13oooo00<0003ooooo
ool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Wooooo
ool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_oo
o`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@ooo
o`80002?oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOoo
ooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>
oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13
oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool20000Soooo`00BOooo`03o`2I
oooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo
08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo
04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool0
04Woool00ol0VOooooooo`13oooo0P0008ooool004Woool00ol0VOooooooo`13oooo00<0003ooooo
ool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Wooooo
ool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`0`oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo02ooool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0;ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00BOooo`03o`2Ioooooooo
02ooool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool004Woool00ol0VOoo
ooooo`0_oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
04Woool00ol0VOooooooo`0`oooo0P0000[oool300001?ooo`030000oooooooo08koool004Woool0
0ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?oo
ooooo`2>oooo0019oooo00?o09Woooooool0@oooo`80002?oooo0019oooo00?o09Woooooool0@ooo
o`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOoo
o`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000
oooooooo08koool004Woool00ol0VOooooooo`13oooo0P0008ooool004Woool00ol0VOooooooo`13
oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019
oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0
003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o
09Woooooool0@oooo`80002?oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool0
04Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool0
0`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool0
0ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool20000Sooo
o`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@ooo
o`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOoo
o`03o`2Ioooooooo03_oool500000oooo`030000oooooooo08koool004Woool00ol0VOooooooo`0m
oooo00<0003oooooool00oooo`030000oooooooo08koool004Woool00ol0VOooooooo`0moooo00<0
003oooooool00oooo`<0002>oooo0019oooo00?o09Woooooool0?Oooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo0019oooo00?o09Woooooool0?Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo0019oooo00?o09Woooooool0??ooo`800005oooo00<0003oooooool0S_ooo`00BOoo
o`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000
oooooooo08koool004Woool00ol0VOooooooo`13oooo0P0008ooool004Woool00ol0VOooooooo`13
oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019
oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0
003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o
09Woooooool0@oooo`80002?oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool0
04Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool0
0`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool0
0ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool20000Sooo
o`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@ooo
o`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOoo
o`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000
oooooooo08koool004Woool00ol0VOooooooo`13oooo0P0008ooool004Woool00ol0VOooooooo`13
oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019
oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`0_oooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo037oool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00BOooo`03o`2I
oooooooo037oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo0019oooo00?o
09Woooooool0<Oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool004Woool0
0ol0VOooooooo`0aoooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo0019oooo00?o09Woooooool0<?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo0019
oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0
003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool20000Soooo`00BOooo`03o`2Ioooooooo
04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool0
04Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool0
0`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool0
0ol0VOooooooo`13oooo0P0008ooool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_oo
o`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@ooo
o`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOoo
o`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`80002?
oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13
oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019
oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0
003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool20000Soooo`00BOooo`03o`2Ioooooooo
04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool0
04Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo03_oool4
00001?ooo`030000oooooooo08koool004Woool00ol0VOooooooo`0koooo00<0003oooooool01Ooo
o`030000oooooooo08koool004Woool00ol0VOooooooo`0loooo00<0003oooooool01?ooo`<0002>
oooo0019oooo00?o09Woooooool0?Oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0019
oooo00?o09Woooooool0>oooo`040000oooooooo00001?ooo`030000oooooooo08koool004Woool0
0ol0VOooooooo`0loooo0P0000Goool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@ooo
o`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOoo
o`03o`2Ioooooooo04?oool20000Soooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>
oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13
oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019
oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo0P00
08ooool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo
04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool0
04Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo04?oool0
0`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@oooo`80002?oooo0019oooo00?o09Wooooo
ool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_oo
o`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0@ooo
o`030000oooooooo08koool004Woool00ol0VOooooooo`13oooo00<0003oooooool0S_ooo`00BOoo
o`03o`2Ioooooooo04?oool20000Soooo`00BOooo`03o`2Ioooooooo04?oool00`000?ooooooo`2>
oooo0019oooo00?o09Woooooool0@oooo`030000oooooooo08koool004Woool00ol0VOooooooo`13
oooo00<0003oooooool0S_ooo`00BOooo`03o`2Ioooooooo02ooool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0;oooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo0019oooo00?o09Woooooool0<?ooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002oooo`050000oooooooooooo0000
07[oool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002Oooo`@00002
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20342 .04578 L
.22272 .04578 L
.23233 .04578 L
.23496 .04578 L
.2364 .04578 L
.23711 .04578 L
.23775 .04578 L
s
.23775 .04578 m
.23804 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`03oooo00?o
09Woool000001oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool0
04_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool0
0`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool0
0ol0VOooooooo`11oooo0P0008ooool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_oo
o`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Ooo
o`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Booo
o`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`80002?
oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11
oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;
oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0
003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool20000Soooo`00Boooo`03o`2Ioooooooo
047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool0
04_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool0
0`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool0
0ol0VOooooooo`11oooo0P0008ooool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_oo
o`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Ooo
o`030000oooooooo08koool004_oool00ol0VOooooooo`0^oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo02goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0;Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00Boooo`03o`2Ioooooooo02goool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`0]
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004_oool0
0ol0VOooooooo`0^oooo0P0000[oool300001?ooo`030000oooooooo08koool004_oool00ol0VOoo
ooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>
oooo001;oooo00?o09Woooooool0@Oooo`80002?oooo001;oooo00?o09Woooooool0@Oooo`030000
oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2I
oooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo
08koool004_oool00ol0VOooooooo`11oooo0P0008ooool004_oool00ol0VOooooooo`11oooo00<0
003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o
09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003ooooo
ool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Wooooo
ool0@Oooo`80002?oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool0
0ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?oo
ooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOoo
ooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool20000Soooo`00Booo
o`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000
oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2I
oooooooo03Woool500000oooo`030000oooooooo08koool004_oool00ol0VOooooooo`0koooo00<0
003oooooool00oooo`030000oooooooo08koool004_oool00ol0VOooooooo`0koooo00<0003ooooo
ool00oooo`<0002>oooo001;oooo00?o09Woooooool0>oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001;oooo00?o09Woooooool0>oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001;oooo00?o09Woooooool0>_ooo`800005oooo00<0003oooooool0S_ooo`00Boooo`03o`2I
oooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo
08koool004_oool00ol0VOooooooo`11oooo0P0008ooool004_oool00ol0VOooooooo`11oooo00<0
003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o
09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003ooooo
ool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Wooooo
ool0@Oooo`80002?oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool0
0ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?oo
ooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOoo
ooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool20000Soooo`00Booo
o`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000
oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2I
oooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo
08koool004_oool00ol0VOooooooo`11oooo0P0008ooool004_oool00ol0VOooooooo`11oooo00<0
003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o
09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`0]oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo
02ooool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001;oooo00?o09Wooooo
ool0;oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool004_oool00ol0VOoo
ooooo`0_oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001;
oooo00?o09Woooooool0;_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001;oooo00?o
09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003ooooo
ool0S_ooo`00Boooo`03o`2Ioooooooo047oool20000Soooo`00Boooo`03o`2Ioooooooo047oool0
0`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool0
0ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?oo
ooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOoo
ooooo`11oooo0P0008ooool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Booo
o`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000
oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2I
oooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`80002?oooo001;
oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0
003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o
09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003ooooo
ool0S_ooo`00Boooo`03o`2Ioooooooo047oool20000Soooo`00Boooo`03o`2Ioooooooo047oool0
0`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool0
0ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo03Woool400001?oo
o`030000oooooooo08koool004_oool00ol0VOooooooo`0ioooo00<0003oooooool01Oooo`030000
oooooooo08koool004_oool00ol0VOooooooo`0joooo00<0003oooooool01?ooo`<0002>oooo001;
oooo00?o09Woooooool0>oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001;oooo00?o
09Woooooool0>Oooo`040000oooooooo00001?ooo`030000oooooooo08koool004_oool00ol0VOoo
ooooo`0joooo0P0000Goool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000
oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2I
oooooooo047oool20000Soooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;
oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0
003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o
09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo0P0008ooool0
04_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool0
0`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool0
0ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2Ioooooooo047oool00`000?oo
ooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`80002?oooo001;oooo00?o09Woooooool0@Ooo
o`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Booo
o`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0@Oooo`030000
oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0003oooooool0S_ooo`00Boooo`03o`2I
oooooooo047oool20000Soooo`00Boooo`03o`2Ioooooooo047oool00`000?ooooooo`2>oooo001;
oooo00?o09Woooooool0@Oooo`030000oooooooo08koool004_oool00ol0VOooooooo`11oooo00<0
003oooooool0S_ooo`00Boooo`03o`2Ioooooooo02goool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001;oooo00?o09Woooooool0;Oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001;oooo00?o09Woooooool0;_ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`<00004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`0000Goool0
0`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0
003oooooool00008oooo0`0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?oo
ooooooooo`00000Eoooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0`0000?oool3
00000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20342 .04578 L
.22272 .04578 L
.23233 .04578 L
.23739 .04578 L
.24016 .04578 L
.24276 .04578 L
.24392 .04578 L
.24502 .04578 L
s
.24502 .04578 m
.24534 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool0
04goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0ooooo0P0008ooool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_oo
o`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?ooo
o`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COoo
o`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`80002?
oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0o
oooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=
oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool20000Soooo`00COooo`03o`2Ioooooooo
03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool0
04goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0ooooo0P0008ooool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_oo
o`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?ooo
o`030000oooooooo08koool004goool00ol0VOooooooo`0/oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo02_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0:oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00COooo`03o`2Ioooooooo02_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool004goool00ol0VOooooooo`0[
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0/oooo0P0000[oool300001?ooo`030000oooooooo08koool004goool00ol0VOoo
ooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>
oooo001=oooo00?o09Woooooool0?oooo`80002?oooo001=oooo00?o09Woooooool0?oooo`030000
oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo
08koool004goool00ol0VOooooooo`0ooooo0P0008ooool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o
09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003ooooo
ool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Wooooo
ool0?oooo`80002?oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOoo
ooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool20000Soooo`00COoo
o`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000
oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03Ooool500000oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ioooo00<0
003oooooool00oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ioooo00<0003ooooo
ool00oooo`<0002>oooo001=oooo00?o09Woooooool0>Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001=oooo00?o09Woooooool0>Oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001=oooo00?o09Woooooool0>?ooo`800005oooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo
08koool004goool00ol0VOooooooo`0ooooo0P0008ooool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o
09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003ooooo
ool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Wooooo
ool0?oooo`80002?oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOoo
ooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool20000Soooo`00COoo
o`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000
oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo
08koool004goool00ol0VOooooooo`0ooooo0P0008ooool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o
09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0[oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo02goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo
02goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001=oooo00?o09Wooooo
ool0;Oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool004goool00ol0VOoo
ooooo`0]oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001=
oooo00?o09Woooooool0;?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001=oooo00?o
09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003ooooo
ool0S_ooo`00COooo`03o`2Ioooooooo03ooool20000Soooo`00COooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOoo
ooooo`0ooooo0P0008ooool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COoo
o`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000
oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`80002?oooo001=
oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o
09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003ooooo
ool0S_ooo`00COooo`03o`2Ioooooooo03ooool20000Soooo`00COooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03Ooool400001?oo
o`030000oooooooo08koool004goool00ol0VOooooooo`0goooo00<0003oooooool01Oooo`030000
oooooooo08koool004goool00ol0VOooooooo`0hoooo00<0003oooooool01?ooo`<0002>oooo001=
oooo00?o09Woooooool0>Oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001=oooo00?o
09Woooooool0=oooo`040000oooooooo00001?ooo`030000oooooooo08koool004goool00ol0VOoo
ooooo`0hoooo0P0000Goool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000
oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03ooool20000Soooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=
oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o
09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo0P0008ooool0
04goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool0
0`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool0
0ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2Ioooooooo03ooool00`000?oo
ooooo`2>oooo001=oooo00?o09Woooooool0?oooo`80002?oooo001=oooo00?o09Woooooool0?ooo
o`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COoo
o`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0?oooo`030000
oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0003oooooool0S_ooo`00COooo`03o`2I
oooooooo03ooool20000Soooo`00COooo`03o`2Ioooooooo03ooool00`000?ooooooo`2>oooo001=
oooo00?o09Woooooool0?oooo`030000oooooooo08koool004goool00ol0VOooooooo`0ooooo00<0
003oooooool0S_ooo`00COooo`03o`2Ioooooooo02_oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001=oooo00?o09Woooooool0:oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001=oooo00?o09Woooooool0;?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`<00004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000Boooo00@0003oooooool00008oooo0`0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002Oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20342 .04578 L
.22272 .04578 L
.23233 .04578 L
.24276 .04578 L
.24754 .04578 L
.25016 .04578 L
.25144 .04578 L
.25261 .04578 L
.25368 .04578 L
s
.25368 .04578 m
.25394 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003ooooo09T01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool0
04ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool0
0`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool0
0ol0VOooooooo`0moooo0P0008ooool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_oo
o`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Ooo
o`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Cooo
o`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`80002?
oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0m
oooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?
oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0
003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool20000Soooo`00Coooo`03o`2Ioooooooo
03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool0
04ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool0
0`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool0
0ol0VOooooooo`0moooo0P0008ooool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_oo
o`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Ooo
o`030000oooooooo08koool004ooool00ol0VOooooooo`0Zoooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo02Woool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0:Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00Coooo`03o`2Ioooooooo02Woool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0Y
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004ooool0
0ol0VOooooooo`0Zoooo0P0000[oool300001?ooo`030000oooooooo08koool004ooool00ol0VOoo
ooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>
oooo001?oooo00?o09Woooooool0?Oooo`80002?oooo001?oooo00?o09Woooooool0?Oooo`030000
oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2I
oooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo
08koool004ooool00ol0VOooooooo`0moooo0P0008ooool004ooool00ol0VOooooooo`0moooo00<0
003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o
09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003ooooo
ool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Wooooo
ool0?Oooo`80002?oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool0
0ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?oo
ooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOoo
ooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool20000Soooo`00Cooo
o`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000
oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2I
oooooooo03Goool500000oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0goooo00<0
003oooooool00oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0goooo00<0003ooooo
ool00oooo`<0002>oooo001?oooo00?o09Woooooool0=oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001?oooo00?o09Woooooool0=oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001?oooo00?o09Woooooool0=_ooo`800005oooo00<0003oooooool0S_ooo`00Coooo`03o`2I
oooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo
08koool004ooool00ol0VOooooooo`0moooo0P0008ooool004ooool00ol0VOooooooo`0moooo00<0
003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o
09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003ooooo
ool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Wooooo
ool0?Oooo`80002?oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool0
0ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?oo
ooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOoo
ooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool20000Soooo`00Cooo
o`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000
oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2I
oooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo
08koool004ooool00ol0VOooooooo`0moooo0P0008ooool004ooool00ol0VOooooooo`0moooo00<0
003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o
09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0Yoooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo
02_oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001?oooo00?o09Wooooo
ool0:oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool004ooool00ol0VOoo
ooooo`0[oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001?
oooo00?o09Woooooool0:_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001?oooo00?o
09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003ooooo
ool0S_ooo`00Coooo`03o`2Ioooooooo03goool20000Soooo`00Coooo`03o`2Ioooooooo03goool0
0`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool0
0ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?oo
ooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOoo
ooooo`0moooo0P0008ooool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Cooo
o`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000
oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2I
oooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`80002?oooo001?
oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0
003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o
09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003ooooo
ool0S_ooo`00Coooo`03o`2Ioooooooo03goool20000Soooo`00Coooo`03o`2Ioooooooo03goool0
0`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool0
0ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03Goool400001?oo
o`030000oooooooo08koool004ooool00ol0VOooooooo`0eoooo00<0003oooooool01Oooo`030000
oooooooo08koool004ooool00ol0VOooooooo`0foooo00<0003oooooool01?ooo`<0002>oooo001?
oooo00?o09Woooooool0=oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001?oooo00?o
09Woooooool0=Oooo`040000oooooooo00001?ooo`030000oooooooo08koool004ooool00ol0VOoo
ooooo`0foooo0P0000Goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000
oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2I
oooooooo03goool20000Soooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?
oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0
003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o
09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo0P0008ooool0
04ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool0
0`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool0
0ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2Ioooooooo03goool00`000?oo
ooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`80002?oooo001?oooo00?o09Woooooool0?Ooo
o`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Cooo
o`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0?Oooo`030000
oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0003oooooool0S_ooo`00Coooo`03o`2I
oooooooo03goool20000Soooo`00Coooo`03o`2Ioooooooo03goool00`000?ooooooo`2>oooo001?
oooo00?o09Woooooool0?Oooo`030000oooooooo08koool004ooool00ol0VOooooooo`0moooo00<0
003oooooool0S_ooo`00Coooo`03o`2Ioooooooo02Woool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001?oooo00?o09Woooooool0:Oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001?oooo00?o09Woooooool0:_ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000_oool00`000?ooooooo`03oooo00<0
003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000
oooooooo00002Oooo`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005Oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`<00003oooo0`00
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.24141 .04578 L
.25127 .04578 L
.25666 .04578 L
.2593 .04578 L
.26045 .04578 L
.26171 .04578 L
s
.26171 .04578 m
.26204 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00D0
003ooooooooooooo09T00oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo
08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo
03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0koooo0P0008ooool0057oool00ol0VOooooooo`0koooo00<0003ooooo
ool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Wooooo
ool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_oo
o`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>ooo
o`80002?oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOoo
ooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>
oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0k
oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2I
oooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo
08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo
03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0koooo0P0008ooool0057oool00ol0VOooooooo`0koooo00<0003ooooo
ool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Wooooo
ool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0Xoooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo02Ooool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool09ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00DOooo`03o`2Ioooooooo
02Ooool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool0057oool00ol0VOoo
ooooo`0Woooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0Xoooo0P0000[oool300001?ooo`030000oooooooo08koool0057oool0
0ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?oo
ooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`80002?oooo001Aoooo00?o09Woooooool0>ooo
o`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOoo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000
oooooooo08koool0057oool00ol0VOooooooo`0koooo0P0008ooool0057oool00ol0VOooooooo`0k
oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0
003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o
09Woooooool0>oooo`80002?oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool0
0`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool0
0ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Sooo
o`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>ooo
o`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOoo
o`03o`2Ioooooooo03?oool500000oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0e
oooo00<0003oooooool00oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0eoooo00<0
003oooooool00oooo`<0002>oooo001Aoooo00?o09Woooooool0=Oooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0=Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Aoooo00?o09Woooooool0=?ooo`800005oooo00<0003oooooool0S_ooo`00DOoo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000
oooooooo08koool0057oool00ol0VOooooooo`0koooo0P0008ooool0057oool00ol0VOooooooo`0k
oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0
003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o
09Woooooool0>oooo`80002?oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool0
0`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool0
0ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Sooo
o`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>ooo
o`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOoo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000
oooooooo08koool0057oool00ol0VOooooooo`0koooo0P0008ooool0057oool00ol0VOooooooo`0k
oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0Woooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo02Woool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00DOooo`03o`2I
oooooooo02Woool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Aoooo00?o
09Woooooool0:Oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool0057oool0
0ol0VOooooooo`0Yoooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001Aoooo00?o09Woooooool0:?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0
003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo
03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool0
0`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool0
0ol0VOooooooo`0koooo0P0008ooool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_oo
o`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>ooo
o`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOoo
o`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`80002?
oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0k
oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0
003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo
03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03?oool4
00001?ooo`030000oooooooo08koool0057oool00ol0VOooooooo`0coooo00<0003oooooool01Ooo
o`030000oooooooo08koool0057oool00ol0VOooooooo`0doooo00<0003oooooool01?ooo`<0002>
oooo001Aoooo00?o09Woooooool0=Oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0<oooo`040000oooooooo00001?ooo`030000oooooooo08koool0057oool0
0ol0VOooooooo`0doooo0P0000Goool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>ooo
o`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOoo
o`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>
oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0k
oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001A
oooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo0P00
08ooool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo
03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0
057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo03_oool0
0`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>oooo`80002?oooo001Aoooo00?o09Wooooo
ool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_oo
o`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0>ooo
o`030000oooooooo08koool0057oool00ol0VOooooooo`0koooo00<0003oooooool0S_ooo`00DOoo
o`03o`2Ioooooooo03_oool20000Soooo`00DOooo`03o`2Ioooooooo03_oool00`000?ooooooo`2>
oooo001Aoooo00?o09Woooooool0>oooo`030000oooooooo08koool0057oool00ol0VOooooooo`0k
oooo00<0003oooooool0S_ooo`00DOooo`03o`2Ioooooooo02Ooool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool09oooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Aoooo00?o09Woooooool0:?ooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500004_ooo`040000oooooooo00002Oooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Woool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`<00002oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.24141 .04578 L
.25127 .04578 L
.26171 .04578 L
.26425 .04578 L
.26698 .04578 L
.26778 .04578 L
.26855 .04578 L
.26923 .04578 L
s
.26923 .04578 m
.26942 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool00oooo`03o`2Ioooo000000Ooool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool0
05?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo0P0008ooool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_oo
o`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Ooo
o`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Dooo
o`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`80002?
oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0i
oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001C
oooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0
003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo
03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool0
05?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo0P0008ooool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_oo
o`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Ooo
o`030000oooooooo08koool005?oool00ol0VOooooooo`0Voooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo02Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool09Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00Doooo`03o`2Ioooooooo02Goool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0U
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0Voooo0P0000[oool300001?ooo`030000oooooooo08koool005?oool00ol0VOoo
ooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>
oooo001Coooo00?o09Woooooool0>Oooo`80002?oooo001Coooo00?o09Woooooool0>Oooo`030000
oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2I
oooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo
08koool005?oool00ol0VOooooooo`0ioooo0P0008ooool005?oool00ol0VOooooooo`0ioooo00<0
003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Wooooo
ool0>Oooo`80002?oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOoo
ooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Dooo
o`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000
oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2I
oooooooo037oool500000oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0coooo00<0
003oooooool00oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0coooo00<0003ooooo
ool00oooo`<0002>oooo001Coooo00?o09Woooooool0<oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Coooo00?o09Woooooool0<oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Coooo00?o09Woooooool0<_ooo`800005oooo00<0003oooooool0S_ooo`00Doooo`03o`2I
oooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo
08koool005?oool00ol0VOooooooo`0ioooo0P0008ooool005?oool00ol0VOooooooo`0ioooo00<0
003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Wooooo
ool0>Oooo`80002?oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOoo
ooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Dooo
o`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000
oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2I
oooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo
08koool005?oool00ol0VOooooooo`0ioooo0P0008ooool005?oool00ol0VOooooooo`0ioooo00<0
003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0Uoooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo02Ooool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo
02Ooool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Coooo00?o09Wooooo
ool09oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool005?oool00ol0VOoo
ooooo`0Woooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001C
oooo00?o09Woooooool09_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOoo
ooooo`0ioooo0P0008ooool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Dooo
o`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000
oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2I
oooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`80002?oooo001C
oooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0
003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003ooooo
ool0S_ooo`00Doooo`03o`2Ioooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo037oool400001?oo
o`030000oooooooo08koool005?oool00ol0VOooooooo`0aoooo00<0003oooooool01Oooo`030000
oooooooo08koool005?oool00ol0VOooooooo`0boooo00<0003oooooool01?ooo`<0002>oooo001C
oooo00?o09Woooooool0<oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0<Oooo`040000oooooooo00001?ooo`030000oooooooo08koool005?oool00ol0VOoo
ooooo`0boooo0P0000Goool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000
oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2I
oooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001C
oooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0
003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o
09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo0P0008ooool0
05?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool0
0ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2Ioooooooo03Woool00`000?oo
ooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`80002?oooo001Coooo00?o09Woooooool0>Ooo
o`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Dooo
o`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool0>Oooo`030000
oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`03o`2I
oooooooo03Woool20000Soooo`00Doooo`03o`2Ioooooooo03Woool00`000?ooooooo`2>oooo001C
oooo00?o09Woooooool0>Oooo`030000oooooooo08koool005?oool00ol0VOooooooo`0ioooo00<0
003oooooool0S_ooo`00Doooo`03o`2Ioooooooo02Goool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001Coooo00?o09Woooooool09Oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Coooo00?o09Woooooool09_ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`<00002
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000_oool010000?oo
ooooo`0000;oool01@000?ooooooooooo`00001goooo001doooo00<0003oooooool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000Soool500001?ooo`030000oooooooo00;oool00`000?oo
ooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000E
oooo00@0003oooooool00009oooo00<0003oool000000oooo`030000oooooooo00?oool00`000?oo
ooooo`1eoooo001foooo00<0003oooooool05oooo`80000;oooo0P0000?oool300000_ooo`030000
oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.24141 .04578 L
.26171 .04578 L
.26709 .04578 L
.27279 .04578 L
.27513 .04578 L
.27643 .04578 L
.27765 .04578 L
s
.27765 .04578 m
.27783 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool0
05Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool0
0`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool0
0ol0VOooooooo`0goooo0P0008ooool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_oo
o`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=ooo
o`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOoo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`80002?
oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0g
oooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001E
oooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0
003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool20000Soooo`00EOooo`03o`2Ioooooooo
03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool0
05Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool0
0`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool0
0ol0VOooooooo`0goooo0P0008ooool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_oo
o`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=ooo
o`030000oooooooo08koool005Goool00ol0VOooooooo`0Toooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo02?oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool08oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00EOooo`03o`2Ioooooooo02?oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0S
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005Goool0
0ol0VOooooooo`0Toooo0P0000[oool300001?ooo`030000oooooooo08koool005Goool00ol0VOoo
ooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>
oooo001Eoooo00?o09Woooooool0=oooo`80002?oooo001Eoooo00?o09Woooooool0=oooo`030000
oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2I
oooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo
08koool005Goool00ol0VOooooooo`0goooo0P0008ooool005Goool00ol0VOooooooo`0goooo00<0
003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o
09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003ooooo
ool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Wooooo
ool0=oooo`80002?oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool0
0ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOoo
ooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool20000Soooo`00EOoo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000
oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2I
oooooooo02ooool500000oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0aoooo00<0
003oooooool00oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0aoooo00<0003ooooo
ool00oooo`<0002>oooo001Eoooo00?o09Woooooool0<Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Eoooo00?o09Woooooool0<Oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Eoooo00?o09Woooooool0<?ooo`800005oooo00<0003oooooool0S_ooo`00EOooo`03o`2I
oooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo
08koool005Goool00ol0VOooooooo`0goooo0P0008ooool005Goool00ol0VOooooooo`0goooo00<0
003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o
09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003ooooo
ool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Wooooo
ool0=oooo`80002?oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool0
0ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOoo
ooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool20000Soooo`00EOoo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000
oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2I
oooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo
08koool005Goool00ol0VOooooooo`0goooo0P0008ooool005Goool00ol0VOooooooo`0goooo00<0
003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o
09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0Soooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo02Goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo
02Goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Eoooo00?o09Wooooo
ool09Oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool005Goool00ol0VOoo
ooooo`0Uoooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001E
oooo00?o09Woooooool09?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Eoooo00?o
09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003ooooo
ool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool20000Soooo`00EOooo`03o`2Ioooooooo03Ooool0
0`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool0
0ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOoo
ooooo`0goooo0P0008ooool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOoo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000
oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2I
oooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`80002?oooo001E
oooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0
003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o
09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003ooooo
ool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool20000Soooo`00EOooo`03o`2Ioooooooo03Ooool0
0`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool0
0ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo02ooool400001?oo
o`030000oooooooo08koool005Goool00ol0VOooooooo`0_oooo00<0003oooooool01Oooo`030000
oooooooo08koool005Goool00ol0VOooooooo`0`oooo00<0003oooooool01?ooo`<0002>oooo001E
oooo00?o09Woooooool0<Oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Eoooo00?o
09Woooooool0;oooo`040000oooooooo00001?ooo`030000oooooooo08koool005Goool00ol0VOoo
ooooo`0`oooo0P0000Goool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000
oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2I
oooooooo03Ooool20000Soooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001E
oooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0
003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o
09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo0P0008ooool0
05Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool0
0`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool0
0ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2Ioooooooo03Ooool00`000?oo
ooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`80002?oooo001Eoooo00?o09Woooooool0=ooo
o`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOoo
o`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool0=oooo`030000
oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0003oooooool0S_ooo`00EOooo`03o`2I
oooooooo03Ooool20000Soooo`00EOooo`03o`2Ioooooooo03Ooool00`000?ooooooo`2>oooo001E
oooo00?o09Woooooool0=oooo`030000oooooooo08koool005Goool00ol0VOooooooo`0goooo00<0
003oooooool0S_ooo`00EOooo`03o`2Ioooooooo02?oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001Eoooo00?o09Woooooool08oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Eoooo00?o09Woooooool09?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001Oooo`<00002
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000;oooo00D0003oooooooooool0
0000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008
oooo1@0000?oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000005Oooo`040000oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool05oooo`80000;oooo0P0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.27193 .04578 L
.27731 .04578 L
.28025 .04578 L
.28302 .04578 L
.28425 .04578 L
.28542 .04578 L
s
.28542 .04578 m
.28558 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000ooooo`2I00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool0
05Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool0
0`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool0
0ol0VOooooooo`0eoooo0P0008ooool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_oo
o`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Ooo
o`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eooo
o`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`80002?
oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0e
oooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001G
oooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo
03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool0
05Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool0
0`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool0
0ol0VOooooooo`0eoooo0P0008ooool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_oo
o`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Ooo
o`030000oooooooo08koool005Ooool00ol0VOooooooo`0Roooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo027oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool08Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00Eoooo`03o`2Ioooooooo027oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0Q
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005Ooool0
0ol0VOooooooo`0Roooo0P0000[oool300001?ooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>
oooo001Goooo00?o09Woooooool0=Oooo`80002?oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo
08koool005Ooool00ol0VOooooooo`0eoooo0P0008ooool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o
09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003ooooo
ool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Wooooo
ool0=Oooo`80002?oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool0
0ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eooo
o`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo02goool500000oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0_oooo00<0
003oooooool00oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0_oooo00<0003ooooo
ool00oooo`<0002>oooo001Goooo00?o09Woooooool0;oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Goooo00?o09Woooooool0;oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Goooo00?o09Woooooool0;_ooo`800005oooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo
08koool005Ooool00ol0VOooooooo`0eoooo0P0008ooool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o
09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003ooooo
ool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Wooooo
ool0=Oooo`80002?oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool0
0ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eooo
o`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo
08koool005Ooool00ol0VOooooooo`0eoooo0P0008ooool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o
09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0Qoooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo02?oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo
02?oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Goooo00?o09Wooooo
ool08oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0Soooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001G
oooo00?o09Woooooool08_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Goooo00?o
09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003ooooo
ool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool0
0`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool0
0ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0eoooo0P0008ooool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eooo
o`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`80002?oooo001G
oooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o
09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003ooooo
ool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool0
0`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool0
0ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo02goool400001?oo
o`030000oooooooo08koool005Ooool00ol0VOooooooo`0]oooo00<0003oooooool01Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0^oooo00<0003oooooool01?ooo`<0002>oooo001G
oooo00?o09Woooooool0;oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Goooo00?o
09Woooooool0;Oooo`040000oooooooo00001?ooo`030000oooooooo08koool005Ooool00ol0VOoo
ooooo`0^oooo0P0000Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001G
oooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o
09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo0P0008ooool0
05Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool0
0`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool0
0ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo03Goool00`000?oo
ooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`80002?oooo001Goooo00?o09Woooooool0=Ooo
o`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eooo
o`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool0=Oooo`030000
oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0003oooooool0S_ooo`00Eoooo`03o`2I
oooooooo03Goool20000Soooo`00Eoooo`03o`2Ioooooooo03Goool00`000?ooooooo`2>oooo001G
oooo00?o09Woooooool0=Oooo`030000oooooooo08koool005Ooool00ol0VOooooooo`0eoooo00<0
003oooooool0S_ooo`00Eoooo`03o`2Ioooooooo027oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001Goooo00?o09Woooooool08Oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Goooo00?o09Woooooool08_ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0
003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`0500004_ooo`040000
oooooooo00002oooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P00
00Coool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.27193 .04578 L
.28302 .04578 L
.2881 .04578 L
.29088 .04578 L
.29224 .04578 L
.29349 .04578 L
s
.29349 .04578 m
.29377 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`050000ooooooooooooo`2I00?oool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo
08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo
03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0coooo0P0008ooool005Woool00ol0VOooooooo`0coooo00<0003ooooo
ool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Wooooo
ool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_oo
o`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<ooo
o`80002?oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOoo
ooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>
oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0c
oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2I
oooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo
08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo
03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0coooo0P0008ooool005Woool00ol0VOooooooo`0coooo00<0003ooooo
ool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Wooooo
ool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0Poooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo01ooool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool07ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00FOooo`03o`2Ioooooooo
01ooool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool005Woool00ol0VOoo
ooooo`0Ooooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0Poooo0P0000[oool300001?ooo`030000oooooooo08koool005Woool0
0ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?oo
ooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`80002?oooo001Ioooo00?o09Woooooool0<ooo
o`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOoo
o`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000
oooooooo08koool005Woool00ol0VOooooooo`0coooo0P0008ooool005Woool00ol0VOooooooo`0c
oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0
003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o
09Woooooool0<oooo`80002?oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool0
0`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool0
0ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Sooo
o`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<ooo
o`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOoo
o`03o`2Ioooooooo02_oool500000oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0]
oooo00<0003oooooool00oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0]oooo00<0
003oooooool00oooo`<0002>oooo001Ioooo00?o09Woooooool0;Oooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0;Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Ioooo00?o09Woooooool0;?ooo`800005oooo00<0003oooooool0S_ooo`00FOoo
o`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000
oooooooo08koool005Woool00ol0VOooooooo`0coooo0P0008ooool005Woool00ol0VOooooooo`0c
oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0
003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o
09Woooooool0<oooo`80002?oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool0
0`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool0
0ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Sooo
o`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<ooo
o`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOoo
o`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000
oooooooo08koool005Woool00ol0VOooooooo`0coooo0P0008ooool005Woool00ol0VOooooooo`0c
oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0Ooooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo027oool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00FOooo`03o`2I
oooooooo027oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Ioooo00?o
09Woooooool08Oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool005Woool0
0ol0VOooooooo`0Qoooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001Ioooo00?o09Woooooool08?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0
003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo
03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool0
0`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool0
0ol0VOooooooo`0coooo0P0008ooool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_oo
o`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<ooo
o`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOoo
o`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`80002?
oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0c
oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0
003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo
03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo02_oool4
00001?ooo`030000oooooooo08koool005Woool00ol0VOooooooo`0[oooo00<0003oooooool01Ooo
o`030000oooooooo08koool005Woool00ol0VOooooooo`0/oooo00<0003oooooool01?ooo`<0002>
oooo001Ioooo00?o09Woooooool0;Oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0:oooo`040000oooooooo00001?ooo`030000oooooooo08koool005Woool0
0ol0VOooooooo`0/oooo0P0000Goool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<ooo
o`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOoo
o`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>
oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0c
oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001I
oooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo0P00
08ooool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo
03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool0
05Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo03?oool0
0`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<oooo`80002?oooo001Ioooo00?o09Wooooo
ool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_oo
o`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool0<ooo
o`030000oooooooo08koool005Woool00ol0VOooooooo`0coooo00<0003oooooool0S_ooo`00FOoo
o`03o`2Ioooooooo03?oool20000Soooo`00FOooo`03o`2Ioooooooo03?oool00`000?ooooooo`2>
oooo001Ioooo00?o09Woooooool0<oooo`030000oooooooo08koool005Woool00ol0VOooooooo`0c
oooo00<0003oooooool0S_ooo`00FOooo`03o`2Ioooooooo01ooool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool07oooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Ioooo00?o09Woooooool08?ooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0C
oooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500004_ooo`040000oooooooo00002oooo`050000oooooooooooo000007[oool0
07Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.27193 .04578 L
.28302 .04578 L
.2881 .04578 L
.29349 .04578 L
.29809 .04578 L
.29935 .04578 L
.30004 .04578 L
.3007 .04578 L
s
.3007 .04578 m
.30102 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00?oool00ol0VOooo`000008oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool0
05_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo0P0008ooool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_oo
o`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Ooo
o`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Fooo
o`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`80002?
oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0a
oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001K
oooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0
003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo
037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool0
05_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo0P0008ooool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_oo
o`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Ooo
o`030000oooooooo08koool005_oool00ol0VOooooooo`0Noooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo01goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool07Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00Foooo`03o`2Ioooooooo01goool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0M
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0Noooo0P0000[oool300001?ooo`030000oooooooo08koool005_oool00ol0VOoo
ooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>
oooo001Koooo00?o09Woooooool0<Oooo`80002?oooo001Koooo00?o09Woooooool0<Oooo`030000
oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2I
oooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo
08koool005_oool00ol0VOooooooo`0aoooo0P0008ooool005_oool00ol0VOooooooo`0aoooo00<0
003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003ooooo
ool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Wooooo
ool0<Oooo`80002?oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?oo
ooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOoo
ooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Fooo
o`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000
oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2I
oooooooo02Woool500000oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0[oooo00<0
003oooooool00oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0[oooo00<0003ooooo
ool00oooo`<0002>oooo001Koooo00?o09Woooooool0:oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Koooo00?o09Woooooool0:oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Koooo00?o09Woooooool0:_ooo`800005oooo00<0003oooooool0S_ooo`00Foooo`03o`2I
oooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo
08koool005_oool00ol0VOooooooo`0aoooo0P0008ooool005_oool00ol0VOooooooo`0aoooo00<0
003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003ooooo
ool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Wooooo
ool0<Oooo`80002?oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?oo
ooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOoo
ooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Fooo
o`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000
oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2I
oooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo
08koool005_oool00ol0VOooooooo`0aoooo0P0008ooool005_oool00ol0VOooooooo`0aoooo00<0
003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0Moooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo01ooool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo
01ooool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Koooo00?o09Wooooo
ool07oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool005_oool00ol0VOoo
ooooo`0Ooooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001K
oooo00?o09Woooooool07_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003ooooo
ool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?oo
ooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOoo
ooooo`0aoooo0P0008ooool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Fooo
o`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000
oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2I
oooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`80002?oooo001K
oooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0
003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003ooooo
ool0S_ooo`00Foooo`03o`2Ioooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo02Woool400001?oo
o`030000oooooooo08koool005_oool00ol0VOooooooo`0Yoooo00<0003oooooool01Oooo`030000
oooooooo08koool005_oool00ol0VOooooooo`0Zoooo00<0003oooooool01?ooo`<0002>oooo001K
oooo00?o09Woooooool0:oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0:Oooo`040000oooooooo00001?ooo`030000oooooooo08koool005_oool00ol0VOoo
ooooo`0Zoooo0P0000Goool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000
oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2I
oooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001K
oooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0
003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o
09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo0P0008ooool0
05_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool0
0ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2Ioooooooo037oool00`000?oo
ooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`80002?oooo001Koooo00?o09Woooooool0<Ooo
o`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Fooo
o`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool0<Oooo`030000
oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0003oooooool0S_ooo`00Foooo`03o`2I
oooooooo037oool20000Soooo`00Foooo`03o`2Ioooooooo037oool00`000?ooooooo`2>oooo001K
oooo00?o09Woooooool0<Oooo`030000oooooooo08koool005_oool00ol0VOooooooo`0aoooo00<0
003oooooool0S_ooo`00Foooo`03o`2Ioooooooo01goool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001Koooo00?o09Woooooool07Oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Koooo00?o09Woooooool07_ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`@00003
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool00`000?oo
ooooo`03oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool00009oooo00<0003oooooool01Oooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000[oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0
003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P00
00Coool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.29205 .04578 L
.29779 .04578 L
.30316 .04578 L
.3056 .04578 L
.30791 .04578 L
.30919 .04578 L
s
.30919 .04578 m
.30937 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool0
05goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool0
0`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool0
0ol0VOooooooo`0_oooo0P0008ooool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_oo
o`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;ooo
o`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOoo
o`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`80002?
oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_
oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001M
oooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0
003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool20000Soooo`00GOooo`03o`2Ioooooooo
02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool0
05goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool0
0`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool0
0ol0VOooooooo`0_oooo0P0008ooool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_oo
o`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;ooo
o`030000oooooooo08koool005goool00ol0VOooooooo`0Loooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo01_oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool06oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00GOooo`03o`2Ioooooooo01_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool005goool00ol0VOooooooo`0K
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005goool0
0ol0VOooooooo`0Loooo0P0000[oool300001?ooo`030000oooooooo08koool005goool00ol0VOoo
ooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>
oooo001Moooo00?o09Woooooool0;oooo`80002?oooo001Moooo00?o09Woooooool0;oooo`030000
oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2I
oooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo
08koool005goool00ol0VOooooooo`0_oooo0P0008ooool005goool00ol0VOooooooo`0_oooo00<0
003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o
09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003ooooo
ool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Wooooo
ool0;oooo`80002?oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool0
0ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOoo
ooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool20000Soooo`00GOoo
o`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000
oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2I
oooooooo02Ooool500000oooo`030000oooooooo08koool005goool00ol0VOooooooo`0Yoooo00<0
003oooooool00oooo`030000oooooooo08koool005goool00ol0VOooooooo`0Yoooo00<0003ooooo
ool00oooo`<0002>oooo001Moooo00?o09Woooooool0:Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Moooo00?o09Woooooool0:Oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Moooo00?o09Woooooool0:?ooo`800005oooo00<0003oooooool0S_ooo`00GOooo`03o`2I
oooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo
08koool005goool00ol0VOooooooo`0_oooo0P0008ooool005goool00ol0VOooooooo`0_oooo00<0
003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o
09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003ooooo
ool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Wooooo
ool0;oooo`80002?oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool0
0ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOoo
ooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool20000Soooo`00GOoo
o`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000
oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2I
oooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo
08koool005goool00ol0VOooooooo`0_oooo0P0008ooool005goool00ol0VOooooooo`0_oooo00<0
003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o
09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0Koooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo01goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo
01goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Moooo00?o09Wooooo
ool07Oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool005goool00ol0VOoo
ooooo`0Moooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001M
oooo00?o09Woooooool07?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Moooo00?o
09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003ooooo
ool0S_ooo`00GOooo`03o`2Ioooooooo02ooool20000Soooo`00GOooo`03o`2Ioooooooo02ooool0
0`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool0
0ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOoo
ooooo`0_oooo0P0008ooool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOoo
o`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000
oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2I
oooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`80002?oooo001M
oooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0
003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o
09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003ooooo
ool0S_ooo`00GOooo`03o`2Ioooooooo02ooool20000Soooo`00GOooo`03o`2Ioooooooo02ooool0
0`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool0
0ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02Ooool400001?oo
o`030000oooooooo08koool005goool00ol0VOooooooo`0Woooo00<0003oooooool01Oooo`030000
oooooooo08koool005goool00ol0VOooooooo`0Xoooo00<0003oooooool01?ooo`<0002>oooo001M
oooo00?o09Woooooool0:Oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Moooo00?o
09Woooooool09oooo`040000oooooooo00001?ooo`030000oooooooo08koool005goool00ol0VOoo
ooooo`0Xoooo0P0000Goool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000
oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2I
oooooooo02ooool20000Soooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001M
oooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0
003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o
09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo0P0008ooool0
05goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool0
0`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool0
0ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2Ioooooooo02ooool00`000?oo
ooooo`2>oooo001Moooo00?o09Woooooool0;oooo`80002?oooo001Moooo00?o09Woooooool0;ooo
o`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOoo
o`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool0;oooo`030000
oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0003oooooool0S_ooo`00GOooo`03o`2I
oooooooo02ooool20000Soooo`00GOooo`03o`2Ioooooooo02ooool00`000?ooooooo`2>oooo001M
oooo00?o09Woooooool0;oooo`030000oooooooo08koool005goool00ol0VOooooooo`0_oooo00<0
003oooooool0S_ooo`00GOooo`03o`2Ioooooooo01_oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001Moooo00?o09Woooooool06oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Moooo00?o09Woooooool07?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`@00003
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00<0003oooooool01?oo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000
oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0001;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.29205 .04578 L
.30316 .04578 L
.30791 .04578 L
.31304 .04578 L
.31454 .04578 L
.31597 .04578 L
.31725 .04578 L
s
.31725 .04578 m
.31743 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooool0V@06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool0
05ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool0
0`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool0
0ol0VOooooooo`0]oooo0P0008ooool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_oo
o`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Ooo
o`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Gooo
o`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`80002?
oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]
oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001O
oooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo
02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool0
05ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool0
0`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool0
0ol0VOooooooo`0]oooo0P0008ooool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_oo
o`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Ooo
o`030000oooooooo08koool005ooool00ol0VOooooooo`0Joooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo01Woool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool06Oooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00Goooo`03o`2Ioooooooo01Woool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0I
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005ooool0
0ol0VOooooooo`0Joooo0P0000[oool300001?ooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>
oooo001Ooooo00?o09Woooooool0;Oooo`80002?oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo
08koool005ooool00ol0VOooooooo`0]oooo0P0008ooool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o
09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003ooooo
ool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Wooooo
ool0;Oooo`80002?oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool0
0ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Gooo
o`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02Goool500000oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0Woooo00<0
003oooooool00oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0Woooo00<0003ooooo
ool00oooo`<0002>oooo001Ooooo00?o09Woooooool09oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Ooooo00?o09Woooooool09oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Ooooo00?o09Woooooool09_ooo`800005oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo
08koool005ooool00ol0VOooooooo`0]oooo0P0008ooool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o
09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003ooooo
ool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Wooooo
ool0;Oooo`80002?oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool0
0ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Gooo
o`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo
08koool005ooool00ol0VOooooooo`0]oooo0P0008ooool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o
09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0Ioooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo
01_oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Ooooo00?o09Wooooo
ool06oooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0Koooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001O
oooo00?o09Woooooool06_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Ooooo00?o
09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003ooooo
ool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool0
0`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool0
0ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0]oooo0P0008ooool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Gooo
o`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`80002?oooo001O
oooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o
09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003ooooo
ool0S_ooo`00Goooo`03o`2Ioooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool0
0`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool0
0ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02Goool400001?oo
o`030000oooooooo08koool005ooool00ol0VOooooooo`0Uoooo00<0003oooooool01Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0Voooo00<0003oooooool01?ooo`<0002>oooo001O
oooo00?o09Woooooool09oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Ooooo00?o
09Woooooool09Oooo`040000oooooooo00001?ooo`030000oooooooo08koool005ooool00ol0VOoo
ooooo`0Voooo0P0000Goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001O
oooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o
09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo0P0008ooool0
05ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool0
0`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool0
0ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2Ioooooooo02goool00`000?oo
ooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`80002?oooo001Ooooo00?o09Woooooool0;Ooo
o`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Gooo
o`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool0;Oooo`030000
oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0003oooooool0S_ooo`00Goooo`03o`2I
oooooooo02goool20000Soooo`00Goooo`03o`2Ioooooooo02goool00`000?ooooooo`2>oooo001O
oooo00?o09Woooooool0;Oooo`030000oooooooo08koool005ooool00ol0VOooooooo`0]oooo00<0
003oooooool0S_ooo`00Goooo`03o`2Ioooooooo01Woool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001Ooooo00?o09Woooooool06Oooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Ooooo00?o09Woooooool06_ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000oooo`D00002
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000[oool01@000?oo
ooooooooo`000002oooo00D0003oooooooooool00000Moooo`00M?ooo`030000oooooooo00;oool0
0`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo
00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`00
00[oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003ooooo
ooooool000005Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`03
oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.30316 .04578 L
.31323 .04578 L
.31875 .04578 L
.32145 .04578 L
.32263 .04578 L
.32392 .04578 L
.32509 .04578 L
s
.32509 .04578 m
.32536 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool01@000?ooooooooooool0V@04oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo
08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo
02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0
067oool00ol0VOooooooo`0[oooo0P0008ooool0067oool00ol0VOooooooo`0[oooo00<0003ooooo
ool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Wooooo
ool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_oo
o`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:ooo
o`80002?oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOoo
ooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>
oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[
oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool20000Soooo`00HOooo`03o`2I
oooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo
08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo
02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0
067oool00ol0VOooooooo`0[oooo0P0008ooool0067oool00ol0VOooooooo`0[oooo00<0003ooooo
ool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Wooooo
ool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0Hoooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo01Ooool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool05ooo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00HOooo`03o`2Ioooooooo
01Ooool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool0067oool00ol0VOoo
ooooo`0Goooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
067oool00ol0VOooooooo`0Hoooo0P0000[oool300001?ooo`030000oooooooo08koool0067oool0
0ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?oo
ooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`80002?oooo001Qoooo00?o09Woooooool0:ooo
o`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOoo
o`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000
oooooooo08koool0067oool00ol0VOooooooo`0[oooo0P0008ooool0067oool00ol0VOooooooo`0[
oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Q
oooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0
003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o
09Woooooool0:oooo`80002?oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0
067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool0
0`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool0
0ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool20000Sooo
o`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:ooo
o`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOoo
o`03o`2Ioooooooo02?oool500000oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0U
oooo00<0003oooooool00oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0Uoooo00<0
003oooooool00oooo`<0002>oooo001Qoooo00?o09Woooooool09Oooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo001Qoooo00?o09Woooooool09Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Qoooo00?o09Woooooool09?ooo`800005oooo00<0003oooooool0S_ooo`00HOoo
o`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o09Woooooool0:oooo`030000
oooooooo08koool0067oool00ol0VOooooooo`0[oooo0P0008ooool0067oool00ol0VOooooooo`0[
oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Q
oooo00?o09Woooooool0:oooo`030000oooooooo08koool0067oool00ol0VOooooooo`0[oooo00<0
003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool00`000?ooooooo`2>oooo001Qoooo00?o
09Woooooool0:oooo`80002?oooo001Qoooo00?o09Woooooool0:oooo`030000oooooooo08koool0
067oool00ol0VOooooooo`0[oooo00<0003oooooool0S_ooo`00HOooo`03o`2Ioooooooo02_oool0
0`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool0
0ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02[oool20000Sooo
o`00H_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_oo
o`030000oooooooo08koool006;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_oo
o`03o`2Ioooooooo02[oool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_ooo`030000
oooooooo08koool006;oool00ol0VOooooooo`0Zoooo0P0008ooool006;oool00ol0VOooooooo`0Z
oooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`2>oooo001R
oooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Foooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00H_ooo`03o`2I
oooooooo01Soool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Roooo00?o
09Woooooool06?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool006;oool0
0ol0VOooooooo`0Hoooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001Roooo00?o09Woooooool05oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001R
oooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Zoooo00<0
003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02[oool20000Soooo`00H_ooo`03o`2Ioooooooo
02[oool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_ooo`030000oooooooo08koool0
06;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02[oool0
0`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool0
0ol0VOooooooo`0Zoooo0P0008ooool006;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_oo
o`00H_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_oo
o`030000oooooooo08koool006;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_oo
o`03o`2Ioooooooo02[oool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_ooo`80002?
oooo001Roooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Z
oooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`2>oooo001R
oooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Zoooo00<0
003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02[oool20000Soooo`00H_ooo`03o`2Ioooooooo
02[oool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_ooo`030000oooooooo08koool0
06;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02;oool4
00001?ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Roooo00<0003oooooool01Ooo
o`030000oooooooo08koool006;oool00ol0VOooooooo`0Soooo00<0003oooooool01?ooo`<0002>
oooo001Roooo00?o09Woooooool09?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001R
oooo00?o09Woooooool08_ooo`040000oooooooo00001?ooo`030000oooooooo08koool006;oool0
0ol0VOooooooo`0Soooo0P0000Goool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_oo
o`030000oooooooo08koool006;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_oo
o`03o`2Ioooooooo02[oool20000Soooo`00H_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`2>
oooo001Roooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Z
oooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`2>oooo001R
oooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Zoooo0P00
08ooool006;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo
02[oool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_ooo`030000oooooooo08koool0
06;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo02[oool0
0`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_ooo`80002?oooo001Roooo00?o09Wooooo
ool0:_ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_oo
o`00H_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool0:_oo
o`030000oooooooo08koool006;oool00ol0VOooooooo`0Zoooo00<0003oooooool0S_ooo`00H_oo
o`03o`2Ioooooooo02[oool20000Soooo`00H_ooo`03o`2Ioooooooo02[oool00`000?ooooooo`2>
oooo001Roooo00?o09Woooooool0:_ooo`030000oooooooo08koool006;oool00ol0VOooooooo`0Z
oooo00<0003oooooool0S_ooo`00H_ooo`03o`2Ioooooooo01Koool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool05_ooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Roooo00?o09Woooooool05oooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200000ooo
o`D00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool0000:oooo00<0003ooooo
ool00_ooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001;oool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`0000[oool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_ooo`800003
oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.30316 .04578 L
.31323 .04578 L
.32392 .04578 L
.32831 .04578 L
.33073 .04578 L
.33193 .04578 L
.33304 .04578 L
s
.33304 .04578 m
.33336 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`04oooo00?o09Woool000001ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool0
06Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool0
0`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool0
0ol0VOooooooo`0Xoooo0P0008ooool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_oo
o`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?oo
o`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?oo
o`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`80002?
oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0X
oooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001T
oooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0
003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool20000Soooo`00I?ooo`03o`2Ioooooooo
02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool0
06Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool0
0`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool0
0ol0VOooooooo`0Xoooo0P0008ooool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_oo
o`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?oo
o`030000oooooooo08koool006Coool00ol0VOooooooo`0Eoooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo01Coool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool05?ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00I?ooo`03o`2Ioooooooo01Coool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool006Coool00ol0VOooooooo`0D
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006Coool0
0ol0VOooooooo`0Eoooo0P0000[oool300001?ooo`030000oooooooo08koool006Coool00ol0VOoo
ooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>
oooo001Toooo00?o09Woooooool0:?ooo`80002?oooo001Toooo00?o09Woooooool0:?ooo`030000
oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2I
oooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo
08koool006Coool00ol0VOooooooo`0Xoooo0P0008ooool006Coool00ol0VOooooooo`0Xoooo00<0
003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o
09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003ooooo
ool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Wooooo
ool0:?ooo`80002?oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool0
0ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOoo
ooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool20000Soooo`00I?oo
o`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000
oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2I
oooooooo023oool500000oooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Roooo00<0
003oooooool00oooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Roooo00<0003ooooo
ool00oooo`<0002>oooo001Toooo00?o09Woooooool08_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Toooo00?o09Woooooool08_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Toooo00?o09Woooooool08Oooo`800005oooo00<0003oooooool0S_ooo`00I?ooo`03o`2I
oooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo
08koool006Coool00ol0VOooooooo`0Xoooo0P0008ooool006Coool00ol0VOooooooo`0Xoooo00<0
003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o
09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003ooooo
ool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Wooooo
ool0:?ooo`80002?oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool0
0ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOoo
ooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool20000Soooo`00I?oo
o`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000
oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2I
oooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo
08koool006Coool00ol0VOooooooo`0Xoooo0P0008ooool006Coool00ol0VOooooooo`0Xoooo00<0
003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o
09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Doooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo
01Koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Toooo00?o09Wooooo
ool05_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool006Coool00ol0VOoo
ooooo`0Foooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001T
oooo00?o09Woooooool05Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Toooo00?o
09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003ooooo
ool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool20000Soooo`00I?ooo`03o`2Ioooooooo02Soool0
0`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool0
0ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOoo
ooooo`0Xoooo0P0008ooool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?oo
o`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000
oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2I
oooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`80002?oooo001T
oooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0
003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o
09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003ooooo
ool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool20000Soooo`00I?ooo`03o`2Ioooooooo02Soool0
0`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool0
0ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo023oool400001?oo
o`030000oooooooo08koool006Coool00ol0VOooooooo`0Poooo00<0003oooooool01Oooo`030000
oooooooo08koool006Coool00ol0VOooooooo`0Qoooo00<0003oooooool01?ooo`<0002>oooo001T
oooo00?o09Woooooool08_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Toooo00?o
09Woooooool08?ooo`040000oooooooo00001?ooo`030000oooooooo08koool006Coool00ol0VOoo
ooooo`0Qoooo0P0000Goool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000
oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2I
oooooooo02Soool20000Soooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001T
oooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0
003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o
09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo0P0008ooool0
06Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool0
0`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool0
0ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo02Soool00`000?oo
ooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`80002?oooo001Toooo00?o09Woooooool0:?oo
o`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?oo
o`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool0:?ooo`030000
oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0003oooooool0S_ooo`00I?ooo`03o`2I
oooooooo02Soool20000Soooo`00I?ooo`03o`2Ioooooooo02Soool00`000?ooooooo`2>oooo001T
oooo00?o09Woooooool0:?ooo`030000oooooooo08koool006Coool00ol0VOooooooo`0Xoooo00<0
003oooooool0S_ooo`00I?ooo`03o`2Ioooooooo01Coool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001Toooo00?o09Woooooool05?ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Toooo00?o09Woooooool05Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003ooooo
ool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`0000Goool0
0`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Boooo00@0
003oooooool00008oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:
oooo0P0000Coool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -54.125 0 ]
[.5 .63053 54.125 13.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -115.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.625 moveto
(8) show
69.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.625 moveto
(,) show
84.563 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22045) show
128.375 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
136.188 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
148.188 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
152.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
161.250 13.625 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.30316 .04578 L
.31323 .04578 L
.32392 .04578 L
.33304 .04578 L
.33554 .04578 L
.33823 .04578 L
.33953 .04578 L
.34076 .04578 L
s
.34076 .04578 m
.34104 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -54.125 0 ]
[.5 .63053 54.125 13.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -115.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.625 moveto
(8) show
69.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.625 moveto
(,) show
84.563 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.22045) show
128.375 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
136.188 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
148.188 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
152.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
161.250 13.625 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Koool200009_ooo`@0000Uoooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Coool400009_ooo`80000Eoooo000Eoooo00@0003oooooool0000Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09?ooo`030000oooooooo
02Koool010000?ooooooo`0001Coool001Ooool00`000?ooooooo`0Uoooo00<0003oooooool09ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Ooool00`000?ooooooo`0Coooo000?oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Noooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Koool00`000?ooooooo`0Woooo00<0003oooooool04_ooo`005Oooo`040000oooooooo
00009Oooo`040000oooooooo00009oooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09?ooo`040000oooooooo00009Oooo`040000oooooooo00005?ooo`005_ooo`80000W
oooo0P0002Ooool200009Oooo`80000Voooo0P0002Ooool200009oooo`80000Eoooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000kooooo0000100000ooool0
01Coool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?oo
ooooo`06oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0
003oooooool01_ooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Ooo
o`030000oooooooo00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo
00Goool00`000?ooooooo`0Coooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool0
06Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool0
0`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool0
0ol0VOooooooo`0Voooo0P0008ooool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_oo
o`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_oo
o`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_oo
o`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`80002?
oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0V
oooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001V
oooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0
003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool20000Soooo`00I_ooo`03o`2Ioooooooo
02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool0
06Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool0
0`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`80002?oooo001Voooo00?o09Wooooo
ool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_oo
o`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool04ooo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo08koool006Koool00ol0VOooooooo`0B
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00I_oo
o`03o`2Ioooooooo01;oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0008koool0
06Koool00ol0VOooooooo`0Boooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`2>
oooo001Voooo00?o09Woooooool04_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`2>oooo001Voooo00?o09Woooooool04oooo`80000:oooo0`0000Coool00`000?oo
ooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOoo
ooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool20000Soooo`00I_oo
o`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000
oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2I
oooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo
08koool006Koool00ol0VOooooooo`0Voooo0P0008ooool006Koool00ol0VOooooooo`0Voooo00<0
003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o
09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003ooooo
ool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Wooooo
ool09_ooo`80002?oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool0
0ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?oo
ooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOoo
ooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool20000Soooo`00I_oo
o`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000
oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2I
oooooooo01koool500000oooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Poooo00<0
003oooooool00oooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Poooo00<0003ooooo
ool00oooo`<0002>oooo001Voooo00?o09Woooooool08?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Voooo00?o09Woooooool08?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Voooo00?o09Woooooool07oooo`800005oooo00<0003oooooool0S_ooo`00I_ooo`03o`2I
oooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo
08koool006Koool00ol0VOooooooo`0Voooo0P0008ooool006Koool00ol0VOooooooo`0Voooo00<0
003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o
09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003ooooo
ool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Wooooo
ool09_ooo`80002?oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool0
0ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?oo
ooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOoo
ooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool20000Soooo`00I_oo
o`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000
oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2I
oooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo
08koool006Koool00ol0VOooooooo`0Voooo0P0008ooool006Koool00ol0VOooooooo`0Voooo00<0
003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o
09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Boooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Voooo00?o09Wooooo
ool05?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool006Koool00ol0VOoo
ooooo`0Doooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001V
oooo00?o09Woooooool04oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Voooo00?o
09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003ooooo
ool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool20000Soooo`00I_ooo`03o`2Ioooooooo02Koool0
0`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool0
0ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?oo
ooooo`2>oooo001Voooo00?o09Woooooool09_ooo`80002?oooo001Voooo00?o09Woooooool09_oo
o`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_oo
o`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000
oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2I
oooooooo02Koool20000Soooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001V
oooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0
003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o
09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo0P0008ooool0
06Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool0
0`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool0
0ol0VOooooooo`0Noooo100000Coool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool07_oo
o`030000oooooooo00Goool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool07oooo`030000
oooooooo00Coool30000S_ooo`00I_ooo`03o`2Ioooooooo023oool00`000?ooooooo`03oooo00<0
003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo01koool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo001Voooo00?o09Woooooool07oooo`800005oooo00<0003oooooool0S_ooo`00I_oo
o`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000
oooooooo08koool006Koool00ol0VOooooooo`0Voooo0P0008ooool006Koool00ol0VOooooooo`0V
oooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001V
oooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0
003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o
09Woooooool09_ooo`80002?oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool0
06Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool0
0`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool0
0ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool20000Sooo
o`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_oo
o`030000oooooooo08koool006Koool00ol0VOooooooo`0Voooo00<0003oooooool0S_ooo`00I_oo
o`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001Voooo00?o09Woooooool09_ooo`030000
oooooooo08koool006Koool00ol0VOooooooo`0Voooo0P0008ooool006Koool00ol0VOooooooo`0V
oooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo02Koool00`000?ooooooo`2>oooo001V
oooo00?o09Woooooool09_ooo`030000oooooooo08koool006Koool00ol0VOooooooo`0Boooo1000
00?oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00I_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`09oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00I_ooo`03o`2I
oooooooo01?oool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0002>oooo001moooo00<0
003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00Goooo`030000oooooooo
05coool00`000?ooooooo`1Ooooo001Noooo00<0003oooooool02?ooo`030000oooooooo05?oool0
0`000?ooooooo`1Noooo001Noooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01Ooo
o`@00003oooo0P0000?oool400000_ooo`@00003oooo0P0000Goool300000_ooo`800005oooo00D0
003oooooooooool000000oooo`D00002oooo0P00017oool00`000?ooooooo`1Noooo001Noooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003ooooo
ool02Oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00@0003oooooool00005oooo00@0
003oooooool00002oooo00<0003oooooool00oooo`030000oooo000000Koool01@000?oooooooooo
o`000002oooo00<0003oooooool03_ooo`030000oooooooo05koool005goool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003ooooo
ool00_ooo`040000oooooooo00000_ooo`D00004oooo00<0003oooooool01?ooo`030000oooooooo
00Goool01@000?ooooooooooo`000002oooo00<0003oooooool03oooo`030000oooooooo05goool0
05koool00`000?ooooooo`0500003Oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00D0
003oooooooooool000000_ooo`040000oooooooo00000_ooo`040000oooooooooooo0P0000Koool0
0`000?ooo`000006oooo00D0003oooooooooool000000_ooo`030000oooooooo00koool00`000?oo
ooooo`1Noooo001Noooo00D0003oooooooooool000003_ooo`040000oooooooo00002?ooo`040000
oooooooo00000_ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooo0000
00?oool00`000?ooooooo`04oooo00D0003oooooooooool000001Oooo`050000oooooooooooo0000
00;oool00`000?ooooooo`04oooo0P0000;oool300000oooo`030000oooooooo05koool005ooool0
0`000?ooooooo`0@oooo0P0000[oool200001?ooo`800004oooo0P0000Goool200000oooo`<0000=
oooo0P0000Coool200000oooo`<00002oooo00H0003oooooool0003oool00002oooo00<0003ooooo
ool0Goooo`00]_ooo`030000oooooooo0080001Uoooo002eoooo0P0000;oool30000I?ooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.49265, \
-0.206556, 0.0243443, 0.0168814}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.49265, -0.206556, 0.0243443, 0.0168814}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.33304 .04578 L
.33788 .04578 L
.34309 .04578 L
.34566 .04578 L
.34693 .04578 L
.34811 .04578 L
.34918 .04578 L
s
.34918 .04578 m
.34946 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo09T01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool0
06Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool0
0ol0VOooooooo`0Toooo0P0008ooool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_oo
o`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?oo
o`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?oo
o`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`80002?
oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0T
oooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001X
oooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0
003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool20000Soooo`00J?ooo`03o`2Ioooooooo
02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool0
06Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool0
0ol0VOooooooo`0Toooo0P0008ooool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_oo
o`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?oo
o`030000oooooooo08koool006Soool00ol0VOooooooo`0Aoooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo013oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool04?ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00J?ooo`03o`2Ioooooooo013oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool006Soool00ol0VOooooooo`0@
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006Soool0
0ol0VOooooooo`0Aoooo0P0000[oool300001?ooo`030000oooooooo08koool006Soool00ol0VOoo
ooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>
oooo001Xoooo00?o09Woooooool09?ooo`80002?oooo001Xoooo00?o09Woooooool09?ooo`030000
oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2I
oooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo
08koool006Soool00ol0VOooooooo`0Toooo0P0008ooool006Soool00ol0VOooooooo`0Toooo00<0
003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o
09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003ooooo
ool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Wooooo
ool09?ooo`80002?oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool0
0ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOoo
ooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool20000Soooo`00J?oo
o`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000
oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2I
oooooooo01coool500000oooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Noooo00<0
003oooooool00oooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Noooo00<0003ooooo
ool00oooo`<0002>oooo001Xoooo00?o09Woooooool07_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Xoooo00?o09Woooooool07_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001Xoooo00?o09Woooooool07Oooo`800005oooo00<0003oooooool0S_ooo`00J?ooo`03o`2I
oooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo
08koool006Soool00ol0VOooooooo`0Toooo0P0008ooool006Soool00ol0VOooooooo`0Toooo00<0
003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o
09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003ooooo
ool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Wooooo
ool09?ooo`80002?oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool0
0ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOoo
ooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool20000Soooo`00J?oo
o`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000
oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2I
oooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo
08koool006Soool00ol0VOooooooo`0Toooo0P0008ooool006Soool00ol0VOooooooo`0Toooo00<0
003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o
09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0@oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo01;oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo
01;oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Xoooo00?o09Wooooo
ool04_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool006Soool00ol0VOoo
ooooo`0Boooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001X
oooo00?o09Woooooool04Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Xoooo00?o
09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003ooooo
ool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool20000Soooo`00J?ooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool0
0ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOoo
ooooo`0Toooo0P0008ooool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?oo
o`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000
oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2I
oooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`80002?oooo001X
oooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0
003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o
09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003ooooo
ool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool20000Soooo`00J?ooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool0
0ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo01coool400001?oo
o`030000oooooooo08koool006Soool00ol0VOooooooo`0Loooo00<0003oooooool01Oooo`030000
oooooooo08koool006Soool00ol0VOooooooo`0Moooo00<0003oooooool01?ooo`<0002>oooo001X
oooo00?o09Woooooool07_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Xoooo00?o
09Woooooool07?ooo`040000oooooooo00001?ooo`030000oooooooo08koool006Soool00ol0VOoo
ooooo`0Moooo0P0000Goool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000
oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2I
oooooooo02Coool20000Soooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001X
oooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0
003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o
09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo0P0008ooool0
06Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool0
0`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool0
0ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo02Coool00`000?oo
ooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`80002?oooo001Xoooo00?o09Woooooool09?oo
o`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?oo
o`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool09?ooo`030000
oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0003oooooool0S_ooo`00J?ooo`03o`2I
oooooooo02Coool20000Soooo`00J?ooo`03o`2Ioooooooo02Coool00`000?ooooooo`2>oooo001X
oooo00?o09Woooooool09?ooo`030000oooooooo08koool006Soool00ol0VOooooooo`0Toooo00<0
003oooooool0S_ooo`00J?ooo`03o`2Ioooooooo013oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001Xoooo00?o09Woooooool04?ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001Xoooo00?o09Woooooool04Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003ooooo
ool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.33304 .04578 L
.34309 .04578 L
.34772 .04578 L
.35028 .04578 L
.35271 .04578 L
.35496 .04578 L
.35624 .04578 L
s
.35624 .04578 m
.35653 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00D0003ooooooooooooo
09T00oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo
08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo
02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool0
06[oool00ol0VOooooooo`0Roooo0P0008ooool006[oool00ol0VOooooooo`0Roooo00<0003ooooo
ool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Wooooo
ool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_oo
o`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_oo
o`80002?oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOoo
ooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>
oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0R
oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool20000Soooo`00J_ooo`03o`2I
oooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo
08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo
02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool0
06[oool00ol0VOooooooo`0Roooo0P0008ooool006[oool00ol0VOooooooo`0Roooo00<0003ooooo
ool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Wooooo
ool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0?oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo00koool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool03_oo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00J_ooo`03o`2Ioooooooo
00koool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool006[oool00ol0VOoo
ooooo`0>oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
06[oool00ol0VOooooooo`0?oooo0P0000[oool300001?ooo`030000oooooooo08koool006[oool0
0ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?oo
ooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`80002?oooo001Zoooo00?o09Woooooool08_oo
o`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_oo
o`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000
oooooooo08koool006[oool00ol0VOooooooo`0Roooo0P0008ooool006[oool00ol0VOooooooo`0R
oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Z
oooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0
003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o
09Woooooool08_ooo`80002?oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool0
06[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool0
0`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool0
0ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool20000Sooo
o`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_oo
o`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_oo
o`03o`2Ioooooooo01[oool500000oooo`030000oooooooo08koool006[oool00ol0VOooooooo`0L
oooo00<0003oooooool00oooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Loooo00<0
003oooooool00oooo`<0002>oooo001Zoooo00?o09Woooooool07?ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo001Zoooo00?o09Woooooool07?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001Zoooo00?o09Woooooool06oooo`800005oooo00<0003oooooool0S_ooo`00J_oo
o`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000
oooooooo08koool006[oool00ol0VOooooooo`0Roooo0P0008ooool006[oool00ol0VOooooooo`0R
oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Z
oooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0
003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o
09Woooooool08_ooo`80002?oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool0
06[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool0
0`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool0
0ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool20000Sooo
o`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_oo
o`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_oo
o`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000
oooooooo08koool006[oool00ol0VOooooooo`0Roooo0P0008ooool006[oool00ol0VOooooooo`0R
oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Z
oooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0>oooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00J_ooo`03o`2I
oooooooo013oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001Zoooo00?o
09Woooooool04?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool006[oool0
0ol0VOooooooo`0@oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001Zoooo00?o09Woooooool03oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001Z
oooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0
003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool20000Soooo`00J_ooo`03o`2Ioooooooo
02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool0
06[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool0
0`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool0
0ol0VOooooooo`0Roooo0P0008ooool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_oo
o`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_oo
o`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_oo
o`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`80002?
oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0R
oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Z
oooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0
003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool20000Soooo`00J_ooo`03o`2Ioooooooo
02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool0
06[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo01[oool4
00001?ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Joooo00<0003oooooool01Ooo
o`030000oooooooo08koool006[oool00ol0VOooooooo`0Koooo00<0003oooooool01?ooo`<0002>
oooo001Zoooo00?o09Woooooool07?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001Z
oooo00?o09Woooooool06_ooo`040000oooooooo00001?ooo`030000oooooooo08koool006[oool0
0ol0VOooooooo`0Koooo0P0000Goool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_oo
o`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_oo
o`03o`2Ioooooooo02;oool20000Soooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>
oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0R
oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Z
oooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo0P00
08ooool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo
02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool0
06[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo02;oool0
0`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_ooo`80002?oooo001Zoooo00?o09Wooooo
ool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_oo
o`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool08_oo
o`030000oooooooo08koool006[oool00ol0VOooooooo`0Roooo00<0003oooooool0S_ooo`00J_oo
o`03o`2Ioooooooo02;oool20000Soooo`00J_ooo`03o`2Ioooooooo02;oool00`000?ooooooo`2>
oooo001Zoooo00?o09Woooooool08_ooo`030000oooooooo08koool006[oool00ol0VOooooooo`0R
oooo00<0003oooooool0S_ooo`00J_ooo`03o`2Ioooooooo00koool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool03_ooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001Zoooo00?o09Woooooool03oooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000ooo
o`D00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?oo
ooooo`0000[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000
oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.34309 .04578 L
.35271 .04578 L
.35742 .04578 L
.36173 .04578 L
.36284 .04578 L
.36405 .04578 L
s
.36405 .04578 m
.36434 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool00ooo
o`03o`2Ioooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool0
06coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool0
0`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool0
0ol0VOooooooo`0Poooo0P0008ooool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_oo
o`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?oo
o`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?oo
o`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`80002?
oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0P
oooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/
oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0
003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool20000Soooo`00K?ooo`03o`2Ioooooooo
023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool0
06coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool0
0`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool0
0ol0VOooooooo`0Poooo0P0008ooool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_oo
o`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?oo
o`030000oooooooo08koool006coool00ol0VOooooooo`0=oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo00coool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool03?ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00K?ooo`03o`2Ioooooooo00coool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool006coool00ol0VOooooooo`0<
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006coool0
0ol0VOooooooo`0=oooo0P0000[oool300001?ooo`030000oooooooo08koool006coool00ol0VOoo
ooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>
oooo001/oooo00?o09Woooooool08?ooo`80002?oooo001/oooo00?o09Woooooool08?ooo`030000
oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2I
oooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo
08koool006coool00ol0VOooooooo`0Poooo0P0008ooool006coool00ol0VOooooooo`0Poooo00<0
003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o
09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003ooooo
ool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Wooooo
ool08?ooo`80002?oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool0
0ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOoo
ooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool20000Soooo`00K?oo
o`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000
oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2I
oooooooo01Soool500000oooo`030000oooooooo08koool006coool00ol0VOooooooo`0Joooo00<0
003oooooool00oooo`030000oooooooo08koool006coool00ol0VOooooooo`0Joooo00<0003ooooo
ool00oooo`<0002>oooo001/oooo00?o09Woooooool06_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001/oooo00?o09Woooooool06_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001/oooo00?o09Woooooool06Oooo`800005oooo00<0003oooooool0S_ooo`00K?ooo`03o`2I
oooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo
08koool006coool00ol0VOooooooo`0Poooo0P0008ooool006coool00ol0VOooooooo`0Poooo00<0
003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o
09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003ooooo
ool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Wooooo
ool08?ooo`80002?oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool0
0ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOoo
ooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool20000Soooo`00K?oo
o`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000
oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2I
oooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo
08koool006coool00ol0VOooooooo`0Poooo0P0008ooool006coool00ol0VOooooooo`0Poooo00<0
003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o
09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0<oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo00koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo
00koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001/oooo00?o09Wooooo
ool03_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool006coool00ol0VOoo
ooooo`0>oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001/
oooo00?o09Woooooool03Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001/oooo00?o
09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003ooooo
ool0S_ooo`00K?ooo`03o`2Ioooooooo023oool20000Soooo`00K?ooo`03o`2Ioooooooo023oool0
0`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool0
0ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOoo
ooooo`0Poooo0P0008ooool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?oo
o`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000
oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2I
oooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`80002?oooo001/
oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0
003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o
09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003ooooo
ool0S_ooo`00K?ooo`03o`2Ioooooooo023oool20000Soooo`00K?ooo`03o`2Ioooooooo023oool0
0`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool0
0ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo01Soool400001?oo
o`030000oooooooo08koool006coool00ol0VOooooooo`0Hoooo00<0003oooooool01Oooo`030000
oooooooo08koool006coool00ol0VOooooooo`0Ioooo00<0003oooooool01?ooo`<0002>oooo001/
oooo00?o09Woooooool06_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001/oooo00?o
09Woooooool06?ooo`040000oooooooo00001?ooo`030000oooooooo08koool006coool00ol0VOoo
ooooo`0Ioooo0P0000Goool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000
oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2I
oooooooo023oool20000Soooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/
oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0
003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o
09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo0P0008ooool0
06coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool0
0`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool0
0ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo023oool00`000?oo
ooooo`2>oooo001/oooo00?o09Woooooool08?ooo`80002?oooo001/oooo00?o09Woooooool08?oo
o`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?oo
o`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool08?ooo`030000
oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0003oooooool0S_ooo`00K?ooo`03o`2I
oooooooo023oool20000Soooo`00K?ooo`03o`2Ioooooooo023oool00`000?ooooooo`2>oooo001/
oooo00?o09Woooooool08?ooo`030000oooooooo08koool006coool00ol0VOooooooo`0Poooo00<0
003oooooool0S_ooo`00K?ooo`03o`2Ioooooooo00coool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001/oooo00?o09Woooooool03?ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001/oooo00?o09Woooooool03Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`D00002
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool0
00000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003ooooo
ool03Oooo`040000oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.34309 .04578 L
.36173 .04578 L
.36626 .04578 L
.36876 .04578 L
.37114 .04578 L
.37178 .04578 L
.37247 .04578 L
s
.37247 .04578 m
.37266 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool0
06koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool0
0`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool0
0ol0VOooooooo`0Noooo0P0008ooool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_oo
o`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_oo
o`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_oo
o`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`80002?
oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0N
oooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^
oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0
003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool20000Soooo`00K_ooo`03o`2Ioooooooo
01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool0
06koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool0
0`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool0
0ol0VOooooooo`0Noooo0P0008ooool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_oo
o`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_oo
o`030000oooooooo08koool006koool00ol0VOooooooo`0;oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo00[oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool02_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00K_ooo`03o`2Ioooooooo00[oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool006koool00ol0VOooooooo`0:
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006koool0
0ol0VOooooooo`0;oooo0P0000[oool300001?ooo`030000oooooooo08koool006koool00ol0VOoo
ooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>
oooo001^oooo00?o09Woooooool07_ooo`80002?oooo001^oooo00?o09Woooooool07_ooo`030000
oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2I
oooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo
08koool006koool00ol0VOooooooo`0Noooo0P0008ooool006koool00ol0VOooooooo`0Noooo00<0
003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o
09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003ooooo
ool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Wooooo
ool07_ooo`80002?oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool0
0ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?oo
ooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOoo
ooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool20000Soooo`00K_oo
o`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000
oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2I
oooooooo01Koool500000oooo`030000oooooooo08koool006koool00ol0VOooooooo`0Hoooo00<0
003oooooool00oooo`030000oooooooo08koool006koool00ol0VOooooooo`0Hoooo00<0003ooooo
ool00oooo`<0002>oooo001^oooo00?o09Woooooool06?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001^oooo00?o09Woooooool06?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001^oooo00?o09Woooooool05oooo`800005oooo00<0003oooooool0S_ooo`00K_ooo`03o`2I
oooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo
08koool006koool00ol0VOooooooo`0Noooo0P0008ooool006koool00ol0VOooooooo`0Noooo00<0
003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o
09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003ooooo
ool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Wooooo
ool07_ooo`80002?oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool0
0ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?oo
ooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOoo
ooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool20000Soooo`00K_oo
o`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000
oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2I
oooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo
08koool006koool00ol0VOooooooo`0Noooo0P0008ooool006koool00ol0VOooooooo`0Noooo00<0
003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o
09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0:oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo00coool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo
00coool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001^oooo00?o09Wooooo
ool03?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool006koool00ol0VOoo
ooooo`0<oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001^
oooo00?o09Woooooool02oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001^oooo00?o
09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003ooooo
ool0S_ooo`00K_ooo`03o`2Ioooooooo01koool20000Soooo`00K_ooo`03o`2Ioooooooo01koool0
0`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool0
0ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?oo
ooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOoo
ooooo`0Noooo0P0008ooool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_oo
o`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000
oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2I
oooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`80002?oooo001^
oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0
003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o
09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003ooooo
ool0S_ooo`00K_ooo`03o`2Ioooooooo01koool20000Soooo`00K_ooo`03o`2Ioooooooo01koool0
0`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool0
0ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01Koool400001?oo
o`030000oooooooo08koool006koool00ol0VOooooooo`0Foooo00<0003oooooool01Oooo`030000
oooooooo08koool006koool00ol0VOooooooo`0Goooo00<0003oooooool01?ooo`<0002>oooo001^
oooo00?o09Woooooool06?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001^oooo00?o
09Woooooool05_ooo`040000oooooooo00001?ooo`030000oooooooo08koool006koool00ol0VOoo
ooooo`0Goooo0P0000Goool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000
oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2I
oooooooo01koool20000Soooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^
oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0
003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o
09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo0P0008ooool0
06koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool0
0`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool0
0ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo01koool00`000?oo
ooooo`2>oooo001^oooo00?o09Woooooool07_ooo`80002?oooo001^oooo00?o09Woooooool07_oo
o`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_oo
o`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool07_ooo`030000
oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0003oooooool0S_ooo`00K_ooo`03o`2I
oooooooo01koool20000Soooo`00K_ooo`03o`2Ioooooooo01koool00`000?ooooooo`2>oooo001^
oooo00?o09Woooooool07_ooo`030000oooooooo08koool006koool00ol0VOooooooo`0Noooo00<0
003oooooool0S_ooo`00K_ooo`03o`2Ioooooooo00[oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001^oooo00?o09Woooooool02_ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001^oooo00?o09Woooooool02oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`@00003
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`030000oooooooo00Coool00`000?oo
ooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.34309 .04578 L
.36173 .04578 L
.37114 .04578 L
.37372 .04578 L
.37649 .04578 L
.37783 .04578 L
.3791 .04578 L
.38025 .04578 L
s
.38025 .04578 m
.38056 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000ooooo`2I00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0
073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool0
0`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool0
0ol0VOooooooo`0Loooo0P0008ooool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_oo
o`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?oo
o`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?oo
o`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`80002?
oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0L
oooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`
oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0
003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool20000Soooo`00L?ooo`03o`2Ioooooooo
01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0
073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool0
0`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool0
0ol0VOooooooo`0Loooo0P0008ooool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_oo
o`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?oo
o`030000oooooooo08koool0073oool00ol0VOooooooo`09oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo00Soool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool02?ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00L?ooo`03o`2Ioooooooo00Soool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool0073oool00ol0VOooooooo`08
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0073oool0
0ol0VOooooooo`09oooo0P0000[oool300001?ooo`030000oooooooo08koool0073oool00ol0VOoo
ooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>
oooo001`oooo00?o09Woooooool07?ooo`80002?oooo001`oooo00?o09Woooooool07?ooo`030000
oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2I
oooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo
08koool0073oool00ol0VOooooooo`0Loooo0P0008ooool0073oool00ol0VOooooooo`0Loooo00<0
003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o
09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003ooooo
ool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Wooooo
ool07?ooo`80002?oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool0
0ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?oo
ooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOoo
ooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool20000Soooo`00L?oo
o`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000
oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2I
oooooooo01Coool500000oooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Foooo00<0
003oooooool00oooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Foooo00<0003ooooo
ool00oooo`<0002>oooo001`oooo00?o09Woooooool05_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001`oooo00?o09Woooooool05_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001`oooo00?o09Woooooool05Oooo`800005oooo00<0003oooooool0S_ooo`00L?ooo`03o`2I
oooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo
08koool0073oool00ol0VOooooooo`0Loooo0P0008ooool0073oool00ol0VOooooooo`0Loooo00<0
003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o
09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003ooooo
ool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Wooooo
ool07?ooo`80002?oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool0
0ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?oo
ooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOoo
ooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool20000Soooo`00L?oo
o`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000
oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2I
oooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo
08koool0073oool00ol0VOooooooo`0Loooo0P0008ooool0073oool00ol0VOooooooo`0Loooo00<0
003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o
09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`08oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo
00[oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001`oooo00?o09Wooooo
ool02_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool0073oool00ol0VOoo
ooooo`0:oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001`
oooo00?o09Woooooool02Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001`oooo00?o
09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003ooooo
ool0S_ooo`00L?ooo`03o`2Ioooooooo01coool20000Soooo`00L?ooo`03o`2Ioooooooo01coool0
0`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool0
0ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?oo
ooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOoo
ooooo`0Loooo0P0008ooool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?oo
o`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000
oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2I
oooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`80002?oooo001`
oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0
003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o
09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003ooooo
ool0S_ooo`00L?ooo`03o`2Ioooooooo01coool20000Soooo`00L?ooo`03o`2Ioooooooo01coool0
0`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool0
0ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01Coool400001?oo
o`030000oooooooo08koool0073oool00ol0VOooooooo`0Doooo00<0003oooooool01Oooo`030000
oooooooo08koool0073oool00ol0VOooooooo`0Eoooo00<0003oooooool01?ooo`<0002>oooo001`
oooo00?o09Woooooool05_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001`oooo00?o
09Woooooool05?ooo`040000oooooooo00001?ooo`030000oooooooo08koool0073oool00ol0VOoo
ooooo`0Eoooo0P0000Goool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000
oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2I
oooooooo01coool20000Soooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`
oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0
003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o
09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo0P0008ooool0
073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool0
0`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool0
0ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo01coool00`000?oo
ooooo`2>oooo001`oooo00?o09Woooooool07?ooo`80002?oooo001`oooo00?o09Woooooool07?oo
o`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?oo
o`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool07?ooo`030000
oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0003oooooool0S_ooo`00L?ooo`03o`2I
oooooooo01coool20000Soooo`00L?ooo`03o`2Ioooooooo01coool00`000?ooooooo`2>oooo001`
oooo00?o09Woooooool07?ooo`030000oooooooo08koool0073oool00ol0VOooooooo`0Loooo00<0
003oooooool0S_ooo`00L?ooo`03o`2Ioooooooo00Soool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001`oooo00?o09Woooooool02?ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001`oooo00?o09Woooooool02Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`@00003
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00<0003oooooool00ooo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.36136 .04578 L
.37176 .04578 L
.37685 .04578 L
.3815 .04578 L
.38384 .04578 L
.3864 .04578 L
.38757 .04578 L
.38881 .04578 L
s
.38881 .04578 m
.38911 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`050000ooooooooooooo`2I00?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo001boooo00?o09Woooooool06_ooo`030000oooooooo
08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Wooooo
ool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_oo
o`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_oo
o`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOoo
ooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>
oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0J
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool20000Soooo`00L_ooo`03o`2I
oooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo
08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Wooooo
ool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`07oooo0P0000Coool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo00Koool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001boooo00?o09Woooooool01_oo
o`040000oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00L_ooo`03o`2Ioooooooo
00Koool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007;oool00ol0VOoo
ooooo`06oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`07oooo0P0000[oool300001?ooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?oo
ooooo`2>oooo001boooo00?o09Woooooool06_ooo`80002?oooo001boooo00?o09Woooooool06_oo
o`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_oo
o`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0J
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0
003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o
09Woooooool06_ooo`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool0
0`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool20000Sooo
o`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_oo
o`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_oo
o`03o`2Ioooooooo01;oool500000oooo`030000oooooooo08koool007;oool00ol0VOooooooo`0D
oooo00<0003oooooool00oooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Doooo00<0
003oooooool00oooo`<0002>oooo001boooo00?o09Woooooool05?ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo001boooo00?o09Woooooool05?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001boooo00?o09Woooooool04oooo`800005oooo00<0003oooooool0S_ooo`00L_oo
o`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0J
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0
003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o
09Woooooool06_ooo`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool0
0`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool20000Sooo
o`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_oo
o`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_oo
o`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0J
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`06oooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo00Soool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00L_ooo`03o`2I
oooooooo00Soool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001boooo00?o
09Woooooool02?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001boooo00?o09Woooooool01oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0
003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool20000Soooo`00L_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool0
0`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_oo
o`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_oo
o`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_oo
o`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`80002?
oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0J
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0
003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool20000Soooo`00L_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01;oool4
00001?ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Boooo00<0003oooooool01Ooo
o`030000oooooooo08koool007;oool00ol0VOooooooo`0Coooo00<0003oooooool01?ooo`<0002>
oooo001boooo00?o09Woooooool05?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool04_ooo`040000oooooooo00001?ooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`0Coooo0P0000Goool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_oo
o`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_oo
o`03o`2Ioooooooo01[oool20000Soooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>
oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0J
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo0P00
08ooool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool0
0`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`80002?oooo001boooo00?o09Wooooo
ool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_oo
o`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_oo
o`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_oo
o`03o`2Ioooooooo01[oool20000Soooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>
oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0J
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo00Koool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`2>oooo001boooo00?o09Woooooool01_ooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001boooo00?o09Woooooool01oooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000_oool01@000?ooooooooooo`00001moooo001koooo00D0
003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.36136 .04578 L
.37176 .04578 L
.3815 .04578 L
.39106 .04578 L
.39381 .04578 L
.39516 .04578 L
.39642 .04578 L
s
.39642 .04578 m
.39671 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00?oool00ol0VOooo`000007oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool0
07Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_oo
o`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?oo
o`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`80002?
oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0H
oooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001d
oooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool20000Soooo`00M?ooo`03o`2Ioooooooo
01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool0
07Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_oo
o`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?oo
o`030000oooooooo08koool007Coool00ol0VOooooooo`05oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo00Coool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001doooo00?o09Woooooool01?ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00M?ooo`03o`2Ioooooooo00Coool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007Coool00ol0VOooooooo`04
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`05oooo0P0000[oool300001?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>
oooo001doooo00?o09Woooooool06?ooo`80002?oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo
08koool007Coool00ol0VOooooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003ooooo
ool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Wooooo
ool06?ooo`80002?oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool20000Soooo`00M?oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo013oool500000oooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Boooo00<0
003oooooool00oooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Boooo00<0003ooooo
ool00oooo`<0002>oooo001doooo00?o09Woooooool04_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool04_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001doooo00?o09Woooooool04Oooo`800005oooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo
08koool007Coool00ol0VOooooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003ooooo
ool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Wooooo
ool06?ooo`80002?oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool20000Soooo`00M?oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo
08koool007Coool00ol0VOooooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`04oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo00Koool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo
00Koool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001doooo00?o09Wooooo
ool01_ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`06oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001d
oooo00?o09Woooooool01Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003ooooo
ool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool20000Soooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`80002?oooo001d
oooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003ooooo
ool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool20000Soooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo013oool400001?oo
o`030000oooooooo08koool007Coool00ol0VOooooooo`0@oooo00<0003oooooool01Oooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Aoooo00<0003oooooool01?ooo`<0002>oooo001d
oooo00?o09Woooooool04_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool04?ooo`040000oooooooo00001?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Aoooo0P0000Goool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool20000Soooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001d
oooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo0P0008ooool0
07Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`80002?oooo001doooo00?o09Woooooool06?oo
o`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool20000Soooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001d
oooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo00Coool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool01?ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001doooo00?o09Woooooool01Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`00
00_oool010000?ooooooooooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.39174 .04578 L
.39675 .04578 L
.40134 .04578 L
.40252 .04578 L
.40381 .04578 L
s
.40381 .04578 m
.40411 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool0
07Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool0
0`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool0
0ol0VOooooooo`0Foooo0P0008ooool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_oo
o`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_oo
o`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_oo
o`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`80002?
oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0F
oooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001f
oooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0
003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool20000Soooo`00M_ooo`03o`2Ioooooooo
01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool0
07Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool0
0`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool0
0ol0VOooooooo`0Foooo0P0008ooool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_oo
o`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_oo
o`030000oooooooo08koool007Koool00ol0VOooooooo`03oooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo00;oool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001foooo00?o09Woooooool00_ooo`040000
oooooooo00002oooo`030000oooooooo00;oool30000S_ooo`00M_ooo`03o`2Ioooooooo00;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007Koool00ol0VOooooooo`02
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool007Koool0
0ol0VOooooooo`03oooo0P0000[oool300001?ooo`030000oooooooo08koool007Koool00ol0VOoo
ooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>
oooo001foooo00?o09Woooooool05_ooo`80002?oooo001foooo00?o09Woooooool05_ooo`030000
oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2I
oooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo
08koool007Koool00ol0VOooooooo`0Foooo0P0008ooool007Koool00ol0VOooooooo`0Foooo00<0
003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o
09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003ooooo
ool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Wooooo
ool05_ooo`80002?oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool0
0ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOoo
ooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool20000Soooo`00M_oo
o`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000
oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2I
oooooooo00koool500000oooo`030000oooooooo08koool007Koool00ol0VOooooooo`0@oooo00<0
003oooooool00oooo`030000oooooooo08koool007Koool00ol0VOooooooo`0@oooo00<0003ooooo
ool00oooo`<0002>oooo001foooo00?o09Woooooool04?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001foooo00?o09Woooooool04?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001foooo00?o09Woooooool03oooo`800005oooo00<0003oooooool0S_ooo`00M_ooo`03o`2I
oooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo
08koool007Koool00ol0VOooooooo`0Foooo0P0008ooool007Koool00ol0VOooooooo`0Foooo00<0
003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o
09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003ooooo
ool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Wooooo
ool05_ooo`80002?oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool0
0ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOoo
ooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool20000Soooo`00M_oo
o`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000
oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2I
oooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo
08koool007Koool00ol0VOooooooo`0Foooo0P0008ooool007Koool00ol0VOooooooo`0Foooo00<0
003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o
09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`02oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo00Coool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo
00Coool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001foooo00?o09Wooooo
ool01?ooo`030000oooooooo00Soool200001Oooo`030000oooooooo08koool007Koool00ol0VOoo
ooooo`04oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001f
oooo00?o09Woooooool00oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001foooo00?o
09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003ooooo
ool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool20000Soooo`00M_ooo`03o`2Ioooooooo01Koool0
0`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool0
0ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOoo
ooooo`0Foooo0P0008ooool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_oo
o`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000
oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2I
oooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`80002?oooo001f
oooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0
003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o
09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003ooooo
ool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool20000Soooo`00M_ooo`03o`2Ioooooooo01Koool0
0`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool0
0ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo00koool400001?oo
o`030000oooooooo08koool007Koool00ol0VOooooooo`0>oooo00<0003oooooool01Oooo`030000
oooooooo08koool007Koool00ol0VOooooooo`0?oooo00<0003oooooool01?ooo`<0002>oooo001f
oooo00?o09Woooooool04?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001foooo00?o
09Woooooool03_ooo`040000oooooooo00001?ooo`030000oooooooo08koool007Koool00ol0VOoo
ooooo`0?oooo0P0000Goool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000
oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2I
oooooooo01Koool20000Soooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001f
oooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0
003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o
09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo0P0008ooool0
07Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool0
0`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool0
0ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo01Koool00`000?oo
ooooo`2>oooo001foooo00?o09Woooooool05_ooo`80002?oooo001foooo00?o09Woooooool05_oo
o`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_oo
o`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001foooo00?o09Woooooool05_ooo`030000
oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0003oooooool0S_ooo`00M_ooo`03o`2I
oooooooo01Koool20000Soooo`00M_ooo`03o`2Ioooooooo01Koool00`000?ooooooo`2>oooo001f
oooo00?o09Woooooool05_ooo`030000oooooooo08koool007Koool00ol0VOooooooo`0Foooo00<0
003oooooool0S_ooo`00M_ooo`03o`2Ioooooooo00;oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001foooo00?o09Woooooool00_ooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001foooo00?o09Woooooool00oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Oooo`<00002
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002oooo`050000oooooooooooo000007goool0
07[oool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`D00003
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo017oool200002oooo`800002oooo00<0003oooooool0O?ooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40134 .04578 L
.40616 .04578 L
.40882 .04578 L
.41013 .04578 L
.41134 .04578 L
.41203 .04578 L
s
.41203 .04578 m
.41221 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooool0V@05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool0
07Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool0
0`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool0
0ol0VOooooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?oo
o`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?oo
o`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`80002?
oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0D
oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001h
oooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0
003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool20000Soooo`00N?ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool0
07Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool0
0`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool0
0ol0VOooooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?oo
o`030000oooooooo08koool007Soool01?l0VOooooooooooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo08koool007Soool01?l0VOooooooo`0000;oool00`000?ooooooo`06oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00N?ooo`04o`2Ioooooooo00000_ooo`030000
oooooooo00Woool00`000?ooooooo`02oooo0`0008koool007Soool01?l0VOooooooo`0000;oool0
0`000?ooooooo`07oooo0P0000Goool00`000?ooooooo`2>oooo001hoooo00Co09Woooooool00002
oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001hoooo00Co
09Woooooooooool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool0
07Soool00ol0VOooooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool20000Soooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0D
oooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2I
oooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`80002?oooo001hoooo00?o
09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool03?ooo`D00003oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo00koool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo00koool00`000?ooooooo`03
oooo0`0008koool007Soool00ol0VOooooooo`0>oooo00<0003oooooool00oooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0>oooo00<0003oooooool00oooo`030000oooooooo08koool0
07Soool00ol0VOooooooo`0=oooo0P0000Goool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool20000Soooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0D
oooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2I
oooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`80002?oooo001hoooo00?o
09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool20000Soooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo00D00002oooo0P0000Coool2
00001Oooo`030000oooooooo08koool007Soool00ol0VOooooooo`02oooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`02oooo00<0
003oooooool02_ooo`030000oooooooo00;oool30000S_ooo`00N?ooo`03o`2Ioooooooo00;oool0
0`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool00_oo
o`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00N?ooo`04o`2I
oooooooooooo0P0000[oool300001?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0D
oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001h
oooo00?o09Woooooool05?ooo`80002?oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool0
07Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool2
0000Soooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?oo
o`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo0P0008ooool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0D
oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001h
oooo00?o09Woooooool05?ooo`80002?oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool03?ooo`@00004oooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo00coool00`000?ooooooo`05oooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo00goool00`000?ooooooo`04oooo0`0008koool007Soool00ol0VOoo
ooooo`0>oooo00<0003oooooool00oooo`030000oooooooo08koool007Soool00ol0VOooooooo`0<
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo00goool2
00001Oooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?oo
o`80002?oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0D
oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool20000Soooo`00N?ooo`03o`2I
oooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool0
07Soool00ol0VOooooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?oo
o`80002?oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool0100000?oool200001?ooo`800005oooo00<0003oooooool0S_oo
o`00N?ooo`04o`2Ioooooooo00002oooo`040000oooooooo00001?ooo`030000oooooooo08koool0
07Soool01Ol0VOooooooooooo`00000=oooo00<0003oooooool00_ooo`<0002>oooo001moooo00<0
003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Goool300000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002oooo`040000oooooooo00000_ooo`050000oooooooooooo000007[oool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002?ooo`D00004oooo00<0003ooooo
ool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003ooooo
ool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000_oool200000ooo
o`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40134 .04578 L
.41134 .04578 L
.41408 .04578 L
.41703 .04578 L
.41846 .04578 L
.41917 .04578 L
.41982 .04578 L
s
.41982 .04578 m
.42012 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool01@000?ooooooooooool0V@03oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo001joooo00?o09Woooooool04_ooo`030000oooooooo
08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo
01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo0P0008ooool007[oool00ol0VOooooooo`0Boooo00<0003ooooo
ool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Wooooo
ool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_oo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_oo
o`80002?oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOoo
ooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>
oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2I
oooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo
08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo
01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo0P0008ooool007[oool00ol0VOooooooo`0Boooo00<0003ooooo
ool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Wooooo
ool04_ooo`030000oooooooo08koool007[oool01?l0VOooo`00000000Coool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00N_ooo`05o`2I0000oooooooo000000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001joooo00Go09T0003oooooool000002oooo`030000oooooooo
00;oool30000S_ooo`00N_ooo`05o`2I0000oooooooo000000Woool200001Oooo`030000oooooooo
08koool007[oool01Ol0V@000?ooooooo`000009oooo00<0003oooooool01?ooo`030000oooooooo
08koool007[oool01?l0VOooo`00000000[oool300001?ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?oo
ooooo`2>oooo001joooo00?o09Woooooool04_ooo`80002?oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000
oooooooo08koool007[oool00ol0VOooooooo`0Boooo0P0008ooool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001j
oooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0
003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o
09Woooooool04_ooo`80002?oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Sooo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo00[oool500000oooo`030000oooooooo08koool007[oool00ol0VOooooooo`0<
oooo00<0003oooooool00oooo`030000oooooooo08koool007[oool00ol0VOooooooo`0<oooo00<0
003oooooool00oooo`<0002>oooo001joooo00?o09Woooooool03?ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool03?ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001joooo00?o09Woooooool02oooo`800005oooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000
oooooooo08koool007[oool00ol0VOooooooo`0Boooo0P0008ooool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001j
oooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0
003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o
09Woooooool04_ooo`80002?oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Sooo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000
oooooooo08koool007[oool00ol0VOooooooo`0Boooo0P0008ooool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001j
oooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0V@000000000300000_oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001joooo00Co09Woooooool00009oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00N_ooo`04o`2Ioooooooo00003?ooo`030000
oooooooo00;oool30000S_ooo`00N_ooo`04o`2Ioooooooo00002_ooo`800005oooo00<0003ooooo
ool0S_ooo`00N_ooo`04o`2Ioooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001joooo00Co09Woool00000000:oooo0`0000Coool00`000?ooooooo`2>oooo001joooo00?o
09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003ooooo
ool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?oo
ooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOoo
ooooo`0Boooo0P0008ooool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000
oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2I
oooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`80002?oooo001j
oooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0
003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o
09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003ooooo
ool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo00[oool400001?oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0:oooo00<0003oooooool01Oooo`030000
oooooooo08koool007[oool00ol0VOooooooo`0;oooo00<0003oooooool01?ooo`<0002>oooo001j
oooo00?o09Woooooool03?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001joooo00?o
09Woooooool02_ooo`040000oooooooo00001?ooo`030000oooooooo08koool007[oool00ol0VOoo
ooooo`0;oooo0P0000Goool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000
oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2I
oooooooo01;oool20000Soooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001j
oooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0
003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o
09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo0P0008ooool0
07[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?oo
ooooo`2>oooo001joooo00?o09Woooooool04_ooo`80002?oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000
oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2I
oooooooo01;oool20000Soooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001j
oooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0
003oooooool0S_ooo`00N_ooo`03o`2I0000000000800003oooo0P0000Coool200001Oooo`030000
oooooooo08koool007[oool00ol0V@000?ooo`0:oooo00@0003oooooool00004oooo00<0003ooooo
ool0S_ooo`00N_ooo`03o`2Ioooo000000goool00`000?ooooooo`02oooo0`0008koool007goool0
0`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2E
oooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003ooooo
ool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000Woool200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0
003oooooool00oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool3
00000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.41127 .04578 L
.41696 .04578 L
.42237 .04578 L
.42482 .04578 L
.42617 .04578 L
.42744 .04578 L
.42816 .04578 L
s
.42816 .04578 m
.42836 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`03oooo00?o09Woool000002?ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool0
07coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool0
0ol0VOooooooo`0@oooo0P0008ooool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_oo
o`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?oo
o`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?oo
o`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`80002?
oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@
oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001l
oooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0
003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool20000Soooo`00O?ooo`03o`2Ioooooooo
013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool0
07coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool0
0ol0VOooooooo`0@oooo0P0008ooool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_oo
o`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?oo
o`030000oooooooo08koool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`2>
oooo001koooo00@0003o09Woool00008oooo00@0003oooooool00004oooo00<0003oooooool0S_oo
o`00Noooo`040000o`2Ioooo00002oooo`030000oooooooo00;oool30000S_ooo`00Noooo`040000
o`2Ioooo00002Oooo`800005oooo00<0003oooooool0S_ooo`00Noooo`040000o`2Ioooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001loooo0P0000[oool300001?ooo`030000
oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2I
oooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`80002?oooo001l
oooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0
003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o
09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo0P0008ooool0
07coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool0
0ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?oo
ooooo`2>oooo001loooo00?o09Woooooool04?ooo`80002?oooo001loooo00?o09Woooooool04?oo
o`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?oo
o`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000
oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2I
oooooooo013oool20000Soooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001l
oooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0
003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo00Soool500000oooo`030000oooooooo08koool0
07coool00ol0VOooooooo`0:oooo00<0003oooooool00oooo`030000oooooooo08koool007coool0
0ol0VOooooooo`0:oooo00<0003oooooool00oooo`<0002>oooo001loooo00?o09Woooooool02_oo
o`030000oooooooo00?oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool02_ooo`030000
oooooooo00?oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool02Oooo`800005oooo00<0
003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o
09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo0P0008ooool0
07coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool0
0ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?oo
ooooo`2>oooo001loooo00?o09Woooooool04?ooo`80002?oooo001loooo00?o09Woooooool04?oo
o`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?oo
o`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000
oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2I
oooooooo013oool20000Soooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001l
oooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0
003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o
09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo0P0008ooool0
07coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007_oool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`2>oooo001loooo00?o09T0003oool02?oo
o`040000oooooooo00001?ooo`030000oooooooo08koool007coool00ol0V@000?ooo`0;oooo00<0
003oooooool00_ooo`<0002>oooo001loooo00?o09T0003oool02Oooo`800005oooo00<0003ooooo
ool0S_ooo`00O?ooo`03o`2I0000oooo00Woool00`000?ooooooo`04oooo00<0003oooooool0S_oo
o`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?oo
o`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?oo
o`03o`2Ioooooooo013oool20000Soooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>
oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@
oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001l
oooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo0P00
08ooool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo
013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool0
07coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool0
0`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`80002?oooo001loooo00?o09Wooooo
ool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_oo
o`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?oo
o`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?oo
o`03o`2Ioooooooo013oool20000Soooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>
oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@
oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo00Soool400001?ooo`030000oooooooo
08koool007coool00ol0VOooooooo`08oooo00<0003oooooool01Oooo`030000oooooooo08koool0
07coool00ol0VOooooooo`09oooo00<0003oooooool01?ooo`<0002>oooo001loooo00?o09Wooooo
ool02_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool02?oo
o`040000oooooooo00001?ooo`030000oooooooo08koool007coool00ol0VOooooooo`09oooo0P00
00Goool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool0
07coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool2
0000Soooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Wooooo
ool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_oo
o`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?oo
o`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo0P0008ooool007coool00ol0VOoo
ooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>
oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@
oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001l
oooo00?o09Woooooool04?ooo`80002?oooo001loooo00?o09Woooooool04?ooo`030000oooooooo
08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo
013oool00`000?ooooooo`2>oooo001loooo00?o09Woooooool04?ooo`030000oooooooo08koool0
07coool00ol0VOooooooo`0@oooo00<0003oooooool0S_ooo`00O?ooo`03o`2Ioooooooo013oool2
0000Soooo`00O?ooo`03o`2Ioooooooo013oool00`000?ooooooo`2>oooo001loooo00?o09Wooooo
ool04?ooo`030000oooooooo08koool007coool00ol0VOooooooo`0@oooo00<0003oooooool0S_oo
o`00Noooo`@00003oooo0P0000Coool200001Oooo`030000oooooooo08koool007_oool00`000?l0
VOooo`09oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00O?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool0000;oooo00<0003oooooool00oooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?ooooooo`00
00Woool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool300000oooo`<00002oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.41127 .04578 L
.42237 .04578 L
.42781 .04578 L
.43049 .04578 L
.43298 .04578 L
.43522 .04578 L
.43648 .04578 L
s
.43648 .04578 m
.43676 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool0
07koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool0
0ol0VOooooooo`0>oooo0P0008ooool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_oo
o`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_oo
o`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_oo
o`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`80002?
oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>
oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001n
oooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0
003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool20000Soooo`00O_ooo`03o`2Ioooooooo
00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool0
07koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool0
0ol0VOooooooo`0>oooo0P0008ooool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_oo
o`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_oo
o`030000oooooooo08koool007coool2000000Co09Woooooooooool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0008koool0
07_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`8000000ol0VOoo
ooooo`07oooo0`0000Coool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000
oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2I
oooooooo00koool20000Soooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001n
oooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0
003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o
09Woooooool03_ooo`80002?oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool0
07koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool0
0ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool20000Sooo
o`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_oo
o`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_oo
o`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000
oooooooo08koool007koool00ol0VOooooooo`0>oooo0P0008ooool007koool00ol0VOooooooo`0>
oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001n
oooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`06oooo1@00
00?oool00`000?ooooooo`2>oooo001noooo00?o09Woooooool02?ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool02?ooo`030000oooooooo00?oool30000S_oo
o`00O_ooo`03o`2Ioooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00O_oo
o`03o`2Ioooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00O_ooo`03o`2I
oooooooo00Ooool200001Oooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0
003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o
09Woooooool03_ooo`80002?oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool0
07koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool0
0ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool20000Sooo
o`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_oo
o`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00Oooo
o`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000
oooooooo08koool007ooool00ol0VOooooooo`0=oooo0P0008ooool007ooool00ol0VOooooooo`0=
oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001o
oooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0
003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o
09Woooooool03Oooo`80002?oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool0
07ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool0
0`000?ooooooo`2>oooo001koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0S_oo
o`00OOooo`030000ooooo`2I00Ooool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001m
oooo00<0003ooooo09T02_ooo`030000oooooooo00;oool30000S_ooo`00OOooo`030000ooooo`2I
00Soool200001Oooo`030000oooooooo08koool007goool00`000?ooool0V@08oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool007coool2000000?ooooo09Woool01oooo`<00004oooo00<0
003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o
09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo0P0008ooool0
07ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool0
0`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool0
0ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?oo
ooooo`2>oooo001ooooo00?o09Woooooool03Oooo`80002?oooo001ooooo00?o09Woooooool03Ooo
o`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Oooo
o`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000
oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2I
oooooooo00goool20000Soooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001o
oooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0
003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o
09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo0P0008ooool0
07ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool0
0`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool0
0ol0VOooooooo`05oooo100000Coool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool01_ooo`030000
oooooooo00Coool30000S_ooo`00Ooooo`03o`2Ioooooooo00Ooool00`000?ooooooo`03oooo00<0
003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00Goool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo001ooooo00?o09Woooooool01_ooo`800005oooo00<0003oooooool0S_ooo`00Oooo
o`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000
oooooooo08koool007ooool00ol0VOooooooo`0=oooo0P0008ooool007ooool00ol0VOooooooo`0=
oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001o
oooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0
003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o
09Woooooool03Oooo`80002?oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool0
07ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool0
0`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000oooooooo08koool007ooool0
0ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool20000Sooo
o`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Ooo
o`030000oooooooo08koool007ooool00ol0VOooooooo`0=oooo00<0003oooooool0S_ooo`00Oooo
o`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001ooooo00?o09Woooooool03Oooo`030000
oooooooo08koool007ooool00ol0VOooooooo`0=oooo0P0008ooool007ooool00ol0VOooooooo`0=
oooo00<0003oooooool0S_ooo`00Ooooo`03o`2Ioooooooo00goool00`000?ooooooo`2>oooo001o
oooo00?o09Woooooool03Oooo`030000oooooooo08koool007_oool4000000?o09Woooooool00P00
00Coool200001Oooo`030000oooooooo08koool007_oool01@000?ooooooooooool0V@07oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00O?ooo`040000ooooooooo`2I2_ooo`030000
oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`0000Coool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0
003oooooool00008oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00003oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`1koooo001l
oooo00<0003oooooool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.42237 .04578 L
.43215 .04578 L
.43755 .04578 L
.44021 .04578 L
.44151 .04578 L
.44268 .04578 L
.44387 .04578 L
s
.44387 .04578 m
.44415 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003ooooo09T01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0
083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool0
0`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool0
0ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?oo
o`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`80002?
oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<
oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020
oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0
003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool20000Soooo`00P?ooo`03o`2Ioooooooo
00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0
083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool0
0`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool0
0ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`030000oooooooo08koool007coool200000_ooo`04o`2Ioooo000000001?ooo`800005oooo00<0
003oooooool0S_ooo`00Noooo`060000oooooooo0000ooooo`2I1_ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007_oool01P000?ooooooo`000?ooool0V@Woool00`000?ooooooo`02
oooo0`0008koool007_oool01P000?ooooooo`000?ooool0V@Ooool200001Oooo`030000oooooooo
08koool007_oool01P000?ooooooo`000?ooool0V@Ooool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00O?ooo`800002oooo00?o09Woooooool01Oooo`<00004oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<
oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool20000Soooo`00P?ooo`03o`2I
oooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0
083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0003ooooo
ool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Wooooo
ool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`80002?oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool01?ooo`D00003oooo00<0003oooooool0S_ooo`00P?ooo`03o`2I
oooooooo00Koool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00Koool00`000?ooooooo`03oooo0`0008koool0083oool00ol0VOooooooo`06oooo00<0003ooooo
ool00oooo`030000oooooooo08koool0083oool00ol0VOooooooo`06oooo00<0003oooooool00ooo
o`030000oooooooo08koool0083oool00ol0VOooooooo`05oooo0P0000Goool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<
oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool20000Soooo`00P?ooo`03o`2I
oooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0
083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0003ooooo
ool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Wooooo
ool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`80002?oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<
oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool20000Soooo`00P?ooo`03o`2I
oooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00Noooo`D000001?l0VOoo
o`00000000Coool200001Oooo`030000oooooooo08koool007goool010000?ooooooool0V@Koool0
10000?ooooooo`0000Coool00`000?ooooooo`2>oooo001moooo00@0003ooooooooo09T9oooo00<0
003oooooool00_ooo`<0002>oooo001moooo00@0003ooooooooo09T7oooo0P0000Goool00`000?oo
ooooo`2>oooo001moooo00@0003ooooooooo09T7oooo00<0003oooooool01?ooo`030000oooooooo
08koool007coool200000_ooo`03o`2Ioooooooo00Goool300001?ooo`030000oooooooo08koool0
083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool0
0`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`80002?oooo0020oooo00?o09Wooooo
ool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?oo
o`03o`2Ioooooooo00coool20000Soooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<
oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020
oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo0P00
08ooool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0
083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool0
0`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`80002?oooo0020oooo00?o09Wooooo
ool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool01?oo
o`@00004oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00Coool00`000?ooooooo`05
oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00Goool00`000?ooooooo`04oooo0`00
08koool0083oool00ol0VOooooooo`06oooo00<0003oooooool00oooo`030000oooooooo08koool0
083oool00ol0VOooooooo`04oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00P?oo
o`03o`2Ioooooooo00Goool200001Oooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<
oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020
oooo00?o09Woooooool03?ooo`80002?oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0
083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool2
0000Soooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Wooooo
ool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_oo
o`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?oo
o`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<
oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020
oooo00?o09Woooooool03?ooo`80002?oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00coool00`000?ooooooo`2>oooo001koooo10000003ooooo`2Ioooo00800004oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00<0003oooooool00_ooo`03o`2Ioooooooo00Coool010000?oo
ooooo`0000Coool00`000?ooooooo`2>oooo001loooo00D0003ooooooooooooo09T02Oooo`030000
oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?oo
ooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000Soool010000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo0`00
00Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.42237 .04578 L
.43215 .04578 L
.43755 .04578 L
.44268 .04578 L
.44744 .04578 L
.44874 .04578 L
.45013 .04578 L
.45143 .04578 L
s
.45143 .04578 m
.45173 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00D0003ooooooooooooo09T01?ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo0022oooo00?o09Woooooool02_ooo`030000oooooooo
08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo
00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool0
08;oool00ol0VOooooooo`0:oooo0P0008ooool008;oool00ol0VOooooooo`0:oooo00<0003ooooo
ool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Wooooo
ool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_oo
o`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_oo
o`80002?oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOoo
ooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>
oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:
oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool20000Soooo`00P_ooo`03o`2I
oooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo
08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo
00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool0
08;oool00ol0VOooooooo`0:oooo0P0008ooool008;oool00ol0VOooooooo`0:oooo00<0003ooooo
ool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Wooooo
ool02_ooo`030000oooooooo08koool007coool200001?ooo`800004oooo0P0000Goool00`000?oo
ooooo`2>oooo001koooo00@0003oooooool00003oooo00?o09Woooooool00_ooo`040000oooooooo
00001?ooo`030000oooooooo08koool007_oool010000?ooooooo`0000?oool00ol0VOooooooo`05
oooo00<0003oooooool00_ooo`<0002>oooo001koooo00@0003oooooool00003oooo00?o09Wooooo
ool00oooo`800005oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00000oooo`03o`2I
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`800004oooo00?o
09Woooooool00oooo`<00004oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool0
0`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool0
0ol0VOooooooo`0:oooo0P0008ooool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_oo
o`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_oo
o`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_oo
o`03o`2Ioooooooo00[oool20000Soooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>
oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:
oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022
oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo0P00
08ooool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo
00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool0
08;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool0
0`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`80002?oooo0022oooo00?o09Wooooo
ool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_oo
o`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool00_oo
o`D00003oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00Coool00`000?ooooooo`03
oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00Coool00`000?ooooooo`03oooo0`00
08koool008;oool00ol0VOooooooo`04oooo00<0003oooooool00oooo`030000oooooooo08koool0
08;oool00ol0VOooooooo`04oooo00<0003oooooool00oooo`030000oooooooo08koool008;oool0
0ol0VOooooooo`03oooo0P0000Goool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_oo
o`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_oo
o`03o`2Ioooooooo00[oool20000Soooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>
oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:
oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022
oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo0P00
08ooool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo
00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool0
08;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool0
0`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`80002?oooo0022oooo00?o09Wooooo
ool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_oo
o`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_oo
o`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_oo
o`03o`2Ioooooooo00[oool20000Soooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>
oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:
oooo00<0003oooooool0S_ooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo
08koool007goool00`000?ooooooo`02oooo00?o09Woooooool00_ooo`040000oooooooo00001?oo
o`030000oooooooo08koool007goool00`000?ooooooo`02oooo00?o09Woooooool01Oooo`030000
oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00;oool00ol0VOooooooo`03oooo0P00
00Goool00`000?ooooooo`2>oooo001moooo00<0003oooooool00_ooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`800004oooo00?o09Woooooool00ooo
o`<00004oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>
oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:
oooo0P0008ooool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2I
oooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo
08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo
00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`80002?oooo0022oooo00?o
09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003ooooo
ool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Wooooo
ool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_oo
o`00P_ooo`03o`2Ioooooooo00[oool20000Soooo`00P_ooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOoo
ooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>
oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:
oooo0P0008ooool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2I
oooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo
08koool008;oool00ol0VOooooooo`02oooo100000Coool00`000?ooooooo`2>oooo0022oooo00?o
09Woooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`2>oooo0022oooo00?o09Wooooo
ool00oooo`030000oooooooo00Coool30000S_ooo`00P_ooo`03o`2Ioooooooo00Coool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00;oool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool00oooo`800005oooo00<0003ooooo
ool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Wooooo
ool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo0P0008ooool008;oool0
0ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOoo
ooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>
oooo0022oooo00?o09Woooooool02_ooo`80002?oooo0022oooo00?o09Woooooool02_ooo`030000
oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2I
oooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo
08koool008;oool00ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo
00[oool20000Soooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o
09Woooooool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo00<0003ooooo
ool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?ooooooo`2>oooo0022oooo00?o09Wooooo
ool02_ooo`030000oooooooo08koool008;oool00ol0VOooooooo`0:oooo0P0008ooool008;oool0
0ol0VOooooooo`0:oooo00<0003oooooool0S_ooo`00P_ooo`03o`2Ioooooooo00[oool00`000?oo
ooooo`2>oooo0022oooo00?o09Woooooool02_ooo`030000oooooooo08koool007_oool400000ooo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00<0003oooooool01?ooo`03o`2I
oooooooo00;oool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001loooo00<0003ooooo
ool00oooo`03o`2Ioooooooo00Goool00`000?ooooooo`02oooo0`0008koool007goool00`000?oo
ooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001l
oooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P00
00Coool200001Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0
003oooooool03Oooo`040000oooooooo00002_ooo`030000oooooooo00?oool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000coool010000?ooooooo`0000_oool01@000?oooooooooo
o`00001moooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000Woool4
00000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.42237 .04578 L
.43215 .04578 L
.44268 .04578 L
.44778 .04578 L
.45262 .04578 L
.45697 .04578 L
.45816 .04578 L
.45943 .04578 L
s
.45943 .04578 m
.45973 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool00oooo`04o`2Ioooooooo
00001oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_oo
o`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?oo
o`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?oo
o`03o`2Ioooooooo00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024
oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P00
08ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool0
08Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_oo
o`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?oo
o`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?oo
o`03o`2Ioooooooo00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo00<0003oooooool0S_ooo`00O?ooo`800004oooo0P000004o`2Ioooooooooooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00005oooo00Co09Woooooool00002oooo00<0
003oooooool00_ooo`030000oooooooo08koool007_oool010000?ooooooo`0000Goool00ol0VOoo
ooooo`03oooo00<0003oooooool00_ooo`<0002>oooo001koooo00@0003oooooool00005oooo00Co
09Woooooooooool200001Oooo`030000oooooooo08koool007_oool010000?ooooooo`0000Goool0
1Ol0VOooooooooooo`000006oooo00<0003oooooool0S_ooo`00O?ooo`800006oooo00Co09Wooooo
ooooool300001?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003ooooo
ool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Wooooo
ool02?ooo`80002?oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool0
0ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOoo
ooooo`08oooo0P0008ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?oo
o`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000
oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2I
oooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024
oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0
003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o
09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003ooooo
ool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool0
0ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00D00003oooo00<0
003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00;oool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00Q?ooo`03o`2Ioooooooo00;oool00`000?ooooooo`03oooo0`0008koool008Coool0
0ol0VOooooooo`02oooo00<0003oooooool00oooo`030000oooooooo08koool008Coool00ol0VOoo
ooooo`02oooo00<0003oooooool00oooo`030000oooooooo08koool008Coool01?l0VOoooooooooo
o`800005oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo0P0008ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2I
oooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo
08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o
09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003ooooo
ool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_oo
o`00Q?ooo`03o`2Ioooooooo00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOoo
ooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo0P0008ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2I
oooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo
08koool007_oool500000_ooo`8000001?l0VOooooooooooo`800005oooo00<0003oooooool0S_oo
o`00OOooo`030000oooooooo00Coool01?l0VOooooooo`0000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00OOooo`030000oooooooo00Coool00ol0VOooooooo`03oooo00<0003ooooo
ool00_ooo`<0002>oooo001moooo00<0003oooooool01?ooo`04o`2Ioooooooooooo0P0000Goool0
0`000?ooooooo`2>oooo001moooo00<0003oooooool01?ooo`05o`2Ioooooooooooo000000Koool0
0`000?ooooooo`2>oooo001loooo0P0000Koool01?l0VOooooooooooo`<00004oooo00<0003ooooo
ool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P0008ooool008Coool0
0ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOoo
ooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Woooooool02?ooo`030000
oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2I
oooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo
08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o
09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003ooooo
ool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P0008ooool008Coool0
0ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOoo
ooooo`0400001?ooo`030000oooooooo08koool008Coool01?l0VOooooooo`0000Ooool00`000?oo
ooooo`2>oooo0024oooo00Go09Woooooooooool000001_ooo`<0002>oooo0024oooo00?o09Wooooo
ool00_ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0024oooo00Co09Woooooool00002
oooo00<0003oooooool00_ooo`030000oooooooo08koool008Coool01?l0VOooooooooooo`800005
oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024
oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P00
08ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool0
08Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_oo
o`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?oo
o`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?oo
o`03o`2Ioooooooo00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024
oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P00
08ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool0
07_oool400000oooo`8000001?l0VOooooooooooo`800005oooo00<0003oooooool0S_ooo`00Nooo
o`030000oooooooo00Koool01?l0VOooooooo`0000;oool00`000?ooooooo`02oooo00<0003ooooo
ool0S_ooo`00O?ooo`030000oooooooo00Goool00ol0VOooooooo`03oooo00<0003oooooool00_oo
o`<0002>oooo001moooo00<0003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009
oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Ooo
o`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool01oooo`800004oooo0P0000Goool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03Oooo`040000
oooooooo00002_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool0000;oooo00@0003oooooooooool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000Woool400000oooo`<00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.44268 .04578 L
.45262 .04578 L
.46172 .04578 L
.46388 .04578 L
.46618 .04578 L
.46687 .04578 L
.46751 .04578 L
s
.46751 .04578 m
.46781 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool0
0`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool0
0ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_oo
o`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`80002?
oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05
oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027
oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo
00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool0
0`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool0
0ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_oo
o`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool007coool200001?ooo`800003oooo00?o09T0000000001Oooo`030000
oooooooo08koool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo001koooo00@0003oooooool00008oooo00Co09Woooooool00004oooo0`0008koool0
07_oool010000?ooooooo`0000Soool00ol0V@0000000005oooo00<0003oooooool0S_ooo`00Nooo
o`040000oooooooo00002?ooo`03o`2I0000oooo00Goool00`000?ooooooo`2>oooo001loooo0P00
00Woool01?l0V@000000000000Coool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2Ioooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>
oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05
oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027
oooo00?o09Woooooool01Oooo`80002?oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo
08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo
00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool2
0000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_oo
o`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>
oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool500000oooo`030000
oooooooo08koool008Ooool00ol0VOooo`000005oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooo000000Goool30000S_ooo`00Qoooo`03o`2Ioooo000000Goool00`000?ooooooo`2>oooo0027
oooo00?o09Woool000001Oooo`030000oooooooo08koool008Ooool00ol0V@0000000005oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool0
0`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool0
0ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`2>oooo0027oooo00?o09Woooooool01Oooo`80002?oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027
oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool0
0`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool007_oool5
00000_ooo`800003oooo00?o09T0000000001Oooo`030000oooooooo08koool007goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo
00Ooool01?l0VOooooooo`0000Coool30000S_ooo`00OOooo`030000oooooooo00Ooool00ol0V@00
00000005oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00Ooool00ol0V@000?ooo`05
oooo00<0003oooooool0S_ooo`00O?ooo`800009oooo00Co09T0000000000004oooo00<0003ooooo
ool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool0
0ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>
oooo0027oooo00?o09Woooooool01Oooo`80002?oooo0027oooo00?o09Woooooool01Oooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo
08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo
00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003ooooo
ool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool0
0ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool400001?oo
o`030000oooooooo08koool008Ooool00`000?ooooooo`05oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2I0000oooo00Goool30000S_ooo`00Qoooo`03o`2Ioooo000000Goool00`000?ooooooo`2>
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I00000000
00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool2
0000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_oo
o`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>
oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05
oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027
oooo00?o09Woooooool01Oooo`80002?oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo
08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo
00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool2
0000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_oo
o`00Noooo`@00003oooo0P0000?oool00ol0V@0000000005oooo00<0003oooooool0S_ooo`00Nooo
o`030000oooooooo00Woool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001loooo00<0
003oooooool02?ooo`04o`2Ioooooooo00001?ooo`<0002>oooo001moooo00<0003oooooool02?oo
o`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:
oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?oo
ooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1k
oooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P00
00Coool200001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool0
10000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001koooo00<0
003oooooool01@0000coool010000?ooooooo`0000Woool200001?ooo`030000oooooooo07_oool0
07_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0
003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.44268 .04578 L
.45262 .04578 L
.46172 .04578 L
.46618 .04578 L
.47106 .04578 L
.47329 .04578 L
.47451 .04578 L
.47567 .04578 L
s
.47567 .04578 m
.47594 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000ooooo`2I
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool0
0ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00ooo
o`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?
oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029
oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0
003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool0
0ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00ooo
o`030000oooooooo08koool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`2>
oooo001koooo00@0003oooooool00008oooo00@0003ooooo09T00004oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00002_ooo`03o`2I0000oooo00?oool30000S_ooo`00Noooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002Ooo
o`030000o`2Ioooo00Coool00`000?ooooooo`2>oooo001loooo0P0000[oool300001?ooo`030000
oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2I
oooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?oooo0029
oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0
003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o
09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo0P0008ooool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool0
0ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?oooo0029oooo00?o09Woooooool00ooo
o`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000
oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2I
oooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029
oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0
003oooooool0S_ooo`00Qoooo`D00003oooo00<0003oooooool0S_ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00<0003oooooool00oooo`<0002>oooo0029oooo00<0
003oooooool00oooo`030000oooooooo08koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00R?ooo`800005oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool0
0ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00ooo
o`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?
oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029
oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0
003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool0
0ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00ooo
o`030000oooooooo08koool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`2>
oooo001moooo00<0003oooooool01oooo`040000ooooo`2I00001?ooo`030000oooooooo08koool0
07goool00`000?ooooooo`09oooo00?o09T0003oool00oooo`<0002>oooo001moooo00<0003ooooo
ool02?ooo`800005oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00Soool00`000?l0
VOooo`04oooo00<0003oooooool0S_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`2>
oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2I
oooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo
08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0003ooooo
ool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00ooo
o`80002?oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>
oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2I
oooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo
08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00Qoooo`@00004oooo00<0
003oooooool0S_ooo`00Qoooo`030000ooooo`2I00Goool00`000?ooooooo`2>oooo0028oooo00<0
003o09Woool01?ooo`<0002>oooo0029oooo00<0003oooooool00oooo`030000oooooooo08koool0
08Ooool010000?ooool0V@0000Coool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000
oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2I
oooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo
08koool008Woool00ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0
003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o
09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003ooooo
ool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Wooooo
ool00oooo`80002?oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool0
0ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000
oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00Noooo`@00003
oooo0P0000Coool200001Oooo`030000oooooooo08koool007_oool00`000?ooooooo`09oooo00@0
003ooooo09T00004oooo00<0003oooooool0S_ooo`00O?ooo`030000oooooooo00[oool00ol0V@00
0?ooo`03oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`800004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.44268 .04578 L
.46172 .04578 L
.47106 .04578 L
.47567 .04578 L
.47994 .04578 L
.48231 .04578 L
.483 .04578 L
.48364 .04578 L
s
.48364 .04578 m
.48394 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`050000oooooooo
ooooo`2I00?oool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo002;oooo00Go09Woooooooooool00000T?ooo`00Rooo
o`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go
09Woooooooooool00000T?ooo`00Roooo`04o`2Ioooooooooooo0P0008ooool008_oool01Ol0VOoo
ooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooo
oooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool0
0000T?ooo`00Roooo`04o`2Ioooooooooooo0P0008ooool008_oool01Ol0VOooooooooooo`00002@
oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool0
08_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Rooo
o`04o`2Ioooooooooooo0P0008ooool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go
09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOoo
ooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`04o`2Ioooooooo
oooo0P0008ooool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool0
0000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool007coool200001?ooo`800004oooo0P00
0003ooooo`2Ioooo00;oool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00D0
003oooooool0003o09T00oooo`030000oooooooo08koool007_oool010000?ooooooo`0000_oool0
0`000?l0VOooo`02oooo0`0008koool007_oool010000?ooooooo`0000Woool2000000?ooooo09Wo
ool00_ooo`030000oooooooo08koool007_oool010000?ooooooo`0000Woool010000?ooooooool0
V@?oool00`000?ooooooo`2>oooo001loooo0P0000[oool3000000Go09Woooooooooool00000T?oo
o`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;
oooo00Co09Woooooooooool20000Soooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool0
1Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2I
oooooooooooo0000093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go09Wooooo
ooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOoooooooooo
o`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000
093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go09Woooooooooool00000T?oo
o`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;
oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool0
1?l0VOooooooooooo`80002?oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2I
oooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo0027oooo1@0000?oool0
0`000?ooooooo`2>oooo0029oooo00<0003ooooo09T00oooo`030000oooooooo08koool008Woool0
0`000?ooool0V@03oooo0`0008koool008Woool00`000?ooool0V@03oooo00<0003oooooool0S_oo
o`00ROooo`030000ooooo`2I00?oool00`000?ooooooo`2>oooo0028oooo0P000003ooooo`2Ioooo
00;oool00`000?ooooooo`2>oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2I
oooooooooooo0000093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go09Wooooo
ooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOoooooooooo
o`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000
093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go09Woooooooooool00000T?oo
o`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;
oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool0
1?l0VOooooooooooo`80002?oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2I
oooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Wooooo
ooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01?l0VOoooooooooo
o`80002?oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000
093oool008_oool01Ol0VOooooooooooo`00002@oooo001koooo1@0000;oool200001?ooo`800000
0oooool0VOooo`02oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00Ooool01@000?oo
ooooo`000?l0V@03oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00[oool00`000?l0
VOooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P000003ooooo`2Ioooo00;oool0
0`000?ooooooo`2>oooo001moooo00<0003oooooool02?ooo`040000ooooooooo`2I0oooo`030000
oooooooo08koool007coool200002_ooo`<000001Ol0VOooooooooooo`00002@oooo002;oooo00Go
09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01?l0VOoo
ooooooooo`80002?oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooo
oooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool0
0000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01?l0VOooooooooooo`80002?
oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool0
08_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Rooo
o`05o`2Ioooooooooooo0000093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go
09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOoo
ooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooo
oooo0000093oool008_oool01?l0VOooooooooooo`80002?oooo002;oooo00Go09Woooooooooool0
0000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@
oooo0027oooo10000005o`2Ioooooooooooo0000093oool008Ooool01@000?ooooooooooool0V@03
oooo00<0003oooooool0S_ooo`00R?ooo`040000ooooooooo`2I0oooo`<0002>oooo0029oooo00<0
003ooooo09T00oooo`030000oooooooo08koool008Ooool01@000?ooooooo`000?l0V@03oooo00<0
003oooooool0S_ooo`00R?ooo`8000000oooool0VOooo`02oooo00<0003oooooool0S_ooo`00Rooo
o`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Co
09Woooooooooool20000Soooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOoo
ooooooooo`00002@oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooo
oooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Co09Woooooooooool2
0000Soooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@
oooo002;oooo00Go09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool0
08_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Co09Woooooooooool20000Soooo`00Rooo
o`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go
09Woooooooooool00000T?ooo`00Roooo`05o`2Ioooooooooooo0000093oool008_oool01Ol0VOoo
ooooooooo`00002@oooo002;oooo00Co09Woooooooooool20000Soooo`00Roooo`05o`2Ioooooooo
oooo0000093oool008_oool01Ol0VOooooooooooo`00002@oooo002;oooo00Go09Woooooooooool0
0000T?ooo`00Noooo`@00003oooo0P0000Coool2000000?ooooo09Woool00_ooo`030000oooooooo
08koool007_oool00`000?ooooooo`09oooo00D0003oooooool0003o09T00oooo`030000oooooooo
08koool007coool00`000?ooooooo`0;oooo00<0003o09Woool00_ooo`<0002>oooo001moooo00<0
003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000?oool300001?ooo`030000oooooooo07_oool007_oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool0
0`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00009oooo0`0000Coool00`000?ooooooo`1joooo001koooo00<0
003oooooool01@0000coool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool3
00000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.44268 .04578 L
.46172 .04578 L
.47994 .04578 L
.48519 .04578 L
.48778 .04578 L
.48904 .04578 L
.49018 .04578 L
.4913 .04578 L
s
.4913 .04578 m
.49156 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00?oool00ol0VOooo`000007oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000
093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2I
oooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@
oooo002=oooo00Co09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@
oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOoo
o`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Soooo`00SOoo
o`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?oo
o`00O?ooo`800004oooo0P0000Coool200000oooo`03o`2Ioooo0000093oool007_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000;oool00ol0VOooo`00002@oooo001koooo00@0003ooooo
ool0000;oooo00D0003ooooooooo09Woool00`0008koool007_oool010000?ooooooo`0000Woool2
00000oooo`03o`2Ioooo0000093oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`02
oooo00?o09Woool00000T?ooo`00O?ooo`80000:oooo0`0000;oool00ol0VOooo`00002@oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`000000
08ooool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00Co09Woool00000002?oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@
oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOoo
o`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?oo
o`00SOooo`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOoo
o`00002@oooo002=oooo00?o09Woool00000T?ooo`00Qoooo`D000001?ooool0VOooo`00093oool0
08Woool01`000?ooooooooooool0VOooo`00002@oooo0029oooo00H0003ooooooooooooo09Woool3
0000S_ooo`00ROooo`070000ooooooooooooo`2Ioooo0000093oool008Woool01`000?oooooooooo
ool0VOooo`00002@oooo0028oooo0P0000?oool00ol0VOooo`00002@oooo002=oooo00?o09Woool0
0000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool008goool0
0ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool0
08goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo0000
0000Soooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o
09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=
oooo00Co09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000
093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool007_oool500000_ooo`800004
oooo0P0000?oool00ol0VOooo`00002@oooo001moooo00<0003oooooool01oooo`040000oooooooo
00000_ooo`03o`2Ioooo0000093oool007goool00`000?ooooooo`0:oooo00D0003ooooooooo09Wo
ool00`0008koool007goool00`000?ooooooo`08oooo0P0000?oool00ol0VOooo`00002@oooo001m
oooo00<0003oooooool02?ooo`030000oooooooo00;oool00ol0VOooo`00002@oooo001loooo0P00
00[oool300000_ooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o
09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool0
08goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000
093oool008goool00ol0VOooo`00002@oooo002=oooo00Co09Woool00000002?oooo002=oooo00?o
09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`000000
08ooool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@
oooo002=oooo00?o09Woool00000T?ooo`00Qoooo`@00002oooo00?o09Woool00000T?ooo`00Qooo
o`030000oooooooo00?oool00ol0VOooo`00002@oooo0028oooo00<0003oooooool00_ooo`03o`2I
oooo00000080002>oooo0029oooo00L0003ooooooooooooo09Woool00000T?ooo`00Qoooo`040000
oooooooo00000_ooo`03o`2Ioooo0000093oool008Soool200000oooo`03o`2Ioooo0000093oool0
08goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo0000
0000Soooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o
09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=
oooo00Co09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000
093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOooo`00002@oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@
oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Soooo`00SOooo`03o`2I
oooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00Nooo
o`@00003oooo0P0000Coool200000oooo`03o`2Ioooo0000093oool007_oool00`000?ooooooo`09
oooo00@0003oooooool00002oooo00?o09Woool00000T?ooo`00O?ooo`030000oooooooo00_oool0
1@000?ooooooool0VOooo`030000S_ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00Nooo
o`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003o
oooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo0`0000Coool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool01@000?ooooooooooo`000002
oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool00009oooo0`0000Goool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003oooooool00003
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000
oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.48147 .04578 L
.49012 .04578 L
.49468 .04578 L
.49719 .04578 L
.49842 .04578 L
.49955 .04578 L
s
.49955 .04578 m
.49988 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0008koool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007_oool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`80000:oooo0`0000Coool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo0027oooo1@0000?oool00`000?ooooooo`2>oooo0029oooo00<0003oooooool00ooo
o`030000oooooooo08koool008Woool00`000?ooooooo`03oooo0`0008koool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo0028oooo0P0000Goool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo08koool007goool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`2>
oooo001moooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001l
oooo0P0000[oool300001?ooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo0027oooo1000
00Coool00`000?ooooooo`2>oooo0027oooo00<0003oooooool01Oooo`030000oooooooo08koool0
08Soool00`000?ooooooo`04oooo0`0008koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo08koool008Soool200001Ooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo001koooo100000?oool200001?ooo`800005
oooo00<0003oooooool0S_ooo`00Noooo`030000oooooooo00Woool010000?ooooooo`0000Coool0
0`000?ooooooo`2>oooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool30000S_oo
o`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007ooool0
0`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_ooo`030000oooooooo00Soool00`000?oo
ooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool500000_ooo`800004oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Soool0
0`000?ooooooo`1noooo001moooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`09oooo00<0003oooooool0OOooo`00O_ooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02?ooo`030000oooooooo07koool007koool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool02?ooo`030000oooooooo07koool007ooool00`000?ooooooo`0Aoooo0P0000Woool00`000?oo
ooooo`1ooooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.48147 .04578 L
.49012 .04578 L
.49955 .04578 L
.50205 .04578 L
.50471 .04578 L
.50601 .04578 L
.50722 .04578 L
s
.50722 .04578 m
.5075 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.44268 .04578 L
.46172 .04578 L
.47994 .04578 L
.48519 .04578 L
.48778 .04578 L
.48904 .04578 L
.49018 .04578 L
.4913 .04578 L
.49235 .16033 L
.49346 .16074 L
.49466 .16117 L
.49722 .16211 L
.49834 .16252 L
.49955 .16296 L
.50077 .16284 L
.50192 .16242 L
.50447 .16149 L
.50562 .16107 L
.50685 .16062 L
.5079 .16024 L
.50906 .04578 L
.50971 .04578 L
.51041 .04578 L
.51165 .04578 L
.51444 .04578 L
.51949 .04578 L
.54055 .04578 L
.57866 .04578 L
.61922 .04578 L
.65827 .04578 L
.69977 .04578 L
.73975 .04578 L
.77822 .04578 L
.81913 .04578 L
.85854 .04578 L
.89642 .04578 L
.93676 .04578 L
.97559 .04578 L
.97619 .04578 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00?oool01@1Vooooo`000?ooo`1Vo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`0Boooo002=oooo00D0I_ooool0003oool0I_l0S_ooo`00SOoo
o`0506Kooooo0000oooo06Ko08koool008goool01@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0
I_ooool0003oool0I_l0S_ooo`00SOooo`0506Kooooo0000000006Ko08koool008goool01@1Voooo
o`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool0003oool0I_l0S_ooo`00SOooo`0506Kooooo0000
oooo06Ko08koool008goool01@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool0003oool0
I_l0S_ooo`00SOooo`0506Kooooo0000000006Ko08koool008goool01@1Vooooo`000?ooo`1Vo`2>
oooo002=oooo00D0I_ooool0003oool0I_l0S_ooo`00SOooo`0506Kooooo0000oooo06Ko08koool0
08goool01@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool0003oool0I_l0S_ooo`00SOoo
o`0506Kooooo0000000006Ko08koool008goool01@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0
I_ooool0003oool0I_l0S_ooo`00SOooo`0506Kooooo0000oooo06Ko08koool008goool01@1Voooo
o`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool0003oool0I_l0S_ooo`00SOooo`0506Kooooo0000
000006Ko08koool008goool01@1Vooooo`000?ooo`1Vo`2>oooo002=oooo00D0I_ooool0003oool0
I_l0S_ooo`00SOooo`0506Kooooo0000oooo06Ko08koool007coool200001?ooo`800004oooo0P00
00?oool01@1Vooooo`000?ooo`1Vo`2>oooo001koooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00D0I_ooool0003oool0I_l0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo0080I_l30000S_ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003ooooo
09T0S_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooool0V@2>
oooo001loooo0P0000[oool300001?ooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0
003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo
09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo00<0
003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool2000000?o09Woooooool0S?oo
o`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo
09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo0P00
0003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_oo
o`00Soooo`030000ooooo`2I08koool008Ooool500000oooo`030000ooooo`2I08koool008Woool0
0`000?ooooooo`03oooo00<0003ooooo09T0S_ooo`00ROooo`030000oooooooo00?oool30000S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooool0V@2>oooo0029oooo00<0003oooooool00ooo
o`030000ooooo`2I08koool008Soool200001Oooo`030000ooooo`2I08koool008ooool00`000?oo
ool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool2000000?o
09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>
oooo002?oooo0P000003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0
003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo
09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo001koooo1@00
00;oool200001?ooo`800005oooo00<0003ooooo09T0S_ooo`00OOooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooool0V@2>oooo001moooo00<0003oooooool02_ooo`030000
oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00Soool200001Oooo`030000ooooo`2I
08koool007goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000ooooo`2I08koool0
07coool200002_ooo`<00004oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool0
08ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool008ooool00`000?oo
ool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool0
0`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?oo
ool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool2
000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?oo
ool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008Ooool400001?ooo`030000
ooooo`2I08koool008Ooool00`000?ooooooo`05oooo00<0003ooooo09T0S_ooo`00R?ooo`030000
oooooooo00Coool30000S_ooo`00ROooo`030000oooooooo00?oool00`000?ooool0V@2>oooo0027
oooo00@0003oooooool00004oooo00<0003ooooo09T0S_ooo`00R?ooo`800005oooo00<0003ooooo
09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo0P00
0003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_oo
o`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo
09T0S_ooo`00Soooo`8000000ol0VOooooooo`2<oooo002?oooo00<0003ooooo09T0S_ooo`00Sooo
o`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_oo
o`00Soooo`030000ooooo`2I08koool008ooool2000000?o09Woooooool0S?ooo`00Soooo`030000
ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Sooo
o`030000ooooo`2I08koool008ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo
08coool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000
ooooo`2I08koool007_oool400000oooo`800004oooo0P0000Goool00`000?ooool0V@2>oooo001k
oooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000ooooo`2I08koool007coool0
0`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0002>oooo001moooo00<0003oooooool02?oo
o`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:
oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00005oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000
oooooooo00Ooool010000?ooooooo`0000?oool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P00
00Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.48147 .04578 L
.49955 .04578 L
.50431 .04578 L
.5095 .04578 L
.51188 .04578 L
.51318 .04578 L
.51441 .04578 L
.51555 .04578 L
s
.51555 .04578 m
.51586 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.44268 .04578 L
.46172 .04578 L
.47106 .04578 L
.47567 .04578 L
.47994 .04578 L
.48231 .04578 L
.483 .04578 L
.48364 .04578 L
.48484 .16049 L
.48549 .16072 L
.48618 .16097 L
.48741 .16142 L
.49018 .16244 L
.49499 .16422 L
.49736 .1651 L
.4984 .1655 L
.49955 .16593 L
.5007 .16583 L
.50193 .16537 L
.50451 .1644 L
.50903 .16273 L
.51155 .1618 L
.51288 .16132 L
.51427 .16081 L
.5155 .16037 L
.51619 .04578 L
.51684 .04578 L
.51919 .04578 L
.53752 .04578 L
.57657 .04578 L
.61807 .04578 L
.65805 .04578 L
.69651 .04578 L
.73743 .04578 L
.77684 .04578 L
.81472 .04578 L
.85506 .04578 L
.89389 .04578 L
.93516 .04578 L
Mistroke
.97492 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`050000oooooooo
oooo06Ko00?oool01@000?ooooooooooo`1Vo`03oooo00<0003oooooool01Oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo002;oooo00D0I_ooooooooooool000000ooo
o`0306Kooooooooo08[oool008_oool01@1Vooooooooooooo`000003oooo00<0I_ooooooool0R_oo
o`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`2:oooo002;oooo00D0I_oooooo
ooooool000000oooo`0306Kooooooooo08[oool008_oool0101Vooooooooooooo`800002oooo00<0
I_ooooooool0R_ooo`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`2:oooo002;
oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo08[oool008_oool01@1Voooooooooooo
o`000003oooo00<0I_ooooooool0R_ooo`00Roooo`0506Kooooooooooooo000000?oool00`1Voooo
ooooo`2:oooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo08[oool008_oool0
101Vooooooooooooo`800002oooo00<0I_ooooooool0R_ooo`00Roooo`0506Kooooooooooooo0000
00?oool00`1Vooooooooo`2:oooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo
08[oool008_oool01@1Vooooooooooooo`000003oooo00<0I_ooooooool0R_ooo`00Roooo`0506Ko
oooooooooooo000000?oool00`1Vooooooooo`2:oooo002;oooo00D0I_ooooooooooool000000ooo
o`0306Kooooooooo08[oool008_oool0101Vooooooooooooo`800002oooo00<0I_ooooooool0R_oo
o`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`2:oooo002;oooo00D0I_oooooo
ooooool000000oooo`0306Kooooooooo08[oool008_oool01@1Vooooooooooooo`000003oooo00<0
I_ooooooool0R_ooo`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`2:oooo002;
oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo08[oool008_oool0101Voooooooooooo
o`800002oooo00<0I_ooooooool0R_ooo`00Roooo`0506Kooooooooooooo000000?oool00`1Voooo
ooooo`2:oooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo08[oool008_oool0
1@1Vooooooooooooo`000003oooo00<0I_ooooooool0R_ooo`00O?ooo`800004oooo0P0000Coool2
000000?oool0I_ooool00_ooo`050000oooooooooooo06Ko08coool007_oool010000?ooooooo`00
00Soool01@000?ooooooo`00001Vo`03oooo00D0003oooooooooool0I_l0S?ooo`00Noooo`040000
oooooooo00002oooo`03000006Ko06Ko00;oool300000P1Vohcoool007_oool010000?ooooooo`00
00Woool200000oooo`80I_l01@00001Vooooooooool0V@2<oooo001koooo00@0003oooooool00009
oooo00<0003oooooool01?ooo`050000ooooooooooooo`2I08coool007coool200002_ooo`<00004
oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool0
1@000?ooooooooooool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oo
ooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`800002oooo00?o
09Woooooool0R_ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oooooooooo
ool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I
08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:
oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool0
08ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Sooo
o`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2Ioooooooo08[oool008ooool0
1@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000
ooooooooooooo`2I08coool008Ooool500000oooo`050000ooooooooooooo`2I08coool008Woool0
0`000?ooooooo`03oooo00D0003ooooooooooooo09T0S?ooo`00ROooo`030000oooooooo00?oool3
000000?ooooo09Woool0Roooo`00ROooo`030000oooooooo00?oool01@000?ooooooooooool0V@2<
oooo0029oooo00<0003oooooool00oooo`050000ooooooooooooo`2I08coool008Soool200001Ooo
o`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`800002oooo00?o09Woooooool0R_ooo`00Soooo`050000
ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooo
oooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oooooooooo
ool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?oooo00D0003ooooooooooooo
09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<
oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool0
08ooool200000_ooo`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo002?
oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool0
1@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`800002
oooo00?o09Woooooool0R_ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oo
ooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Noooo`D00002oooo0P00
00Coool200001Oooo`050000ooooooooooooo`2I08coool007goool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00D0003ooooooooooooo09T0S?ooo`00OOooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`000003ooooo`2Ioooo08_oool007goool00`000?ooooooo`08oooo0P00
00Goool01@000?ooooooooooool0V@2<oooo001moooo00<0003oooooool02?ooo`030000oooooooo
00Coool01@000?ooooooooooool0V@2<oooo001loooo0P0000[oool300001?ooo`050000oooooooo
ooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo
09T0S?ooo`00Soooo`800002oooo00?o09Woooooool0R_ooo`00Soooo`050000ooooooooooooo`2I
08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?oo
o`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?
oooo0P0000;oool00ol0VOooooooo`2:oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Sooo
o`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_oo
o`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooo
oooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oooooooooo
ool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`800002oooo00?o09Wooooo
ool0R_ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<
oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Qoooo`@00004oooo00D0003ooooooooooooo
09T0S?ooo`00Qoooo`030000oooooooo00Goool01@000?ooooooooooool0V@2<oooo0028oooo00<0
003oooooool01?ooo`<000000oooool0VOooo`2;oooo0029oooo00<0003oooooool00oooo`050000
ooooooooooooo`2I08coool008Ooool010000?ooooooo`0000Coool01@000?ooooooooooool0V@2<
oooo0028oooo0P0000Goool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo
09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2Ioooooooo
08[oool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?oo
o`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?
oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`800002oooo00?o09Woooooool0R_ooo`00Sooo
o`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oo
ooooooooool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?oooo00D0003ooooo
oooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oooooooooo
ool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I
08coool008ooool200000_ooo`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<
oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool0
07_oool400000oooo`800004oooo0P0000Goool01@000?ooooooooooool0V@2<oooo001koooo00<0
003oooooool02Oooo`040000oooooooo00001?ooo`050000ooooooooooooo`2I08coool007coool0
0`000?ooooooo`0;oooo00<0003oooooool00_ooo`<000000oooool0VOooo`2;oooo001moooo00<0
003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`D00002oooo0P0000?oool500000_ooo`030000oooooooo07_oool007_oool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00<0
003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000>oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Woool00`000?oo
ooooo`02oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.5095 .04578 L
.51441 .04578 L
.51896 .04578 L
.52148 .04578 L
.52221 .04578 L
.52289 .04578 L
s
.52289 .04578 m
.52321 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.44268 .04578 L
.45262 .04578 L
.46172 .04578 L
.46618 .04578 L
.47106 .04578 L
.47329 .04578 L
.47451 .04578 L
.47567 .04578 L
.47674 .16043 L
.47791 .16085 L
.47994 .16159 L
.49008 .16535 L
.49504 .16723 L
.4972 .16806 L
.49834 .1685 L
.49955 .16897 L
.50078 .16884 L
.50191 .16841 L
.50414 .16755 L
.50906 .16568 L
.51444 .16366 L
.51707 .16269 L
.51949 .1618 L
.52184 .16094 L
.52302 .16052 L
.52431 .04578 L
.52561 .04578 L
.527 .04578 L
.5295 .04578 L
.54055 .04578 L
.58205 .04578 L
.62203 .04578 L
.6605 .04578 L
.70142 .04578 L
.74082 .04578 L
.77871 .04578 L
.81905 .04578 L
.85787 .04578 L
.89915 .04578 L
Mistroke
.93891 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooo06Ko
00Goool00`000?ooooooo`03oooo00<0I_ooool000001oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool0
0`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Voooo
ooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`28
oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`28oooo0029
oooo00<0I_ooooooool00oooo`800004oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo
00?oool00`000?ooooooo`03oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool0
0`000?ooooooo`03oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?oo
ooooo`03oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03
oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03oooo00<0
I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool200001?ooo`0306Kooooooooo08Soool0
08Woool00`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo08Soool008Woool0
0`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo08Soool008Woool00`1Voooo
ooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo08Soool008Woool00`1Vooooooooo`03
oooo00<0003oooooool00oooo`0306Kooooooooo08Soool008Woool00`1Vooooooooo`03oooo00<0
003oooooool00oooo`0306Kooooooooo08Soool008Woool00`1Vooooooooo`03oooo0P0000Coool0
0`1Vooooooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Voooo
ooooo`28oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`28
oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`28oooo0029
oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`28oooo0029oooo00<0
I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`28oooo0029oooo00<0I_oooooo
ool00oooo`800004oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?oo
ooooo`03oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03
oooo00<0I_ooooooool0R?ooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03oooo00<0
I_ooooooool0R?ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo00?oool0
0`1Vooooooooo`28oooo001koooo00@0003oooooool00008oooo00@0003oool0I_l00004oooo00<0
003oooooool00oooo`0306Kooooooooo08Soool007_oool010000?ooooooo`0000[oool00`1Vo`00
0?ooo`03oooo0`000004oooo06Ko06Ko06KoR_ooo`00Noooo`040000oooooooo00002Oooo`800000
0oooo`1Vo`1Vo`0206Ko00@00000I_l0I_l0I_l2oooo00?o09Woooooool0R?ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo00?oool00`1Vo`000?ooo`04oooo00?o09Woooooool0R?oo
o`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Sooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2I
oooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o
09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool2
00001?ooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Sooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo0P0000Coool00ol0VOooooooo`28
oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo0027
oooo1@0000?oool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00ROooo`030000oooooooo00?oool3
00000oooo`03o`2Ioooooooo08Soool008Woool00`000?ooooooo`03oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool008Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`03o`2I
oooooooo08Soool008Soool200001Oooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o
09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool2
00001?ooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Sooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo0P0000Coool00ol0VOooooooo`28
oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o
09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001moooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001moooo00<0
003oooooool02_ooo`030000oooooooo00;oool300000oooo`03o`2Ioooooooo08Soool007goool0
0`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00OOoo
o`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool00oooo`03o`2Ioooooooo
08Soool007coool200002_ooo`<00004oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo002?oooo0P0000Coool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Sooo
o`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28
oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo
08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo002?oooo0P0000Coool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo0027oooo100000Coool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00R?ooo`030000oooooooo00Coool300000oooo`03o`2Ioooooooo
08Soool008Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08Ooool010000?ooooooo`0000Coool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00R?oo
o`800005oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo0P0000Coool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo
08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004oooo00?o09Wooooo
ool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo08Soool008ooool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28
oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo0P0000Coool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo
08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo001koooo100000?oool200001?ooo`800005oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool007_oool00`000?ooooooo`09oooo00@0003oooooool00004
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool007coool00`000?ooooooo`0;oooo00<0
003oooooool00_ooo`<00003oooo00?o09Woooooool0R?ooo`00OOooo`030000oooooooo00Soool2
0000U_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800003
oooo1@0000;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00D0003ooooo
ooooool000000_ooo`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03oooo`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00004Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.51896 .04578 L
.52455 .04578 L
.52731 .04578 L
.52865 .04578 L
.52986 .04578 L
.53105 .04578 L
s
.53105 .04578 m
.53133 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.44268 .04578 L
.45262 .04578 L
.46172 .04578 L
.46388 .04578 L
.46618 .04578 L
.46687 .04578 L
.46751 .04578 L
.46871 .1604 L
.46984 .1608 L
.47106 .16125 L
.47994 .16452 L
.49008 .16838 L
.49504 .17031 L
.4972 .17116 L
.49834 .17161 L
.49955 .17209 L
.50078 .17196 L
.50191 .17151 L
.50414 .17063 L
.50906 .16871 L
.51949 .16474 L
.52431 .16294 L
.52684 .16201 L
.5295 .16104 L
.53092 .16053 L
.53173 .16024 L
.53248 .04578 L
.53379 .04578 L
.5352 .04578 L
.54055 .04578 L
.58205 .04578 L
.62203 .04578 L
.6605 .04578 L
.70142 .04578 L
.74082 .04578 L
.77871 .04578 L
.81905 .04578 L
.85787 .04578 L
.89915 .04578 L
Mistroke
.93891 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool0
0`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Voooo
ooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26
oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26oooo0027
oooo00<0I_ooooooool01Oooo`800006oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo
00Goool00`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool0
0`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool00`000?oo
ooooo`05oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`05
oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`05oooo00<0
I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool200001_ooo`0306Kooooooooo08Koool0
08Ooool00`1Vooooooooo`05oooo00<0003oooooool01Oooo`0306Kooooooooo08Koool008Ooool0
0`1Vooooooooo`05oooo00<0003oooooool01Oooo`0306Kooooooooo08Koool008Ooool00`1Voooo
ooooo`05oooo00<0003oooooool01Oooo`0306Kooooooooo08Koool008Ooool00`1Vooooooooo`05
oooo00<0003oooooool01Oooo`0306Kooooooooo08Koool008Ooool00`1Vooooooooo`05oooo00<0
003oooooool01Oooo`0306Kooooooooo08Koool008Ooool00`1Vooooooooo`05oooo0P0000Koool0
0`1Vooooooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Voooo
ooooo`26oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26
oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26oooo0027
oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26oooo0027oooo00<0
I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`26oooo0027oooo00<0I_oooooo
ool01Oooo`800006oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool00`000?oo
ooooo`05oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`05
oooo00<0I_ooooooool0Q_ooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`05oooo00<0
I_ooooooool0Q_ooo`00O?ooo`800004oooo0P0000?oool00`1Vo`0000000005oooo00<0003ooooo
ool01Oooo`0306Kooooooooo08Koool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`05oooo00<0I_ooooooool0Q_ooo`00Noooo`040000oooooooo00002?oo
o`80I_l00oooo`000?ooo`03oooo0`0000?oool306KoR?ooo`00Noooo`040000oooooooo00002Ooo
o`8000000`1Vooooooooo`02oooo00@0003oooooooooool206Ko0_ooo`03o`2Ioooooooo08Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`0406Ko00@00000I_l0I_l0I_l4oooo00?o
09Woooooool0Q_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`05oooo00?o09Wooooo
ool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo08Koool008ooool200001_ooo`03o`2Ioooooooo08Koool008ooool0
0`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?oo
ooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000
oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo
08Koool008ooool200001_ooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o
09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0
003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Wooooo
ool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo0P0000Koool0
0ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool0
0`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo0027oooo1@0000?oool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00ROooo`030000
oooooooo00?oool300001Oooo`03o`2Ioooooooo08Koool008Woool00`000?ooooooo`03oooo00<0
003oooooool01Oooo`03o`2Ioooooooo08Koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool01Oooo`03o`2Ioooooooo08Koool008Soool200001Oooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?oo
ooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000
oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo
08Koool008ooool200001_ooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o
09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0
003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Wooooo
ool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo0P0000Koool0
0ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool0
0`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?oo
ooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo00Goool00ol0VOooooooo`26oooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo00Goool00ol0VOooooooo`26
oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool300001Oooo`03o`2Ioooooooo
08Koool007goool00`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`05oooo00?o09Wooooo
ool0Q_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool01Ooo
o`03o`2Ioooooooo08Koool007coool200002_ooo`<00004oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000
oooooooo00Goool00ol0VOooooooo`26oooo002?oooo0P0000Koool00ol0VOooooooo`26oooo002?
oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o
09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0
003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Wooooo
ool0Q_ooo`00Soooo`800006oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool0
0ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool0
0`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool200001_oo
o`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000
oooooooo00Goool00ol0VOooooooo`26oooo002?oooo0P0000Koool00ol0VOooooooo`26oooo002?
oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o
09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo0027oooo1000
00Coool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Qoooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00R?ooo`030000oooooooo00Coool300001Ooo
o`03o`2Ioooooooo08Koool008Woool00`000?ooooooo`03oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`05oooo00?o09Wooooo
ool0Q_ooo`00R?ooo`800005oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool0
0`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo002?oooo0P0000Koool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Ooo
o`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2I
oooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`800006
oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?
oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o
09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOooooooo`26oooo002?oooo00<0
003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool200001_ooo`03o`2Ioooooooo08Koool0
08ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool0
0ol0VOooooooo`26oooo002?oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool008ooool0
0`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Soooo`030000oooooooo00Goool00ol0VOoo
ooooo`26oooo002?oooo0P0000Koool00ol0VOooooooo`26oooo002?oooo00<0003oooooool01Ooo
o`03o`2Ioooooooo08Koool008ooool00`000?ooooooo`05oooo00?o09Woooooool0Q_ooo`00Sooo
o`030000oooooooo00Goool00ol0VOooooooo`26oooo001koooo100000?oool200001?ooo`800005
oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool007_oool00`000?ooooooo`09oooo00@0
003oooooool00004oooo00<0003oooooool01Oooo`03o`2Ioooooooo08Koool007coool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`<00005oooo00?o09Woooooool0Q_ooo`00OOooo`030000
oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool0
07coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0R
oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0
003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool5
00000_ooo`800003oooo100000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`030000
oooooooo00Coool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo07[oool007_oool0
0`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`07oooo00@0003ooooo
ool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003
oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.51896 .04578 L
.52455 .04578 L
.52986 .04578 L
.53463 .04578 L
.53594 .04578 L
.53733 .04578 L
.53865 .04578 L
s
.53865 .04578 m
.53895 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.42237 .04578 L
.43215 .04578 L
.44268 .04578 L
.44778 .04578 L
.45262 .04578 L
.45697 .04578 L
.45816 .04578 L
.45943 .04578 L
.46063 .16034 L
.46172 .16074 L
.48258 .16855 L
.49174 .17214 L
.49424 .17314 L
.49693 .17422 L
.49824 .17475 L
.49947 .17525 L
.50058 .17523 L
.50178 .17474 L
.52053 .16735 L
.52552 .16545 L
.53082 .16347 L
.53534 .16181 L
.53658 .16136 L
.53792 .16087 L
.53918 .16041 L
.54033 .04578 L
.54161 .04578 L
.54282 .04578 L
.54507 .04578 L
.55014 .04578 L
.55926 .04578 L
.57996 .04578 L
.61842 .04578 L
.65934 .04578 L
.69875 .04578 L
.73663 .04578 L
.77697 .04578 L
.8158 .04578 L
.85707 .04578 L
Mistroke
.89683 .04578 L
.93508 .04578 L
.97578 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool00oooo`0406Kooooooooo
00001oooo`030000oooooooo00Goool00`000?ooo`1Vo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool008Coool00`1Vooooooooo`08oooo00<0003oooooool01ooo
o`0306Kooooooooo08Coool008Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`0306Ko
oooooooo08Coool008Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`0306Kooooooooo
08Coool008Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`0306Kooooooooo08Coool0
08Coool00`1Vooooooooo`08oooo0P0000Soool00`1Vooooooooo`24oooo0024oooo00<0I_oooooo
ool02?ooo`030000oooooooo00Ooool00`1Vooooooooo`24oooo0024oooo00<0I_ooooooool02?oo
o`030000oooooooo00Ooool00`1Vooooooooo`24oooo0024oooo00<0I_ooooooool02?ooo`030000
oooooooo00Ooool00`1Vooooooooo`24oooo0024oooo00<0I_ooooooool02?ooo`030000oooooooo
00Ooool00`1Vooooooooo`24oooo0024oooo00<0I_ooooooool02?ooo`030000oooooooo00Ooool0
0`1Vooooooooo`24oooo0024oooo00<0I_ooooooool02?ooo`800008oooo00<0I_ooooooool0Q?oo
o`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00Q?oo
o`0306Kooooooooo00Soool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00Q?ooo`0306Ko
oooooooo00Soool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00QOooo`0306Kooooooooo
00Ooool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00QOooo`0306Kooooooooo00Ooool0
0`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00QOooo`0306Kooooooooo00Ooool200002?oo
o`0306Kooooooooo08Coool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Ko
oooooooo08Coool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo
08Coool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool0
08Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool008Goool0
0`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo08Coool008Goool00`1Voooo
ooooo`07oooo0P0000Soool00`1Vooooooooo`24oooo0025oooo00<0I_ooooooool01oooo`030000
oooooooo00Ooool00`1Vooooooooo`24oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo
00Ooool00`1Vooooooooo`24oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Ooool0
0`1Vooooooooo`24oooo001loooo0P0000Coool2000000Coool0I_ooooooool200001Oooo`030000
oooooooo00Ooool00`1Vooooooooo`24oooo001koooo00@0003oooooool00006oooo00<0I_ooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0I_ooooooool0Q?ooo`00Nooo
o`040000oooooooo00001_ooo`80I_l3oooo00<0003oooooool00_ooo`<00005oooo0`1VohKoool0
07_oool010000?ooooooo`0000Soool00`1Vo`0000000005oooo00@0003oooooooooool406Ko0_oo
o`03o`2Ioooooooo08Coool007_oool010000?ooooooo`0000Woool01000001Vo`1Vo`1Vo`?oool0
10000?ooo`1Vo`1Vo`Koool00ol0VOooooooo`24oooo001loooo0P0000[oool3000000Koool0I_l0
I_l0I_l00000I_l8oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool200002?oo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`800008
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0
003oooooool01oooo`03o`2Ioooooooo08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo0027oooo1@0000?oool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00ROooo`030000oooooooo00?oool300001oooo`03o`2Ioooooooo08Coool0
08Woool00`000?ooooooo`03oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008Woool0
0`000?ooooooo`03oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008Soool200001Ooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`800008
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0
003oooooool01oooo`03o`2Ioooooooo08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`800008
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo00Ooool00ol0VOooooooo`24oooo001moooo00<0003oooooool02_ooo`030000oooooooo
00;oool300001oooo`03o`2Ioooooooo08Coool007goool00`000?ooooooo`08oooo0P0000Goool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00OOooo`030000oooooooo00Soool00`000?oo
ooooo`04oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool007coool200002_ooo`<00004
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P00
00Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?oo
o`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P00
00Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo0027oooo100000Coool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00Qoooo`030000oooooooo00Goool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00R?oo
o`030000oooooooo00Coool300001oooo`03o`2Ioooooooo08Coool008Woool00`000?ooooooo`03
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00R?ooo`800005oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24
oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool2
00002?ooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24
oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo001k
oooo100000?oool200001?ooo`800005oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
07_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool007coool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`<00007oooo00?o
09Woooooool0Q?ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00oooo
ob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo
00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool500000_ooo`800003oooo100000?oool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00<0003oooooool00oooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Soool00`000?ooooooo`05oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004Oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOoo
o`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.52059 .04578 L
.53057 .04578 L
.53984 .04578 L
.54444 .04578 L
.54576 .04578 L
.54701 .04578 L
s
.54701 .04578 m
.54729 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.42237 .04578 L
.43215 .04578 L
.43755 .04578 L
.44268 .04578 L
.44744 .04578 L
.44874 .04578 L
.45013 .04578 L
.45143 .04578 L
.45262 .16032 L
.45379 .16074 L
.45487 .16113 L
.45731 .16202 L
.46172 .16365 L
.48214 .17148 L
.49211 .17549 L
.4944 .17643 L
.49683 .17743 L
.49891 .1783 L
.50009 .17871 L
.5012 .17825 L
.50571 .17638 L
.51061 .17438 L
.51953 .17082 L
.52891 .16718 L
.53423 .16516 L
.53918 .16332 L
.54393 .16157 L
.5453 .16107 L
.54659 .1606 L
.54775 .04578 L
.54901 .04578 L
.55936 .04578 L
.57786 .04578 L
.61878 .04578 L
.65818 .04578 L
.69607 .04578 L
.73641 .04578 L
.77524 .04578 L
.81651 .04578 L
Mistroke
.85627 .04578 L
.89452 .04578 L
.93522 .04578 L
.9744 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00D0003oooooooooool0I_l01?ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00D0003oooooooooool0I_l00oooo`030000oooooooo
00Koool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo0022oooo00<0I_ooooooool02_ooo`030000
oooooooo00Woool00`1Vooooooooo`22oooo0022oooo00<0I_ooooooool02_ooo`030000oooooooo
00Woool00`1Vooooooooo`22oooo0022oooo00<0I_ooooooool02_ooo`030000oooooooo00Woool0
0`1Vooooooooo`22oooo0022oooo00<0I_ooooooool02_ooo`030000oooooooo00Woool00`1Voooo
ooooo`22oooo0022oooo00<0I_ooooooool02_ooo`80000:oooo00<0I_ooooooool0P_ooo`00P_oo
o`0306Kooooooooo00[oool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00P_ooo`0306Ko
oooooooo00[oool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00P_ooo`0306Kooooooooo
00[oool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00P_ooo`0306Kooooooooo00[oool0
0`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00P_ooo`0306Kooooooooo00[oool00`000?oo
ooooo`09oooo00<0I_ooooooool0P_ooo`00P_ooo`0306Kooooooooo00[oool200002_ooo`0306Ko
oooooooo08;oool008;oool00`1Vooooooooo`0:oooo00<0003oooooool02Oooo`0306Kooooooooo
08;oool008;oool00`1Vooooooooo`0:oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool0
08;oool00`1Vooooooooo`0:oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool008?oool0
0`1Vooooooooo`09oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool008?oool00`1Voooo
ooooo`09oooo00<0003oooooool02Oooo`0306Kooooooooo08;oool008?oool00`1Vooooooooo`09
oooo0P0000[oool00`1Vooooooooo`22oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo
00Woool00`1Vooooooooo`22oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool0
0`1Vooooooooo`22oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Voooo
ooooo`22oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Vooooooooo`22
oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Vooooooooo`22oooo0023
oooo00<0I_ooooooool02Oooo`80000:oooo00<0I_ooooooool0P_ooo`00Poooo`0306Kooooooooo
00Woool00`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool0
0`000?ooooooo`09oooo00<0I_ooooooool0P_ooo`00Poooo`0306Kooooooooo00Woool00`000?oo
ooooo`09oooo00<0I_ooooooool0P_ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo00Woool00`1Vooooooooo`22oooo001koooo00@0003oooooool00004oooo00D0I_oooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`09oooo00<0I_ooooooool0P_oo
o`00Noooo`040000oooooooo00001?ooo`<0I_l4oooo00<0003oooooool00_ooo`<00007oooo0`1V
ohCoool007_oool010000?ooooooo`0000Ooool206Ko0P0000Goool00`000?ooooooo`04oooo0`1V
o`;oool00ol0VOooooooo`22oooo001koooo00@0003oooooool00009oooo00<00000I_ooool01?oo
o`030000oooooooo00;oool206Ko1Oooo`03o`2Ioooooooo08;oool007coool200002_ooo`<00000
1@1Vooooooooooooo`000002oooo0P1Vo`Ooool00ol0VOooooooo`22oooo002<oooo0`1Vo`030000
06Ko06Ko00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_oo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo0027oooo1@00
00?oool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00ROooo`030000oooooooo00?oool300002Ooo
o`03o`2Ioooooooo08;oool008Woool00`000?ooooooo`03oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008Woool00`000?ooooooo`03oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool008Soool200001Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_oo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool300002Oooo`03o`2Ioooooooo08;oool007goool00`000?oo
ooooo`08oooo0P0000Goool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
07coool200002_ooo`<00004oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`80000:
oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo0027oooo100000Coool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00R?ooo`030000oooooooo00Coool300002Oooo`03o`2Ioooooooo08;oool0
08Woool00`000?ooooooo`03oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00R?ooo`800005
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P00
00[oool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_oo
o`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P00
00[oool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo001koooo100000?oool200001?ooo`800005oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool007_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool007coool00`000?ooooooo`0;oooo00<0003ooooo
ool00_ooo`<00009oooo00?o09Woooooool0P_ooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P00
00Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo
00Woool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>
oooo00<0003oooooool02_ooo`050000oooooooooooo000007goool007_oool01@000?oooooooooo
o`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.52059 .04578 L
.53984 .04578 L
.54934 .04578 L
.55195 .04578 L
.55338 .04578 L
.55408 .04578 L
.55472 .04578 L
s
.55472 .04578 m
.55504 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.42237 .04578 L
.43215 .04578 L
.43755 .04578 L
.44021 .04578 L
.44151 .04578 L
.44268 .04578 L
.44387 .04578 L
.44498 .16043 L
.44616 .16085 L
.44744 .16131 L
.45262 .16322 L
.46172 .16663 L
.48126 .17431 L
.49162 .17857 L
.4946 .17982 L
.49743 .18102 L
.49866 .18154 L
.49996 .1821 L
.50064 .18184 L
.50139 .18152 L
.50272 .18096 L
.52314 .17253 L
.54221 .16515 L
.54712 .16331 L
.54981 .16232 L
.5523 .16141 L
.5534 .16101 L
.55444 .16064 L
.55563 .04578 L
.55672 .04578 L
.56155 .04578 L
.58241 .04578 L
.62088 .04578 L
.6618 .04578 L
.7012 .04578 L
.73909 .04578 L
.77943 .04578 L
.81825 .04578 L
.85953 .04578 L
Mistroke
.89929 .04578 L
.93753 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oool0I_l01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool00oooo`0306Kooooo000000Soool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0020oooo00<0I_ooooooool03?ooo`030000oooooooo00_oool0
0`1Vooooooooo`20oooo0020oooo00<0I_ooooooool03?ooo`030000oooooooo00_oool00`1Voooo
ooooo`20oooo0020oooo00<0I_ooooooool03?ooo`030000oooooooo00_oool00`1Vooooooooo`20
oooo0020oooo00<0I_ooooooool03?ooo`030000oooooooo00_oool00`1Vooooooooo`20oooo0020
oooo00<0I_ooooooool03?ooo`80000<oooo00<0I_ooooooool0P?ooo`00P?ooo`0306Kooooooooo
00coool00`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00P?ooo`0306Kooooooooo00coool0
0`000?ooooooo`0;oooo00<0I_ooooooool0P?ooo`00P?ooo`0306Kooooooooo00coool00`000?oo
ooooo`0;oooo00<0I_ooooooool0P?ooo`00P?ooo`0306Kooooooooo00coool00`000?ooooooo`0;
oooo00<0I_ooooooool0P?ooo`00P?ooo`0306Kooooooooo00coool00`000?ooooooo`0;oooo00<0
I_ooooooool0P?ooo`00P?ooo`0306Kooooooooo00coool200003?ooo`0306Kooooooooo083oool0
083oool00`1Vooooooooo`0<oooo00<0003oooooool02oooo`0306Kooooooooo083oool0083oool0
0`1Vooooooooo`0<oooo00<0003oooooool02oooo`0306Kooooooooo083oool0083oool00`1Voooo
ooooo`0<oooo00<0003oooooool02oooo`0306Kooooooooo083oool0087oool00`1Vooooooooo`0;
oooo00<0003oooooool02oooo`0306Kooooooooo083oool0087oool00`1Vooooooooo`0;oooo00<0
003oooooool02oooo`0306Kooooooooo083oool0087oool00`1Vooooooooo`0;oooo0P0000coool0
0`1Vooooooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool00`1Voooo
ooooo`20oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool00`1Vooooooooo`20
oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool00`1Vooooooooo`20oooo0021
oooo00<0I_ooooooool02oooo`030000oooooooo00_oool00`1Vooooooooo`20oooo0021oooo00<0
I_ooooooool02oooo`030000oooooooo00_oool00`1Vooooooooo`20oooo0021oooo00<0I_oooooo
ool02oooo`80000<oooo00<0I_ooooooool0P?ooo`00POooo`0306Kooooooooo00_oool00`000?oo
ooooo`0;oooo00<0I_ooooooool0P?ooo`00POooo`0306Kooooooooo00_oool00`000?ooooooo`0;
oooo00<0I_ooooooool0P?ooo`00POooo`0306Kooooooooo00_oool00`000?ooooooo`0;oooo00<0
I_ooooooool0P?ooo`00O?ooo`800003oooo00<0I_l0000000001?ooo`800005oooo00<0003ooooo
ool02oooo`0306Kooooooooo083oool007_oool010000?ooooooo`0000;oool00`1Vooooooooo`03
oooo00@0003oooooool00004oooo00<0003oooooool02oooo`0306Kooooooooo083oool007_oool0
10000?ooooooo`0000;oool306Ko1_ooo`030000oooooooo00;oool300002Oooo`<0I_n2oooo001k
oooo00@0003oooooool00005oooo0`1Vo`03oooo0000000000Goool00`000?ooooooo`07oooo0P1V
o`;oool00ol0VOooooooo`20oooo001koooo00@0003oooooool00008oooo00<0I_l0003oool01Ooo
o`030000oooooooo00Goool206Ko1?ooo`03o`2Ioooooooo083oool007coool200002_ooo`<00000
1@1Vooooooooooooo`000004oooo0`1Vo`Koool00ol0VOooooooo`20oooo002<oooo0P1Vo`04oooo
0000oooooooo0P1Vo`Woool00ol0VOooooooo`20oooo002>oooo00@0I_l00000I_l0I_l;oooo00?o
09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo002?oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?ooo`03o`2Ioooooooo
083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08Ooool500000oooo`030000oooooooo00_oool00ol0VOooooooo`20oooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo00_oool00ol0VOooooooo`20oooo0029oooo00<0003oooooool00ooo
o`<0000;oooo00?o09Woooooool0P?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00R?ooo`800005oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo002?oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?ooo`03o`2Ioooooooo
083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo002?oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001koooo1@0000;oool200001?oo
o`800005oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool007goool00`000?ooooooo`07
oooo00@0003oooooool00004oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool007goool0
0`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000;oooo00?o09Woooooool0P?ooo`00OOoo
o`030000oooooooo00Soool200001Oooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001m
oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool008ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo
083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool008ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008Ooool400001?ooo`030000
oooooooo00_oool00ol0VOooooooo`20oooo0027oooo00<0003oooooool01Oooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo0028oooo00<0003oooooool01?ooo`<0000;oooo00?o09Wooooo
ool0P?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Qoooo`040000oooooooo00001?ooo`030000oooooooo00_oool00ol0VOooooooo`20oooo0028
oooo0P0000Goool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo0P0000coool00ol0VOoo
ooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?ooo`00Soooo`030000
oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo
083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo
00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool007_oool400000oooo`800004oooo0P0000Goool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Noooo`030000oooooooo00Woool010000?ooooooo`00
00Coool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00O?ooo`030000oooooooo00_oool0
0`000?ooooooo`02oooo0`0000_oool00ol0VOooooooo`20oooo001moooo00<0003oooooool02?oo
o`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:
oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool01?ooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?oo
ooooo`0:oooo00@0003oooooooooool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000Aoooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.52059 .04578 L
.53984 .04578 L
.54934 .04578 L
.55436 .04578 L
.55712 .04578 L
.55972 .04578 L
.56092 .04578 L
.56218 .04578 L
.56285 .04578 L
s
.56285 .04578 m
.56303 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.41127 .04578 L
.42237 .04578 L
.42781 .04578 L
.43049 .04578 L
.43298 .04578 L
.43522 .04578 L
.43648 .04578 L
.43762 .16063 L
.43887 .16109 L
.44023 .16158 L
.44268 .16248 L
.46172 .16969 L
.48126 .17756 L
.49162 .18193 L
.4946 .18321 L
.49743 .18444 L
.49866 .18498 L
.49996 .18555 L
.50064 .18529 L
.50139 .18496 L
.50272 .18438 L
.52314 .17574 L
.54221 .16817 L
.55163 .16459 L
.55677 .16268 L
.55928 .16176 L
.56155 .16093 L
.56285 .16046 L
.56407 .04578 L
.56535 .04578 L
.56675 .04578 L
.57243 .04578 L
.58241 .04578 L
.62333 .04578 L
.66273 .04578 L
.70062 .04578 L
.74096 .04578 L
.77978 .04578 L
.82106 .04578 L
Mistroke
.86082 .04578 L
.89907 .04578 L
.93976 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`03000006Kooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001noooo00<0I_ooooooool03_ooo`030000oooooooo00goool0
0ol0V@1Vooooo`1noooo001noooo00<0I_ooooooool03_ooo`030000oooooooo00goool00ol0V@1V
ooooo`1noooo001noooo00<0I_ooooooool03_ooo`030000oooooooo00goool00ol0V@1Vooooo`1n
oooo001noooo00<0I_ooooooool03_ooo`030000oooooooo00goool00ol0V@1Vooooo`1noooo001n
oooo00<0I_ooooooool03_ooo`80000>oooo00?o09T0I_ooool0O_ooo`00O_ooo`0306Kooooooooo
00koool00`000?ooooooo`0=oooo00?o09T0I_ooool0O_ooo`00O_ooo`0306Kooooooooo00koool0
0`000?ooooooo`0=oooo00?o09T0I_ooool0O_ooo`00O_ooo`0306Kooooooooo00koool00`000?oo
ooooo`0=oooo00?o09T0I_ooool0O_ooo`00O_ooo`0306Kooooooooo00koool00`000?ooooooo`0=
oooo00?o09T0I_ooool0O_ooo`00O_ooo`0306Kooooooooo00koool00`000?ooooooo`0=oooo00?o
09T0I_ooool0O_ooo`00O_ooo`0306Kooooooooo00koool200003_ooo`03o`2I06Kooooo07koool0
07koool00`1Vooooooooo`0>oooo00<0003oooooool03Oooo`03o`2I06Kooooo07koool007koool0
0`1Vooooooooo`0>oooo00<0003oooooool03Oooo`03o`2I06Kooooo07koool007koool00`1Voooo
ooooo`0>oooo00<0003oooooool03Oooo`0306Kooooooooo07koool007ooool00`1Vooooooooo`0=
oooo00<0003oooooool03Oooo`0306Kooooooooo07koool007ooool00`1Vooooooooo`0=oooo00<0
003oooooool03Oooo`0306Kooooooooo07koool007ooool00`1Vooooooooo`0=oooo0P0000koool0
0`1Vooooooooo`1noooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo00goool00`1Voooo
ooooo`1noooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo00goool00`1Vooooooooo`1n
oooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo00goool00`1Vooooooooo`1noooo001o
oooo00<0I_ooooooool03Oooo`030000oooooooo00goool00`1Vooooooooo`1noooo001ooooo00<0
I_ooooooool03Oooo`030000oooooooo00goool00`1Vooooooooo`1noooo001ooooo00<0I_oooooo
ool03Oooo`80000>oooo00<0I_ooooooool0O_ooo`00Ooooo`0306Kooooooooo00goool00`000?oo
ooooo`0=oooo00<0I_ooooooool0O_ooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0=
oooo00<0I_ooooooool0O_ooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0=oooo00<0
I_ooooooool0O_ooo`00O?ooo`8000001?ooo`1Vooooooooo`800004oooo0P0000Goool00`000?oo
ooooo`0=oooo00<0I_ooooooool0O_ooo`00Noooo`050000oooooooo000006Ko00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`0=oooo00<0I_ooooooool0O_ooo`00Noooo`040000oooooooo
00000`1Vo`Soool00`000?ooooooo`02oooo0`0000coool206KoP?ooo`00Noooo`040000oooooooo
00000oooo`80I_l4oooo0P0000Goool00`000?ooooooo`0:oooo0P1Vo`03ooooo`2Ioooo07ooool0
07_oool010000?ooooooo`0000Goool306Ko00?oool0003oool01Oooo`030000oooooooo00Ooool3
06Ko0oooo`03o`2Ioooooooo07koool007coool200002Oooo`0406Ko0000000000001?ooo`030000
oooooooo00Goool206Ko1_ooo`03o`2Ioooooooo07koool008Woool306Ko0oooo`030000oooooooo
00;oool306Ko2?ooo`03o`2Ioooooooo07koool008coool206Ko00Coool0003oooooool206Ko2ooo
o`03o`2Ioooooooo07koool008koool0101Vo`000000001Vo`goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo0P0000koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>
oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Qoooo`D00003oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08Woool00`000?ooooooo`03oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008Woool0
0`000?ooooooo`03oooo0`0000goool00ol0VOooooooo`1noooo0029oooo00<0003oooooool00ooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo0029oooo00<0003oooooool00oooo`030000
oooooooo00goool00ol0VOooooooo`1noooo0028oooo0P0000Goool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo0P0000koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>
oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool007_oool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00OOoo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0=oooo00?o09Wooooo
ool0O_ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0000goool00ol0VOoo
ooooo`1noooo001moooo00<0003oooooool02?ooo`800005oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool007goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo
00goool00ol0VOooooooo`1noooo001loooo0P0000[oool300001?ooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_oo
o`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=
oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo0P00
00koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_oo
o`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Qooo
o`@00004oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008Ooool00`000?ooooooo`05
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008Soool00`000?ooooooo`04oooo0`00
00goool00ol0VOooooooo`1noooo0029oooo00<0003oooooool00oooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo0027oooo00@0003oooooool00004oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008Soool200001Oooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo
00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool2
00003_ooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo0P0000koool00ol0VOooooooo`1n
oooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=
oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo
00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Noooo`@00003oooo0P0000Coool2
00001Oooo`030000oooooooo00goool00ol0VOooooooo`1noooo001koooo00<0003oooooool02Ooo
o`040000oooooooo00001?ooo`030000oooooooo00goool00ol0VOooooooo`1noooo001loooo00<0
003oooooool02oooo`030000oooooooo00;oool300003Oooo`03o`2Ioooooooo07koool007goool0
0`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2E
oooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003ooooo
ool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06
oooo1@0000;oool200001Oooo`<00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00[oool0
1@000?ooooooooooo`00001moooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool0
0`000?ooooooo`07oooo1@0000?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00koool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oool000000oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.52059 .04578 L
.53984 .04578 L
.54934 .04578 L
.55972 .04578 L
.56446 .04578 L
.56706 .04578 L
.56834 .04578 L
.56951 .04578 L
.57063 .04578 L
s
.57063 .04578 m
.57092 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40095 .04578 L
.41127 .04578 L
.41696 .04578 L
.42237 .04578 L
.42482 .04578 L
.42617 .04578 L
.42744 .04578 L
.42816 .04578 L
.42894 .16037 L
.42966 .16062 L
.43031 .16086 L
.43298 .16183 L
.44268 .16543 L
.46172 .17283 L
.48214 .18127 L
.49211 .18559 L
.4944 .1866 L
.49683 .18769 L
.49891 .18862 L
.50009 .18907 L
.5012 .18857 L
.50571 .18655 L
.51061 .1844 L
.51953 .18056 L
.53918 .17247 L
.54901 .16861 L
.55936 .16467 L
.56363 .16308 L
.5682 .1614 L
.56955 .16091 L
.57082 .16045 L
.57196 .04578 L
.5732 .04578 L
.57786 .04578 L
.61878 .04578 L
.65818 .04578 L
.69607 .04578 L
.73641 .04578 L
.77524 .04578 L
.81651 .04578 L
Mistroke
.85627 .04578 L
.89452 .04578 L
.93522 .04578 L
.9744 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`03oooo00<0I_ooool000002?ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`040000ooooo`2I06Ko1Oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool007coool00`1Vooooooooo`0@oooo00<0003oooooool03ooo
o`03o`2I06Kooooo07coool007coool00`1Vooooooooo`0@oooo00<0003oooooool03oooo`03o`2I
06Kooooo07coool007coool00`1Vooooooooo`0@oooo00<0003oooooool03oooo`03o`2I06Kooooo
07coool007coool00`1Vooooooooo`0@oooo00<0003oooooool03oooo`03o`2I06Kooooo07coool0
07coool00`1Vooooooooo`0@oooo0P00013oool00ol0V@1Vooooo`1loooo001loooo00<0I_oooooo
ool04?ooo`030000oooooooo00ooool00ol0V@1Vooooo`1loooo001loooo00<0I_ooooooool04?oo
o`030000oooooooo00ooool00ol0V@1Vooooo`1loooo001loooo00<0I_ooooooool04?ooo`030000
oooooooo00ooool00ol0V@1Vooooo`1loooo001loooo00<0I_ooooooool04?ooo`030000oooooooo
00ooool00ol0V@1Vooooo`1loooo001loooo00<0I_ooooooool04?ooo`030000oooooooo00ooool0
0ol0V@1Vooooo`1loooo001loooo00<0I_ooooooool04?ooo`80000@oooo00?o09T0I_ooool0O?oo
o`00O?ooo`0306Kooooooooo013oool00`000?ooooooo`0?oooo00?o09T0I_ooool0O?ooo`00O?oo
o`0306Kooooooooo013oool00`000?ooooooo`0?oooo00?o09T0I_ooool0O?ooo`00O?ooo`0306Ko
oooooooo013oool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00O?ooo`0306Kooooooooo
013oool00`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00O?ooo`0306Kooooooooo013oool0
0`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00O?ooo`0306Kooooooooo013oool200004?oo
o`0306Kooooooooo07coool007coool00`1Vooooooooo`0@oooo00<0003oooooool03oooo`0306Ko
oooooooo07coool007coool00`1Vooooooooo`0@oooo00<0003oooooool03oooo`0306Kooooooooo
07coool007coool00`1Vooooooooo`0@oooo00<0003oooooool03oooo`0306Kooooooooo07coool0
07coool00`1Vooooooooo`0@oooo00<0003oooooool03oooo`0306Kooooooooo07coool007coool0
0`1Vooooooooo`0@oooo00<0003oooooool03oooo`0306Kooooooooo07coool007coool00`1Voooo
ooooo`0@oooo0P00013oool00`1Vooooooooo`1loooo001loooo00<0I_ooooooool04?ooo`030000
oooooooo00ooool00`1Vooooooooo`1loooo001loooo00<0I_ooooooool04?ooo`030000oooooooo
00ooool00`1Vooooooooo`1loooo001loooo00<0I_ooooooool04?ooo`030000oooooooo00ooool0
0`1Vooooooooo`1loooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool03ooo
o`0306Kooooooooo07coool007_oool01000001Vooooo`0000Soool010000?ooooooo`0000Coool0
0`000?ooooooo`0?oooo00<0I_ooooooool0O?ooo`00Noooo`04000006Ko06Ko00002oooo`030000
oooooooo00;oool300003_ooo`80I_mnoooo001koooo00@0003oooooool0000306Ko1_ooo`800005
oooo00<0003oooooool03?ooo`80I_l00oooool0VOooo`1moooo001koooo00@0003oooooool00003
oooo0P1Vo`Coool00`000?ooooooo`04oooo00<0003oooooool02Oooo`<0I_l3oooo00?o09Wooooo
ool0O?ooo`00O?ooo`800006oooo0`1Vo`04oooo0000000000001?ooo`030000oooooooo00Koool3
06Ko1_ooo`03o`2Ioooooooo07coool008Ooool206Ko1_ooo`030000oooooooo00Coool206Ko2Ooo
o`03o`2Ioooooooo07coool008Woool306Ko0oooo`030000oooooooo00;oool206Ko2oooo`03o`2I
oooooooo07coool008coool306Ko0P0000<0I_l=oooo00?o09Woooooool0O?ooo`00S_ooo`0306Ko
0000oooo013oool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00Soooo`80000@oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008Ooool500000oooo`030000oooooooo00ooool00ol0VOooooooo`1loooo0029oooo00<0
003oooooool00oooo`030000oooooooo00ooool00ol0VOooooooo`1loooo0029oooo00<0003ooooo
ool00oooo`<0000?oooo00?o09Woooooool0O?ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00R?ooo`800005oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00Soooo`80000@oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo001koooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool007goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool0
07goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000?oooo00?o09Woooooool0O?oo
o`00OOooo`030000oooooooo00Soool200001Oooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo001moooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`80000@oooo00?o
09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008Ooool400001?oo
o`030000oooooooo00ooool00ol0VOooooooo`1loooo0027oooo00<0003oooooool01Oooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo0028oooo00<0003oooooool01?ooo`<0000?oooo00?o
09Woooooool0O?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo0028oooo0P0000Goool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool0
0ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`80000@oooo00?o09Woooooool0O?ooo`00Sooo
o`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool007_oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Noooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00O?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0000ooool00ol0VOooooooo`1loooo001moooo00<0003ooooo
ool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?oo
o`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002
oooo0P0000Goool300000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00[oool0
10000?ooooooo`0000;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`000?ooooooo`07oooo1@0000Coool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000
oooooooo00000oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
017oool00`000?ooooooo`08oooo00<0003oool000000oooo`030000oooooooo00?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000;oooo0P0000?oool300000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.55838 .04578 L
.56817 .04578 L
.57355 .04578 L
.57618 .04578 L
.57734 .04578 L
.57861 .04578 L
.57931 .04578 L
s
.57931 .04578 m
.57947 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40134 .04578 L
.41134 .04578 L
.41408 .04578 L
.41703 .04578 L
.41846 .04578 L
.41917 .04578 L
.41982 .04578 L
.42104 .16038 L
.42168 .16061 L
.42237 .16086 L
.46395 .17696 L
.4741 .18122 L
.48482 .18587 L
.49397 .18997 L
.49648 .19112 L
.49786 .19175 L
.49916 .19235 L
.50038 .19256 L
.5017 .19195 L
.50401 .19089 L
.54257 .1743 L
.56234 .16654 L
.57232 .1628 L
.57506 .16179 L
.5765 .16127 L
.57801 .16072 L
.57865 .16049 L
.57934 .16024 L
.58009 .04578 L
.58079 .04578 L
.58335 .04578 L
.62484 .04578 L
.66483 .04578 L
.70329 .04578 L
.74421 .04578 L
.78361 .04578 L
.8215 .04578 L
.86184 .04578 L
.90067 .04578 L
.94194 .04578 L
Mistroke
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool01@000?ooooooooooo`1Vo`03oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00;oool0
1@1Vooooooooooooo`000007oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo001joooo00<0I_ooooooool04_ooo`030000
oooooooo01;oool00`1Vooooooooo`1ioooo001joooo00<0I_ooooooool04_ooo`030000oooooooo
01;oool00`1Vooooooooo`1ioooo001joooo00<0I_ooooooool04_ooo`030000oooooooo01;oool0
0`1Vooooooooo`1ioooo001joooo00<0I_ooooooool04_ooo`030000oooooooo01;oool00`1Voooo
ooooo`1ioooo001joooo00<0I_ooooooool04_ooo`80000Coooo00<0I_ooooooool0NOooo`00N_oo
o`0306Kooooooooo01;oool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0306Ko
oooooooo01;oool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0306Kooooooooo
01;oool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0306Kooooooooo01;oool0
0`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0306Kooooooooo01;oool00`000?oo
ooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0306Kooooooooo01;oool200004oooo`0306Ko
oooooooo07Woool007[oool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`0306Kooooooooo
07Woool007[oool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`0306Kooooooooo07Woool0
07[oool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`0306Kooooooooo07Woool007[oool0
0`1Vooooooooo`0Boooo00<0003oooooool04_ooo`0306Kooooooooo07Woool007[oool00`1Voooo
ooooo`0Boooo00<0003oooooool04_ooo`0306Kooooooooo07Woool007[oool00`1Vooooooooo`0B
oooo0P0001?oool00`1Vooooooooo`1ioooo001joooo00<0I_ooooooool04_ooo`030000oooooooo
01;oool00`1Vooooooooo`1ioooo001joooo00<0I_ooooooool04_ooo`030000oooooooo01;oool0
0`1Vooooooooo`1ioooo001joooo00<0I_ooooooool04_ooo`030000oooooooo01;oool00`1Voooo
ooooo`1ioooo001joooo00<0I_ooooooool04_ooo`030000oooooooo01;oool00`1Vooooooooo`1i
oooo001joooo00<0I_ooooooool04_ooo`030000oooooooo01;oool00`1Vooooooooo`1ioooo001j
oooo00<0I_ooooooool04_ooo`80000Coooo00<0I_ooooooool0NOooo`00N_ooo`0306Kooooooooo
01;oool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0306Kooooooooo01;oool0
0`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0306Kooooooooo01;oool00`000?oo
ooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0406Kooooo000000001?ooo`800004oooo0P00
00Goool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00N_ooo`0506Ko0000oooooooo0000
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0Boooo00<0I_ooooooool0NOooo`00N_oo
o`0506Ko000006Kooooo000000_oool00`000?ooooooo`02oooo0`0000ooool406KoNoooo`00Nooo
o`050000oooo06Ko000006Ko00Soool200001Oooo`030000oooooooo00coool306Ko0oooo`03o`2I
oooooooo07Woool007_oool01@000?ooooooo`000?ooo`0206Ko1_ooo`030000oooooooo00Coool0
0`000?ooooooo`0:oooo0P1Vo`Koool00ol0VOooooooo`1ioooo001loooo0P0000Coool306Ko0ooo
o`<00004oooo00<0003oooooool02?ooo`80I_l8oooo00?o09Woooooool0NOooo`00QOooo`80I_l8
oooo00<0003oooooool01_ooo`80I_l:oooo00?o09Woooooool0NOooo`00Qoooo`<0I_l5oooo00<0
003oooooool01?ooo`80I_l<oooo00?o09Woooooool0NOooo`00R_ooo`80I_l3oooo0P0000?oool2
06Ko3_ooo`03o`2Ioooooooo07Woool008coool206Ko00Coool0003oooooool206Ko4?ooo`03o`2I
oooooooo07Woool008koool0101Vo`00001Vo`1Voa;oool00ol0VOooooooo`1ioooo002?oooo00<0
003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Wooooo
ool0NOooo`00Soooo`80000Coooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOoo
ooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool200004ooo
o`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Sooo
o`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2I
oooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P0001?oool00ol0VOooooooo`1ioooo002?
oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo0027oooo1@00
00?oool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00ROooo`030000oooooooo00?oool300004_oo
o`03o`2Ioooooooo07Woool008Woool00`000?ooooooo`03oooo00<0003oooooool04_ooo`03o`2I
oooooooo07Woool008Woool00`000?ooooooo`03oooo00<0003oooooool04_ooo`03o`2Ioooooooo
07Woool008Soool200001Oooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0
003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Wooooo
ool0NOooo`00Soooo`80000Coooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOoo
ooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool200004ooo
o`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Sooo
o`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2I
oooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P0001?oool00ol0VOooooooo`1ioooo002?
oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0
003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Wooooo
ool0NOooo`00Soooo`80000Coooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo01;oool00ol0VOooooooo`1ioooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool300004_ooo`03o`2Ioooooooo07Woool007goool00`000?oo
ooooo`08oooo0P0000Goool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
07coool200002_ooo`<00004oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOoo
ooooo`1ioooo002?oooo0P0001?oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_oo
o`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Sooo
o`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2I
oooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`80000C
oooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?
oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0
003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool200004oooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOoo
ooooo`1ioooo002?oooo0P0001?oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_oo
o`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Sooo
o`030000oooooooo01;oool00ol0VOooooooo`1ioooo0027oooo100000Coool00`000?ooooooo`0B
oooo00?o09Woooooool0NOooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00R?ooo`030000oooooooo00Coool300004_ooo`03o`2Ioooooooo07Woool0
08Woool00`000?ooooooo`03oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00R?ooo`800005
oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P00
01?oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`80000Coooo00?o09Woooooool0NOoo
o`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_oo
o`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Sooo
o`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2I
oooooooo07Woool008ooool200004oooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0B
oooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?
oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P00
01?oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo001koooo100000?oool200001?ooo`800005oooo00<0003oooooool04_oo
o`03o`2Ioooooooo07Woool007_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0
003oooooool04_ooo`03o`2Ioooooooo07Woool007coool00`000?ooooooo`0;oooo00<0003ooooo
ool00_ooo`<0000Boooo00?o09Woooooool0NOooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P00
00Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo
00[oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>
oooo00<0003oooooool02?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo0000017oool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo07_oool0
07coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.55838 .04578 L
.56817 .04578 L
.57861 .04578 L
.58157 .04578 L
.58436 .04578 L
.58558 .04578 L
.58686 .04578 L
s
.58686 .04578 m
.58703 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.40134 .04578 L
.40616 .04578 L
.40882 .04578 L
.41013 .04578 L
.41134 .04578 L
.41203 .04578 L
.41276 .16025 L
.41358 .16055 L
.41432 .16082 L
.41703 .1618 L
.42237 .16377 L
.46243 .17964 L
.48081 .18762 L
.49124 .19236 L
.49386 .19357 L
.49634 .19473 L
.49856 .19578 L
.49982 .19637 L
.50098 .19599 L
.50213 .19545 L
.5032 .19495 L
.50565 .1938 L
.51061 .19151 L
.52092 .18685 L
.54199 .17779 L
.56046 .17033 L
.57093 .16629 L
.57604 .16437 L
.58067 .16265 L
.58307 .16177 L
.58432 .16131 L
.58566 .16083 L
.58682 .1604 L
.58811 .04578 L
.58927 .04578 L
.59036 .04578 L
.60071 .04578 L
.62181 .04578 L
.66064 .04578 L
.70191 .04578 L
Mistroke
.74167 .04578 L
.77992 .04578 L
.82062 .04578 L
.8598 .04578 L
.90143 .04578 L
.94155 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooo`1Vo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Coool00`1Voooo
o`000007oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Coool0
0`1Vooooooooo`1goooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Coool00`1Voooo
ooooo`1goooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Coool00`1Vooooooooo`1g
oooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Coool00`1Vooooooooo`1goooo001h
oooo00<0I_ooooooool05?ooo`80000Eoooo00<0I_ooooooool0Moooo`00N?ooo`0306Kooooooooo
01Coool00`000?ooooooo`0Doooo00<0I_ooooooool0Moooo`00N?ooo`0306Kooooooooo01Coool0
0`000?ooooooo`0Doooo00<0I_ooooooool0Moooo`00N?ooo`0306Kooooooooo01Coool00`000?oo
ooooo`0Doooo00<0I_ooooooool0Moooo`00N?ooo`0306Kooooooooo01Coool00`000?ooooooo`0D
oooo00<0I_ooooooool0Moooo`00N?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Doooo00<0
I_ooooooool0Moooo`00N?ooo`0306Kooooooooo01Coool200005Oooo`0306Kooooooooo07Ooool0
07Soool00`1Vooooooooo`0Doooo00<0003oooooool05?ooo`0306Kooooooooo07Ooool007Soool0
0`1Vooooooooo`0Doooo00<0003oooooool05?ooo`0306Kooooooooo07Ooool007Soool00`1Voooo
ooooo`0Doooo00<0003oooooool05?ooo`0306Kooooooooo07Ooool007Soool00`1Vooooooooo`0D
oooo00<0003oooooool05?ooo`0306Kooooooooo07Ooool007Soool00`1Vooooooooo`0Doooo00<0
003oooooool05?ooo`0306Kooooooooo07Ooool007Soool00`1Vooooooooo`0Doooo0P0001Goool0
0`1Vooooooooo`1goooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Coool00`1Voooo
ooooo`1goooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Coool00`1Vooooooooo`1g
oooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Coool00`1Vooooooooo`1goooo001h
oooo00<0I_ooooooool05?ooo`030000oooooooo01Coool00`1Vooooooooo`1goooo001hoooo00<0
I_ooooooool05?ooo`030000oooooooo01Coool00`1Vooooooooo`1goooo001hoooo00<0I_oooooo
ool05?ooo`80000Eoooo00<0I_ooooooool0Moooo`00N?ooo`0306Kooooooooo01Coool00`000?oo
ooooo`0Doooo00<0I_ooooooool0Moooo`00N?ooo`0306Kooooooooo01Coool00`000?ooooooo`0D
oooo00<0I_ooooooool0Moooo`00N?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Doooo00<0
I_ooooooool0Moooo`00N?ooo`0406Kooooooooooooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool05?ooo`0306Kooooooooo07Ooool007Soool0101Vooooooooo`0000;oool00`000?oo
ooooo`06oooo00@0003oooooool00004oooo00<0003oooooool05?ooo`0306Kooooooooo07Ooool0
07Soool206Ko00Goool0003oooooool000002oooo`030000oooooooo00;oool300004_ooo`<0I_mi
oooo001joooo00D0I_l00000I_ooool000002Oooo`800005oooo00<0003oooooool03oooo`<0I_l2
oooo00?o09Woooooool0Moooo`00Noooo`040000oooo06Ko00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`0<oooo0`1Vo`Goool00ol0VOooooooo`1goooo001loooo0P000004oooo06Ko06Ko
06Ko1_ooo`<00004oooo00<0003oooooool02_ooo`80I_l8oooo00?o09Woooooool0Moooo`00P_oo
o`80I_l;oooo00<0003oooooool02?ooo`80I_l:oooo00?o09Woooooool0Moooo`00Q?ooo`<0I_l8
oooo00<0003oooooool01_ooo`80I_l<oooo00?o09Woooooool0Moooo`00Qoooo`80I_l6oooo0P00
00Goool206Ko3_ooo`03o`2Ioooooooo07Ooool008Woool306Ko0oooo`030000oooooooo00;oool2
06Ko4?ooo`03o`2Ioooooooo07Ooool008coool206Ko00?oool00000I_l00`1Voa;oool00ol0VOoo
ooooo`1goooo002>oooo00<0I_l00000I_l05Oooo`03o`2Ioooooooo07Ooool008ooool00`000?oo
ooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`80000Eoooo00?o09Woooooool0Moooo`00Sooo
o`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2I
oooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000
oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo
07Ooool008ooool200005Oooo`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o
09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0
003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Wooooo
ool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo0P0001Goool0
0ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool0
0`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOoo
ooooo`1goooo0027oooo1@0000?oool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00ROooo`030000
oooooooo00?oool300005?ooo`03o`2Ioooooooo07Ooool008Woool00`000?ooooooo`03oooo00<0
003oooooool05?ooo`03o`2Ioooooooo07Ooool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool05?ooo`03o`2Ioooooooo07Ooool008Soool200001Oooo`030000oooooooo01Coool00ol0VOoo
ooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool00`000?oo
ooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`80000Eoooo00?o09Woooooool0Moooo`00Sooo
o`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2I
oooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000
oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo
07Ooool008ooool200005Oooo`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o
09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0
003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Wooooo
ool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo0P0001Goool0
0ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool0
0`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOoo
ooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool00`000?oo
ooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`80000Eoooo00?o09Woooooool0Moooo`00Sooo
o`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2I
oooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo01Coool00ol0VOooooooo`1goooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo01Coool00ol0VOooooooo`1g
oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool300005?ooo`03o`2Ioooooooo
07Ooool007goool00`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`0Doooo00?o09Wooooo
ool0Moooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool05?oo
o`03o`2Ioooooooo07Ooool007coool200002_ooo`<00004oooo00<0003oooooool05?ooo`03o`2I
oooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000
oooooooo01Coool00ol0VOooooooo`1goooo002?oooo0P0001Goool00ol0VOooooooo`1goooo002?
oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o
09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0
003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Wooooo
ool0Moooo`00Soooo`80000Eoooo00?o09Woooooool0Moooo`00Soooo`030000oooooooo01Coool0
0ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool0
0`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOoo
ooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool200005Ooo
o`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Sooo
o`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2I
oooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000
oooooooo01Coool00ol0VOooooooo`1goooo002?oooo0P0001Goool00ol0VOooooooo`1goooo002?
oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o
09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOooooooo`1goooo0027oooo1000
00Coool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Qoooo`030000oooooooo00Goool0
0`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00R?ooo`030000oooooooo00Coool300005?oo
o`03o`2Ioooooooo07Ooool008Woool00`000?ooooooo`03oooo00<0003oooooool05?ooo`03o`2I
oooooooo07Ooool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0Doooo00?o09Wooooo
ool0Moooo`00R?ooo`800005oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool0
0`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOoo
ooooo`1goooo002?oooo0P0001Goool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?oo
o`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Sooo
o`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2I
oooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`80000E
oooo00?o09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOooooooo`1goooo002?
oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o
09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOooooooo`1goooo002?oooo00<0
003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool200005Oooo`03o`2Ioooooooo07Ooool0
08ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000oooooooo01Coool0
0ol0VOooooooo`1goooo002?oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool008ooool0
0`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Soooo`030000oooooooo01Coool00ol0VOoo
ooooo`1goooo002?oooo0P0001Goool00ol0VOooooooo`1goooo002?oooo00<0003oooooool05?oo
o`03o`2Ioooooooo07Ooool008ooool00`000?ooooooo`0Doooo00?o09Woooooool0Moooo`00Sooo
o`030000oooooooo01Coool00ol0VOooooooo`1goooo001koooo100000?oool200001?ooo`800005
oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool007_oool00`000?ooooooo`09oooo00@0
003oooooool00004oooo00<0003oooooool05?ooo`03o`2Ioooooooo07Ooool007coool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`<0000Doooo00?o09Woooooool0Moooo`00OOooo`030000
oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool0
07coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool5
00000_ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02_ooo`030000oooooooo
00?oool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>
oooo00<0003oooooool02?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000004Oooo`030000oooooooo00Soool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool300000ooo
o`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.55838 .04578 L
.57861 .04578 L
.58392 .04578 L
.58957 .04578 L
.59232 .04578 L
.59367 .04578 L
.59491 .04578 L
s
.59491 .04578 m
.59519 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.39174 .04578 L
.39675 .04578 L
.40134 .04578 L
.40252 .04578 L
.40381 .04578 L
.40503 .16033 L
.40616 .16074 L
.41134 .16263 L
.42237 .16676 L
.4615 .18263 L
.48147 .19151 L
.49198 .19642 L
.49727 .19895 L
.49872 .19965 L
.49953 .20004 L
.50027 .20014 L
.50096 .1998 L
.50171 .19944 L
.50308 .19878 L
.52394 .18905 L
.54314 .18064 L
.56253 .17265 L
.57283 .1686 L
.58393 .16438 L
.58907 .16248 L
.59188 .16145 L
.59325 .16095 L
.59449 .1605 L
.59564 .04578 L
.59673 .04578 L
.59912 .04578 L
.60418 .04578 L
.62319 .04578 L
.66166 .04578 L
.70258 .04578 L
.74198 .04578 L
.77987 .04578 L
.82021 .04578 L
.85903 .04578 L
.90031 .04578 L
Mistroke
.94007 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool0
0`1Vooooooooo`1eoooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Voooo
ooooo`1eoooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`1e
oooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`1eoooo001f
oooo00<0I_ooooooool05_ooo`80000Goooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo
01Koool00`000?ooooooo`0Foooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo01Koool0
0`000?ooooooo`0Foooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo01Koool00`000?oo
ooooo`0Foooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo01Koool00`000?ooooooo`0F
oooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo01Koool00`000?ooooooo`0Foooo00<0
I_ooooooool0MOooo`00M_ooo`0306Kooooooooo01Koool200005oooo`0306Kooooooooo07Goool0
07Koool00`1Vooooooooo`0Foooo00<0003oooooool05_ooo`0306Kooooooooo07Goool007Koool0
0`1Vooooooooo`0Foooo00<0003oooooool05_ooo`0306Kooooooooo07Goool007Koool00`1Voooo
ooooo`0Foooo00<0003oooooool05_ooo`0306Kooooooooo07Goool007Koool00`1Vooooooooo`0F
oooo00<0003oooooool05_ooo`0306Kooooooooo07Goool007Koool00`1Vooooooooo`0Foooo00<0
003oooooool05_ooo`0306Kooooooooo07Goool007Koool00`1Vooooooooo`0Foooo0P0001Ooool0
0`1Vooooooooo`1eoooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Voooo
ooooo`1eoooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`1e
oooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`1eoooo001f
oooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`1eoooo001foooo00<0
I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`1eoooo001foooo00<0I_oooooo
ool05_ooo`80000Goooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo01Koool00`000?oo
ooooo`0Foooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo01Koool00`000?ooooooo`0F
oooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo01Koool00`000?ooooooo`0Foooo00<0
I_ooooooool0MOooo`00M_ooo`0306Kooooooooo00?oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Foooo00<0I_ooooooool0MOooo`00M_ooo`0306Kooooooooo00;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Foooo00<0I_ooooooool0MOoo
o`00M_ooo`@0I_l01Oooo`000?ooooooo`00000;oooo00<0003oooooool00_ooo`<0000Doooo0`1V
ogOoool007[oool01@1Vo`00001Vooooo`000009oooo0P0000Goool00`000?ooooooo`0Boooo0P1V
o`;oool00ol0VOooooooo`1eoooo001koooo00@0003oool0I_l00009oooo00<0003oooooool01?oo
o`030000oooooooo00ooool306Ko1?ooo`03o`2Ioooooooo07Goool007coool2000000Coool0I_l0
I_l0I_l6oooo0`0000Coool00`000?ooooooo`0<oooo0`1Vo`Ooool00ol0VOooooooo`1eoooo0022
oooo0P1Vo`_oool00`000?ooooooo`0:oooo0P1Vo`[oool00ol0VOooooooo`1eoooo0024oooo0P1V
o`Woool00`000?ooooooo`07oooo0`1Vo`coool00ol0VOooooooo`1eoooo0026oooo0P1Vo`Ooool2
00001_ooo`80I_l?oooo00?o09Woooooool0MOooo`00R?ooo`80I_l5oooo00<0003oooooool00ooo
o`80I_lAoooo00?o09Woooooool0MOooo`00R_ooo`80I_l3oooo00@0003oooooooooool206Ko4ooo
o`03o`2Ioooooooo07Goool008coool206Ko00?oool0003oool00P1VoaGoool00ol0VOooooooo`1e
oooo002>oooo00<0I_l00000I_l05oooo`03o`2Ioooooooo07Goool008ooool200005oooo`03o`2I
oooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000
oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo
07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo
01Koool00ol0VOooooooo`1eoooo002?oooo0P0001Ooool00ol0VOooooooo`1eoooo002?oooo00<0
003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Wooooo
ool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003ooooo
ool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOoo
o`00Soooo`80000Goooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOoo
ooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?oo
ooooo`0Foooo00?o09Woooooool0MOooo`00Qoooo`D00003oooo00<0003oooooool05_ooo`03o`2I
oooooooo07Goool008Woool00`000?ooooooo`03oooo00<0003oooooool05_ooo`03o`2Ioooooooo
07Goool008Woool00`000?ooooooo`03oooo0`0001Koool00ol0VOooooooo`1eoooo0029oooo00<0
003oooooool00oooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo0028oooo0P0000Goool00`000?oo
ooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1e
oooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool200005oooo`03o`2I
oooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000
oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo
07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo
01Koool00ol0VOooooooo`1eoooo002?oooo0P0001Ooool00ol0VOooooooo`1eoooo002?oooo00<0
003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Wooooo
ool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003ooooo
ool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOoo
o`00Soooo`80000Goooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOoo
ooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?oo
ooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1e
oooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool200005oooo`03o`2I
oooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000
oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo
07Goool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0Foooo00?o09Wooooo
ool0MOooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0F
oooo00?o09Woooooool0MOooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
01Koool00ol0VOooooooo`1eoooo001moooo00<0003oooooool02?ooo`800005oooo00<0003ooooo
ool05_ooo`03o`2Ioooooooo07Goool007goool00`000?ooooooo`08oooo00<0003oooooool01?oo
o`030000oooooooo01Koool00ol0VOooooooo`1eoooo001loooo0P0000[oool300001?ooo`030000
oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo
07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`80000Goooo00?o
09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0
003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Wooooo
ool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003ooooo
ool05_ooo`03o`2Ioooooooo07Goool008ooool200005oooo`03o`2Ioooooooo07Goool008ooool0
0`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOoo
ooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?oo
ooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1e
oooo002?oooo0P0001Ooool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2I
oooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000
oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo
07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`80000Goooo00?o
09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0
003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Wooooo
ool0MOooo`00Qoooo`@00004oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008Ooool0
0`000?ooooooo`05oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008Soool00`000?oo
ooooo`04oooo0`0001Koool00ol0VOooooooo`1eoooo0029oooo00<0003oooooool00oooo`030000
oooooooo01Koool00ol0VOooooooo`1eoooo0027oooo00@0003oooooool00004oooo00<0003ooooo
ool05_ooo`03o`2Ioooooooo07Goool008Soool200001Oooo`030000oooooooo01Koool00ol0VOoo
ooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?oo
ooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`80000Goooo00?o09Woooooool0MOooo`00Sooo
o`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2I
oooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000
oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo
07Goool008ooool200005oooo`03o`2Ioooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o
09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0
003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Wooooo
ool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo0P0001Ooool0
0ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool0
0`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`030000oooooooo01Koool00ol0VOoo
ooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2Ioooooooo07Goool008ooool00`000?oo
ooooo`0Foooo00?o09Woooooool0MOooo`00Soooo`80000Goooo00?o09Woooooool0MOooo`00Sooo
o`030000oooooooo01Koool00ol0VOooooooo`1eoooo002?oooo00<0003oooooool05_ooo`03o`2I
oooooooo07Goool008ooool00`000?ooooooo`0Foooo00?o09Woooooool0MOooo`00Noooo`@00003
oooo0P0000Coool200001Oooo`030000oooooooo01Koool00ol0VOooooooo`1eoooo001koooo00<0
003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo01Koool00ol0VOooooooo`1e
oooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool300005_ooo`03o`2Ioooooooo
07Goool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001l
oooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0
003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`06oooo1@0000;oool200000oooo`<00004oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000
oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`<00004
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`08
oooo00<0003oooooool00oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P00
00[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.58872 .04578 L
.59405 .04578 L
.59698 .04578 L
.59975 .04578 L
.60102 .04578 L
.60237 .04578 L
.60307 .04578 L
s
.60307 .04578 m
.60327 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.36136 .04578 L
.37176 .04578 L
.3815 .04578 L
.39106 .04578 L
.39381 .04578 L
.39516 .04578 L
.39642 .04578 L
.39756 .1605 L
.39877 .16094 L
.40134 .16187 L
.42237 .16982 L
.46395 .18718 L
.4741 .19177 L
.48482 .19679 L
.49397 .2012 L
.49648 .20243 L
.49786 .20312 L
.49916 .20377 L
.50038 .20399 L
.5017 .20334 L
.50401 .20219 L
.54257 .18431 L
.56195 .1761 L
.57225 .17194 L
.58335 .16761 L
.58849 .16565 L
.59391 .16362 L
.59854 .16191 L
.59981 .16145 L
.60116 .16096 L
.60244 .1605 L
.6036 .04578 L
.60479 .04578 L
.60604 .04578 L
.60829 .04578 L
.61338 .04578 L
.62261 .04578 L
.6605 .04578 L
.70084 .04578 L
.73966 .04578 L
.78094 .04578 L
Mistroke
.8207 .04578 L
.85895 .04578 L
.89964 .04578 L
.93883 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00?oool00`1Vooooo`000007oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
o`1Vo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001doooo00<0I_ooooooool06?ooo`030000oooooooo01Soool0
0`1Vooooooooo`1coooo001doooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00`1Voooo
ooooo`1coooo001doooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00`1Vooooooooo`1c
oooo001doooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00`1Vooooooooo`1coooo001d
oooo00<0I_ooooooool06?ooo`80000Ioooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo
01Soool00`000?ooooooo`0Hoooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo01Soool0
0`000?ooooooo`0Hoooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo01Soool00`000?oo
ooooo`0Hoooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo01Soool00`000?ooooooo`0H
oooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo00<0
I_ooooooool0Loooo`00M?ooo`0306Kooooooooo01Soool200006Oooo`0306Kooooooooo07?oool0
07Coool00`1Vooooooooo`0Hoooo00<0003oooooool06?ooo`0306Kooooooooo07?oool007Coool0
0`1Vooooooooo`0Hoooo00<0003oooooool06?ooo`0306Kooooooooo07?oool007Coool00`1Voooo
ooooo`0Hoooo00<0003oooooool06?ooo`0306Kooooooooo07?oool007Coool00`1Vooooooooo`0H
oooo00<0003oooooool06?ooo`0306Kooooooooo07?oool007Coool00`1Vooooooooo`0Hoooo00<0
003oooooool06?ooo`0306Kooooooooo07?oool007Coool00`1Vooooooooo`0Hoooo0P0001Woool0
0`1Vooooooooo`1coooo001doooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00`1Voooo
ooooo`1coooo001doooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00`1Vooooooooo`1c
oooo001doooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00`1Vooooooooo`1coooo001d
oooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00`1Vooooooooo`1coooo001doooo00<0
I_ooooooool06?ooo`030000oooooooo01Soool00`1Vooooooooo`1coooo001doooo00<0I_oooooo
ool06?ooo`80000Ioooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo01Soool00`000?oo
ooooo`0Hoooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo01Soool00`000?ooooooo`0H
oooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo00<0
I_ooooooool0Loooo`00M?ooo`0306Kooooooooo00Goool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Hoooo00<0I_ooooooool0Loooo`00M?ooo`0306Kooooooooo00Coool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Hoooo00<0I_ooooooool0Looo
o`00M?ooo`<0I_l4oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Eoooo101V
ogGoool007Ooool306Ko00Goool0003oooooool000002Oooo`800005oooo00<0003oooooool05?oo
o`0506Koooooooooooooo`2I07Goool007[oool01@1Vo`00001Vooooo`000009oooo00<0003ooooo
ool01?ooo`030000oooooooo01;oool206Ko1?ooo`03o`2Ioooooooo07?oool007coool2000000<0
I_ooooooool01oooo`<00004oooo00<0003oooooool03oooo`<0I_l6oooo00?o09Woooooool0Looo
o`00Ooooo`80I_l>oooo00<0003oooooool03?ooo`<0I_l9oooo00?o09Woooooool0Loooo`00POoo
o`80I_l<oooo00<0003oooooool02_ooo`80I_l<oooo00?o09Woooooool0Loooo`00Poooo`80I_l:
oooo0P0000Woool206Ko3_ooo`03o`2Ioooooooo07?oool008Goool206Ko2?ooo`030000oooooooo
00Koool206Ko4?ooo`03o`2Ioooooooo07?oool008Ooool306Ko1Oooo`030000oooooooo00Coool2
06Ko4_ooo`03o`2Ioooooooo07?oool008[oool206Ko0oooo`030000oooooooo00;oool206Ko5?oo
o`03o`2Ioooooooo07?oool008coool206Ko00Coool0003oooooool206Ko5_ooo`03o`2Ioooooooo
07?oool008koool0101Vo`000000001VoaSoool00ol0VOooooooo`1coooo002?oooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?oo
o`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Sooo
o`80000Ioooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0H
oooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?
oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool200006Oooo`03o`2Ioooooooo
07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08Ooool500000oooo`030000oooooooo01Soool00ol0VOooooooo`1coooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo01Soool00ol0VOooooooo`1coooo0029oooo00<0003oooooool00ooo
o`<0000Hoooo00?o09Woooooool0Loooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0H
oooo00?o09Woooooool0Loooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Hoooo00?o
09Woooooool0Loooo`00R?ooo`800005oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool0
0ol0VOooooooo`1coooo002?oooo0P0001Woool00ol0VOooooooo`1coooo002?oooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?oo
o`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Sooo
o`80000Ioooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0H
oooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?
oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool200006Oooo`03o`2Ioooooooo
07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool0
0ol0VOooooooo`1coooo002?oooo0P0001Woool00ol0VOooooooo`1coooo002?oooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo001koooo1@0000;oool200001?oo
o`800005oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool007goool00`000?ooooooo`07
oooo00@0003oooooool00004oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool007goool0
0`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000Hoooo00?o09Woooooool0Loooo`00OOoo
o`030000oooooooo00Soool200001Oooo`030000oooooooo01Soool00ol0VOooooooo`1coooo001m
oooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?oo
o`03o`2Ioooooooo07?oool008ooool200006Oooo`03o`2Ioooooooo07?oool008ooool00`000?oo
ooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0H
oooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?
oooo0P0001Woool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo
07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`80000Ioooo00?o09Wooooo
ool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?oo
o`03o`2Ioooooooo07?oool008ooool200006Oooo`03o`2Ioooooooo07?oool008ooool00`000?oo
ooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008Ooool400001?ooo`030000
oooooooo01Soool00ol0VOooooooo`1coooo0027oooo00<0003oooooool01Oooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo0028oooo00<0003oooooool01?ooo`<0000Hoooo00?o09Wooooo
ool0Loooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00Qoooo`040000oooooooo00001?ooo`030000oooooooo01Soool00ol0VOooooooo`1coooo0028
oooo0P0000Goool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08ooool200006Oooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo0P0001Woool00ol0VOoo
ooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?oo
ooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0H
oooo00?o09Woooooool0Loooo`00Soooo`80000Ioooo00?o09Woooooool0Loooo`00Soooo`030000
oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo
07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08ooool200006Oooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool007_oool400000oooo`800004oooo0P0000Goool00`000?oo
ooooo`0Hoooo00?o09Woooooool0Loooo`00Noooo`030000oooooooo00Woool010000?ooooooo`00
00Coool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00O?ooo`030000oooooooo00_oool0
0`000?ooooooo`02oooo0`0001Soool00ol0VOooooooo`1coooo001moooo00<0003oooooool02?oo
o`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:
oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P00
00?oool300001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Ooool010000?oo
ooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`07oooo00@0003oooooool00005oooo00<0
003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000
oooooooo00Ooool300001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo0000017oool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.58872 .04578 L
.59975 .04578 L
.60479 .04578 L
.60756 .04578 L
.60891 .04578 L
.61016 .04578 L
s
.61016 .04578 m
.61046 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.36136 .04578 L
.37176 .04578 L
.37685 .04578 L
.3815 .04578 L
.38384 .04578 L
.3864 .04578 L
.38757 .04578 L
.38881 .04578 L
.38999 .16063 L
.39106 .16101 L
.40134 .16481 L
.42237 .17296 L
.46243 .19007 L
.48081 .19867 L
.49124 .20377 L
.49386 .20508 L
.49634 .20633 L
.49856 .20746 L
.49982 .2081 L
.50098 .20769 L
.50213 .20711 L
.5032 .20656 L
.50565 .20533 L
.51061 .20286 L
.52092 .19784 L
.54199 .18807 L
.58067 .17175 L
.60071 .16404 L
.60559 .16224 L
.60826 .16126 L
.60958 .16078 L
.61079 .16035 L
.61149 .04578 L
.61223 .04578 L
.61378 .04578 L
.6165 .04578 L
.62181 .04578 L
.6597 .04578 L
.70004 .04578 L
.73886 .04578 L
.78014 .04578 L
Mistroke
.8199 .04578 L
.85815 .04578 L
.89884 .04578 L
.93803 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`050000oooooooooooo06Ko00?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
1@000?ooooooooooo`1Vo`03oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo001boooo00<0I_ooooooool06_ooo`030000
oooooooo01[oool00`1Vooooooooo`1aoooo001boooo00<0I_ooooooool06_ooo`030000oooooooo
01[oool00`1Vooooooooo`1aoooo001boooo00<0I_ooooooool06_ooo`030000oooooooo01[oool0
0`1Vooooooooo`1aoooo001boooo00<0I_ooooooool06_ooo`030000oooooooo01[oool00`1Voooo
ooooo`1aoooo001boooo00<0I_ooooooool06_ooo`80000Koooo00<0I_ooooooool0LOooo`00L_oo
o`0306Kooooooooo01[oool00`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Ko
oooooooo01[oool00`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo
01[oool00`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo01[oool0
0`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo01[oool00`000?oo
ooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo01[oool200006oooo`0306Ko
oooooooo077oool007;oool00`1Vooooooooo`0Joooo00<0003oooooool06_ooo`0306Kooooooooo
077oool007;oool00`1Vooooooooo`0Joooo00<0003oooooool06_ooo`0306Kooooooooo077oool0
07;oool00`1Vooooooooo`0Joooo00<0003oooooool06_ooo`0306Kooooooooo077oool007;oool0
0`1Vooooooooo`0Joooo00<0003oooooool06_ooo`0306Kooooooooo077oool007;oool00`1Voooo
ooooo`0Joooo00<0003oooooool06_ooo`0306Kooooooooo077oool007;oool00`1Vooooooooo`0J
oooo0P0001_oool00`1Vooooooooo`1aoooo001boooo00<0I_ooooooool06_ooo`030000oooooooo
01[oool00`1Vooooooooo`1aoooo001boooo00<0I_ooooooool06_ooo`030000oooooooo01[oool0
0`1Vooooooooo`1aoooo001boooo00<0I_ooooooool06_ooo`030000oooooooo01[oool00`1Voooo
ooooo`1aoooo001boooo00<0I_ooooooool06_ooo`030000oooooooo01[oool00`1Vooooooooo`1a
oooo001boooo00<0I_ooooooool06_ooo`030000oooooooo01[oool00`1Vooooooooo`1aoooo001b
oooo00<0I_ooooooool06_ooo`80000Koooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo
01[oool00`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo01[oool0
0`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo01[oool00`000?oo
ooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo00Ooool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`0Joooo00<0I_ooooooool0LOooo`00L_ooo`0306Kooooooooo
00Koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Joooo00<0
I_ooooooool0LOooo`00L_ooo`80I_l7oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000Hoooo0`1Vog?oool007Coool306Ko1?ooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool05_ooo`80I_l2oooo00?o09Woooooool0LOooo`00Moooo`<0I_l01Oooo`000?oooooo
o`000009oooo00<0003oooooool01?ooo`030000oooooooo01Coool206Ko1?ooo`03o`2Ioooooooo
077oool007[oool206Ko0P0000[oool300001?ooo`030000oooooooo017oool306Ko1_ooo`03o`2I
oooooooo077oool007goool206Ko4?ooo`030000oooooooo00ooool206Ko2Oooo`03o`2Ioooooooo
077oool007ooool306Ko3Oooo`030000oooooooo00coool306Ko2oooo`03o`2Ioooooooo077oool0
08;oool206Ko2oooo`80000;oooo0P1Vo`koool00ol0VOooooooo`1aoooo0024oooo0P1Vo`Woool0
0`000?ooooooo`07oooo0`1Voa3oool00ol0VOooooooo`1aoooo0026oooo0P1Vo`Ooool00`000?oo
ooooo`04oooo0`1Voa?oool00ol0VOooooooo`1aoooo0028oooo0P1Vo`Goool00`000?ooooooo`02
oooo0P1VoaKoool00ol0VOooooooo`1aoooo002:oooo0P1Vo`?oool01@000?ooooooooooo`1Vo`0H
oooo00?o09Woooooool0LOooo`00S?ooo`80I_l00oooo`000000000206Ko6Oooo`03o`2Ioooooooo
077oool008koool00`1Vo`00001Vo`0Koooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo002?oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Sooo
o`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Qoooo`D00003oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008Woool00`000?ooooooo`03oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08Woool00`000?ooooooo`03oooo0`0001[oool00ol0VOooooooo`1aoooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo0029oooo00<0003oooooool00ooo
o`030000oooooooo01[oool00ol0VOooooooo`1aoooo0028oooo0P0000Goool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool200006oooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo002?oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Sooo
o`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool200006oooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
07_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0Joooo00?o
09Woooooool0LOooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0001[oool0
0ol0VOooooooo`1aoooo001moooo00<0003oooooool02?ooo`800005oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool007goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000
oooooooo01[oool00ol0VOooooooo`1aoooo001loooo0P0000[oool300001?ooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`80000Koooo00?o09Wooooo
ool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool200006oooo`03o`2Ioooooooo077oool008ooool00`000?oo
ooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`80000Koooo00?o09Wooooo
ool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Qoooo`@00004oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008Ooool00`000?oo
ooooo`05oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008Soool00`000?ooooooo`04
oooo0`0001[oool00ol0VOooooooo`1aoooo0029oooo00<0003oooooool00oooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo0027oooo00@0003oooooool00004oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008Soool200001Oooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000
oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool200006oooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Wooooo
ool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo0P0001_oool00ol0VOoo
ooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?oo
ooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000
oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Noooo`@00003oooo0P00
00Coool200001Oooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001koooo00<0003ooooo
ool02Oooo`040000oooooooo00001?ooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001l
oooo00<0003oooooool02oooo`030000oooooooo00;oool300006_ooo`03o`2Ioooooooo077oool0
07goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?oo
ooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0
003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003ooooo
ool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo1@0000;oool200001Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000
oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool01@000?oo
ooooooooo`00001moooo001koooo00D0003oooooooooool000004Oooo`030000oooooooo00Ooool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`800009
oooo100000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.58872 .04578 L
.59975 .04578 L
.60479 .04578 L
.61016 .04578 L
.61278 .04578 L
.61524 .04578 L
.61745 .04578 L
.61869 .04578 L
s
.61869 .04578 m
.61898 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.34309 .04578 L
.36173 .04578 L
.37114 .04578 L
.37372 .04578 L
.37649 .04578 L
.37783 .04578 L
.3791 .04578 L
.38025 .04578 L
.3815 .16043 L
.38215 .16066 L
.38283 .16091 L
.38405 .16135 L
.38681 .16236 L
.39182 .16422 L
.40117 .16776 L
.42214 .17609 L
.46012 .19264 L
.48126 .20276 L
.49128 .20779 L
.49568 .21005 L
.49689 .21068 L
.49819 .21136 L
.49941 .212 L
.50054 .21202 L
.50162 .21146 L
.5028 .21084 L
.50518 .20961 L
.51011 .20709 L
.52052 .20188 L
.53945 .19285 L
.5607 .18332 L
.58001 .17521 L
.58965 .17134 L
.60009 .16727 L
.60489 .16545 L
.60996 .16355 L
.61429 .16196 L
.61548 .16153 L
.61675 .16106 L
.61796 .16063 L
.61906 .04578 L
Mistroke
.62035 .04578 L
.62156 .04578 L
.62384 .04578 L
.62893 .04578 L
.63808 .04578 L
.65882 .04578 L
.69742 .04578 L
.73847 .04578 L
.77801 .04578 L
.81604 .04578 L
.85651 .04578 L
.89548 .04578 L
.93689 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooo06Ko00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`03oooo00<0I_ooool000001oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01coool0
0`1Vooooooooo`1_oooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01coool00`1Voooo
ooooo`1_oooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01coool00`1Vooooooooo`1_
oooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01coool00`1Vooooooooo`1_oooo001`
oooo00<0I_ooooooool07?ooo`80000Moooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo
01coool00`000?ooooooo`0Loooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo01coool0
0`000?ooooooo`0Loooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo01coool00`000?oo
ooooo`0Loooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo01coool00`000?ooooooo`0L
oooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo01coool00`000?ooooooo`0Loooo00<0
I_ooooooool0Koooo`00L?ooo`0306Kooooooooo01coool200007Oooo`0306Kooooooooo06ooool0
073oool00`1Vooooooooo`0Loooo00<0003oooooool07?ooo`0306Kooooooooo06ooool0073oool0
0`1Vooooooooo`0Loooo00<0003oooooool07?ooo`0306Kooooooooo06ooool0073oool00`1Voooo
ooooo`0Loooo00<0003oooooool07?ooo`0306Kooooooooo06ooool0073oool00`1Vooooooooo`0L
oooo00<0003oooooool07?ooo`0306Kooooooooo06ooool0073oool00`1Vooooooooo`0Loooo00<0
003oooooool07?ooo`0306Kooooooooo06ooool0073oool00`1Vooooooooo`0Loooo0P0001goool0
0`1Vooooooooo`1_oooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01coool00`1Voooo
ooooo`1_oooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01coool00`1Vooooooooo`1_
oooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01coool00`1Vooooooooo`1_oooo001`
oooo00<0I_ooooooool07?ooo`030000oooooooo01coool00`1Vooooooooo`1_oooo001`oooo00<0
I_ooooooool07?ooo`030000oooooooo01coool00`1Vooooooooo`1_oooo001`oooo00<0I_oooooo
ool07?ooo`80000Moooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo01coool00`000?oo
ooooo`0Loooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo01coool00`000?ooooooo`0L
oooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo01coool00`000?ooooooo`0Loooo00<0
I_ooooooool0Koooo`00L?ooo`0306Kooooooooo00Woool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Loooo00<0I_ooooooool0Koooo`00L?ooo`0306Kooooooooo00Soool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Loooo00<0I_ooooooool0Kooo
o`00L?ooo`<0I_l8oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Joooo0`1V
og7oool007?oool00`1Vooooooooo`05oooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`0Foooo101Vo`;oool00ol0VOooooooo`1_oooo001doooo0`1Vo`Coool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool05?ooo`80I_l6oooo00?o09Woooooool0Kooo
o`00Moooo`<0I_l2oooo0P0000[oool300001?ooo`030000oooooooo01;oool206Ko2?ooo`03o`2I
oooooooo06ooool007[oool306Ko4_ooo`030000oooooooo013oool206Ko2_ooo`03o`2Ioooooooo
06ooool007goool206Ko4?ooo`030000oooooooo00koool206Ko3?ooo`03o`2Ioooooooo06ooool0
07ooool306Ko3Oooo`80000=oooo0P1Vo`koool00ol0VOooooooo`1_oooo0022oooo0P1Vo`_oool0
0`000?ooooooo`09oooo0`1Voa3oool00ol0VOooooooo`1_oooo0024oooo0P1Vo`Woool00`000?oo
ooooo`06oooo0`1Voa?oool00ol0VOooooooo`1_oooo0026oooo0P1Vo`Ooool00`000?ooooooo`04
oooo0P1VoaKoool00ol0VOooooooo`1_oooo0028oooo0P1Vo`Goool00`000?ooooooo`02oooo0P1V
oaSoool00ol0VOooooooo`1_oooo002:oooo0P1Vo`?oool200000_ooo`0306Kooooooooo01Soool0
0ol0VOooooooo`1_oooo002<oooo0P1Vo`03oooo000006Ko0080I_lKoooo00?o09Woooooool0Kooo
o`00S_ooo`0306Ko000006Ko01goool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Sooo
o`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo0P0001goool00ol0VOooooooo`1_
oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0L
oooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?
oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o
09Woooooool0Koooo`00Soooo`80000Moooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo
01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool0
08ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Qoooo`D00003oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo06ooool008Woool00`000?ooooooo`03oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool008Woool00`000?ooooooo`03oooo0`0001coool00ol0VOooooooo`1_
oooo0029oooo00<0003oooooool00oooo`030000oooooooo01coool00ol0VOooooooo`1_oooo0029
oooo00<0003oooooool00oooo`030000oooooooo01coool00ol0VOooooooo`1_oooo0028oooo0P00
00Goool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool0
0ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool2
00007Oooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Kooo
o`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Sooo
o`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo0P0001goool00ol0VOooooooo`1_
oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0L
oooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?
oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o
09Woooooool0Koooo`00Soooo`80000Moooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo
01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool0
08ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool0
0ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool2
00007Oooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Kooo
o`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0L
oooo00?o09Woooooool0Koooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00OOooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`0001coool00ol0VOooooooo`1_oooo001moooo00<0003oooooool02?ooo`800005
oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool007goool00`000?ooooooo`08oooo00<0
003oooooool01?ooo`030000oooooooo01coool00ol0VOooooooo`1_oooo001loooo0P0000[oool3
00001?ooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Sooo
o`80000Moooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_
oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0L
oooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?
oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool200007Oooo`03o`2Ioooooooo
06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo
01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool0
08ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool0
0ol0VOooooooo`1_oooo002?oooo0P0001goool00ol0VOooooooo`1_oooo002?oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Kooo
o`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Sooo
o`80000Moooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_
oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0L
oooo00?o09Woooooool0Koooo`00Qoooo`@00004oooo00<0003oooooool07?ooo`03o`2Ioooooooo
06ooool008Ooool00`000?ooooooo`05oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool0
08Soool00`000?ooooooo`04oooo0`0001coool00ol0VOooooooo`1_oooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo01coool00ol0VOooooooo`1_oooo0027oooo00@0003oooooool00004
oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008Soool200001Oooo`030000oooooooo
01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool0
08ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`80000Moooo00?o09Wooooo
ool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Kooo
o`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?oo
o`03o`2Ioooooooo06ooool008ooool200007Oooo`03o`2Ioooooooo06ooool008ooool00`000?oo
ooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_
oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0L
oooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?
oooo0P0001goool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo
06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`030000oooooooo
01coool00ol0VOooooooo`1_oooo002?oooo00<0003oooooool07?ooo`03o`2Ioooooooo06ooool0
08ooool00`000?ooooooo`0Loooo00?o09Woooooool0Koooo`00Soooo`80000Moooo00?o09Wooooo
ool0Koooo`00Soooo`030000oooooooo01coool00ol0VOooooooo`1_oooo002?oooo00<0003ooooo
ool07?ooo`03o`2Ioooooooo06ooool008ooool00`000?ooooooo`0Loooo00?o09Woooooool0Kooo
o`00Noooo`@00003oooo0P0000Coool200001Oooo`030000oooooooo01coool00ol0VOooooooo`1_
oooo001koooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo01coool0
0ol0VOooooooo`1_oooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool300007?oo
o`03o`2Ioooooooo06ooool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001Oooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`09oooo00D0003oooooooooool000000_oo
o`050000oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00Woool00`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo00[oool010000?oooooooooo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000Woool400000oooo`<00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.59832 .04578 L
.60873 .04578 L
.61445 .04578 L
.61984 .04578 L
.62236 .04578 L
.62502 .04578 L
.6257 .04578 L
.62642 .04578 L
s
.62642 .04578 m
.62661 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.34309 .04578 L
.36173 .04578 L
.36626 .04578 L
.36876 .04578 L
.37114 .04578 L
.37178 .04578 L
.37247 .04578 L
.37323 .16031 L
.37393 .16056 L
.37649 .16149 L
.3815 .16333 L
.42308 .17978 L
.46315 .19781 L
.48153 .20687 L
.48656 .20944 L
.49196 .21225 L
.49457 .21363 L
.49705 .21494 L
.49813 .21552 L
.49928 .21613 L
.50054 .21623 L
.5017 .21561 L
.52164 .20527 L
.5427 .19503 L
.58045 .1783 L
.60143 .16983 L
.61061 .16629 L
.61547 .16446 L
.62066 .16254 L
.62329 .16157 L
.62458 .1611 L
.62577 .16067 L
.62685 .16028 L
.628 .04578 L
.62915 .04578 L
.63042 .04578 L
.6395 .04578 L
.65934 .04578 L
.69968 .04578 L
.73851 .04578 L
.77978 .04578 L
Mistroke
.81954 .04578 L
.85779 .04578 L
.89849 .04578 L
.93767 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01koool0
0`1Vooooooooo`1]oooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01koool00`1Voooo
ooooo`1]oooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01koool00`1Vooooooooo`1]
oooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01koool00`1Vooooooooo`1]oooo001^
oooo00<0I_ooooooool07_ooo`80000Ooooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo
01koool00`000?ooooooo`0Noooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo01koool0
0`000?ooooooo`0Noooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo01koool00`000?oo
ooooo`0Noooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo01koool00`000?ooooooo`0N
oooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo01koool00`000?ooooooo`0Noooo00<0
I_ooooooool0KOooo`00K_ooo`0306Kooooooooo01koool200007oooo`0306Kooooooooo06goool0
06koool00`1Vooooooooo`0Noooo00<0003oooooool07_ooo`0306Kooooooooo06goool006koool0
0`1Vooooooooo`0Noooo00<0003oooooool07_ooo`0306Kooooooooo06goool006koool00`1Voooo
ooooo`0Noooo00<0003oooooool07_ooo`0306Kooooooooo06goool006koool00`1Vooooooooo`0N
oooo00<0003oooooool07_ooo`0306Kooooooooo06goool006koool00`1Vooooooooo`0Noooo00<0
003oooooool07_ooo`0306Kooooooooo06goool006koool00`1Vooooooooo`0Noooo0P0001ooool0
0`1Vooooooooo`1]oooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01koool00`1Voooo
ooooo`1]oooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01koool00`1Vooooooooo`1]
oooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01koool00`1Vooooooooo`1]oooo001^
oooo00<0I_ooooooool07_ooo`030000oooooooo01koool00`1Vooooooooo`1]oooo001^oooo00<0
I_ooooooool07_ooo`030000oooooooo01koool00`1Vooooooooo`1]oooo001^oooo00<0I_oooooo
ool07_ooo`80000Ooooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo01koool00`000?oo
ooooo`0Noooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo01koool00`000?ooooooo`0N
oooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo01koool00`000?ooooooo`0Noooo00<0
I_ooooooool0KOooo`00K_ooo`0306Kooooooooo00_oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Noooo00<0I_ooooooool0KOooo`00K_ooo`0306Kooooooooo00[oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Noooo00<0I_ooooooool0KOoo
o`00K_ooo`@0I_l9oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Loooo0`1V
ofooool007;oool206Ko1oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool06Ooo
o`<0I_l2oooo00?o09Woooooool0KOooo`00M?ooo`80I_l5oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo01Koool306Ko1Oooo`03o`2Ioooooooo06goool007Koool2
06Ko1?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Doooo0P1Vo`Soool00ol0VOooooooo`1]
oooo001hoooo0P1VoaGoool00`000?ooooooo`0Boooo0P1Vo`[oool00ol0VOooooooo`1]oooo001j
oooo0`1Voa;oool00`000?ooooooo`0@oooo0P1Vo`coool00ol0VOooooooo`1]oooo001moooo0P1V
oa3oool200003oooo`80I_l>oooo00?o09Woooooool0KOooo`00Ooooo`<0I_l=oooo00<0003ooooo
ool03?ooo`80I_l@oooo00?o09Woooooool0KOooo`00P_ooo`80I_l;oooo00<0003oooooool02_oo
o`80I_lBoooo00?o09Woooooool0KOooo`00Q?ooo`80I_l9oooo00<0003oooooool01oooo`<0I_lD
oooo00?o09Woooooool0KOooo`00Q_ooo`80I_l7oooo00<0003oooooool01Oooo`80I_lGoooo00?o
09Woooooool0KOooo`00R?ooo`80I_l5oooo0P0000Coool206Ko6Oooo`03o`2Ioooooooo06goool0
08[oool206Ko0oooo`040000oooooooooooo0P1Voa_oool00ol0VOooooooo`1]oooo002<oooo0`1V
o`040000oooo06Ko06Ko7Oooo`03o`2Ioooooooo06goool008koool00`1Vo`00001Vo`0Ooooo00?o
09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0
003oooooool07_ooo`03o`2Ioooooooo06goool008ooool200007oooo`03o`2Ioooooooo06goool0
08ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool0
0ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo002?oooo0P0001ooool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_oo
o`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo0027oooo1@0000?oool00`000?ooooooo`0N
oooo00?o09Woooooool0KOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00ROooo`030000oooooooo00?oool300007_ooo`03o`2Ioooooooo06goool0
08Woool00`000?ooooooo`03oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008Woool0
0`000?ooooooo`03oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008Soool200001Ooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000O
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0
003oooooool07_ooo`03o`2Ioooooooo06goool008ooool200007oooo`03o`2Ioooooooo06goool0
08ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool0
0ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo002?oooo0P0001ooool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_oo
o`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000O
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo01koool0
0ol0VOooooooo`1]oooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo01koool00ol0VOooooooo`1]oooo001moooo00<0003oooooool02_ooo`030000oooooooo
00;oool300007_ooo`03o`2Ioooooooo06goool007goool00`000?ooooooo`08oooo0P0000Goool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00OOooo`030000oooooooo00Soool00`000?oo
ooooo`04oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool007coool200002_ooo`<00004
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo0P00
01ooool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool0
08ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool0
0ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Woooooool0KOoo
o`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_oo
o`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool200007oooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0N
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo0P00
01ooool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool0
08ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool0
0ol0VOooooooo`1]oooo0027oooo100000Coool00`000?ooooooo`0Noooo00?o09Woooooool0KOoo
o`00Qoooo`030000oooooooo00Goool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00R?oo
o`030000oooooooo00Coool300007_ooo`03o`2Ioooooooo06goool008Woool00`000?ooooooo`03
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00R?ooo`800005oooo00<0003oooooool07_oo
o`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo0P0001ooool00ol0VOooooooo`1]
oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0N
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo
01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool0
08ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool0
0ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool2
00007oooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOoo
o`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_oo
o`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo0P0001ooool00ol0VOooooooo`1]
oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0N
oooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001k
oooo100000?oool200001?ooo`800005oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool0
07_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool007coool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0000Noooo00?o
09Woooooool0KOooo`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P0000Coool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07
oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool0
0`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`08
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000004Oooo`030000
oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.59832 .04578 L
.60873 .04578 L
.61984 .04578 L
.6254 .04578 L
.62812 .04578 L
.63064 .04578 L
.63292 .04578 L
.63407 .04578 L
s
.63407 .04578 m
.63439 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.34309 .04578 L
.35271 .04578 L
.35742 .04578 L
.36173 .04578 L
.36284 .04578 L
.36405 .04578 L
.3652 .16027 L
.36626 .16066 L
.37114 .16244 L
.3815 .16631 L
.42063 .18212 L
.46221 .2012 L
.48308 .21176 L
.49223 .21661 L
.49474 .21797 L
.49743 .21943 L
.49873 .22014 L
.49996 .22082 L
.50107 .22025 L
.50228 .21959 L
.52102 .20963 L
.54083 .19972 L
.58161 .18116 L
.60186 .17279 L
.61178 .16888 L
.62088 .16541 L
.62973 .16212 L
.63188 .16133 L
.63306 .1609 L
.63418 .1605 L
.6355 .04578 L
.6367 .04578 L
.63904 .04578 L
.65863 .04578 L
.69709 .04578 L
.73801 .04578 L
.77742 .04578 L
.8153 .04578 L
.85564 .04578 L
.89447 .04578 L
.93574 .04578 L
Mistroke
.9755 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool00ooo
o`0306Kooooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oool0I_l01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo023oool0
0`1Vooooooooo`1[oooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo023oool00`1Voooo
ooooo`1[oooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo023oool00`1Vooooooooo`1[
oooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo023oool00`1Vooooooooo`1[oooo001/
oooo00<0I_ooooooool08?ooo`80000Qoooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo
023oool00`000?ooooooo`0Poooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo023oool0
0`000?ooooooo`0Poooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo023oool00`000?oo
ooooo`0Poooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo023oool00`000?ooooooo`0P
oooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo023oool00`000?ooooooo`0Poooo00<0
I_ooooooool0Joooo`00K?ooo`0306Kooooooooo023oool200008Oooo`0306Kooooooooo06_oool0
06coool00`1Vooooooooo`0Poooo00<0003oooooool08?ooo`0306Kooooooooo06_oool006coool0
0`1Vooooooooo`0Poooo00<0003oooooool08?ooo`0306Kooooooooo06_oool006coool00`1Voooo
ooooo`0Poooo00<0003oooooool08?ooo`0306Kooooooooo06_oool006coool00`1Vooooooooo`0P
oooo00<0003oooooool08?ooo`0306Kooooooooo06_oool006coool00`1Vooooooooo`0Poooo00<0
003oooooool08?ooo`0306Kooooooooo06_oool006coool00`1Vooooooooo`0Poooo0P00027oool0
0`1Vooooooooo`1[oooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo023oool00`1Voooo
ooooo`1[oooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo023oool00`1Vooooooooo`1[
oooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo023oool00`1Vooooooooo`1[oooo001/
oooo00<0I_ooooooool08?ooo`030000oooooooo023oool00`1Vooooooooo`1[oooo001/oooo00<0
I_ooooooool08?ooo`030000oooooooo023oool00`1Vooooooooo`1[oooo001/oooo00<0I_oooooo
ool08?ooo`80000Qoooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo023oool00`000?oo
ooooo`0Poooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo023oool00`000?ooooooo`0P
oooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo023oool00`000?ooooooo`0Poooo00<0
I_ooooooool0Joooo`00K?ooo`0306Kooooooooo00goool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Poooo00<0I_ooooooool0Joooo`00K?ooo`0306Kooooooooo00coool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Poooo00<0I_ooooooool0Jooo
o`00K?ooo`<0I_l<oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Noooo0`1V
ofgoool006ooool306Ko2Oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool07?oo
o`80I_l2oooo00?o09Woooooool0Joooo`00L_ooo`80I_l7oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo01Woool306Ko1?ooo`03o`2Ioooooooo06_oool007Coool3
06Ko1Oooo`80000:oooo0`0000Coool00`000?ooooooo`0Foooo0`1Vo`Ooool00ol0VOooooooo`1[
oooo001goooo0P1VoaKoool00`000?ooooooo`0Doooo0P1Vo`[oool00ol0VOooooooo`1[oooo001i
oooo0`1Voa?oool00`000?ooooooo`0Boooo0P1Vo`coool00ol0VOooooooo`1[oooo001loooo0P1V
oa7oool200004Oooo`80I_l>oooo00?o09Woooooool0Joooo`00O_ooo`80I_l?oooo00<0003ooooo
ool03_ooo`80I_l@oooo00?o09Woooooool0Joooo`00P?ooo`80I_l=oooo00<0003oooooool03?oo
o`80I_lBoooo00?o09Woooooool0Joooo`00P_ooo`80I_l;oooo00<0003oooooool02_ooo`80I_lD
oooo00?o09Woooooool0Joooo`00Q?ooo`80I_l9oooo00<0003oooooool01oooo`<0I_lFoooo00?o
09Woooooool0Joooo`00Q_ooo`80I_l7oooo0P0000Goool306Ko6Oooo`03o`2Ioooooooo06_oool0
08Soool206Ko1Oooo`030000oooooooo00;oool206Ko7?ooo`03o`2Ioooooooo06_oool008[oool2
06Ko0oooo`050000oooooooooooo06Ko01koool00ol0VOooooooo`1[oooo002<oooo0P1Vo`03oooo
0000oooo0080I_lOoooo00?o09Woooooool0Joooo`00S_ooo`0306Ko000006Ko027oool00ol0VOoo
ooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool200008Ooo
o`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Sooo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2I
oooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000
oooooooo023oool00ol0VOooooooo`1[oooo002?oooo0P00027oool00ol0VOooooooo`1[oooo002?
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo0027oooo1@00
00?oool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00ROooo`030000oooooooo00?oool300008?oo
o`03o`2Ioooooooo06_oool008Woool00`000?ooooooo`03oooo00<0003oooooool08?ooo`03o`2I
oooooooo06_oool008Woool00`000?ooooooo`03oooo00<0003oooooool08?ooo`03o`2Ioooooooo
06_oool008Soool200001Oooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0
003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Wooooo
ool0Joooo`00Soooo`80000Qoooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool0
0`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOoo
ooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool200008Ooo
o`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Sooo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2I
oooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000
oooooooo023oool00ol0VOooooooo`1[oooo002?oooo0P00027oool00ol0VOooooooo`1[oooo002?
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0
003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Wooooo
ool0Joooo`00Soooo`80000Qoooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool0
0`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo023oool00ol0VOooooooo`1[oooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool300008?ooo`03o`2Ioooooooo06_oool007goool00`000?oo
ooooo`08oooo0P0000Goool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
07coool200002_ooo`<00004oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool0
0`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOoo
ooooo`1[oooo002?oooo0P00027oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Sooo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2I
oooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`80000Q
oooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0
003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool0
0`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOoo
ooooo`1[oooo002?oooo0P00027oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Sooo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo0027oooo100000Coool00`000?ooooooo`0P
oooo00?o09Woooooool0Joooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00R?ooo`030000oooooooo00Coool300008?ooo`03o`2Ioooooooo06_oool0
08Woool00`000?ooooooo`03oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00R?ooo`800005
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo0P00
027oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool0
0`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`80000Qoooo00?o09Woooooool0Jooo
o`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Sooo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2I
oooooooo06_oool008ooool200008Oooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0P
oooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo0P00
027oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo001koooo100000?oool200001?ooo`800005oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool007_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0
003oooooool08?ooo`03o`2Ioooooooo06_oool007coool00`000?ooooooo`0;oooo00<0003ooooo
ool00_ooo`<0000Poooo00?o09Woooooool0Joooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P00
00Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool0
0`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001Oooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?ooooooo`08
oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000A
oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000
oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.59832 .04578 L
.61984 .04578 L
.6298 .04578 L
.63527 .04578 L
.63796 .04578 L
.64043 .04578 L
.64164 .04578 L
.64277 .04578 L
s
.64277 .04578 m
.64306 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.33304 .04578 L
.34309 .04578 L
.34772 .04578 L
.35028 .04578 L
.35271 .04578 L
.35496 .04578 L
.35624 .04578 L
.35742 .16033 L
.35852 .16073 L
.35951 .16109 L
.36173 .1619 L
.3815 .16936 L
.42157 .18598 L
.46012 .20408 L
.47966 .21414 L
.49002 .21972 L
.49275 .22122 L
.49572 .22287 L
.49708 .22363 L
.49852 .22444 L
.49976 .22514 L
.50046 .22501 L
.50112 .22464 L
.5118 .21872 L
.52154 .2135 L
.54061 .20372 L
.57929 .1856 L
.59894 .17721 L
.62043 .16861 L
.63036 .16483 L
.63581 .1628 L
.63849 .16182 L
.63967 .16139 L
.64096 .16092 L
.64217 .16048 L
.64329 .04578 L
.64448 .04578 L
.64576 .04578 L
.65097 .04578 L
.66006 .04578 L
.70134 .04578 L
Mistroke
.7411 .04578 L
.77934 .04578 L
.82004 .04578 L
.85922 .04578 L
.90085 .04578 L
.94097 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00D0003oooooooooool0
I_l00oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00D0003oooooooooool0I_l00oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo001Zoooo00<0I_ooooooool08_ooo`030000
oooooooo02;oool00`1Vooooooooo`1Yoooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo
02;oool00`1Vooooooooo`1Yoooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo02;oool0
0`1Vooooooooo`1Yoooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo02;oool00`1Voooo
ooooo`1Yoooo001Zoooo00<0I_ooooooool08_ooo`80000Soooo00<0I_ooooooool0JOooo`00J_oo
o`0306Kooooooooo02;oool00`000?ooooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Ko
oooooooo02;oool00`000?ooooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo
02;oool00`000?ooooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo02;oool0
0`000?ooooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo02;oool00`000?oo
ooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo02;oool200008oooo`0306Ko
oooooooo06Woool006[oool00`1Vooooooooo`0Roooo00<0003oooooool08_ooo`0306Kooooooooo
06Woool006[oool00`1Vooooooooo`0Roooo00<0003oooooool08_ooo`0306Kooooooooo06Woool0
06[oool00`1Vooooooooo`0Roooo00<0003oooooool08_ooo`0306Kooooooooo06Woool006[oool0
0`1Vooooooooo`0Roooo00<0003oooooool08_ooo`0306Kooooooooo06Woool006[oool00`1Voooo
ooooo`0Roooo00<0003oooooool08_ooo`0306Kooooooooo06Woool006[oool00`1Vooooooooo`0R
oooo0P0002?oool00`1Vooooooooo`1Yoooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo
02;oool00`1Vooooooooo`1Yoooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo02;oool0
0`1Vooooooooo`1Yoooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo02;oool00`1Voooo
ooooo`1Yoooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo02;oool00`1Vooooooooo`1Y
oooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo02;oool00`1Vooooooooo`1Yoooo001Z
oooo00<0I_ooooooool08_ooo`80000Soooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo
02;oool00`000?ooooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo02;oool0
0`000?ooooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo02;oool00`000?oo
ooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo00ooool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`0Roooo00<0I_ooooooool0JOooo`00J_ooo`0306Kooooooooo
00koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Roooo00<0
I_ooooooool0JOooo`00J_ooo`<0I_l>oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000Poooo0`1Vof_oool006goool206Ko3?ooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool07_ooo`80I_l2oooo00?o09Woooooool0JOooo`00Koooo`<0I_l9oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo01_oool306Ko1?ooo`03o`2Ioooooooo
06Woool007;oool306Ko1oooo`80000:oooo0`0000Coool00`000?ooooooo`0Ioooo0P1Vo`Ooool0
0ol0VOooooooo`1Yoooo001eoooo0P1VoaSoool00`000?ooooooo`0Foooo0`1Vo`Woool00ol0VOoo
ooooo`1Yoooo001goooo0`1VoaGoool00`000?ooooooo`0Doooo0P1Vo`coool00ol0VOooooooo`1Y
oooo001joooo0P1Voa?oool200004oooo`80I_l>oooo00?o09Woooooool0JOooo`00O?ooo`80I_lA
oooo00<0003oooooool04?ooo`80I_l@oooo00?o09Woooooool0JOooo`00O_ooo`80I_l?oooo00<0
003oooooool03_ooo`80I_lBoooo00?o09Woooooool0JOooo`00P?ooo`80I_l=oooo00<0003ooooo
ool03?ooo`80I_lDoooo00?o09Woooooool0JOooo`00P_ooo`80I_l;oooo00<0003oooooool02_oo
o`80I_lFoooo00?o09Woooooool0JOooo`00Q?ooo`80I_l9oooo0P0000Soool306Ko6?ooo`03o`2I
oooooooo06Woool008Koool206Ko1oooo`030000oooooooo00Goool206Ko6oooo`03o`2Ioooooooo
06Woool008Soool206Ko1Oooo`030000oooooooo00?oool206Ko7Oooo`03o`2Ioooooooo06Woool0
08[oool00`1Vooooooooo`02oooo00@0003oooooooooool206Ko7oooo`03o`2Ioooooooo06Woool0
08_oool306Ko00?oool0003oool00P1Vob7oool00ol0VOooooooo`1Yoooo002>oooo00<0I_l00000
I_l08oooo`03o`2Ioooooooo06Woool008ooool200008oooo`03o`2Ioooooooo06Woool008ooool0
0`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOoo
ooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?oo
ooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Y
oooo002?oooo0P0002?oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2I
oooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000
oooooooo02;oool00ol0VOooooooo`1Yoooo0027oooo1@0000?oool00`000?ooooooo`0Roooo00?o
09Woooooool0JOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00ROooo`030000oooooooo00?oool300008_ooo`03o`2Ioooooooo06Woool008Woool0
0`000?ooooooo`03oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008Woool00`000?oo
ooooo`03oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008Soool200001Oooo`030000
oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo
06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`80000Soooo00?o
09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0003ooooo
ool08_ooo`03o`2Ioooooooo06Woool008ooool200008oooo`03o`2Ioooooooo06Woool008ooool0
0`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOoo
ooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?oo
ooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Y
oooo002?oooo0P0002?oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2I
oooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000
oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo
06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`80000Soooo00?o
09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo02;oool00ol0VOoo
ooooo`1Yoooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
02;oool00ol0VOooooooo`1Yoooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool3
00008_ooo`03o`2Ioooooooo06Woool007goool00`000?ooooooo`08oooo0P0000Goool00`000?oo
ooooo`0Roooo00?o09Woooooool0JOooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`04
oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool007coool200002_ooo`<00004oooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool0
0ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool0
0`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOoo
ooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?oo
ooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`80000Soooo00?o09Woooooool0JOooo`00Sooo
o`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2I
oooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000
oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo
06Woool008ooool200008oooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o
09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool0
0ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool0
0`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOoo
ooooo`1Yoooo0027oooo100000Coool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Qooo
o`030000oooooooo00Goool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00R?ooo`030000
oooooooo00Coool300008_ooo`03o`2Ioooooooo06Woool008Woool00`000?ooooooo`03oooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool008Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`0Roooo00?o09Woooooool0JOooo`00R?ooo`800005oooo00<0003oooooool08_ooo`03o`2I
oooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000
oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool00ol0VOooooooo`1Yoooo002?
oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o
09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00Soooo`80000Soooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool0
0ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool0
0`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOoo
ooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool200008ooo
o`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Sooo
o`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2I
oooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000
oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo0P0002?oool00ol0VOooooooo`1Yoooo002?
oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o
09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo001koooo1000
00?oool200001?ooo`800005oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool007_oool0
0`000?ooooooo`09oooo00@0003oooooool00004oooo00<0003oooooool08_ooo`03o`2Ioooooooo
06Woool007coool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0000Roooo00?o09Wooooo
ool0JOooo`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Ooo
o`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool0
07coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool500000_ooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`08oooo0`0000Coool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000017oool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.59832 .04578 L
.61984 .04578 L
.6298 .04578 L
.64043 .04578 L
.64559 .04578 L
.64812 .04578 L
.64923 .04578 L
.65045 .04578 L
s
.65045 .04578 m
.65073 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.32392 .04578 L
.33304 .04578 L
.33788 .04578 L
.34309 .04578 L
.34566 .04578 L
.34693 .04578 L
.34811 .04578 L
.34918 .04578 L
.35031 .16063 L
.35157 .16109 L
.35271 .1615 L
.36173 .16484 L
.3815 .17249 L
.42157 .18953 L
.46012 .20809 L
.47966 .2184 L
.49002 .22412 L
.49275 .22566 L
.49572 .22735 L
.49708 .22813 L
.49852 .22897 L
.49976 .22968 L
.50046 .22955 L
.50112 .22917 L
.5118 .2231 L
.52154 .21774 L
.54061 .20772 L
.57929 .18914 L
.59894 .18054 L
.62043 .17172 L
.63036 .16784 L
.63581 .16576 L
.64096 .16383 L
.64576 .16206 L
.64708 .16158 L
.64847 .16107 L
.64966 .16064 L
.65097 .04578 L
.65215 .04578 L
.65323 .04578 L
.65566 .04578 L
.66006 .04578 L
Mistroke
.69982 .04578 L
.73806 .04578 L
.77876 .04578 L
.81794 .04578 L
.85958 .04578 L
.8997 .04578 L
.9383 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oool0I_l01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool00oooo`0306Kooooo000000Soool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool0
0`1Vooooooooo`1Woooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool00`1Voooo
ooooo`1Woooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool00`1Vooooooooo`1W
oooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool00`1Vooooooooo`1Woooo001X
oooo00<0I_ooooooool09?ooo`80000Uoooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo
02Coool00`000?ooooooo`0Toooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo02Coool0
0`000?ooooooo`0Toooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo02Coool00`000?oo
ooooo`0Toooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo02Coool00`000?ooooooo`0T
oooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo02Coool00`000?ooooooo`0Toooo00<0
I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo02Coool200009Oooo`0306Kooooooooo06Ooool0
06Soool00`1Vooooooooo`0Toooo00<0003oooooool09?ooo`0306Kooooooooo06Ooool006Soool0
0`1Vooooooooo`0Toooo00<0003oooooool09?ooo`0306Kooooooooo06Ooool006Soool00`1Voooo
ooooo`0Toooo00<0003oooooool09?ooo`0306Kooooooooo06Ooool006Soool00`1Vooooooooo`0T
oooo00<0003oooooool09?ooo`0306Kooooooooo06Ooool006Soool00`1Vooooooooo`0Toooo00<0
003oooooool09?ooo`0306Kooooooooo06Ooool006Soool00`1Vooooooooo`0Toooo0P0002Goool0
0`1Vooooooooo`1Woooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool00`1Voooo
ooooo`1Woooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool00`1Vooooooooo`1W
oooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool00`1Vooooooooo`1Woooo001X
oooo00<0I_ooooooool09?ooo`030000oooooooo02Coool00`1Vooooooooo`1Woooo001Xoooo00<0
I_ooooooool09?ooo`030000oooooooo02Coool00`1Vooooooooo`1Woooo001Xoooo00<0I_oooooo
ool09?ooo`80000Uoooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo02Coool00`000?oo
ooooo`0Toooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo02Coool00`000?ooooooo`0T
oooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo02Coool00`000?ooooooo`0Toooo00<0
I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo017oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Toooo00<0I_ooooooool0Ioooo`00J?ooo`0306Kooooooooo013oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Toooo00<0I_ooooooool0Iooo
o`00J?ooo`80I_lAoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Soooo0P1V
ofWoool006[oool306Ko3_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool08?oo
o`<0I_l00oooool0VOooo`1Xoooo001]oooo0P1Vo`coool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool07_ooo`80I_l4oooo00?o09Woooooool0Ioooo`00Koooo`<0I_l:
oooo0P0000[oool300001?ooo`030000oooooooo01_oool306Ko1_ooo`03o`2Ioooooooo06Ooool0
07;oool306Ko6_ooo`030000oooooooo01Woool206Ko2Oooo`03o`2Ioooooooo06Ooool007Goool2
06Ko6?ooo`030000oooooooo01Koool306Ko2oooo`03o`2Ioooooooo06Ooool007Ooool306Ko5Ooo
o`80000Eoooo0P1Vo`koool00ol0VOooooooo`1Woooo001joooo0P1Voa?oool00`000?ooooooo`0B
oooo0P1Voa3oool00ol0VOooooooo`1Woooo001loooo0P1Voa7oool00`000?ooooooo`0@oooo0P1V
oa;oool00ol0VOooooooo`1Woooo001noooo0P1Vo`ooool00`000?ooooooo`0>oooo0P1VoaCoool0
0ol0VOooooooo`1Woooo0020oooo0P1Vo`goool00`000?ooooooo`0<oooo0P1VoaKoool00ol0VOoo
ooooo`1Woooo0022oooo0P1Vo`_oool200002oooo`80I_lHoooo00?o09Woooooool0Ioooo`00Q?oo
o`80I_l9oooo00<0003oooooool02?ooo`80I_lJoooo00?o09Woooooool0Ioooo`00Q_ooo`80I_l7
oooo00<0003oooooool01_ooo`80I_lLoooo00?o09Woooooool0Ioooo`00R?ooo`80I_l5oooo00<0
003oooooool01?ooo`80I_lNoooo00?o09Woooooool0Ioooo`00R_ooo`0306Kooooooooo00;oool0
0`000?ooooooo`02oooo0P1Vob3oool00ol0VOooooooo`1Woooo002;oooo0P1Vo`;oool00`000?oo
ooooo`0206Ko8_ooo`03o`2Ioooooooo06Ooool008goool206Ko0P00000306Kooooooooo02;oool0
0ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOoo
ooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?oo
ooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`80000Uoooo00?o09Woooooool0Ioooo`00Sooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Qoooo`D00003
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008Woool00`000?ooooooo`03oooo00<0
003oooooool09?ooo`03o`2Ioooooooo06Ooool008Woool00`000?ooooooo`03oooo0`0002Coool0
0ol0VOooooooo`1Woooo0029oooo00<0003oooooool00oooo`030000oooooooo02Coool00ol0VOoo
ooooo`1Woooo0029oooo00<0003oooooool00oooo`030000oooooooo02Coool00ol0VOooooooo`1W
oooo0028oooo0P0000Goool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo
06Ooool008ooool200009Oooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0
003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Wooooo
ool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P0002Goool0
0ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOoo
ooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?oo
ooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`80000Uoooo00?o09Woooooool0Ioooo`00Sooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo
06Ooool008ooool200009Oooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0
003oooooool09?ooo`03o`2Ioooooooo06Ooool007_oool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00OOooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00OOooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`0002Coool00ol0VOooooooo`1Woooo001moooo00<0003ooooo
ool02?ooo`800005oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool007goool00`000?oo
ooooo`08oooo00<0003oooooool01?ooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo001l
oooo0P0000[oool300001?ooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0
003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Wooooo
ool0Ioooo`00Soooo`80000Uoooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOoo
ooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool200009Ooo
o`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Sooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0
003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Wooooo
ool0Ioooo`00Soooo`80000Uoooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Qoooo`@00004oooo00<0003oooooool09?oo
o`03o`2Ioooooooo06Ooool008Ooool00`000?ooooooo`05oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008Soool00`000?ooooooo`04oooo0`0002Coool00ol0VOooooooo`1Woooo0029
oooo00<0003oooooool00oooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo0027oooo00@0
003oooooool00004oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008Soool200001Ooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`80000U
oooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0
003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool200009Oooo`03o`2Ioooooooo06Ooool0
08ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOoo
ooooo`1Woooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?oo
o`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Sooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`80000U
oooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Noooo`@00003oooo0P0000Coool200001Oooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo001koooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo001loooo00<0003oooooool02oooo`030000oooooooo
00;oool300009?ooo`03o`2Ioooooooo06Ooool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`<00004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Oooo`050000oooooooooooo0000
00;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`08oooo0`0000Goool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000017oool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.59832 .04578 L
.61984 .04578 L
.6298 .04578 L
.64043 .04578 L
.64559 .04578 L
.65045 .04578 L
.65482 .04578 L
.65602 .04578 L
.65728 .04578 L
.65836 .04578 L
s
.65836 .04578 m
.65866 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.30316 .04578 L
.31323 .04578 L
.32392 .04578 L
.33304 .04578 L
.33554 .04578 L
.33823 .04578 L
.33953 .04578 L
.34076 .04578 L
.34187 .16045 L
.34309 .16089 L
.38373 .17661 L
.42286 .19377 L
.46444 .21448 L
.47459 .21996 L
.48531 .22594 L
.49446 .23121 L
.49697 .23269 L
.49835 .2335 L
.49966 .23427 L
.50087 .23396 L
.5022 .23318 L
.50451 .23182 L
.54306 .21054 L
.58384 .19068 L
.60409 .18172 L
.62311 .17382 L
.64127 .1667 L
.64625 .16482 L
.65149 .16287 L
.65596 .16123 L
.65719 .16079 L
.6585 .16031 L
.65974 .04578 L
.66086 .04578 L
.70084 .04578 L
.73931 .04578 L
.78023 .04578 L
.81963 .04578 L
.85752 .04578 L
.89786 .04578 L
.93668 .04578 L
.97619 .04578 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`03000006Kooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool0
0ol0V@1Vooooo`1Uoooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00ol0V@1V
ooooo`1Uoooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00ol0V@1Vooooo`1U
oooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00ol0V@1Vooooo`1Uoooo001V
oooo00<0I_ooooooool09_ooo`80000Woooo00?o09T0I_ooool0IOooo`00I_ooo`0306Kooooooooo
02Koool00`000?ooooooo`0Voooo00?o09T0I_ooool0IOooo`00I_ooo`0306Kooooooooo02Koool0
0`000?ooooooo`0Voooo00?o09T0I_ooool0IOooo`00I_ooo`0306Kooooooooo02Koool00`000?oo
ooooo`0Voooo00?o09T0I_ooool0IOooo`00I_ooo`0306Kooooooooo02Koool00`000?ooooooo`0V
oooo00?o09T0I_ooool0IOooo`00I_ooo`0306Kooooooooo02Koool00`000?ooooooo`0Voooo00?o
09T0I_ooool0IOooo`00I_ooo`0306Kooooooooo02Koool200009oooo`03o`2I06Kooooo06Goool0
06Koool00`1Vooooooooo`0Voooo00<0003oooooool09_ooo`03o`2I06Kooooo06Goool006Koool0
0`1Vooooooooo`0Voooo00<0003oooooool09_ooo`03o`2I06Kooooo06Goool006Koool00`1Voooo
ooooo`0Voooo00<0003oooooool09_ooo`0306Kooooooooo06Goool006Koool00`1Vooooooooo`0V
oooo00<0003oooooool09_ooo`0306Kooooooooo06Goool006Koool00`1Vooooooooo`0Voooo00<0
003oooooool09_ooo`0306Kooooooooo06Goool006Koool00`1Vooooooooo`0Voooo0P0002Ooool0
0`1Vooooooooo`1Uoooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00`1Voooo
ooooo`1Uoooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00`1Vooooooooo`1U
oooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00`1Vooooooooo`1Uoooo001V
oooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00`1Vooooooooo`1Uoooo001Voooo00<0
I_ooooooool09_ooo`030000oooooooo02Koool00`1Vooooooooo`1Uoooo001Voooo00<0I_oooooo
ool09_ooo`80000Woooo00<0I_ooooooool0IOooo`00I_ooo`0306Kooooooooo02Koool00`000?oo
ooooo`0Voooo00<0I_ooooooool0IOooo`00I_ooo`0306Kooooooooo02Koool00`000?ooooooo`0V
oooo00<0I_ooooooool0IOooo`00I_ooo`0306Kooooooooo02Koool00`000?ooooooo`0Voooo00<0
I_ooooooool0IOooo`00I_ooo`0306Kooooooooo01?oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0Voooo00<0I_ooooooool0IOooo`00I_ooo`0306Kooooooooo01;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Voooo00<0I_ooooooool0IOoo
o`00I_ooo`80I_lCoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Toooo0`1V
ofOoool006Soool306Ko4?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool08Ooo
o`<0I_l2oooo00?o09Woooooool0IOooo`00Joooo`80I_l>oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo01ooool206Ko1Oooo`03o`2Ioooooooo06Goool006goool3
06Ko3?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Loooo0`1Vo`Ooool00ol0VOooooooo`1U
oooo001`oooo0`1Voacoool00`000?ooooooo`0Joooo0P1Vo`[oool00ol0VOooooooo`1Uoooo001c
oooo0P1Voa[oool00`000?ooooooo`0Hoooo0P1Vo`coool00ol0VOooooooo`1Uoooo001eoooo0`1V
oaOoool200005oooo`80I_l>oooo00?o09Woooooool0IOooo`00N?ooo`80I_lEoooo00<0003ooooo
ool05?ooo`80I_l@oooo00?o09Woooooool0IOooo`00N_ooo`80I_lCoooo00<0003oooooool04_oo
o`80I_lBoooo00?o09Woooooool0IOooo`00O?ooo`80I_lAoooo00<0003oooooool04?ooo`80I_lD
oooo00?o09Woooooool0IOooo`00O_ooo`80I_l?oooo00<0003oooooool03_ooo`80I_lFoooo00?o
09Woooooool0IOooo`00P?ooo`80I_l=oooo0P0000goool206Ko6?ooo`03o`2Ioooooooo06Goool0
08;oool206Ko2oooo`030000oooooooo00[oool206Ko6_ooo`03o`2Ioooooooo06Goool008Coool2
06Ko2Oooo`030000oooooooo00Soool206Ko7?ooo`03o`2Ioooooooo06Goool008Koool00`1Voooo
ooooo`06oooo00<0003oooooool01_ooo`80I_lNoooo00?o09Woooooool0IOooo`00Qoooo`80I_l6
oooo00<0003oooooool01?ooo`80I_lPoooo00?o09Woooooool0IOooo`00ROooo`80I_l4oooo00<0
003oooooool00_ooo`80I_lRoooo00?o09Woooooool0IOooo`00Roooo`80I_l2oooo0P000003oooo
06Ko06Ko02Coool00ol0VOooooooo`1Uoooo002=oooo0P1Vo`03000006Ko06Ko02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<00000I_ooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool200009oooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008Ooool500000oooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo0029oooo00<0
003oooooool00oooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo0029oooo00<0003ooooo
ool00oooo`<0000Voooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0V
oooo00?o09Woooooool0IOooo`00R?ooo`800005oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo
02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00Soooo`80000Woooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool200009oooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo
02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo001koooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool007goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool0
07goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000Voooo00?o09Woooooool0IOoo
o`00OOooo`030000oooooooo00Soool200001Oooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo001moooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool008ooool200009oooo`03o`2Ioooooooo06Goool008ooool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000Woooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool008ooool200009oooo`03o`2Ioooooooo06Goool008ooool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008Ooool400001?oo
o`030000oooooooo02Koool00ol0VOooooooo`1Uoooo0027oooo00<0003oooooool01Oooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo0028oooo00<0003oooooool01?ooo`<0000Voooo00?o
09Woooooool0IOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo02Koool00ol0VOooooooo`1U
oooo0028oooo0P0000Goool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008ooool200009oooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool0
0ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000Woooo00?o09Woooooool0IOooo`00Sooo
o`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008ooool200009oooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool007_oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Noooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00O?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0002Koool00ol0VOooooooo`1Uoooo001moooo00<0003ooooo
ool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?oo
o`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00Ooooo`030000oooooooo01coool0
0`000?ooooooo`1ooooo001noooo00<0003oooooool02?ooo`030000oooooooo01?oool00`000?oo
ooooo`1noooo001noooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003
oooo0P0000Coool00`000?ooooooo`1noooo001noooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02_ooo`030000oooooooo07koool0
07goool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00[oool00`000?oo
ooooo`1moooo001noooo00<0003oooooool01@0000koool00`000?ooooooo`08oooo00<0003ooooo
ool0O_ooo`00O_ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?oo
ooooo`1noooo001ooooo00<0003oooooool04Oooo`800009oooo00<0003oooooool0Ooooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.64043 .04578 L
.65045 .04578 L
.65954 .04578 L
.66177 .04578 L
.66412 .04578 L
.66534 .04578 L
.66604 .04578 L
s
.66604 .04578 m
.6662 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.30316 .04578 L
.31323 .04578 L
.32392 .04578 L
.32831 .04578 L
.33073 .04578 L
.33193 .04578 L
.33304 .04578 L
.33433 .16059 L
.33502 .16084 L
.33575 .1611 L
.33823 .16201 L
.34309 .1638 L
.38467 .18032 L
.42473 .19842 L
.46328 .21812 L
.48283 .22907 L
.48819 .23219 L
.49393 .23559 L
.49671 .23726 L
.49808 .23809 L
.49935 .23886 L
.50049 .23895 L
.50171 .23821 L
.50429 .23666 L
.54378 .21433 L
.58153 .19544 L
.62173 .17763 L
.64021 .17018 L
.65068 .16614 L
.65578 .16422 L
.66042 .16251 L
.66281 .16163 L
.66407 .16117 L
.6654 .16069 L
.66657 .16027 L
.66785 .04578 L
.66901 .04578 L
.67011 .04578 L
.68046 .04578 L
.70156 .04578 L
.74038 .04578 L
.78166 .04578 L
Mistroke
.82142 .04578 L
.85966 .04578 L
.90036 .04578 L
.93954 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`04oooo00<0I_ooool000001ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`040000ooooo`2I06Ko1Oooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool006Coool00`1Vooooooooo`0Xoooo00<0003oooooool0:?oo
o`03o`2I06Kooooo06?oool006Coool00`1Vooooooooo`0Xoooo00<0003oooooool0:?ooo`03o`2I
06Kooooo06?oool006Coool00`1Vooooooooo`0Xoooo00<0003oooooool0:?ooo`03o`2I06Kooooo
06?oool006Coool00`1Vooooooooo`0Xoooo00<0003oooooool0:?ooo`03o`2I06Kooooo06?oool0
06Coool00`1Vooooooooo`0Xoooo0P0002Woool00ol0V@1Vooooo`1Soooo001Toooo00<0I_oooooo
ool0:?ooo`030000oooooooo02Soool00ol0V@1Vooooo`1Soooo001Toooo00<0I_ooooooool0:?oo
o`030000oooooooo02Soool00ol0V@1Vooooo`1Soooo001Toooo00<0I_ooooooool0:?ooo`030000
oooooooo02Soool00ol0V@1Vooooo`1Soooo001Toooo00<0I_ooooooool0:?ooo`030000oooooooo
02Soool00ol0V@1Vooooo`1Soooo001Toooo00<0I_ooooooool0:?ooo`030000oooooooo02Soool0
0ol0V@1Vooooo`1Soooo001Toooo00<0I_ooooooool0:?ooo`80000Yoooo00?o09T0I_ooool0Hooo
o`00I?ooo`0306Kooooooooo02Soool00`000?ooooooo`0Xoooo00?o09T0I_ooool0Hoooo`00I?oo
o`0306Kooooooooo02Soool00`000?ooooooo`0Xoooo00?o09T0I_ooool0Hoooo`00I?ooo`0306Ko
oooooooo02Soool00`000?ooooooo`0Xoooo00<0I_ooooooool0Hoooo`00I?ooo`0306Kooooooooo
02Soool00`000?ooooooo`0Xoooo00<0I_ooooooool0Hoooo`00I?ooo`0306Kooooooooo02Soool0
0`000?ooooooo`0Xoooo00<0I_ooooooool0Hoooo`00I?ooo`0306Kooooooooo02Soool20000:Ooo
o`0306Kooooooooo06?oool006Coool00`1Vooooooooo`0Xoooo00<0003oooooool0:?ooo`0306Ko
oooooooo06?oool006Coool00`1Vooooooooo`0Xoooo00<0003oooooool0:?ooo`0306Kooooooooo
06?oool006Coool00`1Vooooooooo`0Xoooo00<0003oooooool0:?ooo`0306Kooooooooo06?oool0
06Coool00`1Vooooooooo`0Xoooo00<0003oooooool0:?ooo`0306Kooooooooo06?oool006Coool0
0`1Vooooooooo`0Xoooo00<0003oooooool0:?ooo`0306Kooooooooo06?oool006Coool00`1Voooo
ooooo`0Xoooo0P0002Woool00`1Vooooooooo`1Soooo001Toooo00<0I_ooooooool0:?ooo`030000
oooooooo02Soool00`1Vooooooooo`1Soooo001Toooo00<0I_ooooooool0:?ooo`030000oooooooo
02Soool00`1Vooooooooo`1Soooo001Toooo00<0I_ooooooool0:?ooo`030000oooooooo02Soool0
0`1Vooooooooo`1Soooo001Toooo00<0I_ooooooool05Oooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo02Soool00`1Vooooooooo`1Soooo001Toooo00<0I_ooooooool05?ooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo02Soool00`1Vooooooooo`1S
oooo001Toooo0P1VoaGoool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0002Ooool2
06KoIOooo`00I_ooo`80I_lCoooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0S
oooo101Vo`03ooooo`2Ioooo06Coool006Soool306Ko4?ooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`0Qoooo0P1Vo`Goool00ol0VOooooooo`1Soooo001[oooo0P1V
o`ooool200002_ooo`<00004oooo00<0003oooooool07oooo`80I_l7oooo00?o09Woooooool0Hooo
o`00KOooo`<0I_lOoooo00<0003oooooool07?ooo`<0I_l9oooo00?o09Woooooool0Hoooo`00L?oo
o`80I_lMoooo00<0003oooooool06_ooo`80I_l<oooo00?o09Woooooool0Hoooo`00L_ooo`80I_lK
oooo0P0001Woool206Ko3_ooo`03o`2Ioooooooo06?oool007Coool206Ko6Oooo`030000oooooooo
01Koool206Ko4?ooo`03o`2Ioooooooo06?oool007Koool206Ko5oooo`030000oooooooo01Coool2
06Ko4_ooo`03o`2Ioooooooo06?oool007Soool206Ko5Oooo`030000oooooooo01;oool206Ko5?oo
o`03o`2Ioooooooo06?oool007[oool206Ko4oooo`030000oooooooo013oool206Ko5_ooo`03o`2I
oooooooo06?oool007coool206Ko4Oooo`80000?oooo0P1VoaSoool00ol0VOooooooo`1Soooo001n
oooo0P1Vo`ooool00`000?ooooooo`0<oooo0P1Voa[oool00ol0VOooooooo`1Soooo0020oooo0P1V
o`goool00`000?ooooooo`0:oooo0P1Voacoool00ol0VOooooooo`1Soooo0022oooo0P1Vo`_oool0
0`000?ooooooo`08oooo0P1Voakoool00ol0VOooooooo`1Soooo0024oooo0`1Vo`Soool00`000?oo
ooooo`06oooo0P1Vob3oool00ol0VOooooooo`1Soooo0027oooo0`1Vo`Goool00`000?ooooooo`04
oooo0P1Vob;oool00ol0VOooooooo`1Soooo002:oooo0P1Vo`?oool200000oooo`80I_lToooo00?o
09Woooooool0Hoooo`00S?ooo`0406Kooooooooo00000_ooo`80I_lVoooo00?o09Woooooool0Hooo
o`00SOooo`0306Kooooo00000080I_lXoooo00?o09Woooooool0Hoooo`00S_ooo`0306Ko0000oooo
02Woool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool0
08ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`80000Yoooo00?o09Wooooo
ool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003ooooo
ool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hooo
o`00Qoooo`D00003oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008Woool00`000?ooooooo`03
oooo0`0002Soool00ol0VOooooooo`1Soooo0029oooo00<0003oooooool00oooo`030000oooooooo
02Soool00ol0VOooooooo`1Soooo0029oooo00<0003oooooool00oooo`030000oooooooo02Soool0
0ol0VOooooooo`1Soooo0028oooo0P0000Goool00`000?ooooooo`0Xoooo00?o09Woooooool0Hooo
o`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?oo
o`03o`2Ioooooooo06?oool008ooool20000:Oooo`03o`2Ioooooooo06?oool008ooool00`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1S
oooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0X
oooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?
oooo0P0002Woool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo
06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo
02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool0
08ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`80000Yoooo00?o09Wooooo
ool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003ooooo
ool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hooo
o`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?oo
o`03o`2Ioooooooo06?oool008ooool20000:Oooo`03o`2Ioooooooo06?oool008ooool00`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1S
oooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool007_oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00OOooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00OOoo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`0002Soool00ol0VOooooooo`1Soooo001m
oooo00<0003oooooool02?ooo`800005oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool0
07goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo02Soool00ol0VOoo
ooooo`1Soooo001loooo0P0000[oool300001?ooo`030000oooooooo02Soool00ol0VOooooooo`1S
oooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0X
oooo00?o09Woooooool0Hoooo`00Soooo`80000Yoooo00?o09Woooooool0Hoooo`00Soooo`030000
oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo
06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo
02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool0
08ooool20000:Oooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Wooooo
ool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003ooooo
ool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hooo
o`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo0P0002Woool00ol0VOoo
ooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1S
oooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0X
oooo00?o09Woooooool0Hoooo`00Soooo`80000Yoooo00?o09Woooooool0Hoooo`00Soooo`030000
oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo
06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Qoooo`@00004oooo00<0
003oooooool0:?ooo`03o`2Ioooooooo06?oool008Ooool00`000?ooooooo`05oooo00<0003ooooo
ool0:?ooo`03o`2Ioooooooo06?oool008Soool00`000?ooooooo`04oooo0`0002Soool00ol0VOoo
ooooo`1Soooo0029oooo00<0003oooooool00oooo`030000oooooooo02Soool00ol0VOooooooo`1S
oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool0
08Soool200001Oooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003ooooo
ool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hooo
o`00Soooo`80000Yoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOoo
ooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1S
oooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool20000:Oooo`03o`2I
oooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000
oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo
06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo
02Soool00ol0VOooooooo`1Soooo002?oooo0P0002Woool00ol0VOooooooo`1Soooo002?oooo00<0
003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Wooooo
ool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo002?oooo00<0003ooooo
ool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?ooooooo`0Xoooo00?o09Woooooool0Hooo
o`00Soooo`80000Yoooo00?o09Woooooool0Hoooo`00Soooo`030000oooooooo02Soool00ol0VOoo
ooooo`1Soooo002?oooo00<0003oooooool0:?ooo`03o`2Ioooooooo06?oool008ooool00`000?oo
ooooo`0Xoooo00?o09Woooooool0Hoooo`00Noooo`@00003oooo0P0000Coool200001Oooo`030000
oooooooo02Soool00ol0VOooooooo`1Soooo001koooo00<0003oooooool02Oooo`040000oooooooo
00001?ooo`030000oooooooo02Soool00ol0VOooooooo`1Soooo001loooo00<0003oooooool02ooo
o`030000oooooooo00;oool30000:?ooo`03o`2Ioooooooo06?oool007goool00`000?ooooooo`08
oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P00
00[oool30000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool2
00001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`040000
oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00Soool010000?ooooooo`0000Goool0
0`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0
003oooooool01oooo`040000oooooooo00000oooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_oo
o`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.64043 .04578 L
.65045 .04578 L
.65954 .04578 L
.66412 .04578 L
.66906 .04578 L
.67133 .04578 L
.67257 .04578 L
.67373 .04578 L
s
.67373 .04578 m
.67398 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.30316 .04578 L
.31323 .04578 L
.31875 .04578 L
.32145 .04578 L
.32263 .04578 L
.32392 .04578 L
.32509 .04578 L
.32617 .16051 L
.32721 .16089 L
.32831 .16129 L
.33304 .16302 L
.34309 .16679 L
.38467 .18372 L
.42473 .20228 L
.46328 .22249 L
.48283 .23371 L
.48819 .23691 L
.49393 .24039 L
.49671 .24211 L
.49808 .24296 L
.49935 .24374 L
.50049 .24384 L
.50171 .24308 L
.50429 .24149 L
.54378 .2186 L
.58153 .19922 L
.62173 .18097 L
.64021 .17333 L
.65068 .16919 L
.66042 .16546 L
.6654 .1636 L
.67011 .16186 L
.67271 .16092 L
.67342 .16066 L
.67418 .16039 L
.67482 .04578 L
.67553 .04578 L
.68046 .04578 L
.70156 .04578 L
.7419 .04578 L
.78072 .04578 L
.822 .04578 L
Mistroke
.86176 .04578 L
.9 .04578 L
.9407 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool01@000?ooooooooooo`1Vo`04oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`050000oooooooooooo06Ko00Coool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo001Qoooo00<0I_ooooooool0:oooo`030000
oooooooo02[oool00`1Vooooooooo`1Qoooo001Qoooo00<0I_ooooooool0:oooo`030000oooooooo
02[oool00`1Vooooooooo`1Qoooo001Qoooo00<0I_ooooooool0:oooo`030000oooooooo02[oool0
0`1Vooooooooo`1Qoooo001Qoooo00<0I_ooooooool0:oooo`030000oooooooo02[oool00`1Voooo
ooooo`1Qoooo001Qoooo00<0I_ooooooool0:oooo`80000[oooo00<0I_ooooooool0HOooo`00HOoo
o`0306Kooooooooo02_oool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00HOooo`0306Ko
oooooooo02_oool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00HOooo`0306Kooooooooo
02_oool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00HOooo`0306Kooooooooo02_oool0
0`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00HOooo`0306Kooooooooo02_oool00`000?oo
ooooo`0Zoooo00<0I_ooooooool0HOooo`00HOooo`0306Kooooooooo02_oool20000:oooo`0306Ko
oooooooo067oool0067oool00`1Vooooooooo`0[oooo00<0003oooooool0:_ooo`0306Kooooooooo
067oool0067oool00`1Vooooooooo`0[oooo00<0003oooooool0:_ooo`0306Kooooooooo067oool0
067oool00`1Vooooooooo`0[oooo00<0003oooooool0:_ooo`0306Kooooooooo067oool006;oool0
0`1Vooooooooo`0Zoooo00<0003oooooool0:_ooo`0306Kooooooooo067oool006;oool00`1Voooo
ooooo`0Zoooo00<0003oooooool0:_ooo`0306Kooooooooo067oool006;oool00`1Vooooooooo`0Z
oooo0P0002_oool00`1Vooooooooo`1Qoooo001Roooo00<0I_ooooooool0:_ooo`030000oooooooo
02[oool00`1Vooooooooo`1Qoooo001Roooo00<0I_ooooooool0:_ooo`030000oooooooo02[oool0
0`1Vooooooooo`1Qoooo001Roooo00<0I_ooooooool0:_ooo`030000oooooooo02[oool00`1Voooo
ooooo`1Qoooo001Roooo00<0I_ooooooool0:_ooo`030000oooooooo02[oool00`1Vooooooooo`1Q
oooo001Roooo00<0I_ooooooool0:_ooo`030000oooooooo02[oool00`1Vooooooooo`1Qoooo001R
oooo00<0I_ooooooool0:_ooo`80000[oooo00<0I_ooooooool0HOooo`00H_ooo`0306Kooooooooo
02[oool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00H_ooo`0306Kooooooooo02[oool0
0`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00H_ooo`0306Kooooooooo02[oool00`000?oo
ooooo`0Zoooo00<0I_ooooooool0HOooo`00H_ooo`0306Kooooooooo01Ooool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`0Zoooo00<0I_ooooooool0HOooo`00H_ooo`0306Kooooooooo
01Koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Zoooo00<0
I_ooooooool0HOooo`00H_ooo`<0I_lFoooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000Xoooo0`1Vof?oool006Goool306Ko4oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool09_ooo`80I_l2oooo00?o09Woooooool0HOooo`00J?ooo`80I_lAoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo02?oool306Ko1?ooo`03o`2Ioooooooo
067oool006[oool206Ko4?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Qoooo0P1Vo`Ooool0
0ol0VOooooooo`1Qoooo001/oooo0P1Vob7oool00`000?ooooooo`0Ooooo0P1Vo`Woool00ol0VOoo
ooooo`1Qoooo001^oooo0P1Voaooool00`000?ooooooo`0Loooo0`1Vo`_oool00ol0VOooooooo`1Q
oooo001`oooo0P1Voagoool200006oooo`80I_l>oooo00?o09Woooooool0HOooo`00L_ooo`80I_lK
oooo00<0003oooooool06?ooo`80I_l@oooo00?o09Woooooool0HOooo`00M?ooo`80I_lIoooo00<0
003oooooool05_ooo`80I_lBoooo00?o09Woooooool0HOooo`00M_ooo`80I_lGoooo00<0003ooooo
ool05?ooo`80I_lDoooo00?o09Woooooool0HOooo`00N?ooo`80I_lEoooo00<0003oooooool04_oo
o`80I_lFoooo00?o09Woooooool0HOooo`00N_ooo`80I_lCoooo0P00017oool206Ko6?ooo`03o`2I
oooooooo067oool007coool206Ko4Oooo`030000oooooooo00koool206Ko6_ooo`03o`2Ioooooooo
067oool007koool206Ko3oooo`030000oooooooo00coool206Ko7?ooo`03o`2Ioooooooo067oool0
083oool206Ko3Oooo`030000oooooooo00[oool206Ko7_ooo`03o`2Ioooooooo067oool008;oool2
06Ko2oooo`030000oooooooo00Soool206Ko8?ooo`03o`2Ioooooooo067oool008Coool206Ko2Ooo
o`030000oooooooo00Koool206Ko8_ooo`03o`2Ioooooooo067oool008Koool206Ko1oooo`800005
oooo0P1VobCoool00ol0VOooooooo`1Qoooo0028oooo0P1Vo`Goool00`000?ooooooo`03oooo00<0
I_ooooooool09?ooo`03o`2Ioooooooo067oool008[oool206Ko0oooo`040000oooooooooooo0P1V
obOoool00ol0VOooooooo`1Qoooo002<oooo0P1Vo`03oooo0000oooo0080I_lYoooo00?o09Wooooo
ool0HOooo`00S_ooo`0306Ko000006Ko02_oool00ol0VOooooooo`1Qoooo002?oooo00<0003ooooo
ool0:_ooo`03o`2Ioooooooo067oool008ooool20000:oooo`03o`2Ioooooooo067oool008ooool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008Ooool500000ooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo0029oooo00<0003oooooool00oooo`030000
oooooooo02[oool00ol0VOooooooo`1Qoooo0029oooo00<0003oooooool00oooo`<0000Zoooo00?o
09Woooooool0HOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Zoooo00?o09Wooooo
ool0HOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Zoooo00?o09Woooooool0HOoo
o`00R?ooo`800005oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?oo
ooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Q
oooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000
oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo
067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`80000[oooo00?o
09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Wooooo
ool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003ooooo
ool0:_ooo`03o`2Ioooooooo067oool008ooool20000:oooo`03o`2Ioooooooo067oool008ooool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?oo
ooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Q
oooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000
oooooooo02[oool00ol0VOooooooo`1Qoooo001koooo1@0000;oool200001?ooo`800005oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool007goool00`000?ooooooo`07oooo00@0003ooooo
ool00004oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool007goool00`000?ooooooo`0:
oooo00<0003oooooool00_ooo`<0000Zoooo00?o09Woooooool0HOooo`00OOooo`030000oooooooo
00Soool200001Oooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001moooo00<0003ooooo
ool02?ooo`030000oooooooo00Coool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00O?oo
o`80000:oooo0`0000Coool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000
oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo
067oool008ooool20000:oooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o
09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Wooooo
ool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool0
0ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?oo
ooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`80000[oooo00?o09Woooooool0HOooo`00Sooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000
oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo
067oool008ooool20000:oooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o
09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008Ooool400001?ooo`030000oooooooo02[oool0
0ol0VOooooooo`1Qoooo0027oooo00<0003oooooool01Oooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo0028oooo00<0003oooooool01?ooo`<0000Zoooo00?o09Woooooool0HOooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Qoooo`040000
oooooooo00001?ooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo0028oooo0P0000Goool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool20000:ooo
o`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Sooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000
oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?
oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o
09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Wooooo
ool0HOooo`00Soooo`80000[oooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool0
0ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool20000:ooo
o`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Sooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool007_oool400000oooo`800004oooo0P0000Goool00`000?ooooooo`0Zoooo00?o
09Woooooool0HOooo`00Noooo`030000oooooooo00Woool010000?ooooooo`0000Coool00`000?oo
ooooo`0Zoooo00?o09Woooooool0HOooo`00O?ooo`030000oooooooo00_oool00`000?ooooooo`02
oooo0`0002[oool00ol0VOooooooo`1Qoooo001moooo00<0003oooooool02?ooo`80002Foooo001k
oooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool0
0?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001k
oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000?oool500000_oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00[oool0
0`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0
003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000003oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.64043 .04578 L
.65954 .04578 L
.66906 .04578 L
.67373 .04578 L
.67803 .04578 L
.68044 .04578 L
.68166 .04578 L
.68235 .04578 L
s
.68235 .04578 m
.68251 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.29205 .04578 L
.30316 .04578 L
.30791 .04578 L
.31304 .04578 L
.31454 .04578 L
.31597 .04578 L
.31725 .04578 L
.31798 .16042 L
.31865 .16066 L
.32392 .16258 L
.34309 .16985 L
.38221 .18613 L
.4238 .20577 L
.46386 .22729 L
.48224 .23811 L
.48728 .24118 L
.49267 .24453 L
.49529 .24618 L
.49777 .24775 L
.49885 .24844 L
.49999 .24917 L
.50125 .24837 L
.50241 .24763 L
.52235 .23535 L
.54342 .22318 L
.58117 .20329 L
.62137 .18455 L
.66006 .16863 L
.67044 .16468 L
.6755 .1628 L
.67771 .16199 L
.6801 .16111 L
.6814 .16064 L
.68261 .04578 L
.68375 .04578 L
.68497 .04578 L
.69018 .04578 L
.7012 .04578 L
.73909 .04578 L
.77943 .04578 L
.81825 .04578 L
.85953 .04578 L
Mistroke
.89929 .04578 L
.93753 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooo`1Vo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00?oool0101Vooooooooo`0000Ooool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool005ooool00`1Vooooooooo`0]oooo00<0003oooooool0;?oo
o`0306Kooooooooo05ooool005ooool00`1Vooooooooo`0]oooo00<0003oooooool0;?ooo`0306Ko
oooooooo05ooool005ooool00`1Vooooooooo`0]oooo00<0003oooooool0;?ooo`0306Kooooooooo
05ooool005ooool00`1Vooooooooo`0]oooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool0
05ooool00`1Vooooooooo`0]oooo0P0002goool00`1Vooooooooo`1Ooooo001Ooooo00<0I_oooooo
ool0;Oooo`030000oooooooo02coool00`1Vooooooooo`1Ooooo001Ooooo00<0I_ooooooool0;Ooo
o`030000oooooooo02coool00`1Vooooooooo`1Ooooo001Ooooo00<0I_ooooooool0;Oooo`030000
oooooooo02coool00`1Vooooooooo`1Ooooo001Ooooo00<0I_ooooooool0;Oooo`030000oooooooo
02coool00`1Vooooooooo`1Ooooo001Ooooo00<0I_ooooooool0;Oooo`030000oooooooo02coool0
0`1Vooooooooo`1Ooooo001Ooooo00<0I_ooooooool0;Oooo`80000]oooo00<0I_ooooooool0Gooo
o`00Goooo`0306Kooooooooo02goool00`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`00Gooo
o`0306Kooooooooo02goool00`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`00Goooo`0306Ko
oooooooo02goool00`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`00H?ooo`0306Kooooooooo
02coool00`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`00H?ooo`0306Kooooooooo02coool0
0`000?ooooooo`0/oooo00<0I_ooooooool0Goooo`00H?ooo`0306Kooooooooo02coool20000;Ooo
o`0306Kooooooooo05ooool0063oool00`1Vooooooooo`0/oooo00<0003oooooool0;?ooo`0306Ko
oooooooo05ooool0063oool00`1Vooooooooo`0/oooo00<0003oooooool0;?ooo`0306Kooooooooo
05ooool0063oool00`1Vooooooooo`0/oooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool0
063oool00`1Vooooooooo`0/oooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool0063oool0
0`1Vooooooooo`0/oooo00<0003oooooool0;?ooo`0306Kooooooooo05ooool0063oool00`1Voooo
ooooo`0/oooo0P0002goool00`1Vooooooooo`1Ooooo001Poooo00<0I_ooooooool0;?ooo`030000
oooooooo02coool00`1Vooooooooo`1Ooooo001Poooo00<0I_ooooooool0;?ooo`030000oooooooo
02coool00`1Vooooooooo`1Ooooo001Poooo00<0I_ooooooool0;?ooo`030000oooooooo02coool0
0`1Vooooooooo`1Ooooo001Poooo00<0I_ooooooool06Oooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo02coool00`1Vooooooooo`1Ooooo001Poooo00<0I_ooooooool06?ooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo02coool00`1Vooooooooo`1O
oooo001Poooo0`1VoaSoool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0002_oool2
06KoHOooo`00Hoooo`80I_lFoooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Y
oooo0P1Vo`03ooooo`2Ioooo063oool006Goool306Ko4oooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`0Voooo0`1Vo`?oool00ol0VOooooooo`1Ooooo001Xoooo0P1V
oa;oool200002_ooo`<00004oooo00<0003oooooool09?ooo`80I_l6oooo00?o09Woooooool0Gooo
o`00J_ooo`<0I_lRoooo00<0003oooooool08Oooo`<0I_l8oooo00?o09Woooooool0Goooo`00KOoo
o`80I_lPoooo00<0003oooooool07oooo`80I_l;oooo00?o09Woooooool0Goooo`00Koooo`<0I_lM
oooo0P0001goool306Ko3Oooo`03o`2Ioooooooo05ooool007;oool206Ko6oooo`030000oooooooo
01[oool206Ko4?ooo`03o`2Ioooooooo05ooool007Coool206Ko6Oooo`030000oooooooo01Soool2
06Ko4_ooo`03o`2Ioooooooo05ooool007Koool206Ko5oooo`030000oooooooo01Koool206Ko5?oo
o`03o`2Ioooooooo05ooool007Soool206Ko5Oooo`030000oooooooo01Coool206Ko5_ooo`03o`2I
oooooooo05ooool007[oool206Ko4oooo`80000Coooo0P1VoaSoool00ol0VOooooooo`1Ooooo001l
oooo0P1Voa7oool00`000?ooooooo`0@oooo0P1Voa[oool00ol0VOooooooo`1Ooooo001noooo0P1V
o`ooool00`000?ooooooo`0>oooo0P1Voacoool00ol0VOooooooo`1Ooooo0020oooo0P1Vo`goool0
0`000?ooooooo`0<oooo0P1Voakoool00ol0VOooooooo`1Ooooo0022oooo0P1Vo`_oool00`000?oo
ooooo`0:oooo0P1Vob3oool00ol0VOooooooo`1Ooooo0024oooo0P1Vo`Woool00`000?ooooooo`08
oooo0P1Vob;oool00ol0VOooooooo`1Ooooo0026oooo00<0I_ooooooool01_ooo`800007oooo0P1V
obCoool00ol0VOooooooo`1Ooooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Coool2
06Ko9_ooo`03o`2Ioooooooo05ooool008Soool206Ko1Oooo`030000oooooooo00?oool00`1Voooo
ooooo`0Voooo00?o09Woooooool0Goooo`00R_ooo`0306Kooooooooo00;oool010000?oooooooooo
o`80I_lYoooo00?o09Woooooool0Goooo`00Roooo`80I_l2oooo00@0003oool0I_l0I_l[oooo00?o
09Woooooool0Goooo`00SOooo`80I_l00`00001Vooooo`0/oooo00?o09Woooooool0Goooo`00Sooo
o`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Qoooo`D00003oooo00<0003oooooool0;?ooo`03o`2Ioooooooo
05ooool008Woool00`000?ooooooo`03oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08Woool00`000?ooooooo`03oooo0`0002coool00ol0VOooooooo`1Ooooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo0029oooo00<0003oooooool00ooo
o`030000oooooooo02coool00ol0VOooooooo`1Ooooo0028oooo0P0000Goool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?
oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool20000;Oooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool0
0ol0VOooooooo`1Ooooo002?oooo0P0002goool00ol0VOooooooo`1Ooooo002?oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?oo
o`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Sooo
o`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?
oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool20000;Oooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
07_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0/oooo00?o
09Woooooool0Goooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0002coool0
0ol0VOooooooo`1Ooooo001moooo00<0003oooooool02?ooo`800005oooo00<0003oooooool0;?oo
o`03o`2Ioooooooo05ooool007goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000
oooooooo02coool00ol0VOooooooo`1Ooooo001loooo0P0000[oool300001?ooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Wooooo
ool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?oo
o`03o`2Ioooooooo05ooool008ooool20000;Oooo`03o`2Ioooooooo05ooool008ooool00`000?oo
ooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?
oooo0P0002goool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Wooooo
ool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Qoooo`@00004oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008Ooool00`000?oo
ooooo`05oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008Soool00`000?ooooooo`04
oooo0`0002coool00ol0VOooooooo`1Ooooo0029oooo00<0003oooooool00oooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo0027oooo00@0003oooooool00004oooo00<0003oooooool0;?oo
o`03o`2Ioooooooo05ooool008Soool200001Oooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000
oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool20000;Oooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Wooooo
ool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo0P0002goool00ol0VOoo
ooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?oo
ooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000
oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Noooo`@00003oooo0P00
00Coool200001Oooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001koooo00<0003ooooo
ool02Oooo`040000oooooooo00001?ooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001l
oooo00<0003oooooool02oooo`030000oooooooo00;oool30000;?ooo`03o`2Ioooooooo05ooool0
07goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?oo
ooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`06oooo100000?oool200000oooo`D00002oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0
003oooooool02oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`0:oooo00<0003ooooo
ool01?ooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P00
00[oool200001?ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.64043 .04578 L
.65954 .04578 L
.67803 .04578 L
.68335 .04578 L
.68596 .04578 L
.68711 .04578 L
.68837 .04578 L
.6895 .04578 L
s
.6895 .04578 m
.68976 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.28158 .04578 L
.29205 .04578 L
.29779 .04578 L
.30316 .04578 L
.3056 .04578 L
.30791 .04578 L
.30919 .04578 L
.30992 .16037 L
.31059 .16062 L
.31304 .1615 L
.32392 .16554 L
.34309 .17299 L
.38221 .18968 L
.4238 .20982 L
.46386 .23189 L
.48224 .24298 L
.48728 .24613 L
.49267 .24957 L
.49529 .25125 L
.49777 .25286 L
.49885 .25357 L
.49999 .25432 L
.50125 .2535 L
.50241 .25274 L
.52235 .24014 L
.54342 .22767 L
.58117 .20727 L
.62137 .18806 L
.66006 .17174 L
.6801 .16403 L
.68497 .16223 L
.68765 .16126 L
.68896 .16078 L
.69018 .16034 L
.69087 .04578 L
.69161 .04578 L
.69317 .04578 L
.69589 .04578 L
.7012 .04578 L
.73909 .04578 L
.77943 .04578 L
.81825 .04578 L
.85953 .04578 L
Mistroke
.89929 .04578 L
.93753 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00ol0V@000?ooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Moooo00<0I_ooooooool0;oooo`030000oooooooo02koool0
0ol0V@1Vooooo`1Moooo001Moooo00<0I_ooooooool0;oooo`030000oooooooo02koool00ol0V@1V
ooooo`1Moooo001Moooo00<0I_ooooooool0;oooo`030000oooooooo02koool00ol0V@1Vooooo`1M
oooo001Moooo00<0I_ooooooool0;oooo`030000oooooooo02koool00ol0V@1Vooooo`1Moooo001M
oooo00<0I_ooooooool0;oooo`80000_oooo00?o09T0I_ooool0GOooo`00GOooo`0306Kooooooooo
02ooool00`000?ooooooo`0^oooo00?o09T0I_ooool0GOooo`00GOooo`0306Kooooooooo02ooool0
0`000?ooooooo`0^oooo00?o09T0I_ooool0GOooo`00GOooo`0306Kooooooooo02ooool00`000?oo
ooooo`0^oooo00?o09T0I_ooool0GOooo`00GOooo`0306Kooooooooo02ooool00`000?ooooooo`0^
oooo00?o09T0I_ooool0GOooo`00GOooo`0306Kooooooooo02ooool00`000?ooooooo`0^oooo00?o
09T0I_ooool0GOooo`00GOooo`0306Kooooooooo02ooool20000;oooo`03o`2I06Kooooo05goool0
05goool00`1Vooooooooo`0_oooo00<0003oooooool0;_ooo`03o`2I06Kooooo05goool005goool0
0`1Vooooooooo`0_oooo00<0003oooooool0;_ooo`03o`2I06Kooooo05goool005goool00`1Voooo
ooooo`0_oooo00<0003oooooool0;_ooo`0306Kooooooooo05goool005koool00`1Vooooooooo`0^
oooo00<0003oooooool0;_ooo`0306Kooooooooo05goool005koool00`1Vooooooooo`0^oooo00<0
003oooooool0;_ooo`0306Kooooooooo05goool005koool00`1Vooooooooo`0^oooo0P0002ooool0
0`1Vooooooooo`1Moooo001Noooo00<0I_ooooooool0;_ooo`030000oooooooo02koool00`1Voooo
ooooo`1Moooo001Noooo00<0I_ooooooool0;_ooo`030000oooooooo02koool00`1Vooooooooo`1M
oooo001Noooo00<0I_ooooooool0;_ooo`030000oooooooo02koool00`1Vooooooooo`1Moooo001N
oooo00<0I_ooooooool0;_ooo`030000oooooooo02koool00`1Vooooooooo`1Moooo001Noooo00<0
I_ooooooool0;_ooo`030000oooooooo02koool00`1Vooooooooo`1Moooo001Noooo00<0I_oooooo
ool0;_ooo`80000_oooo00<0I_ooooooool0GOooo`00G_ooo`0306Kooooooooo02koool00`000?oo
ooooo`0^oooo00<0I_ooooooool0GOooo`00G_ooo`0306Kooooooooo02koool00`000?ooooooo`0^
oooo00<0I_ooooooool0GOooo`00G_ooo`0306Kooooooooo02koool00`000?ooooooo`0^oooo00<0
I_ooooooool0GOooo`00G_ooo`0306Kooooooooo01_oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0^oooo00<0I_ooooooool0GOooo`00G_ooo`0306Kooooooooo01[oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0^oooo00<0I_ooooooool0GOoo
o`00G_ooo`80I_lKoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000]oooo0P1V
oeooool0063oool306Ko6?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0:ooo
o`80I_l00oooool0VOooo`1Noooo001Soooo0P1VoaKoool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0:Oooo`80I_l3oooo00?o09Woooooool0GOooo`00IOooo`<0I_lD
oooo0P0000[oool300001?ooo`030000oooooooo02Koool306Ko1Oooo`03o`2Ioooooooo05goool0
06Soool206Ko9Oooo`030000oooooooo02Coool206Ko2?ooo`03o`2Ioooooooo05goool006[oool3
06Ko8_ooo`030000oooooooo027oool306Ko2_ooo`03o`2Ioooooooo05goool006goool206Ko8?oo
o`80000Poooo0P1Vo`goool00ol0VOooooooo`1Moooo001_oooo0`1Voagoool00`000?ooooooo`0L
oooo0`1Vo`ooool00ol0VOooooooo`1Moooo001boooo0P1Voa_oool00`000?ooooooo`0Joooo0P1V
oa;oool00ol0VOooooooo`1Moooo001doooo0P1VoaWoool00`000?ooooooo`0Hoooo0P1VoaCoool0
0ol0VOooooooo`1Moooo001foooo0P1VoaOoool00`000?ooooooo`0Foooo0P1VoaKoool00ol0VOoo
ooooo`1Moooo001hoooo0P1VoaGoool200005Oooo`80I_lHoooo00?o09Woooooool0GOooo`00N_oo
o`80I_lCoooo00<0003oooooool04_ooo`80I_lJoooo00?o09Woooooool0GOooo`00O?ooo`80I_lA
oooo00<0003oooooool04?ooo`80I_lLoooo00?o09Woooooool0GOooo`00O_ooo`80I_l?oooo00<0
003oooooool03_ooo`80I_lNoooo00?o09Woooooool0GOooo`00P?ooo`80I_l=oooo00<0003ooooo
ool03?ooo`80I_lPoooo00?o09Woooooool0GOooo`00P_ooo`80I_l;oooo00<0003oooooool02_oo
o`80I_lRoooo00?o09Woooooool0GOooo`00Q?ooo`80I_l9oooo0P0000Woool206Ko9?ooo`03o`2I
oooooooo05goool008Koool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`80I_lVoooo00?o
09Woooooool0GOooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`04oooo0P1VobSoool0
0ol0VOooooooo`1Moooo0028oooo0P1Vo`Goool00`000?ooooooo`03oooo00<0I_ooooooool0:?oo
o`03o`2Ioooooooo05goool008[oool00`1Vooooooooo`02oooo00<0003oooooool00_ooo`0306Ko
oooooooo02Woool00ol0VOooooooo`1Moooo002;oooo0P1Vo`;oool00`000?ooooooo`0206Ko;?oo
o`03o`2Ioooooooo05goool008goool206Ko0P00000306Kooooooooo02coool00ol0VOooooooo`1M
oooo002>oooo00<0I_l00000I_l0;oooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^
oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo0027
oooo1@0000?oool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00ROooo`030000oooooooo00?oool3
0000;_ooo`03o`2Ioooooooo05goool008Woool00`000?ooooooo`03oooo00<0003oooooool0;_oo
o`03o`2Ioooooooo05goool008Woool00`000?ooooooo`03oooo00<0003oooooool0;_ooo`03o`2I
oooooooo05goool008Soool200001Oooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?
oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^oooo00?o
09Woooooool0GOooo`00Soooo`80000_oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo
02koool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool0
08ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool0
0ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool008ooool2
0000;oooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOoo
o`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_oo
o`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Sooo
o`030000oooooooo02koool00ol0VOooooooo`1Moooo002?oooo0P0002ooool00ol0VOooooooo`1M
oooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^
oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?
oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^oooo00?o
09Woooooool0GOooo`00Soooo`80000_oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo
02koool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool0
08ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo02koool00ol0VOooooooo`1Moooo001moooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo02koool00ol0VOooooooo`1Moooo001moooo00<0
003oooooool02_ooo`030000oooooooo00;oool30000;_ooo`03o`2Ioooooooo05goool007goool0
0`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00OOoo
o`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0;_ooo`03o`2Ioooooooo
05goool007coool200002_ooo`<00004oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool0
08ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool0
0ol0VOooooooo`1Moooo002?oooo0P0002ooool00ol0VOooooooo`1Moooo002?oooo00<0003ooooo
ool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOoo
o`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_oo
o`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Sooo
o`80000_oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool00ol0VOooooooo`1M
oooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^
oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?
oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool008ooool20000;oooo`03o`2Ioooooooo
05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo
02koool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool0
08ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool0
0ol0VOooooooo`1Moooo002?oooo0P0002ooool00ol0VOooooooo`1Moooo002?oooo00<0003ooooo
ool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOoo
o`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo0027oooo100000Coool00`000?oo
ooooo`0^oooo00?o09Woooooool0GOooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`0^
oooo00?o09Woooooool0GOooo`00R?ooo`030000oooooooo00Coool30000;_ooo`03o`2Ioooooooo
05goool008Woool00`000?ooooooo`03oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool0
08Ooool010000?ooooooo`0000Coool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00R?oo
o`800005oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^
oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?
oooo0P0002ooool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo
05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo
02koool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool0
08ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Soooo`80000_oooo00?o09Wooooo
ool0GOooo`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?oooo00<0003ooooo
ool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOoo
o`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_oo
o`03o`2Ioooooooo05goool008ooool20000;oooo`03o`2Ioooooooo05goool008ooool00`000?oo
ooooo`0^oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool00ol0VOooooooo`1M
oooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool008ooool00`000?ooooooo`0^
oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo02koool00ol0VOooooooo`1Moooo002?
oooo0P0002ooool00ol0VOooooooo`1Moooo002?oooo00<0003oooooool0;_ooo`03o`2Ioooooooo
05goool008ooool00`000?ooooooo`0^oooo00?o09Woooooool0GOooo`00Soooo`030000oooooooo
02koool00ol0VOooooooo`1Moooo001koooo100000?oool200001?ooo`800005oooo00<0003ooooo
ool0;_ooo`03o`2Ioooooooo05goool007_oool00`000?ooooooo`09oooo00@0003oooooool00004
oooo00<0003oooooool0;_ooo`03o`2Ioooooooo05goool007coool00`000?ooooooo`0;oooo00<0
003oooooool00_ooo`<0000^oooo00?o09Woooooool0GOooo`00OOooo`030000oooooooo00Soool2
0000U_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003
oooo100000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`030000oooooooo00Coool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?oo
ooooo`09oooo00<0003oooooool01?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`05
00003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?oo
ooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.67958 .04578 L
.6883 .04578 L
.69289 .04578 L
.6954 .04578 L
.69662 .04578 L
.69774 .04578 L
s
.69774 .04578 m
.69804 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.27193 .04578 L
.28302 .04578 L
.2881 .04578 L
.29349 .04578 L
.29809 .04578 L
.29935 .04578 L
.30004 .04578 L
.3007 .04578 L
.30198 .16037 L
.30316 .1608 L
.34135 .1755 L
.38199 .19322 L
.42112 .21256 L
.46271 .2359 L
.48357 .24882 L
.49273 .25476 L
.49523 .25642 L
.49661 .25733 L
.49792 .25821 L
.49914 .25902 L
.50046 .25929 L
.50166 .25849 L
.50277 .25774 L
.52152 .24559 L
.54132 .23351 L
.58059 .21166 L
.61834 .19307 L
.65854 .17555 L
.67702 .16821 L
.68749 .16424 L
.69259 .16235 L
.69501 .16147 L
.69723 .16066 L
.69839 .16024 L
.69962 .04578 L
.70086 .04578 L
.70221 .04578 L
.70692 .04578 L
.71727 .04578 L
.73837 .04578 L
.77871 .04578 L
.81753 .04578 L
.85881 .04578 L
Mistroke
.89857 .04578 L
.93682 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00?oool00`1Vooooo`000008oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?l0V@1Vo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Koooo00<0I_ooooooool0<Oooo`030000oooooooo033oool0
0ol0V@1Vooooo`1Koooo001Koooo00<0I_ooooooool0<Oooo`030000oooooooo033oool00ol0V@1V
ooooo`1Koooo001Koooo00<0I_ooooooool0<Oooo`030000oooooooo033oool00ol0V@1Vooooo`1K
oooo001Koooo00<0I_ooooooool0<Oooo`030000oooooooo033oool00ol0V@1Vooooo`1Koooo001K
oooo00<0I_ooooooool0<Oooo`80000aoooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo
037oool00`000?ooooooo`0`oooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo037oool0
0`000?ooooooo`0`oooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo037oool00`000?oo
ooooo`0`oooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0`
oooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0`oooo00?o
09T0I_ooool0Foooo`00Foooo`0306Kooooooooo037oool20000<Oooo`03o`2I06Kooooo05_oool0
05_oool00`1Vooooooooo`0aoooo00<0003oooooool0<?ooo`03o`2I06Kooooo05_oool005_oool0
0`1Vooooooooo`0aoooo00<0003oooooool0<?ooo`03o`2I06Kooooo05_oool005_oool00`1Voooo
ooooo`0aoooo00<0003oooooool0<?ooo`03o`2I06Kooooo05_oool005_oool00`1Vooooooooo`0a
oooo00<0003oooooool0<?ooo`03o`2I06Kooooo05_oool005_oool00`1Vooooooooo`0aoooo00<0
003oooooool0<?ooo`03o`2I06Kooooo05_oool005_oool00`1Vooooooooo`0aoooo0P00037oool0
0ol0V@1Vooooo`1Koooo001Koooo00<0I_ooooooool0<Oooo`030000oooooooo033oool00ol0V@1V
ooooo`1Koooo001Koooo00<0I_ooooooool0<Oooo`030000oooooooo033oool00ol0V@1Vooooo`1K
oooo001Koooo00<0I_ooooooool0<Oooo`030000oooooooo033oool00ol0V@1Vooooo`1Koooo001K
oooo00<0I_ooooooool0<Oooo`030000oooooooo033oool00ol0V@1Vooooo`1Koooo001Koooo00<0
I_ooooooool0<Oooo`030000oooooooo033oool00ol0V@1Vooooo`1Koooo001Koooo00<0I_oooooo
ool0<Oooo`80000aoooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo037oool00`000?oo
ooooo`0`oooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0`
oooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo037oool00`000?ooooooo`0`oooo00?o
09T0I_ooool0Foooo`00Foooo`0306Kooooooooo01koool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0`oooo00?o09T0I_ooool0Foooo`00Foooo`0306Kooooooooo01goool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0`oooo00?o09T0I_ooool0Fooo
o`00Foooo`<0I_lMoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000_oooo0`1V
oecoool005koool206Ko6oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0;Ooo
o`80I_l00oooool0VOooo`1Loooo001Poooo0`1VoaSoool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0:_ooo`<0I_l3oooo00?o09Woooooool0Foooo`00Hoooo`80I_lG
oooo0P0000[oool300001?ooo`030000oooooooo02Soool206Ko1_ooo`03o`2Ioooooooo05_oool0
06Goool306Ko9oooo`030000oooooooo02Goool306Ko2?ooo`03o`2Ioooooooo05_oool006Soool2
06Ko9Oooo`030000oooooooo02?oool206Ko2oooo`03o`2Ioooooooo05_oool006[oool306Ko8_oo
o`80000Qoooo0`1Vo`goool00ol0VOooooooo`1Koooo001]oooo0P1Vob3oool00`000?ooooooo`0N
oooo0P1Voa3oool00ol0VOooooooo`1Koooo001_oooo0P1Voakoool00`000?ooooooo`0Loooo0P1V
oa;oool00ol0VOooooooo`1Koooo001aoooo0P1Voacoool00`000?ooooooo`0Joooo0P1VoaCoool0
0ol0VOooooooo`1Koooo001coooo0P1Voa[oool00`000?ooooooo`0Hoooo0P1VoaKoool00ol0VOoo
ooooo`1Koooo001eoooo0P1VoaSoool200005oooo`80I_lHoooo00?o09Woooooool0Foooo`00Mooo
o`80I_lFoooo00<0003oooooool05?ooo`80I_lJoooo00?o09Woooooool0Foooo`00NOooo`80I_lD
oooo00<0003oooooool04_ooo`80I_lLoooo00?o09Woooooool0Foooo`00Noooo`80I_lBoooo00<0
003oooooool04?ooo`80I_lNoooo00?o09Woooooool0Foooo`00OOooo`80I_l@oooo00<0003ooooo
ool03_ooo`80I_lPoooo00?o09Woooooool0Foooo`00Ooooo`80I_l>oooo00<0003oooooool03Ooo
o`0306Kooooooooo023oool00ol0VOooooooo`1Koooo0021oooo0P1Vo`coool200003?ooo`80I_lS
oooo00?o09Woooooool0Foooo`00Poooo`80I_l:oooo00<0003oooooool02Oooo`80I_lUoooo00?o
09Woooooool0Foooo`00QOooo`0306Kooooooooo00Ooool00`000?ooooooo`08oooo00<0I_oooooo
ool09Oooo`03o`2Ioooooooo05_oool008Koool206Ko1oooo`030000oooooooo00Koool206Ko:?oo
o`03o`2Ioooooooo05_oool008Soool00`1Vooooooooo`04oooo00<0003oooooool01?ooo`80I_lZ
oooo00?o09Woooooool0Foooo`00ROooo`80I_l4oooo00<0003oooooool00oooo`0306Kooooooooo
02[oool00ol0VOooooooo`1Koooo002;oooo00@0I_ooooooooooool200000_ooo`80I_l]oooo00?o
09Woooooool0Foooo`00S?ooo`80I_l00oooo`000?ooo`0206Ko;oooo`03o`2Ioooooooo05_oool0
08koool00`1Vo`00001Vo`0aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo0027oooo1@0000?oool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00ROoo
o`030000oooooooo00?oool30000<?ooo`03o`2Ioooooooo05_oool008Woool00`000?ooooooo`03
oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008Woool00`000?ooooooo`03oooo00<0
003oooooool0<?ooo`03o`2Ioooooooo05_oool008Soool200001Oooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool0
0`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Sooo
o`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2I
oooooooo05_oool008ooool20000<Oooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?
oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o
09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo0P00
037oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool0
08ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool0
0`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Nooo
o`D00002oooo0P0000Coool200001Oooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001m
oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo033oool00ol0VOoo
ooooo`1Koooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool30000<?ooo`03o`2I
oooooooo05_oool007goool00`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`0`oooo00?o
09Woooooool0Foooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003ooooo
ool0<?ooo`03o`2Ioooooooo05_oool007coool200002_ooo`<00004oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Sooo
o`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo0P00037oool00ol0VOooooooo`1K
oooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?
oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o
09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool0
08ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool2
0000<Oooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Sooo
o`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo0P00037oool00ol0VOooooooo`1K
oooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo0027
oooo100000Coool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Qoooo`030000oooooooo
00Goool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00R?ooo`030000oooooooo00Coool3
0000<?ooo`03o`2Ioooooooo05_oool008Woool00`000?ooooooo`03oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0`oooo00?o
09Woooooool0Foooo`00R?ooo`800005oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool0
08ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo0P00037oool00ol0VOooooooo`1Koooo002?oooo00<0003ooooo
ool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Sooo
o`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?
oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool20000<Oooo`03o`2Ioooooooo
05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool0
08ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo0P00037oool00ol0VOooooooo`1Koooo002?oooo00<0003ooooo
ool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001koooo100000?oool200001?oo
o`800005oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool007_oool00`000?ooooooo`09
oooo00@0003oooooool00004oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool007coool0
0`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0000`oooo00?o09Woooooool0Foooo`00OOoo
o`030000oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo
09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool400000oooo`800003oooo100000?oool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?oo
ooooo`09oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo07Soool0
07Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00Woool00`000?oo
ooooo`05oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003_ooo`030000oooooooo00Woool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.67958 .04578 L
.6883 .04578 L
.69774 .04578 L
.7003 .04578 L
.70301 .04578 L
.70413 .04578 L
.70533 .04578 L
s
.70533 .04578 m
.70566 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.27193 .04578 L
.28302 .04578 L
.2881 .04578 L
.29088 .04578 L
.29224 .04578 L
.29349 .04578 L
.29462 .16058 L
.2957 .16097 L
.29809 .16184 L
.30316 .16371 L
.34135 .17879 L
.38199 .19695 L
.42112 .21678 L
.46271 .24072 L
.48357 .25396 L
.49273 .26005 L
.49523 .26175 L
.49661 .26269 L
.49792 .26358 L
.49914 .26442 L
.50046 .2647 L
.50166 .26387 L
.50277 .26311 L
.52152 .25065 L
.54132 .23826 L
.58059 .21586 L
.61834 .19679 L
.65854 .17883 L
.67702 .17131 L
.68749 .16724 L
.69259 .1653 L
.69723 .16357 L
.69962 .16268 L
.70221 .16173 L
.7034 .1613 L
.70466 .16084 L
.70574 .16045 L
.70692 .04578 L
.70761 .04578 L
.70827 .04578 L
.7095 .04578 L
.71227 .04578 L
.71727 .04578 L
Mistroke
.73837 .04578 L
.77662 .04578 L
.81731 .04578 L
.85649 .04578 L
.89813 .04578 L
.93825 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`050000oooooooooooo06Ko00?oool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool01@000?ooooooool0
V@1Vo`03oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo001Ioooo00<0I_ooooooool0<oooo`030000
oooooooo03;oool00ol0V@1Vooooo`1Ioooo001Ioooo00<0I_ooooooool0<oooo`030000oooooooo
03;oool00ol0V@1Vooooo`1Ioooo001Ioooo00<0I_ooooooool0<oooo`030000oooooooo03;oool0
0ol0V@1Vooooo`1Ioooo001Ioooo00<0I_ooooooool0<oooo`030000oooooooo03;oool00ol0V@1V
ooooo`1Ioooo001Ioooo00<0I_ooooooool0<oooo`80000coooo00?o09T0I_ooool0FOooo`00FOoo
o`0306Kooooooooo03?oool00`000?ooooooo`0boooo00?o09T0I_ooool0FOooo`00FOooo`0306Ko
oooooooo03?oool00`000?ooooooo`0boooo00?o09T0I_ooool0FOooo`00FOooo`0306Kooooooooo
03?oool00`000?ooooooo`0boooo00?o09T0I_ooool0FOooo`00FOooo`0306Kooooooooo03?oool0
0`000?ooooooo`0boooo00?o09T0I_ooool0FOooo`00FOooo`0306Kooooooooo03?oool00`000?oo
ooooo`0boooo00?o09T0I_ooool0FOooo`00FOooo`0306Kooooooooo03?oool20000<oooo`03o`2I
06Kooooo05Woool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<_ooo`03o`2I06Kooooo
05Woool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<_ooo`03o`2I06Kooooo05Woool0
05Woool00`1Vooooooooo`0coooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool005[oool0
0`1Vooooooooo`0boooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool005[oool00`1Voooo
ooooo`0boooo00<0003oooooool0<_ooo`0306Kooooooooo05Woool005[oool00`1Vooooooooo`0b
oooo0P0003?oool00`1Vooooooooo`1Ioooo001Joooo00<0I_ooooooool0<_ooo`030000oooooooo
03;oool00`1Vooooooooo`1Ioooo001Joooo00<0I_ooooooool0<_ooo`030000oooooooo03;oool0
0`1Vooooooooo`1Ioooo001Joooo00<0I_ooooooool0<_ooo`030000oooooooo03;oool00`1Voooo
ooooo`1Ioooo001Joooo00<0I_ooooooool0<_ooo`030000oooooooo03;oool00`1Vooooooooo`1I
oooo001Joooo00<0I_ooooooool0<_ooo`030000oooooooo03;oool00`1Vooooooooo`1Ioooo001J
oooo00<0I_ooooooool0<_ooo`80000coooo00<0I_ooooooool0FOooo`00F_ooo`0306Kooooooooo
03;oool00`000?ooooooo`0boooo00<0I_ooooooool0FOooo`00F_ooo`0306Kooooooooo03;oool0
0`000?ooooooo`0boooo00<0I_ooooooool0FOooo`00F_ooo`0306Kooooooooo03;oool00`000?oo
ooooo`0boooo00<0I_ooooooool0FOooo`00F_ooo`0306Kooooooooo01ooool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`0boooo00<0I_ooooooool0FOooo`00F_ooo`0306Kooooooooo
01koool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0boooo00<0
I_ooooooool0FOooo`00F_ooo`@0I_lMoooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000`oooo0`1Voe_oool005koool206Ko6oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0;Oooo`<0I_l2oooo00?o09Woooooool0FOooo`00H?ooo`<0I_lHoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo02[oool306Ko1Oooo`03o`2Ioooooooo
05Woool006?oool206Ko5oooo`80000:oooo0`0000Coool00`000?ooooooo`0Xoooo0P1Vo`Soool0
0ol0VOooooooo`1Ioooo001Uoooo0P1VobSoool00`000?ooooooo`0Voooo0P1Vo`[oool00ol0VOoo
ooooo`1Ioooo001Woooo0P1VobKoool00`000?ooooooo`0Toooo0P1Vo`coool00ol0VOooooooo`1I
oooo001Yoooo0P1VobCoool200008oooo`80I_l>oooo00?o09Woooooool0FOooo`00Joooo`80I_lR
oooo00<0003oooooool08?ooo`80I_l@oooo00?o09Woooooool0FOooo`00KOooo`80I_lPoooo00<0
003oooooool07_ooo`80I_lBoooo00?o09Woooooool0FOooo`00Koooo`80I_lNoooo00<0003ooooo
ool07?ooo`80I_lDoooo00?o09Woooooool0FOooo`00LOooo`80I_lLoooo00<0003oooooool06_oo
o`80I_lFoooo00?o09Woooooool0FOooo`00Loooo`80I_lJoooo0P0001Woool206Ko6?ooo`03o`2I
oooooooo05Woool007Goool206Ko6?ooo`030000oooooooo01Koool206Ko6_ooo`03o`2Ioooooooo
05Woool007Ooool206Ko5_ooo`030000oooooooo01Coool206Ko7?ooo`03o`2Ioooooooo05Woool0
07Woool206Ko5?ooo`030000oooooooo01;oool206Ko7_ooo`03o`2Ioooooooo05Woool007_oool2
06Ko4_ooo`030000oooooooo013oool206Ko8?ooo`03o`2Ioooooooo05Woool007goool00`1Voooo
ooooo`0?oooo00<0003oooooool03_ooo`80I_lRoooo00?o09Woooooool0FOooo`00O_ooo`80I_l?
oooo0P0000koool00`1Vooooooooo`0Roooo00?o09Woooooool0FOooo`00P?ooo`80I_l=oooo00<0
003oooooool02oooo`80I_lUoooo00?o09Woooooool0FOooo`00P_ooo`0306Kooooooooo00[oool0
0`000?ooooooo`09oooo0P1VobOoool00ol0VOooooooo`1Ioooo0023oooo0P1Vo`[oool00`000?oo
ooooo`08oooo00<0I_ooooooool09oooo`03o`2Ioooooooo05Woool008Goool00`1Vooooooooo`07
oooo00<0003oooooool01_ooo`80I_lZoooo00?o09Woooooool0FOooo`00Q_ooo`80I_l7oooo00<0
003oooooool01?ooo`80I_l/oooo00?o09Woooooool0FOooo`00R?ooo`80I_l5oooo0P0000Coool0
0`1Vooooooooo`0/oooo00?o09Woooooool0FOooo`00R_ooo`80I_l3oooo00@0003oooooooooool2
06Ko;oooo`03o`2Ioooooooo05Woool008coool01@1Vooooooooo`000?ooo`0206Ko<Oooo`03o`2I
oooooooo05Woool008goool206Ko00<00000I_ooool0<_ooo`03o`2Ioooooooo05Woool008Ooool5
00000oooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo0029oooo00<0003oooooool00ooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo0029oooo00<0003oooooool00oooo`<0000b
oooo00?o09Woooooool0FOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0boooo00?o09Wooooo
ool0FOooo`00R?ooo`800005oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOoo
ooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`80000c
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool20000<oooo`03o`2Ioooooooo05Woool0
08ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOoo
ooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001koooo1@0000;oool200001?ooo`800005
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool007goool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool007goool00`000?oo
ooooo`0:oooo00<0003oooooool00_ooo`<0000boooo00?o09Woooooool0FOooo`00OOooo`030000
oooooooo00Soool200001Oooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001moooo00<0
003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`0boooo00?o09Woooooool0FOoo
o`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool008ooool20000<oooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo0P00
03?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool0
08ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`80000coooo00?o09Woooooool0FOoo
o`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool008ooool20000<oooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008Ooool400001?ooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo0027oooo00<0003oooooool01Oooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo0028oooo00<0003oooooool01?ooo`<0000boooo00?o09Woooooool0FOoo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Qooo
o`040000oooooooo00001?ooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo0028oooo0P00
00Goool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool2
0000<oooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOoo
o`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1I
oooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00Soooo`80000coooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool0
08ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool2
0000<oooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOoo
o`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool007_oool400000oooo`800004oooo0P0000Goool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Noooo`030000oooooooo00Woool010000?ooooooo`0000Coool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00O?ooo`030000oooooooo00_oool00`000?oo
ooooo`02oooo0`0003;oool00ol0VOooooooo`1Ioooo001moooo00<0003oooooool02?ooo`80002F
oooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`00
09Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000Coool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003ooooo
ool02_ooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00koool00`000?ooooooo`0:oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.67958 .04578 L
.69774 .04578 L
.7026 .04578 L
.70787 .04578 L
.71028 .04578 L
.7116 .04578 L
.71284 .04578 L
.71389 .04578 L
s
.71389 .04578 m
.71417 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.27193 .04578 L
.27731 .04578 L
.28025 .04578 L
.28302 .04578 L
.28425 .04578 L
.28542 .04578 L
.28606 .16036 L
.28676 .16061 L
.288 .16106 L
.29349 .16307 L
.30316 .16669 L
.3438 .18321 L
.38293 .20124 L
.42451 .22299 L
.46458 .24683 L
.48296 .25882 L
.48799 .26222 L
.49339 .26593 L
.49601 .26776 L
.49729 .26866 L
.49848 .26949 L
.49956 .27026 L
.50071 .27006 L
.50186 .26925 L
.50313 .26836 L
.52307 .25481 L
.54413 .24139 L
.58434 .21812 L
.62302 .19835 L
.66416 .17981 L
.68469 .17141 L
.6947 .16752 L
.70379 .16408 L
.70834 .1624 L
.71073 .16152 L
.71204 .16104 L
.71327 .1606 L
.71433 .04578 L
.71548 .04578 L
.71792 .04578 L
.72221 .04578 L
.7419 .04578 L
.78317 .04578 L
Mistroke
.82293 .04578 L
.86118 .04578 L
.90188 .04578 L
.94106 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooo06Ko00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`03oooo00<0
I_ooool000001oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Goool0
0`1Vooooooooo`1Foooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Goool00`1Voooo
ooooo`1Foooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Goool00`1Vooooooooo`1F
oooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Goool00`1Vooooooooo`1Foooo001G
oooo00<0I_ooooooool0=Oooo`80000foooo00<0I_ooooooool0E_ooo`00Eoooo`0306Kooooooooo
03Goool00`000?ooooooo`0eoooo00<0I_ooooooool0E_ooo`00Eoooo`0306Kooooooooo03Goool0
0`000?ooooooo`0eoooo00<0I_ooooooool0E_ooo`00Eoooo`0306Kooooooooo03Goool00`000?oo
ooooo`0eoooo00<0I_ooooooool0E_ooo`00Eoooo`0306Kooooooooo03Goool00`000?ooooooo`0e
oooo00<0I_ooooooool0E_ooo`00Eoooo`0306Kooooooooo03Goool00`000?ooooooo`0eoooo00<0
I_ooooooool0E_ooo`00Eoooo`0306Kooooooooo03Goool20000=_ooo`0306Kooooooooo05Koool0
05Ooool00`1Vooooooooo`0eoooo00<0003oooooool0=Oooo`0306Kooooooooo05Koool005Ooool0
0`1Vooooooooo`0eoooo00<0003oooooool0=Oooo`0306Kooooooooo05Koool005Ooool00`1Voooo
ooooo`0eoooo00<0003oooooool0=?ooo`0306Koo`2Ioooo05Ooool005Ooool00`1Vooooooooo`0e
oooo00<0003oooooool0=?ooo`0306Koo`2Ioooo05Ooool005Ooool00`1Vooooooooo`0eoooo00<0
003oooooool0=?ooo`0306Koo`2Ioooo05Ooool005Ooool00`1Vooooooooo`0eoooo0P0003Goool0
0`1Vool0VOooo`1Goooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Coool00`1Vool0
VOooo`1Goooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Coool00`1Vool0VOooo`1G
oooo001Goooo00<0I_ooooooool0=Oooo`030000oooooooo03Coool00`1Vool0VOooo`1Goooo001G
oooo00<0I_ooooooool0=Oooo`030000oooooooo03Coool00`1Vool0VOooo`1Goooo001Goooo00<0
I_ooooooool0=Oooo`030000oooooooo03Coool00`1Vool0VOooo`1Goooo001Goooo00<0I_oooooo
ool0=Oooo`80000eoooo00<0I_oo09Woool0Eoooo`00Eoooo`0306Kooooooooo03Goool00`000?oo
ooooo`0doooo00<0I_oo09Woool0Eoooo`00Eoooo`0306Kooooooooo03Goool00`000?ooooooo`0d
oooo00<0I_oo09Woool0Eoooo`00Eoooo`0306Kooooooooo03Goool00`000?ooooooo`0doooo00<0
I_oo09Woool0Eoooo`00Eoooo`0306Kooooooooo02;oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0doooo00<0I_oo09Woool0Eoooo`00Eoooo`0306Kooooooooo027oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0doooo00<0I_oo09Woool0Eooo
o`00Eoooo`@0I_lPoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000coooo0P1V
o`03o`2Ioooooooo05Koool005_oool206Ko7_ooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0;oooo`@0I_l2oooo00?o09Woooooool0E_ooo`00GOooo`80I_lLoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo02goool206Ko1_ooo`03o`2Ioooooooo
05Koool005ooool206Ko6oooo`80000:oooo0`0000Coool00`000?ooooooo`0[oooo0P1Vo`Soool0
0ol0VOooooooo`1Foooo001Qoooo0P1Vobcoool00`000?ooooooo`0Yoooo0P1Vo`[oool00ol0VOoo
ooooo`1Foooo001Soooo0P1Vob[oool00`000?ooooooo`0Woooo0P1Vo`coool00ol0VOooooooo`1F
oooo001Uoooo0`1VobOoool200009_ooo`80I_l>oooo00?o09Woooooool0E_ooo`00J?ooo`<0I_lT
oooo00<0003oooooool08oooo`80I_l@oooo00?o09Woooooool0E_ooo`00Joooo`80I_lRoooo00<0
003oooooool08Oooo`80I_lBoooo00?o09Woooooool0E_ooo`00KOooo`<0I_lOoooo00<0003ooooo
ool07oooo`80I_lDoooo00?o09Woooooool0E_ooo`00L?ooo`80I_lMoooo00<0003oooooool07Ooo
o`80I_lFoooo00?o09Woooooool0E_ooo`00L_ooo`80I_lKoooo0P0001coool206Ko6?ooo`03o`2I
oooooooo05Koool007Coool206Ko6Oooo`030000oooooooo01Woool206Ko6_ooo`03o`2Ioooooooo
05Koool007Koool00`1Vooooooooo`0Foooo00<0003oooooool05oooo`80I_lLoooo00?o09Wooooo
ool0E_ooo`00Moooo`80I_lFoooo00<0003oooooool05Oooo`80I_lNoooo00?o09Woooooool0E_oo
o`00NOooo`80I_lDoooo00<0003oooooool04oooo`80I_lPoooo00?o09Woooooool0E_ooo`00Nooo
o`0306Kooooooooo017oool00`000?ooooooo`0Aoooo0P1Vob;oool00ol0VOooooooo`1Foooo001l
oooo0P1Voa7oool200004?ooo`80I_lToooo00?o09Woooooool0E_ooo`00O_ooo`80I_l?oooo00<0
003oooooool03Oooo`80I_lVoooo00?o09Woooooool0E_ooo`00P?ooo`80I_l=oooo00<0003ooooo
ool02oooo`80I_lXoooo00?o09Woooooool0E_ooo`00P_ooo`80I_l;oooo00<0003oooooool02Ooo
o`80I_lZoooo00?o09Woooooool0E_ooo`00Q?ooo`80I_l9oooo00<0003oooooool02?ooo`0306Ko
oooooooo02[oool00ol0VOooooooo`1Foooo0026oooo00<0I_ooooooool01_ooo`030000oooooooo
00Koool206Ko;Oooo`03o`2Ioooooooo05Koool008Ooool206Ko1_ooo`800005oooo0P1Vobooool0
0ol0VOooooooo`1Foooo0029oooo0P1Vo`Coool00`000?ooooooo`03oooo00<0I_ooooooool0;ooo
o`03o`2Ioooooooo05Koool008_oool01@1Vooooooooooooo`000004oooo00<0I_ooooooool0<?oo
o`03o`2Ioooooooo05Koool008coool0101Vooooooooo`0000;oool206Ko<oooo`03o`2Ioooooooo
05Koool008Ooool5000000Koool0I_ooool0003oool0I_leoooo00?o09Woooooool0E_ooo`00ROoo
o`030000oooooooo00;oool00`1Vo`00001Vo`0foooo00?o09Woooooool0E_ooo`00ROooo`030000
oooooooo00?oool30000=Oooo`03o`2Ioooooooo05Koool008Woool00`000?ooooooo`03oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool008Soool200001Oooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?oo
ooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000
oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo
05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo0P0003Koool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?oo
ooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo03Goool00ol0VOooooooo`1F
oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool30000=Oooo`03o`2Ioooooooo
05Koool007goool00`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool007coool200002_ooo`<00004oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000
oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo0P0003Koool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool20000=_oo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000
oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo0P0003Koool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo0027oooo1000
00Coool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Qoooo`030000oooooooo00Goool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00R?ooo`030000oooooooo00Coool30000=Ooo
o`03o`2Ioooooooo05Koool008Woool00`000?ooooooo`03oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00R?ooo`800005oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo0P0003Koool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000f
oooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool0
08ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo0P0003Koool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo001koooo100000?oool200001?ooo`800005
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool007_oool00`000?ooooooo`09oooo00@0
003oooooool00004oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool007coool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`<0000eoooo00?o09Woooooool0E_ooo`00OOooo`030000
oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool0
07coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool4
00000oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02_ooo`030000oooooooo
00Coool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>
oooo00<0003oooooool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:
oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.70787 .04578 L
.71284 .04578 L
.71741 .04578 L
.71998 .04578 L
.72127 .04578 L
.72201 .04578 L
s
.72201 .04578 m
.72218 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.24141 .04578 L
.26171 .04578 L
.26709 .04578 L
.27279 .04578 L
.27513 .04578 L
.27643 .04578 L
.27765 .04578 L
.27835 .16044 L
.2791 .16071 L
.28042 .16119 L
.28302 .16213 L
.30316 .16976 L
.3438 .18669 L
.38293 .20517 L
.42451 .22748 L
.46458 .25192 L
.48296 .26421 L
.48799 .2677 L
.49339 .27151 L
.49601 .27337 L
.49729 .2743 L
.49848 .27516 L
.49956 .27594 L
.50071 .27574 L
.50186 .27491 L
.50313 .27399 L
.52307 .2601 L
.54413 .24634 L
.58434 .22249 L
.62302 .20221 L
.66416 .1832 L
.68469 .17459 L
.70379 .16707 L
.71327 .16351 L
.71792 .16179 L
.71996 .16105 L
.72105 .16066 L
.72221 .16023 L
.72345 .04578 L
.72462 .04578 L
.72716 .04578 L
.73253 .04578 L
.7419 .04578 L
.78317 .04578 L
Mistroke
.82293 .04578 L
.86118 .04578 L
.90188 .04578 L
.94106 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool0
0`1Vooooooooo`1Doooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool00`1Voooo
ooooo`1Doooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool00`1Vooooooooo`1D
oooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool00`1Vooooooooo`1Doooo001E
oooo00<0I_ooooooool0=oooo`80000hoooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo
03Ooool00`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo03Ooool0
0`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo03Ooool00`000?oo
ooooo`0goooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo03Ooool00`000?ooooooo`0g
oooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo03Ooool00`000?ooooooo`0goooo00<0
I_ooooooool0E?ooo`00EOooo`0306Kooooooooo03Ooool20000>?ooo`0306Kooooooooo05Coool0
05Goool00`1Vooooooooo`0goooo00<0003oooooool0=oooo`0306Kooooooooo05Coool005Goool0
0`1Vooooooooo`0goooo00<0003oooooool0=oooo`0306Kooooooooo05Coool005Goool00`1Voooo
ooooo`0goooo00<0003oooooool0=oooo`0306Kooooooooo05Coool005Goool00`1Vooooooooo`0g
oooo00<0003oooooool0=oooo`0306Kooooooooo05Coool005Goool00`1Vooooooooo`0goooo00<0
003oooooool0=oooo`0306Kooooooooo05Coool005Goool00`1Vooooooooo`0goooo0P0003Soool0
0`1Vooooooooo`1Doooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool00`1Voooo
ooooo`1Doooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool00`1Vooooooooo`1D
oooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool00`1Vooooooooo`1Doooo001E
oooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool00`1Vooooooooo`1Doooo001Eoooo00<0
I_ooooooool0=oooo`030000oooooooo03Ooool00`1Vooooooooo`1Doooo001Eoooo00<0I_oooooo
ool0=oooo`80000hoooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo03Ooool00`000?oo
ooooo`0goooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo03Ooool00`000?ooooooo`0g
oooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo03Ooool00`000?ooooooo`0goooo00<0
I_ooooooool0E?ooo`00EOooo`0306Kooooooooo02Coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0goooo00<0I_ooooooool0E?ooo`00EOooo`0306Kooooooooo02?oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0goooo00<0I_ooooooool0E?oo
o`00EOooo`@0I_lRoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000doooo101V
oeKoool005Woool206Ko8?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0<Ooo
o`<0I_l3oooo00?o09Woooooool0E?ooo`00Foooo`<0I_lMoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo02ooool206Ko1_ooo`03o`2Ioooooooo05Coool005koool2
06Ko7?ooo`80000:oooo0`0000Coool00`000?ooooooo`0]oooo0P1Vo`Soool00ol0VOooooooo`1D
oooo001Poooo0`1Vobcoool00`000?ooooooo`0[oooo0P1Vo`[oool00ol0VOooooooo`1Doooo001S
oooo0P1Vob[oool00`000?ooooooo`0Yoooo0P1Vo`coool00ol0VOooooooo`1Doooo001Uoooo0`1V
obOoool20000:?ooo`80I_l>oooo00?o09Woooooool0E?ooo`00J?ooo`80I_lUoooo00<0003ooooo
ool09Oooo`80I_l@oooo00?o09Woooooool0E?ooo`00J_ooo`80I_lSoooo00<0003oooooool08ooo
o`80I_lBoooo00?o09Woooooool0E?ooo`00K?ooo`80I_lQoooo00<0003oooooool08Oooo`80I_lD
oooo00?o09Woooooool0E?ooo`00K_ooo`80I_lOoooo00<0003oooooool07oooo`80I_lFoooo00?o
09Woooooool0E?ooo`00L?ooo`80I_lMoooo0P0001koool206Ko6?ooo`03o`2Ioooooooo05Coool0
07;oool206Ko6oooo`030000oooooooo01_oool206Ko6_ooo`03o`2Ioooooooo05Coool007Coool2
06Ko6Oooo`030000oooooooo01Woool206Ko7?ooo`03o`2Ioooooooo05Coool007Koool00`1Voooo
ooooo`0Foooo00<0003oooooool05oooo`80I_lNoooo00?o09Woooooool0E?ooo`00Moooo`80I_lF
oooo00<0003oooooool05Oooo`80I_lPoooo00?o09Woooooool0E?ooo`00NOooo`80I_lDoooo00<0
003oooooool04oooo`80I_lRoooo00?o09Woooooool0E?ooo`00Noooo`0306Kooooooooo017oool2
00004_ooo`80I_lToooo00?o09Woooooool0E?ooo`00O?ooo`80I_lAoooo00<0003oooooool03ooo
o`80I_lVoooo00?o09Woooooool0E?ooo`00O_ooo`80I_l?oooo00<0003oooooool03Oooo`80I_lX
oooo00?o09Woooooool0E?ooo`00P?ooo`80I_l=oooo00<0003oooooool02oooo`80I_lZoooo00?o
09Woooooool0E?ooo`00P_ooo`80I_l;oooo00<0003oooooool02Oooo`80I_l/oooo00?o09Wooooo
ool0E?ooo`00Q?ooo`80I_l9oooo00<0003oooooool02?ooo`0306Kooooooooo02coool00ol0VOoo
ooooo`1Doooo0026oooo00<0I_ooooooool01_ooo`800008oooo00<0I_ooooooool0;Oooo`03o`2I
oooooooo05Coool008Ooool00`1Vooooooooo`05oooo00<0003oooooool01Oooo`80I_l`oooo00?o
09Woooooool0E?ooo`00R?ooo`80I_l5oooo00<0003oooooool01?ooo`0306Kooooooooo033oool0
0ol0VOooooooo`1Doooo002:oooo00<0I_ooooooool00_ooo`030000oooooooo00?oool00`1Voooo
ooooo`0aoooo00?o09Woooooool0E?ooo`00Qoooo`D00003oooo00@0003oooooooooool206Ko=?oo
o`03o`2Ioooooooo05Coool008Woool010000?ooooooo`1Vo`;oool010000?ooo`1Vo`1VocKoool0
0ol0VOooooooo`1Doooo0029oooo00@0003oooooooooool206Ko0`0003Ooool00ol0VOooooooo`1D
oooo0029oooo00<0003oooooool00oooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo0029
oooo00<0003oooooool00oooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo0028oooo0P00
00Goool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool0
0ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool2
0000>?ooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=ooo
o`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Sooo
o`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo0P0003Soool00ol0VOooooooo`1D
oooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0g
oooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?
oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o
09Woooooool0E?ooo`00Soooo`80000hoooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo
03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool0
0ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool2
0000>?ooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=ooo
o`03o`2Ioooooooo05Coool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0g
oooo00?o09Woooooool0E?ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00OOooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`0003Ooool00ol0VOooooooo`1Doooo001moooo00<0003oooooool02?ooo`800005
oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool007goool00`000?ooooooo`08oooo00<0
003oooooool01?ooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo001loooo0P0000[oool3
00001?ooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=ooo
o`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Sooo
o`80000hoooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1D
oooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0g
oooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?
oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool20000>?ooo`03o`2Ioooooooo
05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo
03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool0
0ol0VOooooooo`1Doooo002?oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003ooooo
ool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=ooo
o`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Sooo
o`80000hoooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1D
oooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0g
oooo00?o09Woooooool0E?ooo`00Qoooo`@00004oooo00<0003oooooool0=oooo`03o`2Ioooooooo
05Coool008Ooool00`000?ooooooo`05oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08Soool00`000?ooooooo`04oooo0`0003Ooool00ol0VOooooooo`1Doooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo0027oooo00@0003oooooool00004
oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008Soool200001Oooo`030000oooooooo
03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`80000hoooo00?o09Wooooo
ool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003ooooo
ool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=ooo
o`03o`2Ioooooooo05Coool008ooool20000>?ooo`03o`2Ioooooooo05Coool008ooool00`000?oo
ooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1D
oooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0g
oooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?
oooo0P0003Soool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo
05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`030000oooooooo
03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003oooooool0=oooo`03o`2Ioooooooo05Coool0
08ooool00`000?ooooooo`0goooo00?o09Woooooool0E?ooo`00Soooo`80000hoooo00?o09Wooooo
ool0E?ooo`00Soooo`030000oooooooo03Ooool00ol0VOooooooo`1Doooo002?oooo00<0003ooooo
ool0=oooo`03o`2Ioooooooo05Coool008ooool00`000?ooooooo`0goooo00?o09Woooooool0E?oo
o`00Noooo`@00003oooo0P0000Coool200001Oooo`030000oooooooo03Ooool00ol0VOooooooo`1D
oooo001koooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo03Ooool0
0ol0VOooooooo`1Doooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool30000=ooo
o`03o`2Ioooooooo05Coool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool0
0?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?oo
ooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200001Oooo`<00002oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`030000oooooooo00coool01@000?ooooooooooo`00001moooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00koool00`000?ooooooo`08oooo1@0000?oool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`07oooo00@0003oooooool00003
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooo`000003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002oooo`800002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.71741 .04578 L
.72307 .04578 L
.72585 .04578 L
.72707 .04578 L
.72841 .04578 L
.72961 .04578 L
s
.72961 .04578 m
.7299 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.24141 .04578 L
.25127 .04578 L
.26171 .04578 L
.26425 .04578 L
.26698 .04578 L
.26778 .04578 L
.26855 .04578 L
.26923 .04578 L
.26998 .16028 L
.27068 .16054 L
.27144 .16081 L
.27279 .1613 L
.28302 .16508 L
.30316 .17289 L
.34474 .19068 L
.3848 .21018 L
.42335 .2314 L
.46436 .25699 L
.47421 .26365 L
.48478 .27103 L
.4899 .27469 L
.49475 .27822 L
.49686 .27977 L
.49802 .28062 L
.49911 .28143 L
.50028 .28188 L
.50157 .28093 L
.50385 .27925 L
.54182 .25293 L
.5805 .22916 L
.62164 .20687 L
.66127 .18797 L
.69938 .17188 L
.71899 .16433 L
.72463 .16224 L
.72741 .16123 L
.72862 .16079 L
.72927 .16055 L
.72996 .1603 L
.73117 .04578 L
.73229 .04578 L
.73475 .04578 L
.73994 .04578 L
.78121 .04578 L
Mistroke
.82098 .04578 L
.85922 .04578 L
.89992 .04578 L
.9391 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool00oooo`0306Kooooo000000Ooool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oool0I_l01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool0
0`1Vooooooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00`1Voooo
ooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00`1Vooooooooo`1B
oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00`1Vooooooooo`1Boooo001C
oooo00<0I_ooooooool0>Oooo`80000joooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo
03Woool00`000?ooooooo`0ioooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo03Woool0
0`000?ooooooo`0ioooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?oo
ooooo`0ioooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0i
oooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0ioooo00<0
I_ooooooool0D_ooo`00Doooo`0306Kooooooooo03Woool20000>_ooo`0306Kooooooooo05;oool0
05?oool00`1Vooooooooo`0ioooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool005?oool0
0`1Vooooooooo`0ioooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool005?oool00`1Voooo
ooooo`0ioooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool005?oool00`1Vooooooooo`0i
oooo00<0003oooooool0>Oooo`0306Kooooooooo05;oool005?oool00`1Vooooooooo`0ioooo00<0
003oooooool0>Oooo`0306Kooooooooo05;oool005?oool00`1Vooooooooo`0ioooo0P0003[oool0
0`1Vooooooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00`1Voooo
ooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00`1Vooooooooo`1B
oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00`1Vooooooooo`1Boooo001C
oooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00`1Vooooooooo`1Boooo001Coooo00<0
I_ooooooool0>Oooo`030000oooooooo03Woool00`1Vooooooooo`1Boooo001Coooo00<0I_oooooo
ool0>Oooo`80000joooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?oo
ooooo`0ioooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0i
oooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0ioooo00<0
I_ooooooool0D_ooo`00Doooo`0306Kooooooooo02Koool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0ioooo00<0I_ooooooool0D_ooo`00Doooo`0306Kooooooooo02Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0ioooo00<0I_ooooooool0D_oo
o`00Doooo`<0I_lUoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000goooo0`1V
oeCoool005Koool306Ko8_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0=Ooo
o`80I_l2oooo00?o09Woooooool0D_ooo`00FOooo`80I_lPoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo03?oool206Ko1?ooo`03o`2Ioooooooo05;oool005_oool3
06Ko7_ooo`80000:oooo0`0000Coool00`000?ooooooo`0`oooo0`1Vo`Koool00ol0VOooooooo`1B
oooo001Noooo0P1Vobooool00`000?ooooooo`0^oooo0P1Vo`Woool00ol0VOooooooo`1Boooo001P
oooo0P1Vobgoool00`000?ooooooo`0[oooo0`1Vo`_oool00ol0VOooooooo`1Boooo001Roooo0P1V
ob_oool20000:_ooo`80I_l>oooo00?o09Woooooool0D_ooo`00I?ooo`80I_lYoooo00<0003ooooo
ool09oooo`80I_l@oooo00?o09Woooooool0D_ooo`00I_ooo`80I_lWoooo00<0003oooooool09Ooo
o`80I_lBoooo00?o09Woooooool0D_ooo`00J?ooo`80I_lUoooo00<0003oooooool08oooo`80I_lD
oooo00?o09Woooooool0D_ooo`00J_ooo`80I_lSoooo00<0003oooooool08Oooo`80I_lFoooo00?o
09Woooooool0D_ooo`00K?ooo`80I_lQoooo0P00023oool206Ko6?ooo`03o`2Ioooooooo05;oool0
06koool206Ko7oooo`030000oooooooo01goool206Ko6_ooo`03o`2Ioooooooo05;oool0073oool2
06Ko7Oooo`030000oooooooo01_oool206Ko7?ooo`03o`2Ioooooooo05;oool007;oool206Ko6ooo
o`030000oooooooo01Woool206Ko7_ooo`03o`2Ioooooooo05;oool007Coool206Ko6Oooo`030000
oooooooo01Ooool206Ko8?ooo`03o`2Ioooooooo05;oool007Koool206Ko5oooo`030000oooooooo
01Goool206Ko8_ooo`03o`2Ioooooooo05;oool007Soool206Ko5Oooo`80000Doooo0P1VobCoool0
0ol0VOooooooo`1Boooo001joooo0P1Voa?oool00`000?ooooooo`0Boooo00<0I_ooooooool09?oo
o`03o`2Ioooooooo05;oool007coool206Ko4Oooo`030000oooooooo013oool206Ko9oooo`03o`2I
oooooooo05;oool007koool00`1Vooooooooo`0>oooo00<0003oooooool03_ooo`80I_lYoooo00?o
09Woooooool0D_ooo`00Ooooo`80I_l>oooo00<0003oooooool03Oooo`0306Kooooooooo02Woool0
0ol0VOooooooo`1Boooo0021oooo0P1Vo`coool00`000?ooooooo`0;oooo0P1Vobcoool00ol0VOoo
ooooo`1Boooo0023oooo00<0I_ooooooool02Oooo`80000:oooo0P1Vobkoool00ol0VOooooooo`1B
oooo0024oooo0P1Vo`Woool00`000?ooooooo`08oooo00<0I_ooooooool0;_ooo`03o`2Ioooooooo
05;oool008Koool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`80I_laoooo00?o09Wooooo
ool0D_ooo`00Qoooo`80I_l6oooo00<0003oooooool01Oooo`0306Kooooooooo037oool00ol0VOoo
ooooo`1Boooo0027oooo1@0000?oool00`000?ooooooo`04oooo00<0I_ooooooool0<_ooo`03o`2I
oooooooo05;oool008Woool00`000?ooo`1Vo`03oooo00<0003oooooool00_ooo`80I_leoooo00?o
09Woooooool0D_ooo`00ROooo`040000oooooooo06Ko0_ooo`<000000oooo`1Vooooo`0foooo00?o
09Woooooool0D_ooo`00ROooo`040000oooooooooooo0P1Vo`040000oooo06Ko06Ko>?ooo`03o`2I
oooooooo05;oool008Woool00`000?ooooooo`02oooo00<0I_l00000I_l0>_ooo`03o`2Ioooooooo
05;oool008Soool200001Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Wooooo
ool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool0
0ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool0
0`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool20000>_oo
o`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000
oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo0P0003[oool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Wooooo
ool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool0
0ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool0
0`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool30000>Oooo`03o`2Ioooooooo05;oool007goool00`000?oo
ooooo`08oooo0P0000Goool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
07coool200002_ooo`<00004oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool0
0`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo0P0003[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000j
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool0
0ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool0
0`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo0P0003[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo0027oooo100000Coool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00R?ooo`030000oooooooo00Coool30000>Oooo`03o`2Ioooooooo05;oool0
08Woool00`000?ooooooo`03oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00R?ooo`800005
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo0P00
03[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool0
0ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool0
0`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_oo
o`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Sooo
o`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo0P00
03[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool0
0ol0VOooooooo`1Boooo001koooo100000?oool200001?ooo`800005oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool007_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool007coool00`000?ooooooo`0;oooo00<0003ooooo
ool00_ooo`<0000ioooo00?o09Woooooool0D_ooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOoo
o`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?oo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800005oooo0`00
00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0<oooo00@0003oooooool00002
oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>
oooo00<0003oooooool02?ooo`D00004oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oool000000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000;oooo0P0000?oool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.71741 .04578 L
.72307 .04578 L
.72841 .04578 L
.7332 .04578 L
.73451 .04578 L
.7359 .04578 L
.73708 .04578 L
s
.73708 .04578 m
.73741 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.24141 .04578 L
.25127 .04578 L
.25666 .04578 L
.2593 .04578 L
.26045 .04578 L
.26171 .04578 L
.26301 .16063 L
.26425 .16108 L
.26698 .16208 L
.27279 .16422 L
.28302 .1681 L
.30316 .17611 L
.3438 .19391 L
.38293 .21335 L
.42451 .2368 L
.46458 .26249 L
.48296 .27541 L
.48799 .27908 L
.49339 .28308 L
.49601 .28504 L
.49729 .28602 L
.49848 .28692 L
.49956 .28774 L
.50071 .28753 L
.50186 .28666 L
.50313 .2857 L
.52307 .27109 L
.54413 .25663 L
.58434 .23155 L
.62302 .21023 L
.66416 .19024 L
.68469 .1812 L
.70379 .17329 L
.72221 .1661 L
.72752 .16411 L
.73253 .16226 L
.73471 .16146 L
.7359 .16102 L
.73702 .16062 L
.73823 .04578 L
.73887 .04578 L
.73956 .04578 L
.7419 .04578 L
.78317 .04578 L
Mistroke
.82293 .04578 L
.86118 .04578 L
.90188 .04578 L
.94106 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00D0
003oooooooooool0I_l00oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00D0003oooooooooool0I_l00oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo001Aoooo00<0I_ooooooool0>oooo`030000
oooooooo03_oool00`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooooooo
03_oool00`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooooooo03_oool0
0`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooooooo03_oool00`1Voooo
ooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`80000loooo00<0I_ooooooool0D?ooo`00DOoo
o`0306Kooooooooo03_oool00`000?ooooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Ko
oooooooo03_oool00`000?ooooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo
03_oool00`000?ooooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo03_oool0
0`000?ooooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo03_oool00`000?oo
ooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo03_oool20000??ooo`0306Ko
oooooooo053oool0057oool00`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo
053oool0057oool00`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0
057oool00`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0057oool0
0`1Vooooooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0057oool00`1Voooo
ooooo`0koooo00<0003oooooool0>oooo`0306Kooooooooo053oool0057oool00`1Vooooooooo`0k
oooo0P0003coool00`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooooooo
03_oool00`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooooooo03_oool0
0`1Vooooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooooooo03_oool00`1Voooo
ooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooooooo03_oool00`1Vooooooooo`1@
oooo001Aoooo00<0I_ooooooool0>oooo`030000oooooooo03_oool00`1Vooooooooo`1@oooo001A
oooo00<0I_ooooooool0>oooo`80000loooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo
03_oool00`000?ooooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo03_oool0
0`000?ooooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo03_oool00`000?oo
ooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo02Soool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`0koooo00<0I_ooooooool0D?ooo`00DOooo`0306Kooooooooo
02Ooool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0koooo00<0
I_ooooooool0D?ooo`00DOooo`80I_lXoooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000ioooo0`1Voe;oool005?oool306Ko9Oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0=_ooo`<0I_l2oooo00?o09Woooooool0D?ooo`00E_ooo`<0I_lRoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo03Coool206Ko1Oooo`03o`2Ioooooooo
053oool005Woool206Ko8Oooo`80000:oooo0`0000Coool00`000?ooooooo`0aoooo0`1Vo`Ooool0
0ol0VOooooooo`1@oooo001Koooo0`1Voc7oool00`000?ooooooo`0_oooo0P1Vo`[oool00ol0VOoo
ooooo`1@oooo001Noooo0P1Vobooool00`000?ooooooo`0/oooo0`1Vo`coool00ol0VOooooooo`1@
oooo001Poooo0`1Vobcoool20000:oooo`80I_l?oooo00?o09Woooooool0D?ooo`00Hoooo`80I_lZ
oooo00<0003oooooool0:?ooo`80I_lAoooo00?o09Woooooool0D?ooo`00IOooo`<0I_lWoooo00<0
003oooooool09_ooo`80I_lCoooo00?o09Woooooool0D?ooo`00J?ooo`80I_lUoooo00<0003ooooo
ool09?ooo`80I_lEoooo00?o09Woooooool0D?ooo`00J_ooo`80I_lSoooo00<0003oooooool08_oo
o`80I_lGoooo00?o09Woooooool0D?ooo`00K?ooo`80I_lQoooo0P00027oool206Ko6Oooo`03o`2I
oooooooo053oool006koool206Ko7oooo`030000oooooooo01koool206Ko6oooo`03o`2Ioooooooo
053oool0073oool206Ko7Oooo`030000oooooooo01goool00`1Vooooooooo`0Koooo00?o09Wooooo
ool0D?ooo`00L_ooo`80I_lKoooo00<0003oooooool06oooo`80I_lNoooo00?o09Woooooool0D?oo
o`00M?ooo`0306Kooooooooo01Soool00`000?ooooooo`0Ioooo0P1Vob3oool00ol0VOooooooo`1@
oooo001eoooo00<0I_ooooooool05oooo`030000oooooooo01Ooool206Ko8_ooo`03o`2Ioooooooo
053oool007Koool206Ko5oooo`80000Foooo0P1VobCoool00ol0VOooooooo`1@oooo001hoooo00<0
I_ooooooool05?ooo`030000oooooooo01?oool206Ko9_ooo`03o`2Ioooooooo053oool007Woool2
06Ko5?ooo`030000oooooooo017oool206Ko:?ooo`03o`2Ioooooooo053oool007_oool00`1Voooo
ooooo`0Aoooo00<0003oooooool04?ooo`0306Kooooooooo02Soool00ol0VOooooooo`1@oooo001l
oooo0P1Voa7oool00`000?ooooooo`0>oooo0P1Vob_oool00ol0VOooooooo`1@oooo001noooo0P1V
o`ooool00`000?ooooooo`0<oooo0P1Vobgoool00ol0VOooooooo`1@oooo0020oooo0P1Vo`goool2
00003?ooo`0306Kooooooooo02goool00ol0VOooooooo`1@oooo0022oooo0P1Vo`_oool00`000?oo
ooooo`09oooo0P1Voc3oool00ol0VOooooooo`1@oooo0024oooo0P1Vo`Woool00`000?ooooooo`08
oooo00<0I_ooooooool0<?ooo`03o`2Ioooooooo053oool008Koool00`1Vooooooooo`06oooo00<0
003oooooool01_ooo`80I_lcoooo00?o09Woooooool0D?ooo`00Qoooo`D00003oooo00<0003ooooo
ool01?ooo`80I_leoooo00?o09Woooooool0D?ooo`00R?ooo`0306Ko0000oooo00Coool00`000?oo
ooooo`03oooo00<0I_ooooooool0=Oooo`03o`2Ioooooooo053oool008Woool00`00001Vooooo`03
oooo0`0000;oool00`1Vooooooooo`0foooo00?o09Woooooool0D?ooo`00ROooo`030000oooo06Ko
00?oool00`000?ooooooo`0206Ko>Oooo`03o`2Ioooooooo053oool008Woool010000?ooooooo`1V
o`;oool00`000?ooo`1Vo`0koooo00?o09Woooooool0D?ooo`00R?ooo`800003oooo0P1Vo`030000
06Kooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo
053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`80000loooo00?o
09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@
oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo
053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`80000loooo00?o
09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
03_oool00ol0VOooooooo`1@oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool3
0000>oooo`03o`2Ioooooooo053oool007goool00`000?ooooooo`08oooo0P0000Goool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`04
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool007coool200002_ooo`<00004oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool0
0ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`80000loooo00?o09Woooooool0D?ooo`00Sooo
o`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo
053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool0
0ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo0027oooo100000Coool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Qooo
o`030000oooooooo00Goool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00R?ooo`030000
oooooooo00Coool30000>oooo`03o`2Ioooooooo053oool008Woool00`000?ooooooo`03oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00R?ooo`800005oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`80000loooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool0
0ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool20000??oo
o`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Sooo
o`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?
oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo001koooo1000
00?oool200001?ooo`800005oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool007_oool0
0`000?ooooooo`09oooo00@0003oooooool00004oooo00<0003oooooool0>oooo`03o`2Ioooooooo
053oool007coool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0000koooo00?o09Wooooo
ool0D?ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Ooo
o`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool0
07coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0
003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?oo
ooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00_oool00`000?ooooooo`02oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`800004
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`00
00Woool00`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.71905 .04578 L
.72912 .04578 L
.73838 .04578 L
.74309 .04578 L
.74423 .04578 L
.74546 .04578 L
s
.74546 .04578 m
.74564 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20342 .04578 L
.22272 .04578 L
.23233 .04578 L
.24276 .04578 L
.24754 .04578 L
.25016 .04578 L
.25144 .04578 L
.25261 .04578 L
.25368 .04578 L
.2547 .16049 L
.25577 .16088 L
.25694 .16131 L
.26171 .16306 L
.30236 .17908 L
.34148 .19656 L
.38307 .21766 L
.42313 .24078 L
.46168 .26596 L
.48123 .27994 L
.49159 .28771 L
.49457 .28999 L
.49739 .29217 L
.49862 .29313 L
.49993 .29415 L
.50061 .29373 L
.50136 .29314 L
.50269 .29211 L
.52311 .27676 L
.54217 .2633 L
.58238 .23743 L
.62107 .21544 L
.66221 .19482 L
.70183 .17733 L
.7218 .16931 L
.7305 .16597 L
.73994 .16245 L
.74249 .16152 L
.74388 .16101 L
.74519 .16054 L
.7463 .04578 L
.74749 .04578 L
.75003 .04578 L
.75955 .04578 L
.7805 .04578 L
.82178 .04578 L
Mistroke
.86154 .04578 L
.89978 .04578 L
.94048 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oool0I_l01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool00oooo`0306Kooooo000000Ooool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001?oooo00<0I_ooooooool0?Oooo`030000oooooooo03goool0
0`1Vooooooooo`1>oooo001?oooo00<0I_ooooooool0?Oooo`030000oooooooo03goool00`1Voooo
ooooo`1>oooo001?oooo00<0I_ooooooool0?Oooo`030000oooooooo03goool00`1Vooooooooo`1>
oooo001?oooo00<0I_ooooooool0?Oooo`030000oooooooo03goool00`1Vooooooooo`1>oooo001?
oooo00<0I_ooooooool0?Oooo`80000noooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo
03goool00`000?ooooooo`0moooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo03goool0
0`000?ooooooo`0moooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo03goool00`000?oo
ooooo`0moooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo03goool00`000?ooooooo`0m
oooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo03goool00`000?ooooooo`0moooo00<0
I_ooooooool0C_ooo`00Coooo`0306Kooooooooo03goool20000?_ooo`0306Kooooooooo04koool0
04ooool00`1Vooooooooo`0moooo00<0003oooooool0?Oooo`0306Kooooooooo04koool004ooool0
0`1Vooooooooo`0moooo00<0003oooooool0?Oooo`0306Kooooooooo04koool004ooool00`1Voooo
ooooo`0moooo00<0003oooooool0?Oooo`0306Kooooooooo04koool004ooool00`1Vooooooooo`0m
oooo00<0003oooooool0?Oooo`0306Kooooooooo04koool004ooool00`1Vooooooooo`0moooo00<0
003oooooool0?Oooo`0306Kooooooooo04koool004ooool00`1Vooooooooo`0moooo0P0003koool0
0`1Vooooooooo`1>oooo001?oooo00<0I_ooooooool0?Oooo`030000oooooooo03goool00`1Voooo
ooooo`1>oooo001?oooo00<0I_ooooooool0?Oooo`030000oooooooo03goool00`1Vooooooooo`1>
oooo001?oooo00<0I_ooooooool0?Oooo`030000oooooooo03goool00`1Vooooooooo`1>oooo001?
oooo00<0I_ooooooool0?Oooo`030000oooooooo03goool00`1Vooooooooo`1>oooo001?oooo00<0
I_ooooooool0?Oooo`030000oooooooo03goool00`1Vooooooooo`1>oooo001?oooo00<0I_oooooo
ool0?Oooo`80000noooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo03goool00`000?oo
ooooo`0moooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo03goool00`000?ooooooo`0m
oooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo03goool00`000?ooooooo`0moooo00<0
I_ooooooool0C_ooo`00Coooo`0306Kooooooooo02[oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0moooo00<0I_ooooooool0C_ooo`00Coooo`0306Kooooooooo02Woool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0moooo00<0I_ooooooool0C_oo
o`00Coooo`@0I_lXoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000koooo0`1V
oe3oool005?oool306Ko9Oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0>Ooo
o`80I_l2oooo00?o09Woooooool0C_ooo`00E_ooo`80I_lSoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo03Koool306Ko1?ooo`03o`2Ioooooooo04koool005Soool3
06Ko8Oooo`80000:oooo0`0000Coool00`000?ooooooo`0coooo0`1Vo`Ooool00ol0VOooooooo`1>
oooo001Koooo0P1Voc;oool00`000?ooooooo`0aoooo0P1Vo`[oool00ol0VOooooooo`1>oooo001M
oooo0P1Voc3oool00`000?ooooooo`0_oooo0P1Vo`coool00ol0VOooooooo`1>oooo001Ooooo0P1V
obkoool20000;_ooo`80I_l>oooo00?o09Woooooool0C_ooo`00HOooo`80I_l/oooo00<0003ooooo
ool0:oooo`80I_l@oooo00?o09Woooooool0C_ooo`00Hoooo`80I_lZoooo00<0003oooooool0:Ooo
o`80I_lBoooo00?o09Woooooool0C_ooo`00IOooo`80I_lXoooo00<0003oooooool09_ooo`<0I_lD
oooo00?o09Woooooool0C_ooo`00Ioooo`80I_lVoooo00<0003oooooool09?ooo`80I_lGoooo00?o
09Woooooool0C_ooo`00JOooo`80I_lToooo0P0002?oool206Ko6Oooo`03o`2Ioooooooo04koool0
06_oool206Ko8_ooo`030000oooooooo023oool206Ko6oooo`03o`2Ioooooooo04koool006goool2
06Ko8?ooo`030000oooooooo01koool206Ko7Oooo`03o`2Ioooooooo04koool006ooool206Ko7_oo
o`030000oooooooo01coool206Ko7oooo`03o`2Ioooooooo04koool0077oool00`1Vooooooooo`0K
oooo00<0003oooooool06_ooo`80I_lQoooo00?o09Woooooool0C_ooo`00L_ooo`80I_lKoooo00<0
003oooooool06?ooo`80I_lSoooo00?o09Woooooool0C_ooo`00M?ooo`80I_lIoooo0P0001Soool0
0`1Vooooooooo`0Soooo00?o09Woooooool0C_ooo`00M_ooo`0306Kooooooooo01Koool00`000?oo
ooooo`0Eoooo0P1VobKoool00ol0VOooooooo`1>oooo001goooo0P1VoaKoool00`000?ooooooo`0C
oooo0P1VobSoool00ol0VOooooooo`1>oooo001ioooo0P1VoaCoool00`000?ooooooo`0Boooo00<0
I_ooooooool0:?ooo`03o`2Ioooooooo04koool007_oool00`1Vooooooooo`0Aoooo00<0003ooooo
ool04?ooo`80I_l[oooo00?o09Woooooool0C_ooo`00O?ooo`80I_lAoooo00<0003oooooool03_oo
o`80I_l]oooo00?o09Woooooool0C_ooo`00O_ooo`80I_l?oooo0P0000koool00`1Vooooooooo`0]
oooo00?o09Woooooool0C_ooo`00P?ooo`0306Kooooooooo00coool00`000?ooooooo`0;oooo0P1V
oc3oool00ol0VOooooooo`1>oooo0021oooo0P1Vo`coool00`000?ooooooo`09oooo0P1Voc;oool0
0ol0VOooooooo`1>oooo0023oooo0P1Vo`[oool00`000?ooooooo`08oooo00<0I_ooooooool0<_oo
o`03o`2Ioooooooo04koool008Goool00`1Vooooo`00000400000oooo`030000oooooooo00Ooool0
0`1Vooooooooo`0coooo00?o09Woooooool0C_ooo`00Q_ooo`0406Kooooooooo00001Oooo`030000
oooooooo00Goool206Ko=_ooo`03o`2Ioooooooo04koool008Ooool206Ko00<0003oooooool00ooo
o`<00004oooo00<0I_ooooooool0=_ooo`03o`2Ioooooooo04koool008Woool00`000?ooooooo`03
oooo00<0003oooooool00oooo`0306Kooooooooo03Ooool00ol0VOooooooo`1>oooo0029oooo00<0
0000I_ooool00oooo`030000oooooooo00;oool00`1Vooooooooo`0hoooo00?o09Woooooool0C_oo
o`00R?ooo`8000000oooo`1Vo`1Vo`02oooo00<0003oooooool00P1Voc_oool00ol0VOooooooo`1>
oooo002=oooo0P1Vo`030000oooo06Ko03goool00ol0VOooooooo`1>oooo002>oooo00<0I_l00000
I_l0?_ooo`03o`2Ioooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?oo
ooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>
oooo002?oooo0P0003koool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2I
oooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000
oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo
04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`80000noooo00?o
09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0
003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Wooooo
ool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003ooooo
ool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_ooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool007_oool500000_oo
o`800004oooo0P0000Goool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00OOooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0moooo00?o09Woooooool0C_oo
o`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0003goool00ol0VOooooooo`1>
oooo001moooo00<0003oooooool02?ooo`800005oooo00<0003oooooool0?Oooo`03o`2Ioooooooo
04koool007goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo03goool0
0ol0VOooooooo`1>oooo001loooo0P0000[oool300001?ooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?oo
ooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`80000noooo00?o09Woooooool0C_ooo`00Sooo
o`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2I
oooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000
oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo
04koool008ooool20000?_ooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o
09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0
003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Wooooo
ool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo0P0003koool0
0ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?oo
ooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`80000noooo00?o09Woooooool0C_ooo`00Sooo
o`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2I
oooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Qoooo`@00004
oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008Ooool00`000?ooooooo`05oooo00<0
003oooooool0?Oooo`03o`2Ioooooooo04koool008Soool00`000?ooooooo`04oooo0`0003goool0
0ol0VOooooooo`1>oooo0029oooo00<0003oooooool00oooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo0027oooo00@0003oooooool00004oooo00<0003oooooool0?Oooo`03o`2Ioooooooo
04koool008Soool200001Oooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0
003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Wooooo
ool0C_ooo`00Soooo`80000noooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool0
0ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOoo
ooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool20000?_oo
o`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Sooo
o`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2I
oooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Soooo`030000
oooooooo03goool00ol0VOooooooo`1>oooo002?oooo0P0003koool00ol0VOooooooo`1>oooo002?
oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o
09Woooooool0C_ooo`00Soooo`030000oooooooo03goool00ol0VOooooooo`1>oooo002?oooo00<0
003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool00`000?ooooooo`0moooo00?o09Wooooo
ool0C_ooo`00Soooo`80000noooo00?o09Woooooool0C_ooo`00Soooo`030000oooooooo03goool0
0ol0VOooooooo`1>oooo002?oooo00<0003oooooool0?Oooo`03o`2Ioooooooo04koool008ooool0
0`000?ooooooo`0moooo00?o09Woooooool0C_ooo`00Noooo`@00003oooo0P0000Coool200001Ooo
o`030000oooooooo03goool00ol0VOooooooo`1>oooo001koooo00<0003oooooool02Oooo`040000
oooooooo00001?ooo`030000oooooooo03goool00ol0VOooooooo`1>oooo001loooo00<0003ooooo
ool02oooo`030000oooooooo00;oool30000?Oooo`03o`2Ioooooooo04koool007goool00`000?oo
ooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001l
oooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1000
00?oool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02Ooo
o`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00_oool00`000?ooooooo`03
oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_oo
o`030000oooooooo00Soool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool300000ooo
o`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.71905 .04578 L
.73838 .04578 L
.74806 .04578 L
.75071 .04578 L
.75216 .04578 L
.75287 .04578 L
.75351 .04578 L
s
.75351 .04578 m
.7538 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20342 .04578 L
.22272 .04578 L
.23233 .04578 L
.23739 .04578 L
.24016 .04578 L
.24276 .04578 L
.24392 .04578 L
.24502 .04578 L
.24629 .16032 L
.24745 .16074 L
.25261 .16263 L
.26171 .16603 L
.2999 .1814 L
.34055 .19992 L
.37968 .22014 L
.42126 .24454 L
.46133 .27128 L
.4797 .28472 L
.49014 .2927 L
.49523 .2967 L
.49764 .29861 L
.49871 .29946 L
.49988 .3004 L
.50102 .29967 L
.50224 .2987 L
.50482 .29666 L
.5095 .29299 L
.51982 .28508 L
.54088 .26972 L
.58108 .24308 L
.61977 .22044 L
.66091 .19922 L
.70054 .18121 L
.7205 .17296 L
.73864 .16589 L
.74348 .16407 L
.74873 .16213 L
.75114 .16126 L
.75245 .16078 L
.75369 .16033 L
.75473 .04578 L
.75586 .04578 L
.75825 .04578 L
.7792 .04578 L
.82048 .04578 L
Mistroke
.86024 .04578 L
.89849 .04578 L
.93918 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo03ooool0
0`1Vooooooooo`1<oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo03ooool00`1Voooo
ooooo`1<oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo03ooool00`1Vooooooooo`1<
oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo03ooool00`1Vooooooooo`1<oooo001=
oooo00<0I_ooooooool0?oooo`800010oooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo
03ooool00`000?ooooooo`0ooooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo03ooool0
0`000?ooooooo`0ooooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo03ooool00`000?oo
ooooo`0ooooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo03ooool00`000?ooooooo`0o
oooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo03ooool00`000?ooooooo`0ooooo00<0
I_ooooooool0C?ooo`00COooo`0306Kooooooooo03ooool20000@?ooo`0306Kooooooooo04coool0
04goool00`1Vooooooooo`0ooooo00<0003oooooool0?oooo`0306Kooooooooo04coool004goool0
0`1Vooooooooo`0ooooo00<0003oooooool0?oooo`0306Kooooooooo04coool004goool00`1Voooo
ooooo`0ooooo00<0003oooooool0?oooo`0306Kooooooooo04coool004goool00`1Vooooooooo`0o
oooo00<0003oooooool0?oooo`0306Kooooooooo04coool004goool00`1Vooooooooo`0ooooo00<0
003oooooool0?oooo`0306Kooooooooo04coool004goool00`1Vooooooooo`0ooooo0P00043oool0
0`1Vooooooooo`1<oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo03ooool00`1Voooo
ooooo`1<oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo03ooool00`1Vooooooooo`1<
oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo03ooool00`1Vooooooooo`1<oooo001=
oooo00<0I_ooooooool0?oooo`030000oooooooo03ooool00`1Vooooooooo`1<oooo001=oooo00<0
I_ooooooool0?oooo`030000oooooooo03ooool00`1Vooooooooo`1<oooo001=oooo00<0I_oooooo
ool0?oooo`800010oooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo03ooool00`000?oo
ooooo`0ooooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo03ooool00`000?ooooooo`0o
oooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo03ooool00`000?ooooooo`0ooooo00<0
I_ooooooool0C?ooo`00COooo`0306Kooooooooo02coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0ooooo00<0I_ooooooool0C?ooo`00COooo`0306Kooooooooo02_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0ooooo00<0I_ooooooool0C?oo
o`00COooo`<0I_l[oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000noooo0P1V
odkoool0053oool306Ko:?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0>_oo
o`@0I_l00oooool0VOooo`1=oooo001Coooo0P1VobKoool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0>?ooo`80I_l5oooo00?o09Woooooool0C?ooo`00EOooo`<0I_lT
oooo0P0000[oool300001?ooo`030000oooooooo03Goool306Ko1oooo`03o`2Ioooooooo04coool0
05Soool206Ko=Oooo`030000oooooooo03?oool206Ko2_ooo`03o`2Ioooooooo04coool005[oool2
06Ko<oooo`030000oooooooo037oool206Ko3?ooo`03o`2Ioooooooo04coool005coool206Ko<Ooo
o`80000`oooo0P1Vo`koool00ol0VOooooooo`1<oooo001Noooo0P1Vobooool00`000?ooooooo`0]
oooo0P1Voa3oool00ol0VOooooooo`1<oooo001Poooo0P1Vobgoool00`000?ooooooo`0[oooo0P1V
oa;oool00ol0VOooooooo`1<oooo001Roooo0P1Vob_oool00`000?ooooooo`0Yoooo0P1VoaCoool0
0ol0VOooooooo`1<oooo001Toooo0`1VobSoool00`000?ooooooo`0Voooo0`1VoaKoool00ol0VOoo
ooooo`1<oooo001Woooo0P1VobKoool200009Oooo`80I_lIoooo00?o09Woooooool0C?ooo`00JOoo
o`80I_lToooo00<0003oooooool08_ooo`80I_lKoooo00?o09Woooooool0C?ooo`00Joooo`80I_lR
oooo00<0003oooooool08?ooo`80I_lMoooo00?o09Woooooool0C?ooo`00KOooo`80I_lPoooo00<0
003oooooool07_ooo`80I_lOoooo00?o09Woooooool0C?ooo`00Koooo`80I_lNoooo00<0003ooooo
ool07?ooo`80I_lQoooo00?o09Woooooool0C?ooo`00LOooo`80I_lLoooo00<0003oooooool06_oo
o`80I_lSoooo00?o09Woooooool0C?ooo`00Loooo`0306Kooooooooo01Woool200006Oooo`80I_lU
oooo00?o09Woooooool0C?ooo`00M?ooo`0306Kooooooooo01Soool00`000?ooooooo`0Goooo00<0
I_ooooooool09Oooo`03o`2Ioooooooo04coool007Goool206Ko6?ooo`030000oooooooo01Goool2
06Ko:?ooo`03o`2Ioooooooo04coool007Ooool00`1Vooooooooo`0Eoooo00<0003oooooool04ooo
o`80I_lZoooo00?o09Woooooool0C?ooo`00N?ooo`80I_lEoooo00<0003oooooool04_ooo`0306Ko
oooooooo02[oool00ol0VOooooooo`1<oooo001joooo00<0I_ooooooool04_ooo`030000oooooooo
013oool206Ko;Oooo`03o`2Ioooooooo04coool007_oool206Ko4_ooo`80000@oooo00<0I_oooooo
ool0;Oooo`03o`2Ioooooooo04coool007goool206Ko4?ooo`030000oooooooo00koool00`1Voooo
ooooo`0^oooo00?o09Woooooool0C?ooo`00Ooooo`80I_l>oooo00<0003oooooool03?ooo`80I_la
oooo00?o09Woooooool0C?ooo`00POooo`80I_l<oooo00<0003oooooool02oooo`0306Kooooooooo
037oool00ol0VOooooooo`1<oooo0023oooo0P1Vo`;oool500000oooo`030000oooooooo00Woool2
06Ko=?ooo`03o`2Ioooooooo04coool008Goool01@1Vooooooooooooo`000005oooo00<0003ooooo
ool02?ooo`0306Kooooooooo03Coool00ol0VOooooooo`1<oooo0026oooo00@0I_ooooooool00005
oooo0`0000Koool206Ko=oooo`03o`2Ioooooooo04coool008Ooool206Ko00<0003oooooool00ooo
o`030000oooooooo00Goool00`1Vooooooooo`0goooo00?o09Woooooool0C?ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`03oooo0P1Voc[oool00ol0VOooooooo`1<oooo0028oooo0P00
000306Kooooooooo00;oool00`000?ooooooo`02oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
04coool008_oool01@1Vooooooooooooo`000002oooo0P1Vocgoool00ol0VOooooooo`1<oooo002<
oooo00H0I_ooooooool0003oool0I_looooo00?o09Woooooool0C?ooo`00SOooo`80I_l20000@?oo
o`03o`2Ioooooooo04coool008koool00`1Vo`00001Vo`10oooo00?o09Woooooool0C?ooo`00Sooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2I
oooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000
oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?
oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o
09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool20000@?oo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2I
oooooooo04coool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0ooooo00?o
09Woooooool0C?ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`0ooooo00?o09Woooooool0C?ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`0003ooool00ol0VOooooooo`1<oooo001moooo00<0003oooooool02?ooo`800005oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool007goool00`000?ooooooo`08oooo00<0003ooooo
ool01?ooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo001loooo0P0000[oool300001?oo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2I
oooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`800010
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o
09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool008ooool20000@?ooo`03o`2Ioooooooo04coool0
08ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo002?oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2I
oooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`800010
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o
09Woooooool0C?ooo`00Qoooo`@00004oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool0
08Ooool00`000?ooooooo`05oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008Soool0
0`000?ooooooo`04oooo0`0003ooool00ol0VOooooooo`1<oooo0029oooo00<0003oooooool00ooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo0027oooo00@0003oooooool00004oooo00<0
003oooooool0?oooo`03o`2Ioooooooo04coool008Soool200001Oooo`030000oooooooo03ooool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?oo
o`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Sooo
o`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2I
oooooooo04coool008ooool20000@?ooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o
09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00
043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool0
08ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool0
0ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool0
0`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?oo
o`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Nooo
o`@00003oooo0P0000Coool200001Oooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo001k
oooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool30000?oooo`03o`2I
oooooooo04coool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`00
00Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo100000?oool200000oooo`<00004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`030000oooooooo00Woool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`08oooo00@0003oooooool00004
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool01ooo
o`<00004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo
017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.71905 .04578 L
.73838 .04578 L
.74806 .04578 L
.75315 .04578 L
.75593 .04578 L
.75853 .04578 L
.7597 .04578 L
.76081 .04578 L
s
.76081 .04578 m
.76112 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20342 .04578 L
.22272 .04578 L
.23233 .04578 L
.23496 .04578 L
.2364 .04578 L
.23711 .04578 L
.23775 .04578 L
.2389 .16052 L
.24014 .16097 L
.24276 .16193 L
.26171 .16907 L
.30142 .1855 L
.33961 .20336 L
.38026 .22488 L
.41939 .24838 L
.46097 .27673 L
.48184 .29242 L
.49099 .29963 L
.49584 .30354 L
.49723 .30468 L
.49856 .30576 L
.49974 .30673 L
.50104 .30609 L
.5022 .30514 L
.50348 .3041 L
.50607 .302 L
.51073 .29826 L
.51978 .29117 L
.53959 .27633 L
.57979 .2489 L
.61848 .2256 L
.65962 .20374 L
.69924 .18521 L
.73735 .16944 L
.74744 .16557 L
.75239 .16371 L
.75696 .16203 L
.75952 .16109 L
.76081 .16063 L
.76154 .16036 L
.76223 .04578 L
.76296 .04578 L
.76366 .04578 L
.76498 .04578 L
.76794 .04578 L
Mistroke
.77791 .04578 L
.81615 .04578 L
.85685 .04578 L
.89603 .04578 L
.93767 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`03oooo00<0
I_ooool000001oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooo06Ko00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool0
0`1Vooooooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool00`1Voooo
ooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool00`1Vooooooooo`1:
oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool00`1Vooooooooo`1:oooo001;
oooo00<0I_ooooooool0@Oooo`800012oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo
047oool00`000?ooooooo`11oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo047oool0
0`000?ooooooo`11oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo047oool00`000?oo
ooooo`11oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`11
oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`11oooo00<0
I_ooooooool0B_ooo`00Boooo`0306Kooooooooo047oool20000@_ooo`0306Kooooooooo04[oool0
04_oool00`1Vooooooooo`11oooo00<0003oooooool0@Oooo`0306Kooooooooo04[oool004_oool0
0`1Vooooooooo`11oooo00<0003oooooool0@Oooo`0306Kooooooooo04[oool004_oool00`1Voooo
ooooo`11oooo00<0003oooooool0@Oooo`0306Kooooooooo04[oool004_oool00`1Vooooooooo`11
oooo00<0003oooooool0@Oooo`0306Kooooooooo04[oool004_oool00`1Vooooooooo`11oooo00<0
003oooooool0@Oooo`0306Kooooooooo04[oool004_oool00`1Vooooooooo`11oooo0P0004;oool0
0`1Vooooooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool00`1Voooo
ooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool00`1Vooooooooo`1:
oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool00`1Vooooooooo`1:oooo001;
oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool00`1Vooooooooo`1:oooo001;oooo00<0
I_ooooooool0@Oooo`030000oooooooo047oool00`1Vooooooooo`1:oooo001;oooo00<0I_oooooo
ool0@Oooo`800012oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo047oool00`000?oo
ooooo`11oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`11
oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`11oooo00<0
I_ooooooool0B_ooo`00Boooo`0306Kooooooooo02koool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`11oooo00<0I_ooooooool0B_ooo`00Boooo`0306Kooooooooo02goool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`11oooo00<0I_ooooooool0B_oo
o`00Boooo`<0I_l]oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000ooooo0`1V
odcoool004koool206Ko:oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0?Ooo
o`80I_l2oooo00?o09Woooooool0B_ooo`00D?ooo`<0I_lXoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo03[oool306Ko1?ooo`03o`2Ioooooooo04[oool005?oool2
06Ko9oooo`80000:oooo0`0000Coool00`000?ooooooo`0hoooo0P1Vo`Ooool00ol0VOooooooo`1:
oooo001Eoooo0`1VocOoool00`000?ooooooo`0eoooo0`1Vo`Woool00ol0VOooooooo`1:oooo001H
oooo0P1VocGoool00`000?ooooooo`0coooo0P1Vo`coool00ol0VOooooooo`1:oooo001Joooo0P1V
oc?oool20000<Oooo`<0I_l>oooo00?o09Woooooool0B_ooo`00G?ooo`80I_laoooo00<0003ooooo
ool0;_ooo`80I_lAoooo00?o09Woooooool0B_ooo`00G_ooo`80I_l_oooo00<0003oooooool0;?oo
o`80I_lCoooo00?o09Woooooool0B_ooo`00H?ooo`80I_l]oooo00<0003oooooool0:_ooo`80I_lE
oooo00?o09Woooooool0B_ooo`00H_ooo`80I_l[oooo00<0003oooooool0:?ooo`80I_lGoooo00?o
09Woooooool0B_ooo`00I?ooo`<0I_lXoooo0P0002Ooool206Ko6Oooo`03o`2Ioooooooo04[oool0
06Ooool206Ko9_ooo`030000oooooooo02Coool206Ko6oooo`03o`2Ioooooooo04[oool006Woool2
06Ko9?ooo`030000oooooooo02;oool206Ko7Oooo`03o`2Ioooooooo04[oool006_oool206Ko8_oo
o`030000oooooooo027oool00`1Vooooooooo`0Moooo00?o09Woooooool0B_ooo`00KOooo`80I_lP
oooo00<0003oooooool07oooo`80I_lPoooo00?o09Woooooool0B_ooo`00Koooo`80I_lNoooo00<0
003oooooool07Oooo`80I_lRoooo00?o09Woooooool0B_ooo`00LOooo`80I_lLoooo0P0001goool0
0`1Vooooooooo`0Roooo00?o09Woooooool0B_ooo`00Loooo`0306Kooooooooo01Woool00`000?oo
ooooo`0Joooo0P1VobGoool00ol0VOooooooo`1:oooo001doooo00<0I_ooooooool06?ooo`030000
oooooooo01Soool206Ko9oooo`03o`2Ioooooooo04[oool007Goool206Ko6?ooo`030000oooooooo
01Ooool00`1Vooooooooo`0Woooo00?o09Woooooool0B_ooo`00Moooo`0306Kooooooooo01Goool0
0`000?ooooooo`0Eoooo0P1Vob[oool00ol0VOooooooo`1:oooo001hoooo0P1VoaGoool00`000?oo
ooooo`0Coooo0P1Vobcoool00ol0VOooooooo`1:oooo001joooo00<0I_ooooooool04_ooo`80000C
oooo00<0I_ooooooool0;?ooo`03o`2Ioooooooo04[oool007_oool206Ko4_ooo`030000oooooooo
013oool206Ko;oooo`03o`2Ioooooooo04[oool007goool00`1Vooooooooo`0?oooo00<0003ooooo
ool03oooo`0306Kooooooooo02ooool00ol0VOooooooo`1:oooo001noooo0P1Vo`ooool00`000?oo
ooooo`0=oooo0P1Voc;oool00ol0VOooooooo`1:oooo0020oooo0P1Vo`Goool500000oooo`030000
oooooooo00_oool206Ko=?ooo`03o`2Ioooooooo04[oool008;oool00`1Vooooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00[oool00`1Vooooooooo`0doooo00?o09Woooooool0B_oo
o`00Poooo`80I_l4oooo00<0003oooooool00oooo`<00008oooo0P1VocOoool00ol0VOooooooo`1:
oooo0025oooo00D0I_ooooooooooool000001Oooo`030000oooooooo00Ooool00`1Vooooooooo`0g
oooo00?o09Woooooool0B_ooo`00Q_ooo`0406Kooooooooo00001Oooo`030000oooooooo00Koool0
0`1Vooooooooo`0hoooo00?o09Woooooool0B_ooo`00Qoooo`0306Ko0000000000Goool00`000?oo
ooooo`04oooo0P1Voc_oool00ol0VOooooooo`1:oooo0029oooo00<0I_ooooooool00oooo`030000
oooooooo00?oool00`1Vooooooooo`0koooo00?o09Woooooool0B_ooo`00R_ooo`0306Kooooooooo
00;oool00`000?ooooooo`02oooo00<0I_ooooooool0??ooo`03o`2Ioooooooo04[oool008_oool2
06Ko0_ooo`8000000oooo`1Vo`1Vo`0ooooo00?o09Woooooool0B_ooo`00SOooo`0506Kooooo0000
oooo06Ko047oool00ol0VOooooooo`1:oooo002>oooo00<0I_l00000I_l0@_ooo`03o`2Ioooooooo
04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo
047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool0
08ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo0P0004;oool00ol0VOoo
ooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11
oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Noooo`D00002oooo0P00
00Coool200001Oooo`030000oooooooo047oool00ol0VOooooooo`1:oooo001moooo00<0003ooooo
ool01oooo`040000oooooooo00001?ooo`030000oooooooo047oool00ol0VOooooooo`1:oooo001m
oooo00<0003oooooool02_ooo`030000oooooooo00;oool30000@Oooo`03o`2Ioooooooo04[oool0
07goool00`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00OOooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool007coool200002_ooo`<00004oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo
047oool00ol0VOooooooo`1:oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo
047oool00ol0VOooooooo`1:oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo0027oooo100000Coool0
0`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Qoooo`030000oooooooo00Goool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00R?ooo`030000oooooooo00Coool30000@Oooo`03o`2I
oooooooo04[oool008Woool00`000?ooooooo`03oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00R?ooo`800005oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o
09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool0
0`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo001koooo100000?oool200001?ooo`800005oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool007_oool00`000?ooooooo`09oooo00@0003ooooo
ool00004oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool007coool00`000?ooooooo`0;
oooo00<0003oooooool00_ooo`<00011oooo00?o09Woooooool0B_ooo`00OOooo`030000oooooooo
00Soool20000U_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool2
00002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000ooo
o`800003oooo0`0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00@0
003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02?ooo`040000oooooooo00001Ooo
o`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool0
0`000?ooooooo`07oooo0`0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0`0000?oool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.71905 .04578 L
.73838 .04578 L
.74806 .04578 L
.75853 .04578 L
.76334 .04578 L
.76596 .04578 L
.76725 .04578 L
.76842 .04578 L
.76949 .04578 L
s
.76949 .04578 m
.76975 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20342 .04578 L
.21345 .04578 L
.22272 .04578 L
.22738 .04578 L
.22852 .04578 L
.22974 .04578 L
.23043 .16033 L
.23107 .16056 L
.23233 .16102 L
.24276 .16487 L
.26171 .17219 L
.30142 .18903 L
.33961 .20735 L
.38026 .22942 L
.41939 .2535 L
.46097 .28258 L
.48184 .29866 L
.49099 .30606 L
.49584 .31007 L
.49723 .31123 L
.49856 .31234 L
.49974 .31334 L
.50104 .31268 L
.5022 .31171 L
.50348 .31064 L
.50607 .30848 L
.51073 .30466 L
.51978 .29738 L
.53959 .28216 L
.57979 .25404 L
.61848 .23015 L
.65962 .20774 L
.69924 .18874 L
.73735 .17257 L
.75696 .16497 L
.76261 .16287 L
.76538 .16185 L
.7666 .16141 L
.76794 .16092 L
.76914 .16049 L
.77026 .04578 L
.77145 .04578 L
.77272 .04578 L
.77791 .04578 L
.81919 .04578 L
Mistroke
.85895 .04578 L
.89719 .04578 L
.93789 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool01@000?ooooooooooo`1Vo`03
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`050000oooooooooooo06Ko00?oool00`000?ooooooo`06oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo0019oooo00<0I_ooooooool0@oooo`030000
oooooooo04?oool00`1Vooooooooo`18oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo
04?oool00`1Vooooooooo`18oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo04?oool0
0`1Vooooooooo`18oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo04?oool00`1Voooo
ooooo`18oooo0019oooo00<0I_ooooooool0@oooo`800014oooo00<0I_ooooooool0B?ooo`00BOoo
o`0306Kooooooooo04?oool00`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Ko
oooooooo04?oool00`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo
04?oool00`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo04?oool0
0`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo04?oool00`000?oo
ooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo04?oool20000A?ooo`0306Ko
oooooooo04Soool004Woool00`1Vooooooooo`13oooo00<0003oooooool0@oooo`0306Kooooooooo
04Soool004Woool00`1Vooooooooo`13oooo00<0003oooooool0@oooo`0306Kooooooooo04Soool0
04Woool00`1Vooooooooo`13oooo00<0003oooooool0@oooo`0306Kooooooooo04Soool004Woool0
0`1Vooooooooo`13oooo00<0003oooooool0@oooo`0306Kooooooooo04Soool004Woool00`1Voooo
ooooo`13oooo00<0003oooooool0@oooo`0306Kooooooooo04Soool004Woool00`1Vooooooooo`13
oooo0P0004Coool00`1Vooooooooo`18oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo
04?oool00`1Vooooooooo`18oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo04?oool0
0`1Vooooooooo`18oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo04?oool00`1Voooo
ooooo`18oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo04?oool00`1Vooooooooo`18
oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo04?oool00`1Vooooooooo`18oooo0019
oooo00<0I_ooooooool0@oooo`800014oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo
04?oool00`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo04?oool0
0`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo04?oool00`000?oo
ooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo033oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`13oooo00<0I_ooooooool0B?ooo`00BOooo`0306Kooooooooo
02ooool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`13oooo00<0
I_ooooooool0B?ooo`00BOooo`80I_l`oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<00011oooo0`1Vod[oool004_oool306Ko;Oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0?oooo`80I_l2oooo00?o09Woooooool0B?ooo`00C_ooo`80I_l[oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo03goool206Ko1?ooo`03o`2Ioooooooo
04Soool0053oool306Ko:Oooo`80000:oooo0`0000Coool00`000?ooooooo`0joooo0`1Vo`Koool0
0ol0VOooooooo`18oooo001Coooo0P1Voc[oool00`000?ooooooo`0hoooo0P1Vo`Woool00ol0VOoo
ooooo`18oooo001Eoooo0`1VocOoool00`000?ooooooo`0eoooo0`1Vo`_oool00ol0VOooooooo`18
oooo001Hoooo0P1VocGoool20000=?ooo`80I_l>oooo00?o09Woooooool0B?ooo`00F_ooo`80I_lc
oooo00<0003oooooool0<?ooo`<0I_l@oooo00?o09Woooooool0B?ooo`00G?ooo`80I_laoooo00<0
003oooooool0;_ooo`80I_lCoooo00?o09Woooooool0B?ooo`00G_ooo`80I_l_oooo00<0003ooooo
ool0;?ooo`80I_lEoooo00?o09Woooooool0B?ooo`00H?ooo`80I_l]oooo00<0003oooooool0:_oo
o`80I_lGoooo00?o09Woooooool0B?ooo`00H_ooo`80I_l[oooo0P0002Woool206Ko6Oooo`03o`2I
oooooooo04Soool006Coool206Ko:Oooo`030000oooooooo02Koool206Ko6oooo`03o`2Ioooooooo
04Soool006Koool206Ko9oooo`030000oooooooo02Coool206Ko7Oooo`03o`2Ioooooooo04Soool0
06Soool206Ko9Oooo`030000oooooooo02;oool206Ko7oooo`03o`2Ioooooooo04Soool006[oool2
06Ko8oooo`030000oooooooo027oool00`1Vooooooooo`0Ooooo00?o09Woooooool0B?ooo`00K?oo
o`80I_lQoooo00<0003oooooool07oooo`80I_lRoooo00?o09Woooooool0B?ooo`00K_ooo`80I_lO
oooo0P0001koool206Ko9?ooo`03o`2Ioooooooo04Soool0073oool00`1Vooooooooo`0Loooo00<0
003oooooool07?ooo`0306Kooooooooo02Coool00ol0VOooooooo`18oooo001aoooo0P1Voacoool0
0`000?ooooooo`0Joooo0P1VobOoool00ol0VOooooooo`18oooo001coooo0P1Voa[oool00`000?oo
ooooo`0Hoooo0P1VobWoool00ol0VOooooooo`18oooo001eoooo00<0I_ooooooool05oooo`030000
oooooooo01Ooool00`1Vooooooooo`0Yoooo00?o09Woooooool0B?ooo`00M_ooo`80I_lGoooo00<0
003oooooool05Oooo`80I_l/oooo00?o09Woooooool0B?ooo`00N?ooo`80I_lEoooo0P0001Coool2
06Ko;_ooo`03o`2Ioooooooo04Soool007[oool00`1Vooooooooo`0Boooo00<0003oooooool04_oo
o`0306Kooooooooo02koool00ol0VOooooooo`18oooo001koooo0P1Voa;oool00`000?ooooooo`0@
oooo0P1Voc7oool00ol0VOooooooo`18oooo001moooo00<0I_ooooooool03oooo`030000oooooooo
00ooool00`1Vooooooooo`0aoooo00?o09Woooooool0B?ooo`00O_ooo`80I_l7oooo1@0000?oool0
0`000?ooooooo`0=oooo0P1VocCoool00ol0VOooooooo`18oooo0020oooo0P1Vo`Ooool00`000?oo
ooooo`03oooo00<0003oooooool02oooo`80I_lfoooo00?o09Woooooool0B?ooo`00P_ooo`0306Ko
oooooooo00Coool00`000?ooooooo`03oooo0`0000[oool00`1Vooooooooo`0foooo00?o09Wooooo
ool0B?ooo`00Poooo`80I_l4oooo00<0003oooooool00oooo`030000oooooooo00Soool206Ko>Ooo
o`03o`2Ioooooooo04Soool008Goool01@1Vooooooooooooo`000005oooo00<0003oooooool01ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`18oooo0026oooo00@0I_ooool000000005oooo00<0
003oooooool01_ooo`0306Kooooooooo03[oool00ol0VOooooooo`18oooo0027oooo00<0I_oooooo
ool01Oooo`030000oooooooo00Coool206Ko?Oooo`03o`2Ioooooooo04Soool008Soool00`1Voooo
ooooo`04oooo00<0003oooooool00oooo`0306Kooooooooo03goool00ol0VOooooooo`18oooo0029
oooo00<0I_ooooooool00oooo`800003oooo00<0I_ooooooool0?_ooo`03o`2Ioooooooo04Soool0
08[oool00`1Vooooooooo`02oooo00D0003oooooooooool0I_l0@Oooo`03o`2Ioooooooo04Soool0
08_oool206Ko0_ooo`040000oooooooo06Ko@_ooo`03o`2Ioooooooo04Soool008goool01@1Voooo
o`000?ooo`1Vo`13oooo00?o09Woooooool0B?ooo`00S_ooo`0306Ko000006Ko04Coool00ol0VOoo
ooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool20000A?oo
o`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Sooo
o`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2I
oooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000
oooooooo04?oool00ol0VOooooooo`18oooo002?oooo0P0004Coool00ol0VOooooooo`18oooo002?
oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0
003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Wooooo
ool0B?ooo`00Soooo`800014oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool0
0ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool0
0`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo04?oool00ol0VOooooooo`18oooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo04?oool00ol0VOooooooo`18oooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool30000@oooo`03o`2Ioooooooo04Soool007goool00`000?oo
ooooo`08oooo0P0000Goool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool0
07coool200002_ooo`<00004oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool0
0`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOoo
ooooo`18oooo002?oooo0P0004Coool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@ooo
o`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Sooo
o`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2I
oooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`800014
oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?
oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0
003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool20000A?ooo`03o`2Ioooooooo04Soool0
08ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool0
0ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool0
0`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOoo
ooooo`18oooo002?oooo0P0004Coool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@ooo
o`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Sooo
o`030000oooooooo04?oool00ol0VOooooooo`18oooo0027oooo100000Coool00`000?ooooooo`13
oooo00?o09Woooooool0B?ooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`13oooo00?o
09Woooooool0B?ooo`00R?ooo`030000oooooooo00Coool30000@oooo`03o`2Ioooooooo04Soool0
08Woool00`000?ooooooo`03oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00R?ooo`800005
oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo0P00
04Coool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool0
08ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool0
0ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool0
0`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`800014oooo00?o09Woooooool0B?oo
o`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@ooo
o`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Sooo
o`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2I
oooooooo04Soool008ooool20000A?ooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13
oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?
oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool008ooool00`000?ooooooo`13oooo00?o
09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool00ol0VOooooooo`18oooo002?oooo0P00
04Coool00ol0VOooooooo`18oooo002?oooo00<0003oooooool0@oooo`03o`2Ioooooooo04Soool0
08ooool00`000?ooooooo`13oooo00?o09Woooooool0B?ooo`00Soooo`030000oooooooo04?oool0
0ol0VOooooooo`18oooo001koooo100000?oool200001?ooo`800005oooo00<0003oooooool0@ooo
o`03o`2Ioooooooo04Soool007_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0
003oooooool0@oooo`03o`2Ioooooooo04Soool007coool00`000?ooooooo`0;oooo00<0003ooooo
ool00_ooo`<00013oooo00?o09Woooooool0B?ooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800005oooo00<0
003oooooool00_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0;oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooooooo00[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo
00D0000>oooo00<0003oooooool02_ooo`050000oooooooooooo000007goool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00O?ooo`030000oooooooo017oool200002Oooo`@00002oooo00<0003oooooool0O?oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.75718 .04578 L
.76707 .04578 L
.77247 .04578 L
.77511 .04578 L
.77626 .04578 L
.77751 .04578 L
s
.77751 .04578 m
.77784 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20178 .04578 L
.20742 .04578 L
.21274 .04578 L
.21753 .04578 L
.21884 .04578 L
.22022 .04578 L
.22141 .04578 L
.22272 .16041 L
.22401 .16088 L
.2252 .16131 L
.22791 .1623 L
.23285 .16413 L
.24213 .16764 L
.263 .17592 L
.30213 .19299 L
.34372 .21359 L
.38378 .23617 L
.42233 .26075 L
.46334 .29039 L
.48376 .30664 L
.48888 .31088 L
.49373 .31497 L
.49584 .31676 L
.49809 .31868 L
.49926 .31969 L
.50055 .31986 L
.50172 .31885 L
.50282 .3179 L
.52115 .30264 L
.5408 .28722 L
.57948 .25952 L
.62062 .23354 L
.66025 .21151 L
.69836 .19276 L
.71961 .18325 L
.73892 .17513 L
.74855 .17127 L
.759 .1672 L
.76379 .16539 L
.76887 .16349 L
.7732 .16189 L
.77438 .16146 L
.77566 .161 L
.77686 .16056 L
.77796 .04578 L
Mistroke
.77925 .04578 L
.78047 .04578 L
.78274 .04578 L
.78783 .04578 L
.79699 .04578 L
.81772 .04578 L
.85633 .04578 L
.89738 .04578 L
.93692 .04578 L
.97494 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`00001Vooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00?oool00`1Vooooo`000008oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0016oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool0
0`1Vooooooooo`16oooo0016oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool00`1Voooo
ooooo`16oooo0016oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool00`1Vooooooooo`16
oooo0016oooo00<0I_ooooooool0A_ooo`030000oooooooo04Goool00`1Vooooooooo`16oooo0016
oooo00<0I_ooooooool0A_ooo`800016oooo00<0I_ooooooool0A_ooo`00A_ooo`0306Kooooooooo
04Koool00`000?ooooooo`15oooo00<0I_ooooooool0A_ooo`00A_ooo`0306Kooooooooo04Koool0
0`000?ooooooo`15oooo00<0I_ooooooool0A_ooo`00A_ooo`0306Kooooooooo04Koool00`000?oo
ooooo`15oooo00<0I_ooooooool0A_ooo`00A_ooo`0306Kooooooooo04Koool00`000?ooooooo`15
oooo00<0I_ooooooool0A_ooo`00A_ooo`0306Kooooooooo04Koool00`000?ooooooo`15oooo00<0
I_ooooooool0A_ooo`00A_ooo`0306Kooooooooo04Koool20000A_ooo`0306Kooooooooo04Koool0
04Koool00`1Vooooooooo`16oooo00<0003oooooool0AOooo`0306Kooooooooo04Koool004Koool0
0`1Vooooooooo`16oooo00<0003oooooool0AOooo`0306Kooooooooo04Koool004Koool00`1Voooo
ooooo`16oooo00<0003oooooool0AOooo`0306Kooooooooo04Koool004Ooool00`1Vooooooooo`15
oooo00<0003oooooool0AOooo`0306Kooooooooo04Koool004Ooool00`1Vooooooooo`15oooo00<0
003oooooool0AOooo`0306Kooooooooo04Koool004Ooool00`1Vooooooooo`15oooo0P0004Koool0
0`1Vooooooooo`16oooo0017oooo00<0I_ooooooool0AOooo`030000oooooooo04Goool00`1Voooo
ooooo`16oooo0017oooo00<0I_ooooooool0AOooo`030000oooooooo04Goool00`1Vooooooooo`16
oooo0017oooo00<0I_ooooooool0AOooo`030000oooooooo04Goool00`1Vooooooooo`16oooo0017
oooo00<0I_ooooooool0AOooo`030000oooooooo04Goool00`1Vooooooooo`16oooo0017oooo00<0
I_ooooooool0AOooo`030000oooooooo04Goool00`1Vooooooooo`16oooo0017oooo00<0I_oooooo
ool0AOooo`800016oooo00<0I_ooooooool0A_ooo`00Aoooo`0306Kooooooooo04Goool00`000?oo
ooooo`15oooo00<0I_ooooooool0A_ooo`00Aoooo`0306Kooooooooo04Goool00`000?ooooooo`15
oooo00<0I_ooooooool0A_ooo`00Aoooo`0306Kooooooooo04Goool00`000?ooooooo`15oooo00<0
I_ooooooool0A_ooo`00Aoooo`0306Kooooooooo03;oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`15oooo00<0I_ooooooool0A_ooo`00Aoooo`0306Kooooooooo037oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`15oooo00<0I_ooooooool0A_oo
o`00Aoooo`80I_lboooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00013oooo0`1V
odSoool004Woool206Ko<?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0@?oo
o`<0I_l2oooo00?o09Woooooool0A_ooo`00Boooo`<0I_l]oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo03goool306Ko1Oooo`03o`2Ioooooooo04Koool004koool2
06Ko;?ooo`80000:oooo0`0000Coool00`000?ooooooo`0koooo0P1Vo`Soool00ol0VOooooooo`16
oooo001@oooo0`1Voccoool00`000?ooooooo`0ioooo0P1Vo`[oool00ol0VOooooooo`16oooo001C
oooo0P1Voc[oool00`000?ooooooo`0goooo0P1Vo`coool00ol0VOooooooo`16oooo001Eoooo0`1V
ocOoool20000=_ooo`80I_l>oooo00?o09Woooooool0A_ooo`00F?ooo`80I_leoooo00<0003ooooo
ool0<oooo`80I_l@oooo00?o09Woooooool0A_ooo`00F_ooo`<0I_lboooo00<0003oooooool0<Ooo
o`80I_lBoooo00?o09Woooooool0A_ooo`00GOooo`80I_l`oooo00<0003oooooool0;oooo`80I_lD
oooo00?o09Woooooool0A_ooo`00Goooo`80I_l^oooo00<0003oooooool0;Oooo`80I_lFoooo00?o
09Woooooool0A_ooo`00HOooo`80I_l/oooo0P0002coool206Ko6?ooo`03o`2Ioooooooo04Koool0
06?oool206Ko:_ooo`030000oooooooo02Woool206Ko6_ooo`03o`2Ioooooooo04Koool006Goool2
06Ko:?ooo`030000oooooooo02Ooool206Ko7?ooo`03o`2Ioooooooo04Koool006Ooool206Ko9_oo
o`030000oooooooo02Goool206Ko7_ooo`03o`2Ioooooooo04Koool006Woool206Ko9?ooo`030000
oooooooo02?oool206Ko8?ooo`03o`2Ioooooooo04Koool006_oool206Ko8_ooo`030000oooooooo
027oool206Ko8_ooo`03o`2Ioooooooo04Koool006goool206Ko8?ooo`80000Poooo0P1VobCoool0
0ol0VOooooooo`16oooo001_oooo0P1Voakoool00`000?ooooooo`0Moooo0P1VobKoool00ol0VOoo
ooooo`16oooo001aoooo00<0I_ooooooool06oooo`030000oooooooo01coool00`1Vooooooooo`0V
oooo00?o09Woooooool0A_ooo`00L_ooo`80I_lKoooo00<0003oooooool06_ooo`80I_lYoooo00?o
09Woooooool0A_ooo`00M?ooo`0306Kooooooooo01Soool00`000?ooooooo`0Hoooo0P1Vob_oool0
0ol0VOooooooo`16oooo001eoooo00<0I_ooooooool05oooo`030000oooooooo01Ooool00`1Voooo
ooooo`0[oooo00?o09Woooooool0A_ooo`00M_ooo`80I_lGoooo0P0001Koool206Ko;_ooo`03o`2I
oooooooo04Koool007Soool00`1Vooooooooo`0Doooo00<0003oooooool04oooo`80I_l`oooo00?o
09Woooooool0A_ooo`00NOooo`80I_lDoooo00<0003oooooool04_ooo`0306Kooooooooo033oool0
0ol0VOooooooo`16oooo001koooo00<0I_ooooooool04Oooo`030000oooooooo017oool00`1Voooo
ooooo`0aoooo00?o09Woooooool0A_ooo`00O?ooo`80I_l9oooo1@0000?oool00`000?ooooooo`0?
oooo0P1VocCoool00ol0VOooooooo`16oooo001noooo00<0I_ooooooool02?ooo`030000oooooooo
00?oool00`000?ooooooo`0>oooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo04Koool007ooool0
0`1Vooooooooo`07oooo00<0003oooooool00oooo`<0000=oooo00<0I_ooooooool0=Oooo`03o`2I
oooooooo04Koool0083oool206Ko1oooo`030000oooooooo00?oool00`000?ooooooo`0<oooo00<0
I_ooooooool0=_ooo`03o`2Ioooooooo04Koool008;oool00`1Vooooooooo`04oooo00<0003ooooo
ool00oooo`030000oooooooo00[oool206Ko>Oooo`03o`2Ioooooooo04Koool008?oool206Ko0ooo
o`800005oooo00<0003oooooool02Oooo`0306Kooooooooo03Woool00ol0VOooooooo`16oooo0025
oooo00<0I_ooooooool01oooo`030000oooooooo00Soool00`1Vooooooooo`0joooo00?o09Wooooo
ool0A_ooo`00Q_ooo`0306Kooooooooo00Koool00`000?ooooooo`06oooo0P1Vocgoool00ol0VOoo
ooooo`16oooo0027oooo00<0I_ooooooool01Oooo`800006oooo00<0I_ooooooool0?Oooo`03o`2I
oooooooo04Koool008Soool206Ko1Oooo`030000oooooooo00?oool206Ko@?ooo`03o`2Ioooooooo
04Koool008[oool00`1Vooooooooo`02oooo00<0003oooooool00_ooo`0306Kooooooooo043oool0
0ol0VOooooooo`16oooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo047oool0
0ol0VOooooooo`16oooo002<oooo00@0I_ooooooool00002oooo00<0I_ooooooool0@_ooo`03o`2I
oooooooo04Koool008goool206Ko00<0003oool0I_l0AOooo`03o`2Ioooooooo04Koool008koool0
0`1Vo`0000000016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?oo
ooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16
oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool20000A_ooo`03o`2I
oooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000
oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo
04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16oooo002?oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo001koooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool007goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool0
07goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<00015oooo00?o09Woooooool0A_oo
o`00OOooo`030000oooooooo00Soool200001Oooo`030000oooooooo04Goool00ol0VOooooooo`16
oooo001moooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?ooooooo`15oooo00?o
09Woooooool0A_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool008ooool20000A_ooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?oo
ooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16
oooo002?oooo0P0004Koool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2I
oooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000
oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo
04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o
09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool008ooool20000A_ooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008Ooool400001?oo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo0027oooo00<0003oooooool01Oooo`030000
oooooooo04Goool00ol0VOooooooo`16oooo0028oooo00<0003oooooool01?ooo`<00015oooo00?o
09Woooooool0A_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo04Goool00ol0VOooooooo`16
oooo0028oooo0P0000Goool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000
oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo
04Koool008ooool20000A_ooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o
09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Wooooo
ool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool0
0ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOoo
ooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?oo
ooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2I
oooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000
oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo
04Koool008ooool20000A_ooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o
09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0
003oooooool0AOooo`03o`2Ioooooooo04Koool007_oool400000oooo`800004oooo0P0000Goool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Noooo`030000oooooooo00Woool010000?oo
ooooo`0000Coool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00O?ooo`030000oooooooo
00_oool00`000?ooooooo`02oooo0`0004Goool00ol0VOooooooo`16oooo001moooo00<0003ooooo
ool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?oo
o`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003
oooo0P0000Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003ooooo
ool02oooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0
003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`0:oooo00<0003oooooool01?oo
o`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool0
0`000?ooooooo`0:oooo00@0003oooooooooool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Woool4
00000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.75718 .04578 L
.76707 .04578 L
.77751 .04578 L
.78008 .04578 L
.78283 .04578 L
.78364 .04578 L
.78441 .04578 L
.7851 .04578 L
s
.7851 .04578 m
.78528 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.20178 .04578 L
.20742 .04578 L
.21019 .04578 L
.2114 .04578 L
.21274 .04578 L
.21394 .04578 L
.21506 .16051 L
.21625 .16094 L
.21753 .1614 L
.22272 .16331 L
.26394 .17961 L
.30365 .19744 L
.34184 .21683 L
.38249 .24019 L
.42162 .2657 L
.4632 .29647 L
.47335 .30461 L
.48407 .3135 L
.49322 .32134 L
.49573 .32352 L
.49711 .32473 L
.49842 .32588 L
.49963 .32696 L
.50095 .32644 L
.50215 .32538 L
.50327 .3244 L
.54182 .29254 L
.58108 .26383 L
.61883 .23938 L
.65904 .21636 L
.69772 .19679 L
.73886 .17843 L
.75939 .17013 L
.7694 .16627 L
.77849 .16287 L
.78304 .1612 L
.78428 .16075 L
.7856 .16027 L
.78673 .04578 L
.78797 .04578 L
.79691 .04578 L
.8166 .04578 L
.85694 .04578 L
.89576 .04578 L
.93704 .04578 L
Mistroke
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`00001Vooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo04Ooool0
0ol0V@1Vooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo04Ooool00ol0V@1V
ooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo04Ooool00ol0V@1Vooooo`14
oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo04Ooool00ol0V@1Vooooo`14oooo0015
oooo00<0I_ooooooool0Aoooo`800018oooo00?o09T0I_ooool0A?ooo`00AOooo`0306Kooooooooo
04Ooool00`000?ooooooo`17oooo00?o09T0I_ooool0A?ooo`00AOooo`0306Kooooooooo04Ooool0
0`000?ooooooo`17oooo00?o09T0I_ooool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?oo
ooooo`17oooo00?o09T0I_ooool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`17
oooo00?o09T0I_ooool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`17oooo00?o
09T0I_ooool0A?ooo`00AOooo`0306Kooooooooo04Ooool20000B?ooo`03o`2I06Kooooo04Coool0
04Goool00`1Vooooooooo`17oooo00<0003oooooool0Aoooo`03o`2I06Kooooo04Coool004Goool0
0`1Vooooooooo`17oooo00<0003oooooool0Aoooo`03o`2I06Kooooo04Coool004Goool00`1Voooo
ooooo`17oooo00<0003oooooool0Aoooo`0306Kooooooooo04Coool004Goool00`1Vooooooooo`17
oooo00<0003oooooool0Aoooo`0306Kooooooooo04Coool004Goool00`1Vooooooooo`17oooo00<0
003oooooool0Aoooo`0306Kooooooooo04Coool004Goool00`1Vooooooooo`17oooo0P0004Soool0
0`1Vooooooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo04Ooool00`1Voooo
ooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo04Ooool00`1Vooooooooo`14
oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo04Ooool00`1Vooooooooo`14oooo0015
oooo00<0I_ooooooool0Aoooo`030000oooooooo04Ooool00`1Vooooooooo`14oooo0015oooo00<0
I_ooooooool0Aoooo`030000oooooooo04Ooool00`1Vooooooooo`14oooo0015oooo00<0I_oooooo
ool0Aoooo`800018oooo00<0I_ooooooool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?oo
ooooo`17oooo00<0I_ooooooool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`17
oooo00<0I_ooooooool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`17oooo00<0
I_ooooooool0A?ooo`00AOooo`0306Kooooooooo03Coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`17oooo00<0I_ooooooool0A?ooo`00AOooo`0306Kooooooooo03?oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`17oooo00<0I_ooooooool0A?oo
o`00AOooo`@0I_lboooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00015oooo0`1V
odKoool004Woool206Ko<?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0@_oo
o`<0I_l2oooo00?o09Woooooool0A?ooo`00Boooo`80I_l^oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo03ooool306Ko1Oooo`03o`2Ioooooooo04Coool004goool2
06Ko;Oooo`80000:oooo0`0000Coool00`000?ooooooo`0moooo0P1Vo`Soool00ol0VOooooooo`14
oooo001?oooo0P1Vockoool00`000?ooooooo`0joooo0`1Vo`[oool00ol0VOooooooo`14oooo001A
oooo0`1Voc_oool00`000?ooooooo`0hoooo0P1Vo`goool00ol0VOooooooo`14oooo001Doooo0P1V
ocWoool20000=oooo`80I_l?oooo00?o09Woooooool0A?ooo`00E_ooo`<0I_lfoooo00<0003ooooo
ool0=?ooo`80I_lAoooo00?o09Woooooool0A?ooo`00FOooo`80I_ldoooo00<0003oooooool0<_oo
o`80I_lCoooo00?o09Woooooool0A?ooo`00Foooo`80I_lboooo00<0003oooooool0<?ooo`80I_lE
oooo00?o09Woooooool0A?ooo`00GOooo`80I_l`oooo00<0003oooooool0;_ooo`80I_lGoooo00?o
09Woooooool0A?ooo`00Goooo`80I_l^oooo0P0002goool206Ko6Oooo`03o`2Ioooooooo04Coool0
067oool206Ko;?ooo`030000oooooooo02[oool206Ko6oooo`03o`2Ioooooooo04Coool006?oool2
06Ko:_ooo`030000oooooooo02Soool206Ko7Oooo`03o`2Ioooooooo04Coool006Goool206Ko:?oo
o`030000oooooooo02Koool206Ko7oooo`03o`2Ioooooooo04Coool006Ooool206Ko9_ooo`030000
oooooooo02Coool206Ko8Oooo`03o`2Ioooooooo04Coool006Woool206Ko9?ooo`030000oooooooo
02;oool206Ko8oooo`03o`2Ioooooooo04Coool006_oool00`1Vooooooooo`0Qoooo0P0002;oool0
0`1Vooooooooo`0Soooo00?o09Woooooool0A?ooo`00K?ooo`80I_lQoooo00<0003oooooool07ooo
o`80I_lVoooo00?o09Woooooool0A?ooo`00K_ooo`80I_lOoooo00<0003oooooool07Oooo`80I_lX
oooo00?o09Woooooool0A?ooo`00L?ooo`0306Kooooooooo01coool00`000?ooooooo`0Loooo00<0
I_ooooooool0:?ooo`03o`2Ioooooooo04Coool0077oool206Ko7?ooo`030000oooooooo01[oool2
06Ko:oooo`03o`2Ioooooooo04Coool007?oool00`1Vooooooooo`0Ioooo00<0003oooooool06Ooo
o`0306Kooooooooo02_oool00ol0VOooooooo`14oooo001doooo0P1VoaWoool200006Oooo`0306Ko
oooooooo02coool00ol0VOooooooo`14oooo001foooo0P1VoaOoool00`000?ooooooo`0Foooo0P1V
obooool00ol0VOooooooo`14oooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01Goool0
0`1Vooooooooo`0_oooo00?o09Woooooool0A?ooo`00NOooo`80I_lDoooo00<0003oooooool04ooo
o`80I_lboooo00?o09Woooooool0A?ooo`00Noooo`0306Kooooooooo00Woool500000oooo`030000
oooooooo01;oool00`1Vooooooooo`0boooo00?o09Woooooool0A?ooo`00O?ooo`0306Kooooooooo
00[oool00`000?ooooooo`03oooo00<0003oooooool04?ooo`80I_leoooo00?o09Woooooool0A?oo
o`00OOooo`80I_l:oooo00<0003oooooool00oooo`<0000?oooo00<0I_ooooooool0=Oooo`03o`2I
oooooooo04Coool007ooool00`1Vooooooooo`07oooo00<0003oooooool00oooo`030000oooooooo
00koool00`1Vooooooooo`0foooo00?o09Woooooool0A?ooo`00P?ooo`0306Kooooooooo00Koool0
0`000?ooooooo`03oooo00<0003oooooool03?ooo`80I_lioooo00?o09Woooooool0A?ooo`00POoo
o`0306Kooooooooo00Coool200001Oooo`030000oooooooo00_oool00`1Vooooooooo`0ioooo00?o
09Woooooool0A?ooo`00P_ooo`80I_l;oooo00<0003oooooool02Oooo`80I_lloooo00?o09Wooooo
ool0A?ooo`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`08oooo00<0I_ooooooool0??oo
o`03o`2Ioooooooo04Coool008Goool00`1Vooooooooo`07oooo0P0000Soool00`1Vooooooooo`0m
oooo00?o09Woooooool0A?ooo`00Q_ooo`80I_l7oooo00<0003oooooool01Oooo`80I_m0oooo00?o
09Woooooool0A?ooo`00R?ooo`0306Kooooooooo00Coool00`000?ooooooo`04oooo00<0I_oooooo
ool0@?ooo`03o`2Ioooooooo04Coool008Woool206Ko1?ooo`030000oooooooo00?oool00`1Voooo
ooooo`11oooo00?o09Woooooool0A?ooo`00Roooo`0506Kooooooooooooo000000Coool00`1Voooo
ooooo`12oooo00?o09Woooooool0A?ooo`00S?ooo`0406Kooooooooo00000_ooo`80I_m5oooo00?o
09Woooooool0A?ooo`00SOooo`0506Kooooo0000000006Ko04Ooool00ol0VOooooooo`14oooo002>
oooo00<0I_l00000I_l0B?ooo`03o`2Ioooooooo04Coool008ooool00`00001Vooooo`17oooo00?o
09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0
003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Wooooo
ool0A?ooo`00Soooo`800018oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool0
0ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?oo
o`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Sooo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`17oooo00?o
09Woooooool0A?ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`0004Ooool00ol0VOooooooo`14oooo001moooo00<0003oooooool02?ooo`800005oooo00<0
003oooooool0Aoooo`03o`2Ioooooooo04Coool007goool00`000?ooooooo`08oooo00<0003ooooo
ool01?ooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo001loooo0P0000[oool300001?oo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018
oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o
09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0
003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo04Coool0
08ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool0
0ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aooo
o`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Sooo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018
oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o
09Woooooool0A?ooo`00Qoooo`@00004oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
08Ooool00`000?ooooooo`05oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008Soool0
0`000?ooooooo`04oooo0`0004Ooool00ol0VOooooooo`14oooo0029oooo00<0003oooooool00ooo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo0027oooo00@0003oooooool00004oooo00<0
003oooooool0Aoooo`03o`2Ioooooooo04Coool008Soool200001Oooo`030000oooooooo04Ooool0
0ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018oooo00?o09Woooooool0A?oo
o`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aooo
o`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Sooo
o`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17
oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?
oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o
09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo0P00
04Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool0
08ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool0
0ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018oooo00?o09Woooooool0A?oo
o`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aooo
o`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Nooo
o`@00003oooo0P0000Coool200001Oooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo001k
oooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool30000Aoooo`03o`2I
oooooooo04Coool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`00
00Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo100000?oool200001?ooo`800004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`030000oooooooo00Woool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`08oooo00@0003oooooool00004
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool02?oo
o`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.75718 .04578 L
.77751 .04578 L
.78293 .04578 L
.78866 .04578 L
.79102 .04578 L
.79232 .04578 L
.79355 .04578 L
s
.79355 .04578 m
.79373 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.19227 .04578 L
.19721 .04578 L
.20178 .04578 L
.20433 .04578 L
.20562 .04578 L
.20635 .16023 L
.20704 .16048 L
.21274 .16256 L
.22272 .16629 L
.26149 .18194 L
.30271 .20082 L
.34242 .22148 L
.38061 .24394 L
.42126 .27101 L
.46039 .30055 L
.48036 .3171 L
.49087 .32623 L
.49616 .33094 L
.49761 .33225 L
.49841 .33297 L
.49917 .33365 L
.49987 .33429 L
.50063 .33383 L
.50133 .3332 L
.50197 .33262 L
.52284 .31437 L
.54204 .29861 L
.5813 .2692 L
.61906 .24415 L
.65926 .22055 L
.69795 .2005 L
.73909 .18169 L
.75961 .17318 L
.76962 .16923 L
.77871 .16575 L
.78326 .16404 L
.78819 .16222 L
.79045 .16139 L
.79169 .16094 L
.79284 .16052 L
.79383 .04578 L
.79489 .04578 L
.79713 .04578 L
.81682 .04578 L
.85809 .04578 L
Mistroke
.89786 .04578 L
.9361 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00?oool0101Vooooooooo`0000Ooool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooo06Ko00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool004;oool00`1Vooooooooo`1:oooo00<0003oooooool0BOoo
o`0306Kooooooooo04;oool004;oool00`1Vooooooooo`1:oooo00<0003oooooool0BOooo`0306Ko
oooooooo04;oool004;oool00`1Vooooooooo`1:oooo00<0003oooooool0BOooo`0306Kooooooooo
04;oool004;oool00`1Vooooooooo`1:oooo00<0003oooooool0BOooo`0306Kooooooooo04;oool0
04;oool00`1Vooooooooo`1:oooo0P0004[oool00`1Vooooooooo`12oooo0012oooo00<0I_oooooo
ool0B_ooo`030000oooooooo04Woool00`1Vooooooooo`12oooo0012oooo00<0I_ooooooool0B_oo
o`030000oooooooo04Woool00`1Vooooooooo`12oooo0012oooo00<0I_ooooooool0B_ooo`030000
oooooooo04Woool00`1Vooooooooo`12oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo
04Woool00`1Vooooooooo`12oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo04Woool0
0`1Vooooooooo`12oooo0012oooo00<0I_ooooooool0B_ooo`80001:oooo00<0I_ooooooool0@_oo
o`00@_ooo`0306Kooooooooo04[oool00`000?ooooooo`19oooo00<0I_ooooooool0@_ooo`00@_oo
o`0306Kooooooooo04[oool00`000?ooooooo`19oooo00<0I_ooooooool0@_ooo`00@_ooo`0306Ko
oooooooo04[oool00`000?ooooooo`19oooo00<0I_ooooooool0@_ooo`00@oooo`0306Kooooooooo
04Woool00`000?ooooooo`19oooo00<0I_ooooooool0@_ooo`00@oooo`0306Kooooooooo04Woool0
0`000?ooooooo`19oooo00<0I_ooooooool0@_ooo`00@oooo`0306Kooooooooo04Woool20000B_oo
o`0306Kooooooooo04;oool004?oool00`1Vooooooooo`19oooo00<0003oooooool0BOooo`0306Ko
oooooooo04;oool004?oool00`1Vooooooooo`19oooo00<0003oooooool0BOooo`0306Kooooooooo
04;oool004?oool00`1Vooooooooo`19oooo00<0003oooooool0BOooo`0306Kooooooooo04;oool0
04?oool00`1Vooooooooo`19oooo00<0003oooooool0BOooo`0306Kooooooooo04;oool004?oool0
0`1Vooooooooo`19oooo00<0003oooooool0BOooo`0306Kooooooooo04;oool004?oool00`1Voooo
ooooo`19oooo0P0004[oool00`1Vooooooooo`12oooo0013oooo00<0I_ooooooool0BOooo`030000
oooooooo04Woool00`1Vooooooooo`12oooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo
04Woool00`1Vooooooooo`12oooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo04Woool0
0`1Vooooooooo`12oooo0013oooo00<0I_ooooooool0=_ooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo04Woool00`1Vooooooooo`12oooo0013oooo00<0I_ooooooool0=Oooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo04Woool00`1Vooooooooo`12
oooo0013oooo0`1VocGoool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0004Soool2
06KoA?ooo`00A_ooo`<0I_lboooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`15
oooo0`1Vo`03ooooo`2Ioooo04?oool004Woool206Ko<?ooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`13oooo0P1Vo`Coool00ol0VOooooooo`12oooo001;oooo0`1V
obkoool200002_ooo`<00004oooo00<0003oooooool0@?ooo`<0I_l6oooo00?o09Woooooool0@_oo
o`00C_ooo`80I_looooo00<0003oooooool0?Oooo`<0I_l9oooo00?o09Woooooool0@_ooo`00D?oo
o`<0I_lloooo00<0003oooooool0>_ooo`<0I_l<oooo00?o09Woooooool0@_ooo`00Doooo`80I_lj
oooo0P0003Woool206Ko3oooo`03o`2Ioooooooo04;oool005Goool206Ko>?ooo`030000oooooooo
03Koool206Ko4Oooo`03o`2Ioooooooo04;oool005Ooool206Ko=_ooo`030000oooooooo03Coool2
06Ko4oooo`03o`2Ioooooooo04;oool005Woool206Ko=?ooo`030000oooooooo03;oool206Ko5Ooo
o`03o`2Ioooooooo04;oool005_oool206Ko<_ooo`030000oooooooo033oool206Ko5oooo`03o`2I
oooooooo04;oool005goool206Ko<?ooo`80000_oooo0P1VoaWoool00ol0VOooooooo`12oooo001O
oooo0P1Vobkoool00`000?ooooooo`0/oooo0P1Voa_oool00ol0VOooooooo`12oooo001Qoooo00<0
I_ooooooool0:oooo`030000oooooooo02[oool206Ko7Oooo`03o`2Ioooooooo04;oool006;oool2
06Ko:oooo`030000oooooooo02Soool206Ko7oooo`03o`2Ioooooooo04;oool006Coool206Ko:Ooo
o`030000oooooooo02Koool206Ko8Oooo`03o`2Ioooooooo04;oool006Koool00`1Vooooooooo`0V
oooo00<0003oooooool09?ooo`80I_lSoooo00?o09Woooooool0@_ooo`00Ioooo`80I_lVoooo0P00
02?oool206Ko9Oooo`03o`2Ioooooooo04;oool006Woool206Ko9?ooo`030000oooooooo027oool0
0`1Vooooooooo`0Uoooo00?o09Woooooool0@_ooo`00Joooo`80I_lRoooo00<0003oooooool07ooo
o`80I_lXoooo00?o09Woooooool0@_ooo`00KOooo`80I_lPoooo00<0003oooooool07Oooo`80I_lZ
oooo00?o09Woooooool0@_ooo`00Koooo`80I_lNoooo00<0003oooooool07?ooo`0306Kooooooooo
02[oool00ol0VOooooooo`12oooo001aoooo0P1Voacoool00`000?ooooooo`0Joooo0P1Vobgoool0
0ol0VOooooooo`12oooo001coooo00<0I_ooooooool06Oooo`80000Joooo00<0I_ooooooool0;Ooo
o`03o`2Ioooooooo04;oool007Coool00`1Vooooooooo`0Hoooo00<0003oooooool06?ooo`0306Ko
oooooooo02koool00ol0VOooooooo`12oooo001eoooo0P1VoaSoool00`000?ooooooo`0Foooo0P1V
oc7oool00ol0VOooooooo`12oooo001goooo00<0I_ooooooool05Oooo`030000oooooooo01Goool0
0`1Vooooooooo`0aoooo00?o09Woooooool0@_ooo`00N?ooo`80I_l=oooo1@0000?oool00`000?oo
ooooo`0Coooo0P1VocCoool00ol0VOooooooo`12oooo001joooo00<0I_ooooooool03?ooo`030000
oooooooo00?oool00`000?ooooooo`0Boooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo04;oool0
07_oool206Ko3?ooo`030000oooooooo00?oool300004Oooo`0306Kooooooooo03Goool00ol0VOoo
ooooo`12oooo001moooo00<0I_ooooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`0?
oooo0P1VocSoool00ol0VOooooooo`12oooo001noooo00<0I_ooooooool02?ooo`030000oooooooo
00?oool00`000?ooooooo`0>oooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo04;oool007ooool2
06Ko1oooo`800005oooo00<0003oooooool03Oooo`0306Kooooooooo03Woool00ol0VOooooooo`12
oooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00coool00`1Vooooooooo`0joooo00?o
09Woooooool0@_ooo`00P_ooo`0306Kooooooooo00[oool00`000?ooooooo`0:oooo0P1Vocgoool0
0ol0VOooooooo`12oooo0023oooo0P1Vo`[oool200002_ooo`0306Kooooooooo03goool00ol0VOoo
ooooo`12oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Soool00`1Vooooooooo`0n
oooo00?o09Woooooool0@_ooo`00Q_ooo`0306Kooooooooo00Koool00`000?ooooooo`07oooo00<0
I_ooooooool0?oooo`03o`2Ioooooooo04;oool008Ooool206Ko1_ooo`030000oooooooo00Goool2
06Ko@_ooo`03o`2Ioooooooo04;oool008Woool00`1Vooooooooo`03oooo00<0003oooooool01?oo
o`0306Kooooooooo04;oool00ol0VOooooooo`12oooo002:oooo00<0I_ooooooool00_ooo`030000
oooooooo00?oool00`1Vooooooooo`13oooo00?o09Woooooool0@_ooo`00Roooo`0406Kooooooooo
oooo0P0000;oool206KoA_ooo`03o`2Ioooooooo04;oool008coool0101Vooooooooo`0000;oool0
0`1Vooooooooo`16oooo00?o09Woooooool0@_ooo`00SOooo`0306Kooooo00000080I_m9oooo00?o
09Woooooool0@_ooo`00S_ooo`0306Ko0000oooo04[oool00ol0VOooooooo`12oooo002?oooo00<0
003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Wooooo
ool0@_ooo`00Soooo`80001:oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool0
0ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool0
0`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOoo
ooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool20000B_oo
o`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Sooo
o`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2I
oooooooo04;oool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`19oooo00?o
09Woooooool0@_ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`19oooo00?o09Woooooool0@_ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`0004Woool00ol0VOooooooo`12oooo001moooo00<0003oooooool02?ooo`800005oooo00<0
003oooooool0BOooo`03o`2Ioooooooo04;oool007goool00`000?ooooooo`08oooo00<0003ooooo
ool01?ooo`030000oooooooo04Woool00ol0VOooooooo`12oooo001loooo0P0000[oool300001?oo
o`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2I
oooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:
oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?
oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o
09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0
003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool20000B_ooo`03o`2Ioooooooo04;oool0
08ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool0
0ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool0
0`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOoo
ooooo`12oooo002?oooo0P0004[oool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOoo
o`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Sooo
o`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2I
oooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:
oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?
oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o
09Woooooool0@_ooo`00Qoooo`@00004oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool0
08Ooool00`000?ooooooo`05oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008Soool0
0`000?ooooooo`04oooo0`0004Woool00ol0VOooooooo`12oooo0029oooo00<0003oooooool00ooo
o`030000oooooooo04Woool00ol0VOooooooo`12oooo0027oooo00@0003oooooool00004oooo00<0
003oooooool0BOooo`03o`2Ioooooooo04;oool008Soool200001Oooo`030000oooooooo04Woool0
0ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool0
0`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Woooooool0@_oo
o`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOoo
o`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Sooo
o`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2I
oooooooo04;oool008ooool20000B_ooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19
oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?
oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o
09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo0P00
04[oool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool0
08ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`030000oooooooo04Woool0
0ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOooo`03o`2Ioooooooo04;oool008ooool0
0`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Soooo`80001:oooo00?o09Woooooool0@_oo
o`00Soooo`030000oooooooo04Woool00ol0VOooooooo`12oooo002?oooo00<0003oooooool0BOoo
o`03o`2Ioooooooo04;oool008ooool00`000?ooooooo`19oooo00?o09Woooooool0@_ooo`00Nooo
o`@00003oooo0P0000Coool200001Oooo`030000oooooooo04Woool00ol0VOooooooo`12oooo001k
oooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo04Woool00ol0VOoo
ooooo`12oooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool30000BOooo`03o`2I
oooooooo04;oool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`00
00Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQ
oooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08
oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo100000?oool200001?ooo`800004oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00<0003oooooool02Oooo`040000oooooooo00000_ooo`040000oooooooo00000ooo
o`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooooooo00Soool010000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool02?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.7878 .04578 L
.79321 .04578 L
.79616 .04578 L
.79892 .04578 L
.80016 .04578 L
.80134 .04578 L
s
.80134 .04578 m
.8015 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.16408 .04578 L
.18221 .04578 L
.18703 .04578 L
.19227 .04578 L
.19467 .04578 L
.19598 .04578 L
.19721 .04578 L
.19826 .04578 L
.19939 .16058 L
.20064 .16104 L
.20178 .16145 L
.22272 .16934 L
.26243 .1858 L
.30062 .2037 L
.34126 .22527 L
.38039 .24882 L
.42198 .27723 L
.46204 .30837 L
.48042 .32402 L
.49085 .33331 L
.49595 .33796 L
.49712 .33904 L
.49836 .34019 L
.49942 .34118 L
.50059 .34116 L
.50181 .34003 L
.50296 .33897 L
.50553 .3366 L
.51022 .33235 L
.52053 .32318 L
.5416 .30537 L
.58028 .27559 L
.62142 .24766 L
.66105 .22397 L
.69916 .20381 L
.73972 .18486 L
.77876 .16876 L
.789 .16486 L
.7944 .16285 L
.79735 .16177 L
.79879 .16124 L
.80011 .16077 L
.80134 .16032 L
.80251 .04578 L
.80375 .04578 L
.8051 .04578 L
Mistroke
.81059 .04578 L
.82026 .04578 L
.86096 .04578 L
.90014 .04578 L
.94177 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`050000oooooooooooo06Ko00Coool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool01P000?ooooooooooool0V@1Vo`?oool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06
oooo00<0003oooooool01Oooo`030000oooooooo01;oool0043oool00`1Vooooooooo`1<oooo00<0
003oooooool0Boooo`03o`2I06Kooooo043oool0043oool00`1Vooooooooo`1<oooo00<0003ooooo
ool0Boooo`03o`2I06Kooooo043oool0043oool00`1Vooooooooo`1<oooo00<0003oooooool0Booo
o`03o`2I06Kooooo043oool0043oool00`1Vooooooooo`1<oooo00<0003oooooool0Boooo`03o`2I
06Kooooo043oool0043oool00`1Vooooooooo`1<oooo0P0004coool00ol0V@1Vooooo`10oooo0010
oooo00<0I_ooooooool0C?ooo`030000oooooooo04_oool00ol0V@1Vooooo`10oooo0010oooo00<0
I_ooooooool0C?ooo`030000oooooooo04_oool00ol0V@1Vooooo`10oooo0010oooo00<0I_oooooo
ool0C?ooo`030000oooooooo04_oool00ol0V@1Vooooo`10oooo0010oooo00<0I_ooooooool0C?oo
o`030000oooooooo04_oool00ol0V@1Vooooo`10oooo0010oooo00<0I_ooooooool0C?ooo`030000
oooooooo04_oool00ol0V@1Vooooo`10oooo0010oooo00<0I_ooooooool0C?ooo`80001<oooo00?o
09T0I_ooool0@?ooo`00@?ooo`0306Kooooooooo04coool00`000?ooooooo`1;oooo00?o09T0I_oo
ool0@?ooo`00@?ooo`0306Kooooooooo04coool00`000?ooooooo`1;oooo00?o09T0I_ooool0@?oo
o`00@?ooo`0306Kooooooooo04coool00`000?ooooooo`1;oooo00<0I_ooooooool0@?ooo`00@Ooo
o`0306Kooooooooo04_oool00`000?ooooooo`1;oooo00<0I_ooooooool0@?ooo`00@Oooo`0306Ko
oooooooo04_oool00`000?ooooooo`1;oooo00<0I_ooooooool0@?ooo`00@Oooo`0306Kooooooooo
04_oool20000C?ooo`0306Kooooooooo043oool0047oool00`1Vooooooooo`1;oooo00<0003ooooo
ool0Boooo`0306Kooooooooo043oool0047oool00`1Vooooooooo`1;oooo00<0003oooooool0Booo
o`0306Kooooooooo043oool0047oool00`1Vooooooooo`1;oooo00<0003oooooool0Boooo`0306Ko
oooooooo043oool0047oool00`1Vooooooooo`1;oooo00<0003oooooool0Boooo`0306Kooooooooo
043oool0047oool00`1Vooooooooo`1;oooo00<0003oooooool0Boooo`0306Kooooooooo043oool0
047oool00`1Vooooooooo`1;oooo0P0004coool00`1Vooooooooo`10oooo0011oooo00<0I_oooooo
ool0Boooo`030000oooooooo04_oool00`1Vooooooooo`10oooo0011oooo00<0I_ooooooool0Booo
o`030000oooooooo04_oool00`1Vooooooooo`10oooo0011oooo00<0I_ooooooool0Boooo`030000
oooooooo04_oool00`1Vooooooooo`10oooo0011oooo00<0I_ooooooool0>?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo04_oool00`1Vooooooooo`10oooo0011oooo00<0I_oooooo
ool0=oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo04_oool0
0`1Vooooooooo`10oooo0011oooo0P1VocSoool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0`0004[oool206Ko@_ooo`00@oooo`<0I_leoooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`17oooo0`1Vo`03ooooo`2Ioooo047oool004Koool306Ko<_ooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`14oooo0`1Vo`Coool00ol0VOooooooo`10
oooo0019oooo0P1Voc7oool200002_ooo`<00004oooo00<0003oooooool0@_ooo`80I_l7oooo00?o
09Woooooool0@?ooo`00Boooo`<0I_m1oooo00<0003oooooool0?oooo`<0I_l9oooo00?o09Wooooo
ool0@?ooo`00C_ooo`80I_looooo00<0003oooooool0?Oooo`80I_l<oooo00?o09Woooooool0@?oo
o`00D?ooo`80I_lmoooo0P0003coool206Ko3_ooo`03o`2Ioooooooo043oool005;oool206Ko>ooo
o`030000oooooooo03Woool206Ko4?ooo`03o`2Ioooooooo043oool005Coool206Ko>Oooo`030000
oooooooo03Ooool206Ko4_ooo`03o`2Ioooooooo043oool005Koool206Ko=oooo`030000oooooooo
03Goool206Ko5?ooo`03o`2Ioooooooo043oool005Soool206Ko=Oooo`030000oooooooo03?oool2
06Ko5_ooo`03o`2Ioooooooo043oool005[oool206Ko<oooo`80000boooo0P1VoaSoool00ol0VOoo
ooooo`10oooo001Loooo0P1Voc7oool00`000?ooooooo`0_oooo0P1Voa[oool00ol0VOooooooo`10
oooo001Noooo0P1Vobooool00`000?ooooooo`0]oooo0P1Voacoool00ol0VOooooooo`10oooo001P
oooo0P1Vobgoool00`000?ooooooo`0[oooo0P1Voakoool00ol0VOooooooo`10oooo001Roooo0P1V
ob_oool00`000?ooooooo`0Yoooo0P1Vob3oool00ol0VOooooooo`10oooo001Toooo0P1VobWoool0
0`000?ooooooo`0Woooo0P1Vob;oool00ol0VOooooooo`10oooo001Voooo00<0I_ooooooool09_oo
o`80000Voooo0P1VobCoool00ol0VOooooooo`10oooo001Woooo0P1VobKoool00`000?ooooooo`0S
oooo0P1VobKoool00ol0VOooooooo`10oooo001Yoooo0P1VobCoool00`000?ooooooo`0Roooo00<0
I_ooooooool09_ooo`03o`2Ioooooooo043oool006_oool00`1Vooooooooo`0Qoooo00<0003ooooo
ool08?ooo`80I_lYoooo00?o09Woooooool0@?ooo`00K?ooo`80I_lQoooo00<0003oooooool07_oo
o`80I_l[oooo00?o09Woooooool0@?ooo`00K_ooo`80I_lOoooo00<0003oooooool07Oooo`0306Ko
oooooooo02_oool00ol0VOooooooo`10oooo001`oooo00<0I_ooooooool07?ooo`80000Loooo0P1V
obkoool00ol0VOooooooo`10oooo001aoooo0P1Voacoool00`000?ooooooo`0Joooo00<0I_oooooo
ool0;_ooo`03o`2Ioooooooo043oool007?oool00`1Vooooooooo`0Ioooo00<0003oooooool06Ooo
o`0306Kooooooooo02ooool00ol0VOooooooo`10oooo001doooo0P1VoaWoool00`000?ooooooo`0G
oooo0P1Voc;oool00ol0VOooooooo`10oooo001foooo0P1Vo`ooool500000oooo`030000oooooooo
01Koool00`1Vooooooooo`0boooo00?o09Woooooool0@?ooo`00N?ooo`0306Kooooooooo00koool0
0`000?ooooooo`03oooo00<0003oooooool05Oooo`0306Kooooooooo03?oool00ol0VOooooooo`10
oooo001ioooo0P1Vo`koool00`000?ooooooo`03oooo0`0001?oool206Ko=_ooo`03o`2Ioooooooo
043oool007_oool00`1Vooooooooo`0;oooo00<0003oooooool00oooo`030000oooooooo01;oool0
0`1Vooooooooo`0foooo00?o09Woooooool0@?ooo`00O?ooo`0306Kooooooooo00[oool00`000?oo
ooooo`03oooo00<0003oooooool04?ooo`80I_lioooo00?o09Woooooool0@?ooo`00OOooo`80I_l9
oooo0P0000Goool00`000?ooooooo`0?oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo043oool0
07ooool00`1Vooooooooo`0=oooo00<0003oooooool03_ooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`10oooo0020oooo00<0I_ooooooool03?ooo`030000oooooooo00coool206Ko?Oooo`03o`2I
oooooooo043oool0087oool00`1Vooooooooo`0;oooo0P0000coool00`1Vooooooooo`0moooo00?o
09Woooooool0@?ooo`00P_ooo`80I_l;oooo00<0003oooooool02Oooo`80I_m0oooo00?o09Wooooo
ool0@?ooo`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`08oooo00<0I_ooooooool0@?oo
o`03o`2Ioooooooo043oool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Ko
oooooooo047oool00ol0VOooooooo`10oooo0026oooo00<0I_ooooooool01_ooo`030000oooooooo
00Koool00`1Vooooooooo`12oooo00?o09Woooooool0@?ooo`00Qoooo`80I_l6oooo00<0003ooooo
ool01?ooo`80I_m5oooo00?o09Woooooool0@?ooo`00ROooo`0306Kooooooooo00?oool200001?oo
o`0306Kooooooooo04Goool00ol0VOooooooo`10oooo002:oooo00<0I_ooooooool00_ooo`030000
oooooooo00;oool00`1Vooooooooo`16oooo00?o09Woooooool0@?ooo`00Roooo`0506Kooooooooo
oooo000000?oool00`1Vooooooooo`17oooo00?o09Woooooool0@?ooo`00S?ooo`0406Kooooooooo
00000_ooo`0306Kooooooooo04Soool00ol0VOooooooo`10oooo002=oooo00<0I_ooool000000P1V
od_oool00ol0VOooooooo`10oooo002>oooo00<0I_l00000I_l0C?ooo`03o`2Ioooooooo043oool0
08ooool20000C?ooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003ooooo
ool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo001koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0Boooo`03o`2Ioooooooo
043oool007goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0Booo
o`03o`2Ioooooooo043oool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0001;
oooo00?o09Woooooool0@?ooo`00OOooo`030000oooooooo00Soool200001Oooo`030000oooooooo
04_oool00ol0VOooooooo`10oooo001moooo00<0003oooooool02?ooo`030000oooooooo00Coool0
0`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00O?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000
oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo
043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo
04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0
003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003ooooo
ool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00Soooo`80001<oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000
oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo
043oool008Ooool400001?ooo`030000oooooooo04_oool00ol0VOooooooo`10oooo0027oooo00<0
003oooooool01Oooo`030000oooooooo04_oool00ol0VOooooooo`10oooo0028oooo00<0003ooooo
ool01?ooo`<0001;oooo00?o09Woooooool0@?ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo
04_oool00ol0VOooooooo`10oooo0028oooo0P0000Goool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003ooooo
ool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool008ooool0
0`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?oo
ooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000
oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo
043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`80001<oooo00?o
09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0
003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003ooooo
ool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool008ooool0
0`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool007_oool400000ooo
o`800004oooo0P0000Goool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Noooo`030000
oooooooo00Woool010000?ooooooo`0000Coool00`000?ooooooo`1;oooo00?o09Woooooool0@?oo
o`00O?ooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`0004_oool00ol0VOooooooo`10
oooo001moooo00<0003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0
003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`@00003oooo0P0000?oool300001?ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?oo
ooooo`0;oooo00<0003oooooool00_ooo`030000oooooooo07_oool007[oool00`000?ooooooo`02
oooo00<0003oooooool03_ooo`030000oooooooo00Woool300001?ooo`030000oooooooo07[oool0
07_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P00
00[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.7878 .04578 L
.79892 .04578 L
.80403 .04578 L
.80682 .04578 L
.80819 .04578 L
.80943 .04578 L
s
.80943 .04578 m
.80971 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.16408 .04578 L
.17277 .04578 L
.18221 .04578 L
.18475 .04578 L
.18744 .04578 L
.18855 .04578 L
.18974 .04578 L
.19104 .16044 L
.19227 .16088 L
.20178 .16438 L
.22272 .17247 L
.26394 .19003 L
.30365 .20925 L
.34184 .23015 L
.38249 .25533 L
.42162 .28282 L
.4632 .316 L
.47335 .32477 L
.48407 .33436 L
.49322 .3428 L
.49573 .34515 L
.49711 .34646 L
.49842 .3477 L
.49963 .34886 L
.50095 .3483 L
.50215 .34716 L
.50327 .3461 L
.54182 .31176 L
.58108 .28081 L
.61883 .25446 L
.65904 .22964 L
.69772 .20855 L
.73886 .18876 L
.75939 .17981 L
.77849 .17198 L
.79691 .16487 L
.80222 .1629 L
.80482 .16194 L
.80723 .16106 L
.80835 .16065 L
.80941 .16027 L
.81051 .04578 L
.81172 .04578 L
.8166 .04578 L
.85542 .04578 L
.8967 .04578 L
Mistroke
.93646 .04578 L
.9747 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooo06Ko00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`03oooo00Co09T0I_ooool00007
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo01;oool003koool00`1Vooooooooo`1>oooo00<0003oooooool0COoo
o`03o`2I06Kooooo03koool003koool00`1Vooooooooo`1>oooo00<0003oooooool0COooo`03o`2I
06Kooooo03koool003koool00`1Vooooooooo`1>oooo00<0003oooooool0COooo`03o`2I06Kooooo
03koool003koool00`1Vooooooooo`1>oooo00<0003oooooool0COooo`03o`2I06Kooooo03koool0
03koool00`1Vooooooooo`1>oooo0P0004koool00ol0V@1Vooooo`0noooo000noooo00<0I_oooooo
ool0C_ooo`030000oooooooo04goool00ol0V@1Vooooo`0noooo000noooo00<0I_ooooooool0C_oo
o`030000oooooooo04goool00ol0V@1Vooooo`0noooo000noooo00<0I_ooooooool0C_ooo`030000
oooooooo04goool00ol0V@1Vooooo`0noooo000noooo00<0I_ooooooool0C_ooo`030000oooooooo
04goool00ol0V@1Vooooo`0noooo000noooo00<0I_ooooooool0C_ooo`030000oooooooo04goool0
0ol0V@1Vooooo`0noooo000noooo00<0I_ooooooool0C_ooo`80001>oooo00?o09T0I_ooool0?_oo
o`00?_ooo`0306Kooooooooo04koool00`000?ooooooo`1=oooo00?o09T0I_ooool0?_ooo`00?_oo
o`0306Kooooooooo04koool00`000?ooooooo`1=oooo00?o09T0I_ooool0?_ooo`00?_ooo`0306Ko
oooooooo04koool00`000?ooooooo`1=oooo00<0I_ooooooool0?_ooo`00?oooo`0306Kooooooooo
04goool00`000?ooooooo`1=oooo00<0I_ooooooool0?_ooo`00?oooo`0306Kooooooooo04goool0
0`000?ooooooo`1=oooo00<0I_ooooooool0?_ooo`00?oooo`0306Kooooooooo04goool20000C_oo
o`0306Kooooooooo03koool003ooool00`1Vooooooooo`1=oooo00<0003oooooool0COooo`0306Ko
oooooooo03koool003ooool00`1Vooooooooo`1=oooo00<0003oooooool0COooo`0306Kooooooooo
03koool003ooool00`1Vooooooooo`1=oooo00<0003oooooool0COooo`0306Kooooooooo03koool0
03ooool00`1Vooooooooo`1=oooo00<0003oooooool0COooo`0306Kooooooooo03koool003ooool0
0`1Vooooooooo`1=oooo00<0003oooooool0COooo`0306Kooooooooo03koool003ooool00`1Voooo
ooooo`1=oooo0P0004koool00`1Vooooooooo`0noooo000ooooo00<0I_ooooooool0COooo`030000
oooooooo04goool00`1Vooooooooo`0noooo000ooooo00<0I_ooooooool0COooo`030000oooooooo
04goool00`1Vooooooooo`0noooo000ooooo00<0I_ooooooool0COooo`030000oooooooo04goool0
0`1Vooooooooo`0noooo000ooooo00<0I_ooooooool0>_ooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo04goool00`1Vooooooooo`0noooo000ooooo00<0I_ooooooool0>Oooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo04goool00`1Vooooooooo`0n
oooo000ooooo00<0I_ooooooool0>Oooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000C?ooo`80I_m0oooo0010oooo0`1VocSoool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo04Woool306Ko00?ooooo09Woool0?oooo`00@oooo`<0I_leoooo00@0003oooooool00009
oooo00<0003oooooool01?ooo`030000oooooooo04Ooool206Ko1?ooo`03o`2Ioooooooo03koool0
04Koool306Ko<oooo`80000:oooo0`0000Coool00`000?ooooooo`14oooo0`1Vo`Koool00ol0VOoo
ooooo`0noooo0019oooo0`1Vod?oool00`000?ooooooo`12oooo0P1Vo`Woool00ol0VOooooooo`0n
oooo001<oooo0P1Vod7oool00`000?ooooooo`0ooooo0`1Vo`_oool00ol0VOooooooo`0noooo001>
oooo0`1Vockoool20000?_ooo`80I_l>oooo00?o09Woooooool0?_ooo`00DOooo`80I_lloooo00<0
003oooooool0>_ooo`<0I_l@oooo00?o09Woooooool0?_ooo`00Doooo`80I_ljoooo00<0003ooooo
ool0>?ooo`80I_lCoooo00?o09Woooooool0?_ooo`00EOooo`80I_lhoooo00<0003oooooool0=_oo
o`80I_lEoooo00?o09Woooooool0?_ooo`00Eoooo`80I_lfoooo00<0003oooooool0=?ooo`80I_lG
oooo00?o09Woooooool0?_ooo`00FOooo`80I_ldoooo0P0003?oool206Ko6Oooo`03o`2Ioooooooo
03koool005_oool206Ko<_ooo`030000oooooooo033oool206Ko6oooo`03o`2Ioooooooo03koool0
05goool206Ko<?ooo`030000oooooooo02koool206Ko7Oooo`03o`2Ioooooooo03koool005ooool2
06Ko;_ooo`030000oooooooo02coool206Ko7oooo`03o`2Ioooooooo03koool0067oool00`1Voooo
ooooo`0[oooo00<0003oooooool0:oooo`0306Kooooooooo01ooool00ol0VOooooooo`0noooo001R
oooo0P1Vob_oool00`000?ooooooo`0Yoooo0P1Vob;oool00ol0VOooooooo`0noooo001Toooo0P1V
obWoool20000:?ooo`80I_lToooo00?o09Woooooool0?_ooo`00I_ooo`0306Kooooooooo02Koool0
0`000?ooooooo`0Voooo00<0I_ooooooool09?ooo`03o`2Ioooooooo03koool006Ooool206Ko9_oo
o`030000oooooooo02Coool206Ko9oooo`03o`2Ioooooooo03koool006Woool206Ko9?ooo`030000
oooooooo02;oool206Ko:Oooo`03o`2Ioooooooo03koool006_oool00`1Vooooooooo`0Qoooo00<0
003oooooool08Oooo`0306Kooooooooo02Woool00ol0VOooooooo`0noooo001/oooo0P1Vob7oool0
0`000?ooooooo`0Ooooo0P1Vobcoool00ol0VOooooooo`0noooo001^oooo0P1Voaooool200007_oo
o`80I_l^oooo00?o09Woooooool0?_ooo`00L?ooo`0306Kooooooooo01coool00`000?ooooooo`0L
oooo00<0I_ooooooool0;_ooo`03o`2Ioooooooo03koool0077oool206Ko7?ooo`030000oooooooo
01[oool206Ko<Oooo`03o`2Ioooooooo03koool007?oool00`1Vooooooooo`0Ioooo00<0003ooooo
ool06Oooo`0306Kooooooooo037oool00ol0VOooooooo`0noooo001doooo0P1Voa7oool500000ooo
o`030000oooooooo01Soool00`1Vooooooooo`0boooo00?o09Woooooool0?_ooo`00M_ooo`80I_lA
oooo00<0003oooooool00oooo`030000oooooooo01Koool206Ko=Oooo`03o`2Ioooooooo03koool0
07Soool00`1Vooooooooo`0>oooo00<0003oooooool00oooo`<0000Eoooo00<0I_ooooooool0=Ooo
o`03o`2Ioooooooo03koool007Woool206Ko3_ooo`030000oooooooo00?oool00`000?ooooooo`0C
oooo0P1VocSoool00ol0VOooooooo`0noooo001koooo00<0I_ooooooool02oooo`030000oooooooo
00?oool00`000?ooooooo`0Boooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo03koool007coool0
0`1Vooooooooo`09oooo0P0000Goool00`000?ooooooo`0Aoooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo03koool007goool00`1Vooooooooo`0?oooo00<0003oooooool03oooo`80I_lloooo00?o
09Woooooool0?_ooo`00O_ooo`0306Kooooooooo00koool00`000?ooooooo`0>oooo00<0I_oooooo
ool0??ooo`03o`2Ioooooooo03koool007ooool00`1Vooooooooo`0=oooo0P0000koool00`1Voooo
ooooo`0moooo00?o09Woooooool0?_ooo`00P?ooo`80I_l=oooo00<0003oooooool03?ooo`0306Ko
oooooooo03koool00ol0VOooooooo`0noooo0022oooo00<0I_ooooooool02_ooo`030000oooooooo
00[oool206Ko@Oooo`03o`2Ioooooooo03koool008?oool00`1Vooooooooo`09oooo00<0003ooooo
ool02Oooo`0306Kooooooooo047oool00ol0VOooooooo`0noooo0024oooo00<0I_ooooooool02?oo
o`030000oooooooo00Soool00`1Vooooooooo`12oooo00?o09Woooooool0?_ooo`00QOooo`0306Ko
oooooooo00Ooool00`000?ooooooo`07oooo00<0I_ooooooool0@oooo`03o`2Ioooooooo03koool0
08Koool206Ko1oooo`800007oooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo03koool008Soool0
0`1Vooooooooo`04oooo00<0003oooooool01Oooo`0306Kooooooooo04Goool00ol0VOooooooo`0n
oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00Coool00`1Vooooooooo`16oooo00?o
09Woooooool0?_ooo`00R_ooo`0306Kooooooooo00;oool00`000?ooooooo`02oooo0P1VodWoool0
0ol0VOooooooo`0noooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo04[oool0
0ol0VOooooooo`0moooo002<oooo00@0I_ooooooool00002oooo00<0I_ooooooool0Boooo`03o`2I
oooooooo03goool008goool01@1Vooooo`000000001Vo`1>oooo00?o09Woooooool0?Oooo`00S_oo
o`0306Ko000006Ko04ooool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2I
oooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000
oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo
03goool008ooool20000Coooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o
09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0
003oooooool0C_ooo`03o`2Ioooooooo03goool007_oool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00OOooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00OOooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`0004koool00ol0VOooooooo`0moooo001moooo00<0003ooooo
ool02?ooo`800005oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool007goool00`000?oo
ooooo`08oooo00<0003oooooool01?ooo`030000oooooooo04koool00ol0VOooooooo`0moooo001l
oooo0P0000[oool300001?ooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0
003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Wooooo
ool0?Oooo`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool0
0ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool0
0`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOoo
ooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool20000Cooo
o`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Sooo
o`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2I
oooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000
oooooooo04koool00ol0VOooooooo`0moooo002?oooo0P0004ooool00ol0VOooooooo`0moooo002?
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o
09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0
003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Wooooo
ool0?Oooo`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool0
0ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool0
0`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Qoooo`@00004oooo00<0003oooooool0C_oo
o`03o`2Ioooooooo03goool008Ooool00`000?ooooooo`05oooo00<0003oooooool0C_ooo`03o`2I
oooooooo03goool008Soool00`000?ooooooo`04oooo0`0004koool00ol0VOooooooo`0moooo0029
oooo00<0003oooooool00oooo`030000oooooooo04koool00ol0VOooooooo`0moooo0027oooo00@0
003oooooool00004oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008Soool200001Ooo
o`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2I
oooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`80001?
oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o
09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0
003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool20000Coooo`03o`2Ioooooooo03goool0
08ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool0
0ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool0
0`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOoo
ooooo`0moooo002?oooo0P0004ooool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_oo
o`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Sooo
o`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2I
oooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`80001?
oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o
09Woooooool0?Oooo`00Noooo`@00003oooo0P0000Coool200001Oooo`030000oooooooo04koool0
0ol0VOooooooo`0moooo001koooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000
oooooooo04koool00ol0VOooooooo`0moooo001loooo00<0003oooooool02oooo`030000oooooooo
00;oool30000C_ooo`03o`2Ioooooooo03goool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool0
07Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200000oooo`<00004
oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02oooo`050000oooooooooooo0000
00;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo
00koool00`000?ooooooo`09oooo0`0000Goool00`000?ooooooo`02oooo00<0003oooooool0Mooo
o`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000oooooooo00000ooo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.7878 .04578 L
.79892 .04578 L
.80403 .04578 L
.80943 .04578 L
.81404 .04578 L
.8153 .04578 L
.81599 .04578 L
.81665 .04578 L
s
.81665 .04578 m
.81697 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.16408 .04578 L
.17277 .04578 L
.17735 .04578 L
.17986 .04578 L
.18109 .04578 L
.18221 .04578 L
.18341 .16054 L
.1847 .16101 L
.18744 .16201 L
.19227 .16379 L
.20178 .16738 L
.22272 .17567 L
.26243 .19298 L
.30062 .2118 L
.34126 .23447 L
.38039 .25923 L
.42198 .2891 L
.46204 .32183 L
.48042 .33828 L
.49085 .34805 L
.49595 .35294 L
.49712 .35408 L
.49836 .35529 L
.49942 .35632 L
.50059 .35631 L
.50181 .35512 L
.50296 .354 L
.50553 .35151 L
.51022 .34704 L
.52053 .33741 L
.5416 .31868 L
.58028 .28737 L
.62142 .25801 L
.66105 .23311 L
.69916 .21192 L
.73972 .19199 L
.77876 .17507 L
.789 .17096 L
.80011 .16666 L
.8052 .16474 L
.81059 .16273 L
.81281 .16192 L
.8152 .16105 L
.8159 .1608 L
.81656 .16055 L
.81781 .04578 L
Mistroke
.81898 .04578 L
.82026 .04578 L
.86096 .04578 L
.90014 .04578 L
.94177 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00?o09T0003oool01_oo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo04ooool0
0ol0V@1Vooooo`0loooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo04ooool00ol0V@1V
ooooo`0loooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo04ooool00ol0V@1Vooooo`0l
oooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo04ooool00ol0V@1Vooooo`0loooo000l
oooo00<0I_ooooooool0D?ooo`80001@oooo00?o09T0I_ooool0??ooo`00??ooo`0306Kooooooooo
053oool00`000?ooooooo`1?oooo00?o09T0I_ooool0??ooo`00??ooo`0306Kooooooooo053oool0
0`000?ooooooo`1?oooo00?o09T0I_ooool0??ooo`00??ooo`0306Kooooooooo053oool00`000?oo
ooooo`1?oooo00?o09T0I_ooool0??ooo`00??ooo`0306Kooooooooo053oool00`000?ooooooo`1?
oooo00?o09T0I_ooool0??ooo`00??ooo`0306Kooooooooo053oool00`000?ooooooo`1?oooo00?o
09T0I_ooool0??ooo`00??ooo`0306Kooooooooo053oool20000D?ooo`03o`2I06Kooooo03coool0
03coool00`1Vooooooooo`1@oooo00<0003oooooool0Coooo`03o`2I06Kooooo03coool003coool0
0`1Vooooooooo`1@oooo00<0003oooooool0Coooo`03o`2I06Kooooo03coool003coool00`1Voooo
ooooo`1@oooo00<0003oooooool0Coooo`0306Kooooooooo03coool003goool00`1Vooooooooo`1?
oooo00<0003oooooool0Coooo`0306Kooooooooo03coool003goool00`1Vooooooooo`1?oooo00<0
003oooooool0Coooo`0306Kooooooooo03coool003goool00`1Vooooooooo`1?oooo0P00053oool0
0`1Vooooooooo`0loooo000moooo00<0I_ooooooool0Coooo`030000oooooooo04ooool00`1Voooo
ooooo`0loooo000moooo00<0I_ooooooool0Coooo`030000oooooooo04ooool00`1Vooooooooo`0l
oooo000moooo00<0I_ooooooool0Coooo`030000oooooooo04ooool00`1Vooooooooo`0loooo000m
oooo00<0I_ooooooool0Coooo`030000oooooooo04ooool00`1Vooooooooo`0loooo000moooo00<0
I_ooooooool0Coooo`030000oooooooo04ooool00`1Vooooooooo`0loooo000moooo00<0I_oooooo
ool0Coooo`80001@oooo00<0I_ooooooool0??ooo`00?Oooo`0306Kooooooooo04ooool00`000?oo
ooooo`1?oooo00<0I_ooooooool0??ooo`00?Oooo`0306Kooooooooo04ooool00`000?ooooooo`1?
oooo00<0I_ooooooool0??ooo`00?Oooo`0306Kooooooooo04ooool00`000?ooooooo`1?oooo00<0
I_ooooooool0??ooo`00?Oooo`0306Kooooooooo03coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1?oooo00<0I_ooooooool0??ooo`00?Oooo`0306Kooooooooo03_oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1?oooo00<0I_ooooooool0??oo
o`00?Oooo`80I_lloooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001>oooo0P1V
ockoool003ooool306Ko>Oooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0B_oo
o`@0I_l00oooool0VOooo`0moooo0012oooo0P1VocOoool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0Aoooo`<0I_l5oooo00?o09Woooooool0??ooo`00A?ooo`80I_lf
oooo0P0000[oool300001?ooo`030000oooooooo04Goool206Ko2?ooo`03o`2Ioooooooo03coool0
04Koool306KoA_ooo`030000oooooooo04?oool206Ko2_ooo`03o`2Ioooooooo03coool004Woool2
06KoA?ooo`030000oooooooo047oool206Ko3?ooo`03o`2Ioooooooo03coool004_oool306Ko@Ooo
o`800010oooo0P1Vo`koool00ol0VOooooooo`0loooo001>oooo0P1Vocooool00`000?ooooooo`0m
oooo0P1Voa3oool00ol0VOooooooo`0loooo001@oooo0P1Vocgoool00`000?ooooooo`0koooo0P1V
oa;oool00ol0VOooooooo`0loooo001Boooo0P1Voc_oool00`000?ooooooo`0ioooo0P1VoaCoool0
0ol0VOooooooo`0loooo001Doooo0P1VocWoool00`000?ooooooo`0goooo0P1VoaKoool00ol0VOoo
ooooo`0loooo001Foooo0P1VocOoool20000=_ooo`80I_lHoooo00?o09Woooooool0??ooo`00F?oo
o`80I_leoooo00<0003oooooool0<oooo`80I_lJoooo00?o09Woooooool0??ooo`00F_ooo`80I_lc
oooo00<0003oooooool0<Oooo`80I_lLoooo00?o09Woooooool0??ooo`00G?ooo`80I_laoooo00<0
003oooooool0;oooo`80I_lNoooo00?o09Woooooool0??ooo`00G_ooo`80I_l_oooo00<0003ooooo
ool0;Oooo`80I_lPoooo00?o09Woooooool0??ooo`00H?ooo`80I_l]oooo00<0003oooooool0;?oo
o`0306Kooooooooo023oool00ol0VOooooooo`0loooo001Roooo0P1Vob_oool20000:oooo`80I_lS
oooo00?o09Woooooool0??ooo`00I?ooo`80I_lYoooo00<0003oooooool0:?ooo`80I_lUoooo00?o
09Woooooool0??ooo`00I_ooo`0306Kooooooooo02Koool00`000?ooooooo`0Woooo00<0I_oooooo
ool09Oooo`03o`2Ioooooooo03coool006Ooool206Ko9_ooo`030000oooooooo02Goool206Ko:?oo
o`03o`2Ioooooooo03coool006Woool206Ko9?ooo`030000oooooooo02?oool206Ko:_ooo`03o`2I
oooooooo03coool006_oool00`1Vooooooooo`0Qoooo00<0003oooooool08_ooo`0306Kooooooooo
02[oool00ol0VOooooooo`0loooo001/oooo0P1Vob7oool200008Oooo`80I_l]oooo00?o09Wooooo
ool0??ooo`00K_ooo`80I_lOoooo00<0003oooooool07_ooo`80I_l_oooo00?o09Woooooool0??oo
o`00L?ooo`0306Kooooooooo01coool00`000?ooooooo`0Moooo00<0I_ooooooool0;oooo`03o`2I
oooooooo03coool0077oool206Ko7?ooo`030000oooooooo01_oool206Ko<_ooo`03o`2Ioooooooo
03coool007?oool00`1Vooooooooo`0Aoooo1@0000?oool00`000?ooooooo`0Joooo00<0I_oooooo
ool0<_ooo`03o`2Ioooooooo03coool007Coool00`1Vooooooooo`0Boooo00<0003oooooool00ooo
o`030000oooooooo01Woool00`1Vooooooooo`0coooo00?o09Woooooool0??ooo`00MOooo`80I_lB
oooo00<0003oooooool00oooo`<0000Goooo0P1VocKoool00ol0VOooooooo`0loooo001goooo00<0
I_ooooooool03oooo`030000oooooooo00?oool00`000?ooooooo`0Foooo00<0I_ooooooool0=_oo
o`03o`2Ioooooooo03coool007Soool00`1Vooooooooo`0>oooo00<0003oooooool00oooo`030000
oooooooo01Goool00`1Vooooooooo`0goooo00?o09Woooooool0??ooo`00NOooo`80I_l=oooo0P00
00Goool00`000?ooooooo`0Coooo0P1Voc[oool00ol0VOooooooo`0loooo001koooo00<0I_oooooo
ool04Oooo`030000oooooooo01;oool00`1Vooooooooo`0joooo00?o09Woooooool0??ooo`00O?oo
o`0306Kooooooooo013oool00`000?ooooooo`0Aoooo00<0I_ooooooool0>oooo`03o`2Ioooooooo
03coool007goool00`1Vooooooooo`0?oooo0P00013oool206Ko?_ooo`03o`2Ioooooooo03coool0
07koool00`1Vooooooooo`0>oooo00<0003oooooool03_ooo`0306Kooooooooo03koool00ol0VOoo
ooooo`0loooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo00goool00`1Vooooooooo`0o
oooo00?o09Woooooool0??ooo`00P?ooo`80I_l=oooo00<0003oooooool03?ooo`0306Kooooooooo
043oool00ol0VOooooooo`0loooo0022oooo00<0I_ooooooool02_ooo`030000oooooooo00[oool2
06Ko@oooo`03o`2Ioooooooo03coool008?oool00`1Vooooooooo`09oooo00<0003oooooool02Ooo
o`0306Kooooooooo04?oool00ol0VOooooooo`0loooo0024oooo00<0I_ooooooool02?ooo`800009
oooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo03coool008Goool00`1Vooooooooo`07oooo00<0
003oooooool01oooo`0306Kooooooooo04Goool00ol0VOooooooo`0loooo0026oooo00<0I_oooooo
ool01_ooo`030000oooooooo00Koool00`1Vooooooooo`16oooo00?o09Woooooool0??ooo`00Qooo
o`80I_l6oooo00<0003oooooool01?ooo`80I_m9oooo00?o09Woooooool0??ooo`00ROooo`0306Ko
oooooooo00?oool00`000?ooooooo`03oooo00<0I_ooooooool0BOooo`03o`2Ioooooooo03coool0
08[oool00`1Vooooooooo`02oooo00<0003oooooool00_ooo`0306Kooooooooo04[oool00ol0VOoo
ooooo`0loooo002;oooo0P1Vo`;oool200000_ooo`0306Kooooooooo04_oool00ol0VOooooooo`0l
oooo002=oooo00<0I_ooool000000_ooo`0306Kooooooooo04coool00ol0VOooooooo`0loooo002=
oooo00<0I_ooool000000P1Vodooool00ol0VOooooooo`0loooo002>oooo00<0I_l00000I_l0D?oo
o`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Sooo
o`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo0P00053oool00ol0VOooooooo`0l
oooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?
oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo001k
oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool0
07goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0Coooo`03o`2I
oooooooo03coool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0001?oooo00?o
09Woooooool0??ooo`00OOooo`030000oooooooo00Soool200001Oooo`030000oooooooo04ooool0
0ol0VOooooooo`0loooo001moooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?oo
ooooo`1?oooo00?o09Woooooool0??ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`1?
oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?
oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool20000D?ooo`03o`2Ioooooooo
03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo
04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool0
08ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool0
0ol0VOooooooo`0loooo002?oooo0P00053oool00ol0VOooooooo`0loooo002?oooo00<0003ooooo
ool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??oo
o`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Cooo
o`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Sooo
o`80001@oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0l
oooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?
oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?
oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool20000D?ooo`03o`2Ioooooooo
03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo
04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool0
08Ooool400001?ooo`030000oooooooo04ooool00ol0VOooooooo`0loooo0027oooo00<0003ooooo
ool01Oooo`030000oooooooo04ooool00ol0VOooooooo`0loooo0028oooo00<0003oooooool01?oo
o`<0001?oooo00?o09Woooooool0??ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1?
oooo00?o09Woooooool0??ooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo04ooool0
0ol0VOooooooo`0loooo0028oooo0P0000Goool00`000?ooooooo`1?oooo00?o09Woooooool0??oo
o`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Cooo
o`03o`2Ioooooooo03coool008ooool20000D?ooo`03o`2Ioooooooo03coool008ooool00`000?oo
ooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0l
oooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?
oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?
oooo0P00053oool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo
03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo
04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool0
08ooool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`80001@oooo00?o09Wooooo
ool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003ooooo
ool0Coooo`03o`2Ioooooooo03coool008ooool00`000?ooooooo`1?oooo00?o09Woooooool0??oo
o`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0loooo002?oooo00<0003oooooool0Cooo
o`03o`2Ioooooooo03coool008ooool20000D?ooo`03o`2Ioooooooo03coool008ooool00`000?oo
ooooo`1?oooo00?o09Woooooool0??ooo`00Soooo`030000oooooooo04ooool00ol0VOooooooo`0l
oooo002?oooo00<0003oooooool0Coooo`03o`2Ioooooooo03coool007_oool400000oooo`800004
oooo0P0000Goool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00Noooo`030000oooooooo
00Woool010000?ooooooo`0000Coool00`000?ooooooo`1?oooo00?o09Woooooool0??ooo`00O?oo
o`030000oooooooo00_oool00`000?ooooooo`02oooo0`0004ooool00ol0VOooooooo`0loooo001m
oooo00<0003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003ooooo
ool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00Ooooo`030000
oooooooo01coool00`000?ooooooo`1ooooo001noooo00<0003oooooool02?ooo`030000oooooooo
01?oool00`000?ooooooo`1noooo001noooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004oooo0P0000Coool00`000?ooooooo`1noooo001noooo00D0003oooooooooool0
00000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00009oooo00<0
003oooooool0O_ooo`00OOooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool02Oooo`030000oooooooo07goool007koool00`000?ooooooo`0500003oooo`030000oooooooo
00Ooool00`000?ooooooo`1noooo001noooo00D0003oooooooooool000003oooo`040000oooooooo
00002Oooo`030000oooooooo07koool007ooool00`000?ooooooo`0Aoooo0P0000Woool00`000?oo
ooooo`1ooooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.79749 .04578 L
.80799 .04578 L
.81373 .04578 L
.81909 .04578 L
.82156 .04578 L
.8239 .04578 L
.82518 .04578 L
s
.82518 .04578 m
.82537 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.12507 .04578 L
.14415 .04578 L
.16254 .04578 L
.16783 .04578 L
.17044 .04578 L
.17158 .04578 L
.17284 .04578 L
.17396 .04578 L
.17502 .16038 L
.17613 .16078 L
.17733 .16122 L
.18221 .16301 L
.22343 .17926 L
.26314 .19705 L
.30133 .21638 L
.34198 .23969 L
.38111 .26512 L
.42269 .29582 L
.46276 .32946 L
.48114 .34636 L
.49157 .3564 L
.49418 .35898 L
.49666 .36143 L
.49889 .36365 L
.50015 .36462 L
.50131 .36345 L
.51093 .35397 L
.52125 .34412 L
.54231 .32496 L
.58158 .29248 L
.61933 .26482 L
.65953 .23877 L
.69822 .21662 L
.73936 .19586 L
.77898 .17825 L
.79895 .17017 L
.80765 .16681 L
.81709 .16326 L
.81964 .16233 L
.82234 .16134 L
.82345 .16093 L
.82464 .1605 L
.82595 .04578 L
.82718 .04578 L
.8367 .04578 L
.85765 .04578 L
.89893 .04578 L
Mistroke
.93869 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool00oooo`0306Kooooo000000Soool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oool0I_l01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo05;oool0
0`1Vooooooooo`0ioooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo05;oool00`1Voooo
ooooo`0ioooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo05;oool00`1Vooooooooo`0i
oooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo05;oool00`1Vooooooooo`0ioooo000j
oooo00<0I_ooooooool0D_ooo`80001Coooo00<0I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo
05;oool00`000?ooooooo`1Boooo00<0I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo05;oool0
0`000?ooooooo`1Boooo00<0I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo05;oool00`000?oo
ooooo`1Boooo00<0I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`1B
oooo00<0I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`1Boooo00<0
I_ooooooool0>Oooo`00>_ooo`0306Kooooooooo05;oool20000Doooo`0306Kooooooooo03Woool0
03[oool00`1Vooooooooo`1Boooo00<0003oooooool0D_ooo`0306Kooooooooo03Woool003[oool0
0`1Vooooooooo`1Boooo00<0003oooooool0D_ooo`0306Kooooooooo03Woool003[oool00`1Voooo
ooooo`1Boooo00<0003oooooool0DOooo`0306Koo`2Ioooo03[oool003[oool00`1Vooooooooo`1B
oooo00<0003oooooool0DOooo`0306Koo`2Ioooo03[oool003[oool00`1Vooooooooo`1Boooo00<0
003oooooool0DOooo`0306Koo`2Ioooo03[oool003[oool00`1Vooooooooo`1Boooo0P0005;oool0
0`1Vool0VOooo`0joooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo057oool00`1Vool0
VOooo`0joooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo057oool00`1Vool0VOooo`0j
oooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo057oool00`1Vool0VOooo`0joooo000j
oooo00<0I_ooooooool0D_ooo`030000oooooooo057oool00`1Vool0VOooo`0joooo000joooo00<0
I_ooooooool0D_ooo`030000oooooooo057oool00`1Vool0VOooo`0joooo000joooo00<0I_oooooo
ool0D_ooo`80001Boooo00<0I_oo09Woool0>_ooo`00>_ooo`0306Kooooooooo05;oool00`000?oo
ooooo`1Aoooo00<0I_oo09Woool0>_ooo`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`1A
oooo00<0I_oo09Woool0>_ooo`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`1Aoooo00<0
I_oo09Woool0>_ooo`00>_ooo`0306Kooooooooo03ooool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Aoooo00<0I_oo09Woool0>_ooo`00>_ooo`0306Kooooooooo03koool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Aoooo00<0I_oo09Woool0>_oo
o`00>_ooo`@0I_lmoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001?oooo0`1V
o`03o`2Ioooooooo03Woool003koool206Ko>oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0COooo`80I_l3oooo00?o09Woooooool0>Oooo`00@?ooo`80I_lioooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo04[oool306Ko1Oooo`03o`2Ioooooooo
03Woool004;oool206Ko>?ooo`80000:oooo0`0000Coool00`000?ooooooo`18oooo0P1Vo`Soool0
0ol0VOooooooo`0ioooo0014oooo0P1VodWoool00`000?ooooooo`15oooo0`1Vo`[oool00ol0VOoo
ooooo`0ioooo0016oooo0`1VodKoool00`000?ooooooo`13oooo0P1Vo`goool00ol0VOooooooo`0i
oooo0019oooo0P1VodCoool20000@_ooo`80I_l?oooo00?o09Woooooool0>Oooo`00Boooo`<0I_m1
oooo00<0003oooooool0?oooo`80I_lAoooo00?o09Woooooool0>Oooo`00C_ooo`80I_looooo00<0
003oooooool0?Oooo`80I_lCoooo00?o09Woooooool0>Oooo`00D?ooo`80I_lmoooo00<0003ooooo
ool0>oooo`80I_lEoooo00?o09Woooooool0>Oooo`00D_ooo`80I_lkoooo00<0003oooooool0>Ooo
o`80I_lGoooo00?o09Woooooool0>Oooo`00E?ooo`80I_lioooo0P0003Soool206Ko6Oooo`03o`2I
oooooooo03Woool005Koool206Ko=oooo`030000oooooooo03Goool206Ko6oooo`03o`2Ioooooooo
03Woool005Soool206Ko=Oooo`030000oooooooo03?oool206Ko7Oooo`03o`2Ioooooooo03Woool0
05[oool206Ko<oooo`030000oooooooo037oool206Ko7oooo`03o`2Ioooooooo03Woool005coool2
06Ko<Oooo`030000oooooooo02ooool206Ko8Oooo`03o`2Ioooooooo03Woool005koool206Ko;ooo
o`030000oooooooo02goool206Ko8oooo`03o`2Ioooooooo03Woool0063oool206Ko;Oooo`80000/
oooo0P1VobGoool00ol0VOooooooo`0ioooo001Roooo0P1Vob_oool00`000?ooooooo`0Yoooo0P1V
obOoool00ol0VOooooooo`0ioooo001Toooo0P1VobWoool00`000?ooooooo`0Woooo0P1VobWoool0
0ol0VOooooooo`0ioooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00`1Voooo
ooooo`0Yoooo00?o09Woooooool0>Oooo`00Ioooo`80I_lVoooo00<0003oooooool09?ooo`80I_l/
oooo00?o09Woooooool0>Oooo`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0
I_ooooooool0;?ooo`03o`2Ioooooooo03Woool006[oool00`1Vooooooooo`0Roooo0P0002?oool0
0`1Vooooooooo`0]oooo00?o09Woooooool0>Oooo`00Joooo`80I_lRoooo00<0003oooooool08?oo
o`80I_l`oooo00?o09Woooooool0>Oooo`00KOooo`0306Kooooooooo01ooool00`000?ooooooo`0O
oooo00<0I_ooooooool0<?ooo`03o`2Ioooooooo03Woool006koool206Ko7oooo`030000oooooooo
01goool206Ko<oooo`03o`2Ioooooooo03Woool0073oool00`1Vooooooooo`0Doooo1@0000?oool0
0`000?ooooooo`0Loooo00<0I_ooooooool0<oooo`03o`2Ioooooooo03Woool0077oool206Ko5_oo
o`030000oooooooo00?oool00`000?ooooooo`0Joooo0P1VocKoool00ol0VOooooooo`0ioooo001c
oooo00<0I_ooooooool04oooo`030000oooooooo00?oool300006Oooo`0306Kooooooooo03Koool0
0ol0VOooooooo`0ioooo001doooo00<0I_ooooooool04_ooo`030000oooooooo00?oool00`000?oo
ooooo`0Hoooo00<0I_ooooooool0=oooo`03o`2Ioooooooo03Woool007Goool206Ko4_ooo`030000
oooooooo00?oool00`000?ooooooo`0Foooo0P1Voc[oool00ol0VOooooooo`0ioooo001goooo00<0
I_ooooooool03_ooo`800005oooo00<0003oooooool05Oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0ioooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01?oool206Ko?Oooo`03o`2I
oooooooo03Woool007Woool206Ko5?ooo`030000oooooooo01;oool00`1Vooooooooo`0moooo00?o
09Woooooool0>Oooo`00Noooo`0306Kooooooooo017oool200004_ooo`0306Kooooooooo03koool0
0ol0VOooooooo`0ioooo001loooo00<0I_ooooooool04?ooo`030000oooooooo00ooool206Ko@Ooo
o`03o`2Ioooooooo03Woool007goool00`1Vooooooooo`0?oooo00<0003oooooool03_ooo`0306Ko
oooooooo047oool00ol0VOooooooo`0ioooo001noooo00<0I_ooooooool03_ooo`030000oooooooo
00goool00`1Vooooooooo`12oooo00?o09Woooooool0>Oooo`00Ooooo`0306Kooooooooo00goool0
0`000?ooooooo`0<oooo00<0I_ooooooool0@oooo`03o`2Ioooooooo03Woool0083oool206Ko3Ooo
o`030000oooooooo00[oool206KoA_ooo`03o`2Ioooooooo03Woool008;oool00`1Vooooooooo`0:
oooo0P0000[oool00`1Vooooooooo`16oooo00?o09Woooooool0>Oooo`00Poooo`0306Kooooooooo
00Woool00`000?ooooooo`08oooo00<0I_ooooooool0Aoooo`03o`2Ioooooooo03Woool008Coool0
0`1Vooooooooo`08oooo00<0003oooooool01oooo`0306Kooooooooo04Soool00ol0VOooooooo`0i
oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Koool00`1Vooooooooo`19oooo00?o
09Woooooool0>Oooo`00Q_ooo`0306Kooooooooo00Koool00`000?ooooooo`04oooo0P1Vodcoool0
0ol0VOooooooo`0ioooo0027oooo0P1Vo`Koool00`000?ooooooo`03oooo00<0I_ooooooool0C?oo
o`03o`2Ioooooooo03Woool008Woool00`1Vooooooooo`03oooo0P0000?oool00`1Vooooooooo`1=
oooo00?o09Woooooool0>Oooo`00R_ooo`0306Kooooooooo00;oool01@000?ooooooooooo`1Vo`1@
oooo00?o09Woooooool0>Oooo`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`1>
oooo00?o09Woooooool0>Oooo`00S?ooo`0406Kooooooooo00000_ooo`0306Kooooooooo04ooool0
0ol0VOooooooo`0ioooo002=oooo00<0I_ooool000000P1Voe;oool00ol0VOooooooo`0ioooo002>
oooo00<0I_l0003oool0Doooo`03o`2Ioooooooo03Woool008ooool20000Doooo`03o`2Ioooooooo
03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo
05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool0
07_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`1Boooo00?o09Woooooool0>Ooo
o`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1Boooo00?o
09Woooooool0>Oooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0005;oool0
0ol0VOooooooo`0ioooo001moooo00<0003oooooool02?ooo`800005oooo00<0003oooooool0D_oo
o`03o`2Ioooooooo03Woool007goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000
oooooooo05;oool00ol0VOooooooo`0ioooo001loooo0P0000[oool300001?ooo`030000oooooooo
05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool0
08ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`80001Coooo00?o09Wooooo
ool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003ooooo
ool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Ooo
o`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_oo
o`03o`2Ioooooooo03Woool008ooool20000Doooo`03o`2Ioooooooo03Woool008ooool00`000?oo
ooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0i
oooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1B
oooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?
oooo0P0005?oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo
03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo
05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool0
08ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`80001Coooo00?o09Wooooo
ool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003ooooo
ool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Ooo
o`00Qoooo`@00004oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008Ooool00`000?oo
ooooo`05oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008Soool00`000?ooooooo`04
oooo0`0005;oool00ol0VOooooooo`0ioooo0029oooo00<0003oooooool00oooo`030000oooooooo
05;oool00ol0VOooooooo`0ioooo0027oooo00@0003oooooool00004oooo00<0003oooooool0D_oo
o`03o`2Ioooooooo03Woool008Soool200001Oooo`030000oooooooo05;oool00ol0VOooooooo`0i
oooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1B
oooo00?o09Woooooool0>Oooo`00Soooo`80001Coooo00?o09Woooooool0>Oooo`00Soooo`030000
oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo
03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo
05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool0
08ooool20000Doooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Wooooo
ool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003ooooo
ool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Ooo
o`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo0P0005?oool00ol0VOoo
ooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?oo
ooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0i
oooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1B
oooo00?o09Woooooool0>Oooo`00Soooo`80001Coooo00?o09Woooooool0>Oooo`00Soooo`030000
oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo
03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Noooo`@00003oooo0P00
00Coool200001Oooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo001koooo00<0003ooooo
ool02Oooo`040000oooooooo00001?ooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo001l
oooo00<0003oooooool02oooo`030000oooooooo00;oool30000D_ooo`03o`2Ioooooooo03Woool0
07goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?oo
ooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0
003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003ooooo
ool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0
003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01ooo
o`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000ooool00`000?ooooooo`06oooo00@0003oooooool00003oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.79749 .04578 L
.80799 .04578 L
.81909 .04578 L
.8239 .04578 L
.82904 .04578 L
.83056 .04578 L
.832 .04578 L
.83329 .04578 L
s
.83329 .04578 m
.83347 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.12507 .04578 L
.14415 .04578 L
.1536 .04578 L
.15825 .04578 L
.16254 .04578 L
.16494 .04578 L
.16615 .04578 L
.16683 .16029 L
.16748 .16052 L
.17284 .16248 L
.18221 .16597 L
.22098 .18159 L
.2622 .20042 L
.30191 .22102 L
.34011 .24343 L
.38075 .27042 L
.41988 .29989 L
.46146 .33545 L
.48233 .35513 L
.49148 .36418 L
.49633 .36908 L
.49773 .37051 L
.49905 .37186 L
.50024 .3726 L
.50153 .37127 L
.51122 .36148 L
.52028 .3526 L
.54008 .33405 L
.58086 .2993 L
.62013 .2698 L
.65788 .24468 L
.69808 .22103 L
.73677 .20092 L
.77791 .18206 L
.79844 .17353 L
.80844 .16957 L
.81753 .16607 L
.82208 .16436 L
.82701 .16253 L
.82927 .1617 L
.83051 .16125 L
.83167 .16083 L
.83265 .16048 L
.83371 .04578 L
.83489 .04578 L
.83596 .04578 L
.85564 .04578 L
Mistroke
.8954 .04578 L
.93365 .04578 L
.97435 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00D0003oooooooooool0I_l00oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00D0003ooooo
ooooool0I_l00oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo000hoooo00<0I_ooooooool0E?ooo`030000
oooooooo05Coool00`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo
05Coool00`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo05Coool0
0`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo05Coool00`1Voooo
ooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`80001Eoooo00<0I_ooooooool0=oooo`00>?oo
o`0306Kooooooooo05Coool00`000?ooooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Ko
oooooooo05Coool00`000?ooooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo
05Coool00`000?ooooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo05Coool0
0`000?ooooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo05Coool00`000?oo
ooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo05Coool20000EOooo`0306Ko
oooooooo03Ooool003Soool00`1Vooooooooo`1Doooo00<0003oooooool0E?ooo`0306Kooooooooo
03Ooool003Soool00`1Vooooooooo`1Doooo00<0003oooooool0E?ooo`0306Kooooooooo03Ooool0
03Soool00`1Vooooooooo`1Doooo00<0003oooooool0E?ooo`0306Kooooooooo03Ooool003Soool0
0`1Vooooooooo`1Doooo00<0003oooooool0E?ooo`0306Kooooooooo03Ooool003Soool00`1Voooo
ooooo`1Doooo00<0003oooooool0E?ooo`0306Kooooooooo03Ooool003Soool00`1Vooooooooo`1D
oooo0P0005Goool00`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo
05Coool00`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo05Coool0
0`1Vooooooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo05Coool00`1Voooo
ooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo05Coool00`1Vooooooooo`0g
oooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo05Coool00`1Vooooooooo`0goooo000h
oooo00<0I_ooooooool0E?ooo`80001Eoooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo
05Coool00`000?ooooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo05Coool0
0`000?ooooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo05Coool00`000?oo
ooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo047oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`1Doooo00<0I_ooooooool0=oooo`00>?ooo`0306Kooooooooo
043oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Doooo00<0
I_ooooooool0=oooo`00>?ooo`<0I_m0oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0001Boooo0`1VocWoool003_oool306Ko?Oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0Coooo`<0I_l2oooo00?o09Woooooool0=oooo`00?_ooo`80I_lkoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo04goool206Ko1Oooo`03o`2Ioooooooo
03Ooool0043oool306Ko>Oooo`80000:oooo0`0000Coool00`000?ooooooo`1:oooo0`1Vo`Ooool0
0ol0VOooooooo`0goooo0013oooo0P1Vod[oool00`000?ooooooo`17oooo0`1Vo`[oool00ol0VOoo
ooooo`0goooo0015oooo0`1VodOoool00`000?ooooooo`15oooo0P1Vo`goool00ol0VOooooooo`0g
oooo0018oooo0P1VodGoool20000A?ooo`80I_l?oooo00?o09Woooooool0=oooo`00B_ooo`80I_m3
oooo00<0003oooooool0@Oooo`80I_lAoooo00?o09Woooooool0=oooo`00C?ooo`80I_m1oooo00<0
003oooooool0?oooo`80I_lCoooo00?o09Woooooool0=oooo`00C_ooo`80I_looooo00<0003ooooo
ool0?Oooo`80I_lEoooo00?o09Woooooool0=oooo`00D?ooo`80I_lmoooo00<0003oooooool0>ooo
o`80I_lGoooo00?o09Woooooool0=oooo`00D_ooo`80I_lkoooo0P0003[oool206Ko6Oooo`03o`2I
oooooooo03Ooool005Coool206Ko>Oooo`030000oooooooo03Ooool206Ko6oooo`03o`2Ioooooooo
03Ooool005Koool206Ko=oooo`030000oooooooo03Goool206Ko7Oooo`03o`2Ioooooooo03Ooool0
05Soool206Ko=Oooo`030000oooooooo03?oool206Ko7oooo`03o`2Ioooooooo03Ooool005[oool2
06Ko<oooo`030000oooooooo037oool206Ko8Oooo`03o`2Ioooooooo03Ooool005coool206Ko<Ooo
o`030000oooooooo02ooool206Ko8oooo`03o`2Ioooooooo03Ooool005koool206Ko;oooo`80000_
oooo00<0I_ooooooool08oooo`03o`2Ioooooooo03Ooool0063oool00`1Vooooooooo`0/oooo00<0
003oooooool0;?ooo`80I_lVoooo00?o09Woooooool0=oooo`00HOooo`80I_l/oooo00<0003ooooo
ool0:_ooo`80I_lXoooo00?o09Woooooool0=oooo`00Hoooo`80I_lZoooo00<0003oooooool0:Ooo
o`0306Kooooooooo02Soool00ol0VOooooooo`0goooo001Uoooo00<0I_ooooooool09oooo`030000
oooooooo02Ooool206Ko:oooo`03o`2Ioooooooo03Ooool006Koool206Ko9oooo`030000oooooooo
02Koool00`1Vooooooooo`0[oooo00?o09Woooooool0=oooo`00J?ooo`0306Kooooooooo02Coool2
00009Oooo`80I_l^oooo00?o09Woooooool0=oooo`00JOooo`80I_lToooo00<0003oooooool08_oo
o`80I_l`oooo00?o09Woooooool0=oooo`00Joooo`80I_lRoooo00<0003oooooool08Oooo`0306Ko
oooooooo033oool00ol0VOooooooo`0goooo001]oooo00<0I_ooooooool07oooo`030000oooooooo
01ooool206Ko<oooo`03o`2Ioooooooo03Ooool006koool206Ko5oooo`D00003oooo00<0003ooooo
ool07Oooo`80I_leoooo00?o09Woooooool0=oooo`00L?ooo`0306Kooooooooo01Koool00`000?oo
ooooo`03oooo00<0003oooooool07?ooo`0306Kooooooooo03Goool00ol0VOooooooo`0goooo001a
oooo00<0I_ooooooool05Oooo`030000oooooooo00?oool300006oooo`0306Kooooooooo03Koool0
0ol0VOooooooo`0goooo001boooo0P1VoaGoool00`000?ooooooo`03oooo00<0003oooooool06Ooo
o`80I_lioooo00?o09Woooooool0=oooo`00M?ooo`0306Kooooooooo01;oool00`000?ooooooo`03
oooo00<0003oooooool06?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0goooo001eoooo00<0
I_ooooooool04?ooo`800005oooo00<0003oooooool05oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0goooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`0k
oooo00?o09Woooooool0=oooo`00Moooo`80I_lFoooo00<0003oooooool05?ooo`80I_lnoooo00?o
09Woooooool0=oooo`00NOooo`0306Kooooooooo01?oool200005?ooo`0306Kooooooooo03koool0
0ol0VOooooooo`0goooo001joooo00<0I_ooooooool04_ooo`030000oooooooo01;oool00`1Voooo
ooooo`0ooooo00?o09Woooooool0=oooo`00Noooo`0306Kooooooooo017oool00`000?ooooooo`0A
oooo00<0I_ooooooool0@?ooo`03o`2Ioooooooo03Ooool007coool206Ko4Oooo`030000oooooooo
00ooool206Ko@oooo`03o`2Ioooooooo03Ooool007koool00`1Vooooooooo`0>oooo00<0003ooooo
ool03_ooo`0306Kooooooooo04?oool00ol0VOooooooo`0goooo001ooooo00<0I_ooooooool03Ooo
o`030000oooooooo00goool00`1Vooooooooo`14oooo00?o09Woooooool0=oooo`00P?ooo`0306Ko
oooooooo00coool200003Oooo`0306Kooooooooo04Goool00ol0VOooooooo`0goooo0021oooo00<0
I_ooooooool02oooo`030000oooooooo00_oool00`1Vooooooooo`16oooo00?o09Woooooool0=ooo
o`00P_ooo`80I_l;oooo00<0003oooooool02Oooo`80I_m9oooo00?o09Woooooool0=oooo`00Q?oo
o`0306Kooooooooo00Soool00`000?ooooooo`08oooo00<0I_ooooooool0BOooo`03o`2Ioooooooo
03Ooool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo04[oool0
0ol0VOooooooo`0goooo0026oooo00<0I_ooooooool01_ooo`030000oooooooo00Koool00`1Voooo
ooooo`1;oooo00?o09Woooooool0=oooo`00Qoooo`0306Kooooooooo00Goool200001_ooo`0306Ko
oooooooo04coool00ol0VOooooooo`0goooo0028oooo00<0I_ooooooool01?ooo`030000oooooooo
00Coool00`1Vooooooooo`1=oooo00?o09Woooooool0=oooo`00ROooo`0306Kooooooooo00?oool0
0`000?ooooooo`03oooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo03Ooool008[oool00`1Voooo
ooooo`02oooo00<0003oooooool00_ooo`0306Kooooooooo04ooool00ol0VOooooooo`0goooo002;
oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo053oool00ol0VOooooooo`0goooo002<
oooo00@0I_ooooooool00002oooo00<0I_ooooooool0DOooo`03o`2Ioooooooo03Ooool008goool0
1@1Vooooo`000000001Vo`1Doooo00?o09Woooooool0=oooo`00S_ooo`0306Ko0000oooo05Goool0
0ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo05Coool00ol0VOooooooo`0goooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool30000E?ooo`03o`2Ioooooooo03Ooool007goool00`000?oo
ooooo`08oooo0P0000Goool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`04oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool0
07coool200002_ooo`<00004oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOoo
ooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Sooo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2I
oooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`80001E
oooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?
oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o
09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0
003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool20000EOooo`03o`2Ioooooooo03Ooool0
08ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool0
0ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOoo
ooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Sooo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo0027oooo100000Coool00`000?ooooooo`1D
oooo00?o09Woooooool0=oooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`1Doooo00?o
09Woooooool0=oooo`00R?ooo`030000oooooooo00Coool30000E?ooo`03o`2Ioooooooo03Ooool0
08Woool00`000?ooooooo`03oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00R?ooo`800005
oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o
09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo0P00
05Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool0
08ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool0
0ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`80001Eoooo00?o09Woooooool0=ooo
o`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Sooo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2I
oooooooo03Ooool008ooool20000EOooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1D
oooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?
oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o
09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo0P00
05Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool0
08ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool0
0ol0VOooooooo`0goooo001koooo100000?oool200001?ooo`800005oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool007_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0
003oooooool0E?ooo`03o`2Ioooooooo03Ooool007coool00`000?ooooooo`0;oooo00<0003ooooo
ool00_ooo`<0001Doooo00?o09Woooooool0=oooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800003oooo1@00
00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo
00Woool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000?
oooo00<0003oooooool02?ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000003oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1l
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.79749 .04578 L
.81909 .04578 L
.82924 .04578 L
.83479 .04578 L
.83749 .04578 L
.83868 .04578 L
.83996 .04578 L
.84114 .04578 L
s
.84114 .04578 m
.84141 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.12507 .04578 L
.13506 .04578 L
.14415 .04578 L
.14868 .04578 L
.1536 .04578 L
.15586 .04578 L
.15709 .04578 L
.15825 .04578 L
.15923 .16041 L
.16029 .1608 L
.16254 .16161 L
.18221 .16902 L
.22343 .1861 L
.26314 .2048 L
.30133 .22513 L
.34198 .24963 L
.38111 .27637 L
.42269 .30864 L
.46276 .344 L
.48114 .36177 L
.49157 .37233 L
.49418 .37503 L
.49666 .37761 L
.49889 .37995 L
.50015 .38097 L
.50131 .37974 L
.51093 .36977 L
.52125 .35941 L
.54231 .33928 L
.58158 .30513 L
.61933 .27605 L
.65953 .24866 L
.69822 .22538 L
.73936 .20355 L
.77898 .18504 L
.81709 .16929 L
.82718 .16543 L
.83213 .16357 L
.8367 .16189 L
.83926 .16096 L
.84055 .16049 L
.84128 .04578 L
.84197 .04578 L
.84768 .04578 L
.85765 .04578 L
.89648 .04578 L
.93775 .04578 L
Mistroke
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oool0I_l01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool00ooo
o`0306Kooooo000000Ooool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool0
0`1Vooooooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool00`1Voooo
ooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool00`1Vooooooooo`0e
oooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool00`1Vooooooooo`0eoooo000f
oooo00<0I_ooooooool0E_ooo`80001Goooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo
05Koool00`000?ooooooo`1Foooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool0
0`000?ooooooo`1Foooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?oo
ooooo`1Foooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`1F
oooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`1Foooo00<0
I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool20000Eoooo`0306Kooooooooo03Goool0
03Koool00`1Vooooooooo`1Foooo00<0003oooooool0E_ooo`0306Kooooooooo03Goool003Koool0
0`1Vooooooooo`1Foooo00<0003oooooool0E_ooo`0306Kooooooooo03Goool003Koool00`1Voooo
ooooo`1Foooo00<0003oooooool0E_ooo`0306Kooooooooo03Goool003Koool00`1Vooooooooo`1F
oooo00<0003oooooool0E_ooo`0306Kooooooooo03Goool003Koool00`1Vooooooooo`1Foooo00<0
003oooooool0E_ooo`0306Kooooooooo03Goool003Koool00`1Vooooooooo`1Foooo0P0005Ooool0
0`1Vooooooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool00`1Voooo
ooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool00`1Vooooooooo`0e
oooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool00`1Vooooooooo`0eoooo000f
oooo00<0I_ooooooool0E_ooo`030000oooooooo05Koool00`1Vooooooooo`0eoooo000foooo00<0
I_ooooooool0E_ooo`030000oooooooo05Koool00`1Vooooooooo`0eoooo000foooo00<0I_oooooo
ool0E_ooo`80001Goooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?oo
ooooo`1Foooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`1F
oooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`1Foooo00<0
I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo04?oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Foooo00<0I_ooooooool0=Oooo`00=_ooo`0306Kooooooooo04;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Foooo00<0I_ooooooool0=Ooo
o`00=_ooo`<0I_m2oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Coooo101V
ocOoool003Woool206Ko@?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0DOoo
o`80I_l3oooo00?o09Woooooool0=Oooo`00>oooo`<0I_lmoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo04koool306Ko1Oooo`03o`2Ioooooooo03Goool003koool3
06Ko>oooo`80000:oooo0`0000Coool00`000?ooooooo`1<oooo0P1Vo`Soool00ol0VOooooooo`0e
oooo0011oooo0P1Vodcoool00`000?ooooooo`1:oooo0P1Vo`[oool00ol0VOooooooo`0eoooo0013
oooo0`1VodWoool00`000?ooooooo`18oooo0P1Vo`coool00ol0VOooooooo`0eoooo0016oooo0P1V
odOoool20000A_ooo`<0I_l>oooo00?o09Woooooool0=Oooo`00B?ooo`80I_m5oooo00<0003ooooo
ool0@oooo`80I_lAoooo00?o09Woooooool0=Oooo`00B_ooo`80I_m3oooo00<0003oooooool0@Ooo
o`80I_lCoooo00?o09Woooooool0=Oooo`00C?ooo`80I_m1oooo00<0003oooooool0?oooo`80I_lE
oooo00?o09Woooooool0=Oooo`00C_ooo`80I_looooo00<0003oooooool0?Oooo`80I_lGoooo00?o
09Woooooool0=Oooo`00D?ooo`80I_lmoooo0P0003coool206Ko6Oooo`03o`2Ioooooooo03Goool0
05;oool206Ko>oooo`030000oooooooo03Woool206Ko6oooo`03o`2Ioooooooo03Goool005Coool2
06Ko>Oooo`030000oooooooo03Ooool206Ko7Oooo`03o`2Ioooooooo03Goool005Koool206Ko=ooo
o`030000oooooooo03Koool00`1Vooooooooo`0Moooo00?o09Woooooool0=Oooo`00F?ooo`80I_le
oooo00<0003oooooool0=?ooo`80I_lPoooo00?o09Woooooool0=Oooo`00F_ooo`80I_lcoooo00<0
003oooooool0<_ooo`80I_lRoooo00?o09Woooooool0=Oooo`00G?ooo`80I_laoooo0P0003;oool0
0`1Vooooooooo`0Roooo00?o09Woooooool0=Oooo`00G_ooo`0306Kooooooooo02koool00`000?oo
ooooo`0_oooo0P1VobGoool00ol0VOooooooo`0eoooo001Ooooo0P1Vobkoool00`000?ooooooo`0]
oooo0P1VobOoool00ol0VOooooooo`0eoooo001Qoooo0P1Vobcoool00`000?ooooooo`0[oooo0P1V
obWoool00ol0VOooooooo`0eoooo001Soooo00<0I_ooooooool0:Oooo`030000oooooooo02Woool2
06Ko:oooo`03o`2Ioooooooo03Goool006Coool206Ko:Oooo`030000oooooooo02Ooool206Ko;Ooo
o`03o`2Ioooooooo03Goool006Koool00`1Vooooooooo`0Voooo0P0002Ooool00`1Vooooooooo`0]
oooo00?o09Woooooool0=Oooo`00Ioooo`80I_lVoooo00<0003oooooool09?ooo`80I_l`oooo00?o
09Woooooool0=Oooo`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0I_oooooo
ool0<?ooo`03o`2Ioooooooo03Goool006[oool00`1Vooooooooo`0Roooo00<0003oooooool08_oo
o`0306Kooooooooo037oool00ol0VOooooooo`0eoooo001[oooo0P1Voa[oool500000oooo`030000
oooooooo023oool206Ko=?ooo`03o`2Ioooooooo03Goool006goool00`1Vooooooooo`0Ioooo00<0
003oooooool00oooo`030000oooooooo01ooool00`1Vooooooooo`0doooo00?o09Woooooool0=Ooo
o`00K_ooo`80I_lIoooo00<0003oooooool00oooo`<0000Moooo0P1VocOoool00ol0VOooooooo`0e
oooo001`oooo00<0I_ooooooool05_ooo`030000oooooooo00?oool00`000?ooooooo`0Loooo00<0
I_ooooooool0=oooo`03o`2Ioooooooo03Goool0077oool206Ko5_ooo`030000oooooooo00?oool0
0`000?ooooooo`0Joooo0P1Voc[oool00ol0VOooooooo`0eoooo001coooo00<0I_ooooooool04_oo
o`800005oooo00<0003oooooool06Oooo`0306Kooooooooo03[oool00ol0VOooooooo`0eoooo001d
oooo00<0I_ooooooool06?ooo`030000oooooooo01Soool00`1Vooooooooo`0koooo00?o09Wooooo
ool0=Oooo`00MOooo`80I_lHoooo00<0003oooooool05_ooo`80I_lnoooo00?o09Woooooool0=Ooo
o`00Moooo`0306Kooooooooo01Goool200005_ooo`0306Kooooooooo03koool00ol0VOooooooo`0e
oooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01?oool206Ko@Oooo`03o`2Ioooooooo
03Goool007Woool206Ko5?ooo`030000oooooooo01;oool00`1Vooooooooo`11oooo00?o09Wooooo
ool0=Oooo`00Noooo`0306Kooooooooo017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0@_oo
o`03o`2Ioooooooo03Goool007coool00`1Vooooooooo`0@oooo00<0003oooooool04?ooo`0306Ko
oooooooo04?oool00ol0VOooooooo`0eoooo001moooo00<0I_ooooooool03oooo`030000oooooooo
00ooool00`1Vooooooooo`14oooo00?o09Woooooool0=Oooo`00O_ooo`0306Kooooooooo00koool2
00003oooo`0306Kooooooooo04Goool00ol0VOooooooo`0eoooo001ooooo00<0I_ooooooool03Ooo
o`030000oooooooo00coool206KoB?ooo`03o`2Ioooooooo03Goool0083oool206Ko3Oooo`030000
oooooooo00_oool00`1Vooooooooo`18oooo00?o09Woooooool0=Oooo`00P_ooo`0306Kooooooooo
00[oool00`000?ooooooo`0:oooo00<0I_ooooooool0BOooo`03o`2Ioooooooo03Goool008?oool0
0`1Vooooooooo`09oooo00<0003oooooool02Oooo`0306Kooooooooo04[oool00ol0VOooooooo`0e
oooo0024oooo00<0I_ooooooool02?ooo`030000oooooooo00Soool00`1Vooooooooo`1;oooo00?o
09Woooooool0=Oooo`00QOooo`0306Kooooooooo00Ooool200002?ooo`0306Kooooooooo04coool0
0ol0VOooooooo`0eoooo0026oooo00<0I_ooooooool01_ooo`030000oooooooo00Koool00`1Voooo
ooooo`1=oooo00?o09Woooooool0=Oooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`04
oooo0P1Voe3oool00ol0VOooooooo`0eoooo0028oooo00<0I_ooooooool01?ooo`030000oooooooo
00?oool00`1Vooooooooo`1@oooo00?o09Woooooool0=Oooo`00ROooo`0306Kooooooooo00?oool0
0`000?ooooooo`02oooo00<0I_ooooooool0DOooo`03o`2Ioooooooo03Goool008[oool00`1Voooo
ooooo`02oooo00D0003oooooooooool0I_l0E?ooo`03o`2Ioooooooo03Goool008_oool0101Voooo
ooooooooo`800002oooo00<0I_ooooooool0D_ooo`03o`2Ioooooooo03Goool008coool0101Voooo
ooooo`0000;oool00`1Vooooooooo`1Coooo00?o09Woooooool0=Oooo`00SOooo`0506Kooooo0000
oooo06Ko05Koool00ol0VOooooooo`0eoooo002>oooo00<0I_l00000I_l0Eoooo`03o`2Ioooooooo
03Goool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`1Foooo00?o09Wooooo
ool0=Oooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1F
oooo00?o09Woooooool0=Oooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
05Koool00ol0VOooooooo`0eoooo001moooo00<0003oooooool02?ooo`800005oooo00<0003ooooo
ool0E_ooo`03o`2Ioooooooo03Goool007goool00`000?ooooooo`08oooo00<0003oooooool01?oo
o`030000oooooooo05Koool00ol0VOooooooo`0eoooo001loooo0P0000[oool300001?ooo`030000
oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo
03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o
09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0
003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Wooooo
ool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003ooooo
ool0E_ooo`03o`2Ioooooooo03Goool008ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool0
0`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOoo
ooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?oo
ooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0e
oooo002?oooo0P0005Ooool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000
oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo
03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o
09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0
003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Wooooo
ool0=Oooo`00Qoooo`@00004oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008Ooool0
0`000?ooooooo`05oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008Soool00`000?oo
ooooo`04oooo0`0005Koool00ol0VOooooooo`0eoooo0029oooo00<0003oooooool00oooo`030000
oooooooo05Koool00ol0VOooooooo`0eoooo0027oooo00@0003oooooool00004oooo00<0003ooooo
ool0E_ooo`03o`2Ioooooooo03Goool008Soool200001Oooo`030000oooooooo05Koool00ol0VOoo
ooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?oo
ooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Sooo
o`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000
oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo
03Goool008ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o
09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0
003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Wooooo
ool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo0P0005Ooool0
0ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool0
0`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOoo
ooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?oo
ooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Woooooool0=Oooo`00Sooo
o`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Noooo`@00003
oooo0P0000Coool200001Oooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo001koooo00<0
003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo05Koool00ol0VOooooooo`0e
oooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool30000E_ooo`03o`2Ioooooooo
03Goool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`07oooo0P0000Coool200000oooo`D00002oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool0000:oooo00D0003oooooooooool000000_ooo`050000oooooooooooo0000
07[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500003oooo`030000oooooooo00Soool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002_ooo`030000
oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.79749 .04578 L
.81909 .04578 L
.82924 .04578 L
.83996 .04578 L
.84438 .04578 L
.84681 .04578 L
.84801 .04578 L
.84911 .04578 L
s
.84911 .04578 m
.84944 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.12507 .04578 L
.13506 .04578 L
.14415 .04578 L
.14635 .04578 L
.14868 .04578 L
.1499 .04578 L
.15059 .04578 L
.15124 .16039 L
.15238 .1608 L
.1536 .16125 L
.16254 .16454 L
.18221 .17214 L
.22343 .18966 L
.26314 .20883 L
.30133 .22967 L
.34198 .25479 L
.38111 .28221 L
.42269 .31529 L
.46276 .35155 L
.48114 .36977 L
.49157 .3806 L
.49418 .38337 L
.49666 .38601 L
.49889 .38841 L
.50015 .38945 L
.50131 .3882 L
.51093 .37797 L
.52125 .36735 L
.54231 .34671 L
.58158 .31169 L
.61933 .28188 L
.65953 .2538 L
.69822 .22993 L
.73936 .20755 L
.77898 .18857 L
.81709 .17241 L
.8367 .16483 L
.84235 .16273 L
.84512 .16171 L
.84634 .16127 L
.84768 .16078 L
.84888 .16035 L
.85 .04578 L
.85119 .04578 L
.85246 .04578 L
.85765 .04578 L
.89893 .04578 L
Mistroke
.93869 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo05Soool0
0`1Vooooooooo`0coooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo05Soool00`1Voooo
ooooo`0coooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo05Soool00`1Vooooooooo`0c
oooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo05Soool00`1Vooooooooo`0coooo000d
oooo00<0I_ooooooool0F?ooo`80001Ioooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo
05Soool00`000?ooooooo`1Hoooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo05Soool0
0`000?ooooooo`1Hoooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo05Soool00`000?oo
ooooo`1Hoooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo05Soool00`000?ooooooo`1H
oooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo05Soool00`000?ooooooo`1Hoooo00<0
I_ooooooool0<oooo`00=?ooo`0306Kooooooooo05Soool20000FOooo`0306Kooooooooo03?oool0
03Coool00`1Vooooooooo`1Hoooo00<0003oooooool0F?ooo`0306Kooooooooo03?oool003Coool0
0`1Vooooooooo`1Hoooo00<0003oooooool0F?ooo`0306Kooooooooo03?oool003Coool00`1Voooo
ooooo`1Hoooo00<0003oooooool0F?ooo`0306Kooooooooo03?oool003Coool00`1Vooooooooo`1H
oooo00<0003oooooool0F?ooo`0306Kooooooooo03?oool003Coool00`1Vooooooooo`1Hoooo00<0
003oooooool0F?ooo`0306Kooooooooo03?oool003Coool00`1Vooooooooo`1Hoooo0P0005Woool0
0`1Vooooooooo`0coooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo05Soool00`1Voooo
ooooo`0coooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo05Soool00`1Vooooooooo`0c
oooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo05Soool00`1Vooooooooo`0coooo000d
oooo00<0I_ooooooool0F?ooo`030000oooooooo05Soool00`1Vooooooooo`0coooo000doooo00<0
I_ooooooool0F?ooo`030000oooooooo05Soool00`1Vooooooooo`0coooo000doooo00<0I_oooooo
ool0F?ooo`80001Ioooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo05Soool00`000?oo
ooooo`1Hoooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo05Soool00`000?ooooooo`1H
oooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo05Soool00`000?ooooooo`1Hoooo00<0
I_ooooooool0<oooo`00=?ooo`0306Kooooooooo04Goool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Hoooo00<0I_ooooooool0<oooo`00=?ooo`0306Kooooooooo04Coool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Hoooo00<0I_ooooooool0<ooo
o`00=?ooo`80I_m5oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Foooo0`1V
ocGoool003Koool306Ko@_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0E?oo
o`80I_l2oooo00?o09Woooooool0<oooo`00>Oooo`80I_m0oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo057oool306Ko1?ooo`03o`2Ioooooooo03?oool003_oool3
06Ko?_ooo`80000:oooo0`0000Coool00`000?ooooooo`1>oooo0`1Vo`Ooool00ol0VOooooooo`0c
oooo000noooo0`1Vodkoool00`000?ooooooo`1<oooo0P1Vo`[oool00ol0VOooooooo`0coooo0011
oooo0P1Vodcoool00`000?ooooooo`1:oooo0P1Vo`coool00ol0VOooooooo`0coooo0013oooo0`1V
odWoool20000BOooo`80I_l>oooo00?o09Woooooool0<oooo`00A_ooo`80I_m7oooo00<0003ooooo
ool0AOooo`<0I_l@oooo00?o09Woooooool0<oooo`00B?ooo`80I_m5oooo00<0003oooooool0@ooo
o`80I_lCoooo00?o09Woooooool0<oooo`00B_ooo`80I_m3oooo00<0003oooooool0@Oooo`80I_lE
oooo00?o09Woooooool0<oooo`00C?ooo`80I_m1oooo00<0003oooooool0?oooo`80I_lGoooo00?o
09Woooooool0<oooo`00C_ooo`80I_looooo0P0003koool206Ko6Oooo`03o`2Ioooooooo03?oool0
053oool206Ko?Oooo`030000oooooooo03_oool206Ko6oooo`03o`2Ioooooooo03?oool005;oool2
06Ko>oooo`030000oooooooo03Woool206Ko7Oooo`03o`2Ioooooooo03?oool005Coool206Ko>Ooo
o`030000oooooooo03Ooool206Ko7oooo`03o`2Ioooooooo03?oool005Koool00`1Vooooooooo`0f
oooo00<0003oooooool0=_ooo`0306Kooooooooo01ooool00ol0VOooooooo`0coooo001Goooo0P1V
ocKoool00`000?ooooooo`0doooo0P1Vob;oool00ol0VOooooooo`0coooo001Ioooo0P1VocCoool2
0000<oooo`80I_lToooo00?o09Woooooool0<oooo`00Foooo`0306Kooooooooo037oool00`000?oo
ooooo`0aoooo00<0I_ooooooool09?ooo`03o`2Ioooooooo03?oool005coool206Ko<Oooo`030000
oooooooo02ooool206Ko9oooo`03o`2Ioooooooo03?oool005koool206Ko;oooo`030000oooooooo
02goool206Ko:Oooo`03o`2Ioooooooo03?oool0063oool206Ko;Oooo`030000oooooooo02_oool2
06Ko:oooo`03o`2Ioooooooo03?oool006;oool206Ko:oooo`030000oooooooo02Woool206Ko;Ooo
o`03o`2Ioooooooo03?oool006Coool206Ko:Oooo`80000Xoooo0P1Vobooool00ol0VOooooooo`0c
oooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00`1Vooooooooo`0_oooo00?o
09Woooooool0<oooo`00Ioooo`80I_lVoooo00<0003oooooool09?ooo`80I_lboooo00?o09Wooooo
ool0<oooo`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0I_ooooooool0<_oo
o`03o`2Ioooooooo03?oool006[oool00`1Vooooooooo`0Joooo1@0000?oool00`000?ooooooo`0R
oooo00<0I_ooooooool0<oooo`03o`2Ioooooooo03?oool006_oool206Ko7?ooo`030000oooooooo
00?oool00`000?ooooooo`0Poooo0P1VocKoool00ol0VOooooooo`0coooo001]oooo00<0I_oooooo
ool06Oooo`030000oooooooo00?oool300007oooo`0306Kooooooooo03Koool00ol0VOooooooo`0c
oooo001^oooo0P1VoaWoool00`000?ooooooo`03oooo00<0003oooooool07Oooo`80I_lioooo00?o
09Woooooool0<oooo`00L?ooo`0306Kooooooooo01Koool00`000?ooooooo`03oooo00<0003ooooo
ool07?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0coooo001aoooo00<0I_ooooooool05?oo
o`800005oooo00<0003oooooool06oooo`0306Kooooooooo03[oool00ol0VOooooooo`0coooo001b
oooo0P1Voa_oool00`000?ooooooo`0Ioooo0P1Vocgoool00ol0VOooooooo`0coooo001doooo00<0
I_ooooooool06?ooo`030000oooooooo01Soool00`1Vooooooooo`0moooo00?o09Woooooool0<ooo
o`00MOooo`0306Kooooooooo01Ooool200006?ooo`0306Kooooooooo03koool00ol0VOooooooo`0c
oooo001foooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`0ooooo00?o
09Woooooool0<oooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Doooo0P1Vod;oool0
0ol0VOooooooo`0coooo001hoooo0P1VoaGoool00`000?ooooooo`0Coooo00<0I_ooooooool0@_oo
o`03o`2Ioooooooo03?oool007[oool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`0306Ko
oooooooo04?oool00ol0VOooooooo`0coooo001koooo00<0I_ooooooool04Oooo`030000oooooooo
017oool00`1Vooooooooo`14oooo00?o09Woooooool0<oooo`00O?ooo`0306Kooooooooo013oool2
00004Oooo`0306Kooooooooo04Goool00ol0VOooooooo`0coooo001moooo00<0I_ooooooool03ooo
o`030000oooooooo00ooool00`1Vooooooooo`16oooo00?o09Woooooool0<oooo`00O_ooo`0306Ko
oooooooo00koool00`000?ooooooo`0>oooo00<0I_ooooooool0Aoooo`03o`2Ioooooooo03?oool0
07ooool00`1Vooooooooo`0=oooo00<0003oooooool03?ooo`80I_m:oooo00?o09Woooooool0<ooo
o`00P?ooo`80I_l=oooo00<0003oooooool02oooo`0306Kooooooooo04[oool00ol0VOooooooo`0c
oooo0022oooo00<0I_ooooooool02_ooo`030000oooooooo00[oool00`1Vooooooooo`1;oooo00?o
09Woooooool0<oooo`00Poooo`0306Kooooooooo00Woool200002_ooo`0306Kooooooooo04coool0
0ol0VOooooooo`0coooo0024oooo00<0I_ooooooool02?ooo`030000oooooooo00Soool00`1Voooo
ooooo`1=oooo00?o09Woooooool0<oooo`00QOooo`0306Kooooooooo00Ooool00`000?ooooooo`07
oooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo03?oool008Koool00`1Vooooooooo`06oooo00<0
003oooooool01_ooo`0306Kooooooooo04ooool00ol0VOooooooo`0coooo0027oooo00<0I_oooooo
ool01Oooo`030000oooooooo00Coool206KoD_ooo`03o`2Ioooooooo03?oool008Soool00`1Voooo
ooooo`04oooo00<0003oooooool00oooo`0306Kooooooooo05;oool00ol0VOooooooo`0coooo0029
oooo00<0I_ooooooool00oooo`800003oooo00<0I_ooooooool0Doooo`03o`2Ioooooooo03?oool0
08[oool00`1Vooooooooo`02oooo00D0003oooooooooool0I_l0E_ooo`03o`2Ioooooooo03?oool0
08_oool01@1Vooooooooooooo`000003oooo00<0I_ooooooool0E?ooo`03o`2Ioooooooo03?oool0
08coool0101Vooooooooo`0000;oool00`1Vooooooooo`1Eoooo00?o09Woooooool0<oooo`00Nooo
o`D00002oooo0P0000Coool200000oooo`0506Kooooo0000oooo06Ko05Soool00ol0VOooooooo`0c
oooo001moooo00<0003oooooool01oooo`040000oooooooo00000_ooo`80I_l00`00001Vooooo`1H
oooo00?o09Woooooool0<oooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
05Soool00ol0VOooooooo`0coooo001moooo00<0003oooooool02?ooo`800005oooo00<0003ooooo
ool0F?ooo`03o`2Ioooooooo03?oool007goool00`000?ooooooo`08oooo00<0003oooooool01?oo
o`030000oooooooo05Soool00ol0VOooooooo`0coooo001loooo0P0000[oool300001?ooo`030000
oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2Ioooooooo
03?oool008ooool00`000?ooooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`80001Ioooo00?o
09Woooooool0<oooo`00Soooo`030000oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0
003oooooool0F?ooo`03o`2Ioooooooo03?oool008ooool00`000?ooooooo`1Hoooo00?o09Wooooo
ool0<oooo`00Soooo`030000oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0003ooooo
ool0F?ooo`03o`2Ioooooooo03?oool008ooool20000FOooo`03o`2Ioooooooo03?oool008ooool0
0`000?ooooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`030000oooooooo05Soool00ol0VOoo
ooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2Ioooooooo03?oool008ooool00`000?oo
ooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`030000oooooooo05Soool00ol0VOooooooo`0c
oooo002?oooo0P0005Woool00ol0VOooooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2I
oooooooo03?oool008ooool00`000?ooooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`030000
oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2Ioooooooo
03?oool008ooool00`000?ooooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`80001Ioooo00?o
09Woooooool0<oooo`00Soooo`030000oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0
003oooooool0F?ooo`03o`2Ioooooooo03?oool008ooool00`000?ooooooo`1Hoooo00?o09Wooooo
ool0<oooo`00Qoooo`@00004oooo00<0003oooooool0F?ooo`03o`2Ioooooooo03?oool008Ooool0
0`000?ooooooo`05oooo00<0003oooooool0F?ooo`03o`2Ioooooooo03?oool008Soool00`000?oo
ooooo`04oooo0`0005Soool00ol0VOooooooo`0coooo0029oooo00<0003oooooool00oooo`030000
oooooooo05Soool00ol0VOooooooo`0coooo0027oooo00@0003oooooool00004oooo00<0003ooooo
ool0F?ooo`03o`2Ioooooooo03?oool008Soool200001Oooo`030000oooooooo05Soool00ol0VOoo
ooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2Ioooooooo03?oool008ooool00`000?oo
ooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`80001Ioooo00?o09Woooooool0<oooo`00Sooo
o`030000oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2I
oooooooo03?oool008ooool00`000?ooooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`030000
oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2Ioooooooo
03?oool008ooool20000FOooo`03o`2Ioooooooo03?oool008ooool00`000?ooooooo`1Hoooo00?o
09Woooooool0<oooo`00Soooo`030000oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0
003oooooool0F?ooo`03o`2Ioooooooo03?oool008ooool00`000?ooooooo`1Hoooo00?o09Wooooo
ool0<oooo`00Soooo`030000oooooooo05Soool00ol0VOooooooo`0coooo002?oooo0P0005Woool0
0ol0VOooooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2Ioooooooo03?oool008ooool0
0`000?ooooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`030000oooooooo05Soool00ol0VOoo
ooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2Ioooooooo03?oool008ooool00`000?oo
ooooo`1Hoooo00?o09Woooooool0<oooo`00Soooo`80001Ioooo00?o09Woooooool0<oooo`00Sooo
o`030000oooooooo05Soool00ol0VOooooooo`0coooo002?oooo00<0003oooooool0F?ooo`03o`2I
oooooooo03?oool008ooool00`000?ooooooo`1Hoooo00?o09Woooooool0<oooo`00Noooo`@00003
oooo0P0000Coool200001Oooo`030000oooooooo05Soool00ol0VOooooooo`0coooo001koooo00<0
003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo05Soool00ol0VOooooooo`0c
oooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool30000F?ooo`03o`2Ioooooooo
03?oool007goool00`000?ooooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001l
oooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0
003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`07oooo0P0000Coool200000oooo`@00003oooo00<0003oooooool0Noooo`00Nooo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000
oooooooo00002?ooo`030000oooooooo00Coool00`000?ooooooo`1koooo001joooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000
oooooooo07[oool007_oool00`000?ooooooo`0500003oooo`030000oooooooo00Soool00`000?oo
ooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003ooooo
ool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.79749 .04578 L
.81909 .04578 L
.82924 .04578 L
.83996 .04578 L
.84911 .04578 L
.85162 .04578 L
.85431 .04578 L
.85561 .04578 L
.85685 .04578 L
s
.85685 .04578 m
.85712 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.10458 .04578 L
.11448 .04578 L
.12507 .04578 L
.1302 .04578 L
.13506 .04578 L
.13942 .04578 L
.14061 .04578 L
.14188 .04578 L
.14296 .16027 L
.14415 .1607 L
.18444 .17625 L
.22321 .1932 L
.26444 .21364 L
.30414 .236 L
.34234 .26032 L
.38298 .28963 L
.42211 .32161 L
.46369 .36022 L
.47384 .37043 L
.48456 .38158 L
.49371 .3914 L
.49622 .39414 L
.4976 .39566 L
.49891 .39711 L
.50013 .39817 L
.50145 .39671 L
.50376 .39416 L
.54231 .35432 L
.58309 .31713 L
.62236 .28556 L
.66011 .25867 L
.70031 .23335 L
.739 .21183 L
.78014 .19165 L
.80067 .18251 L
.81977 .17453 L
.83819 .16727 L
.8435 .16526 L
.8485 .16339 L
.853 .16173 L
.85423 .16129 L
.85554 .16081 L
.85665 .16041 L
.85787 .04578 L
.85917 .04578 L
.86037 .04578 L
.86309 .04578 L
Mistroke
.86804 .04578 L
.87732 .04578 L
.89821 .04578 L
.9374 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`03oooo00<0I_ooool000001oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooo06Ko00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000boooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool0
0`1Vooooooooo`0aoooo000boooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool00`1Voooo
ooooo`0aoooo000boooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool00`1Vooooooooo`0a
oooo000boooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool00`1Vooooooooo`0aoooo000b
oooo00<0I_ooooooool0F_ooo`80001Koooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo
05[oool00`000?ooooooo`1Joooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool0
0`000?ooooooo`1Joooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool00`000?oo
ooooo`1Joooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool00`000?ooooooo`1J
oooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool00`000?ooooooo`1Joooo00<0
I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool20000Foooo`0306Kooooooooo037oool0
03;oool00`1Vooooooooo`1Joooo00<0003oooooool0F_ooo`0306Kooooooooo037oool003;oool0
0`1Vooooooooo`1Joooo00<0003oooooool0F_ooo`0306Kooooooooo037oool003;oool00`1Voooo
ooooo`1Joooo00<0003oooooool0F_ooo`0306Kooooooooo037oool003;oool00`1Vooooooooo`1J
oooo00<0003oooooool0F_ooo`0306Kooooooooo037oool003;oool00`1Vooooooooo`1Joooo00<0
003oooooool0F_ooo`0306Kooooooooo037oool003;oool00`1Vooooooooo`1Joooo0P0005_oool0
0`1Vooooooooo`0aoooo000boooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool00`1Voooo
ooooo`0aoooo000boooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool00`1Vooooooooo`0a
oooo000boooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool00`1Vooooooooo`0aoooo000b
oooo00<0I_ooooooool0F_ooo`030000oooooooo05[oool00`1Vooooooooo`0aoooo000boooo00<0
I_ooooooool0F_ooo`030000oooooooo05[oool00`1Vooooooooo`0aoooo000boooo00<0I_oooooo
ool0F_ooo`80001Koooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool00`000?oo
ooooo`1Joooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool00`000?ooooooo`1J
oooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo05[oool00`000?ooooooo`1Joooo00<0
I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo04Ooool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Joooo00<0I_ooooooool0<Oooo`00<_ooo`0306Kooooooooo04Koool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Joooo00<0I_ooooooool0<Ooo
o`00<_ooo`80I_m7oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Hoooo0`1V
oc?oool003Coool306KoA?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0E?oo
o`@0I_l2oooo00?o09Woooooool0<Oooo`00=oooo`80I_m2oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo05;oool206Ko1_ooo`03o`2Ioooooooo037oool003Woool3
06Ko@?ooo`80000:oooo0`0000Coool00`000?ooooooo`1?oooo0`1Vo`Soool00ol0VOooooooo`0a
oooo000loooo0`1Voe3oool00`000?ooooooo`1=oooo0P1Vo`_oool00ol0VOooooooo`0aoooo000o
oooo0P1Vodkoool00`000?ooooooo`1;oooo0P1Vo`goool00ol0VOooooooo`0aoooo0011oooo0`1V
od_oool20000B_ooo`80I_l?oooo00?o09Woooooool0<Oooo`00A?ooo`80I_m9oooo00<0003ooooo
ool0Aoooo`80I_lAoooo00?o09Woooooool0<Oooo`00A_ooo`<0I_m6oooo00<0003oooooool0AOoo
o`80I_lCoooo00?o09Woooooool0<Oooo`00BOooo`80I_m4oooo00<0003oooooool0@oooo`80I_lE
oooo00?o09Woooooool0<Oooo`00Boooo`80I_m2oooo00<0003oooooool0@Oooo`80I_lGoooo00?o
09Woooooool0<Oooo`00COooo`80I_m0oooo0P00043oool206Ko6Oooo`03o`2Ioooooooo037oool0
04ooool206Ko?_ooo`030000oooooooo03goool206Ko6oooo`03o`2Ioooooooo037oool0057oool2
06Ko??ooo`030000oooooooo03_oool206Ko7Oooo`03o`2Ioooooooo037oool005?oool206Ko>_oo
o`030000oooooooo03Woool206Ko7oooo`03o`2Ioooooooo037oool005Goool206Ko>?ooo`030000
oooooooo03Ooool206Ko8Oooo`03o`2Ioooooooo037oool005Ooool00`1Vooooooooo`0eoooo00<0
003oooooool0=_ooo`0306Kooooooooo027oool00ol0VOooooooo`0aoooo001Hoooo0P1VocGoool2
0000=Oooo`80I_lToooo00?o09Woooooool0<Oooo`00F_ooo`80I_lcoooo00<0003oooooool0<_oo
o`80I_lVoooo00?o09Woooooool0<Oooo`00G?ooo`0306Kooooooooo033oool00`000?ooooooo`0a
oooo00<0I_ooooooool09_ooo`03o`2Ioooooooo037oool005goool206Ko<?ooo`030000oooooooo
02ooool206Ko:Oooo`03o`2Ioooooooo037oool005ooool00`1Vooooooooo`0]oooo00<0003ooooo
ool0;Oooo`80I_l[oooo00?o09Woooooool0<Oooo`00H?ooo`0306Kooooooooo02coool00`000?oo
ooooo`0/oooo00<0I_ooooooool0:oooo`03o`2Ioooooooo037oool0067oool206Ko;?ooo`80000[
oooo0P1Vobkoool00ol0VOooooooo`0aoooo001Soooo00<0I_ooooooool0:Oooo`030000oooooooo
02Soool206Ko<?ooo`03o`2Ioooooooo037oool006Coool206Ko:Oooo`030000oooooooo02Ooool0
0`1Vooooooooo`0`oooo00?o09Woooooool0<Oooo`00I_ooo`0306Kooooooooo02Koool00`000?oo
ooooo`0Uoooo0P1Voc?oool00ol0VOooooooo`0aoooo001Woooo0P1Voakoool500000oooo`030000
oooooooo02Coool00`1Vooooooooo`0coooo00?o09Woooooool0<Oooo`00JOooo`0306Kooooooooo
01goool00`000?ooooooo`03oooo00<0003oooooool08oooo`0306Kooooooooo03Coool00ol0VOoo
ooooo`0aoooo001Zoooo0P1Voagoool00`000?ooooooo`03oooo0`00027oool206Ko=oooo`03o`2I
oooooooo037oool006coool206Ko6oooo`030000oooooooo00?oool00`000?ooooooo`0Poooo00<0
I_ooooooool0=oooo`03o`2Ioooooooo037oool006koool00`1Vooooooooo`0Hoooo00<0003ooooo
ool00oooo`030000oooooooo01koool206Ko>_ooo`03o`2Ioooooooo037oool006ooool206Ko5ooo
o`800005oooo00<0003oooooool07Oooo`0306Kooooooooo03[oool00ol0VOooooooo`0aoooo001a
oooo00<0I_ooooooool06oooo`030000oooooooo01coool00`1Vooooooooo`0koooo00?o09Wooooo
ool0<Oooo`00L_ooo`0306Kooooooooo01[oool00`000?ooooooo`0Joooo0P1Vockoool00ol0VOoo
ooooo`0aoooo001coooo00<0I_ooooooool06Oooo`80000Joooo00<0I_ooooooool0?_ooo`03o`2I
oooooooo037oool007Coool00`1Vooooooooo`0Hoooo00<0003oooooool06?ooo`0306Kooooooooo
03ooool00ol0VOooooooo`0aoooo001eoooo00<0I_ooooooool05oooo`030000oooooooo01Ooool0
0`1Vooooooooo`10oooo00?o09Woooooool0<Oooo`00M_ooo`80I_lGoooo00<0003oooooool05Ooo
o`80I_m3oooo00?o09Woooooool0<Oooo`00N?ooo`0306Kooooooooo01Coool00`000?ooooooo`0D
oooo00<0I_ooooooool0@oooo`03o`2Ioooooooo037oool007Woool00`1Vooooooooo`0Coooo00<0
003oooooool04oooo`0306Kooooooooo04Coool00ol0VOooooooo`0aoooo001joooo00<0I_oooooo
ool04_ooo`80000Coooo00<0I_ooooooool0AOooo`03o`2Ioooooooo037oool007_oool00`1Voooo
ooooo`0Aoooo00<0003oooooool04Oooo`0306Kooooooooo04Koool00ol0VOooooooo`0aoooo001l
oooo00<0I_ooooooool04?ooo`030000oooooooo013oool00`1Vooooooooo`17oooo00?o09Wooooo
ool0<Oooo`00OOooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0B?oo
o`03o`2Ioooooooo037oool007koool00`1Vooooooooo`0>oooo00<0003oooooool03Oooo`80I_m;
oooo00?o09Woooooool0<Oooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0<oooo00<0
I_ooooooool0Boooo`03o`2Ioooooooo037oool0083oool206Ko3Oooo`80000<oooo00<0I_oooooo
ool0C?ooo`03o`2Ioooooooo037oool008;oool00`1Vooooooooo`0:oooo00<0003oooooool02_oo
o`0306Kooooooooo04goool00ol0VOooooooo`0aoooo0023oooo00<0I_ooooooool02Oooo`030000
oooooooo00Woool00`1Vooooooooo`1>oooo00?o09Woooooool0<Oooo`00Q?ooo`0306Kooooooooo
00Soool00`000?ooooooo`08oooo00<0I_ooooooool0Coooo`03o`2Ioooooooo037oool008Goool0
0`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo053oool00ol0VOooooooo`0a
oooo0026oooo00<0I_ooooooool01_ooo`030000oooooooo00Koool00`1Vooooooooo`1Aoooo00?o
09Woooooool0<Oooo`00Qoooo`0306Kooooooooo00Goool200001_ooo`0306Kooooooooo05;oool0
0ol0VOooooooo`0aoooo0028oooo00<0I_ooooooool01?ooo`030000oooooooo00Coool00`1Voooo
ooooo`1Coooo00?o09Woooooool0<Oooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03
oooo00<0I_ooooooool0E?ooo`03o`2Ioooooooo037oool008[oool00`1Vooooooooo`02oooo00<0
003oooooool00_ooo`0306Kooooooooo05Goool00ol0VOooooooo`0aoooo001koooo1@0000;oool2
00001?ooo`8000000oooo`1Vooooo`02oooo00D0003oooooooooool0I_l0F?ooo`03o`2Ioooooooo
037oool007goool00`000?ooooooo`07oooo00H0003oooooool0003oool0I_l2oooo00@0003ooooo
ool0I_mIoooo00?o09Woooooool0<Oooo`00OOooo`030000oooooooo00[oool00`000?ooo`1Vo`02
oooo0`0005[oool00ol0VOooooooo`0aoooo001moooo00<0003oooooool02?ooo`800003oooo0P1V
o`03000006Kooooo05[oool00ol0VOooooooo`0aoooo001moooo00<0003oooooool02?ooo`030000
oooooooo00?oool00`1Vo`000?ooo`1Koooo00?o09Woooooool0<Oooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool0
0ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool2
0000Foooo`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Ooo
o`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_oo
o`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Sooo
o`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?oooo0P0005_oool00ol0VOooooooo`0a
oooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1J
oooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?
oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1Joooo00?o
09Woooooool0<Oooo`00Soooo`80001Koooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo
05[oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool0
08ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool0
0ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool2
0000Foooo`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Ooo
o`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_oo
o`03o`2Ioooooooo037oool008Ooool400001?ooo`030000oooooooo05[oool00ol0VOooooooo`0a
oooo0027oooo00<0003oooooool01Oooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo0028
oooo00<0003oooooool01?ooo`<0001Joooo00?o09Woooooool0<Oooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Qoooo`040000oooooooo00001?oo
o`030000oooooooo05[oool00ol0VOooooooo`0aoooo0028oooo0P0000Goool00`000?ooooooo`1J
oooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?
oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool20000Foooo`03o`2Ioooooooo
037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo
05[oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool0
08ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool0
0ol0VOooooooo`0aoooo002?oooo0P0005_oool00ol0VOooooooo`0aoooo002?oooo00<0003ooooo
ool0F_ooo`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Ooo
o`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_oo
o`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Sooo
o`80001Koooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0a
oooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool00`000?ooooooo`1J
oooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo05[oool00ol0VOooooooo`0aoooo002?
oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool008ooool20000Foooo`03o`2Ioooooooo
037oool008ooool00`000?ooooooo`1Joooo00?o09Woooooool0<Oooo`00Soooo`030000oooooooo
05[oool00ol0VOooooooo`0aoooo002?oooo00<0003oooooool0F_ooo`03o`2Ioooooooo037oool0
07_oool400000oooo`800004oooo0P0000Goool00`000?ooooooo`1Joooo00?o09Woooooool0<Ooo
o`00Noooo`030000oooooooo00Woool010000?ooooooo`0000Coool00`000?ooooooo`1Joooo00?o
09Woooooool0<Oooo`00O?ooo`030000oooooooo00_oool00`000?ooooooo`02oooo0`0005[oool0
0ol0VOooooooo`0aoooo001moooo00<0003oooooool02?ooo`80002Foooo001koooo00@0003ooooo
ool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool400000oooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`040000oooooooo00002?ooo`030000oooooooo00?oool010000?ooooooo`00
00?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool0
0`000?ooooooo`08oooo00<0003oooooool01Oooo`030000oooooooo00;oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0000ooool00`000?ooooooo`08oooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.83996 .04578 L
.84911 .04578 L
.85396 .04578 L
.85916 .04578 L
.86176 .04578 L
.86305 .04578 L
.86423 .04578 L
s
.86423 .04578 m
.8645 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.10458 .04578 L
.11448 .04578 L
.11992 .04578 L
.12507 .04578 L
.12986 .04578 L
.13117 .04578 L
.13256 .04578 L
.13375 .04578 L
.13506 .16028 L
.13624 .16071 L
.13732 .1611 L
.13975 .16199 L
.14415 .16361 L
.18386 .17931 L
.22205 .19638 L
.2627 .21695 L
.30183 .2394 L
.34341 .2665 L
.38348 .29619 L
.42203 .32852 L
.46303 .3675 L
.48345 .38888 L
.48857 .39446 L
.49343 .39983 L
.49778 .40472 L
.49897 .40607 L
.50024 .40696 L
.50132 .40573 L
.50252 .40438 L
.52084 .38427 L
.54049 .36395 L
.58069 .32611 L
.61938 .29395 L
.66052 .26378 L
.70014 .2382 L
.73825 .21644 L
.77881 .19597 L
.81786 .17859 L
.83777 .17051 L
.84826 .16646 L
.85399 .1643 L
.85936 .16231 L
.86181 .16142 L
.86301 .16098 L
.86413 .16057 L
.86542 .04578 L
.86609 .04578 L
Mistroke
.86681 .04578 L
.86926 .04578 L
.88016 .04578 L
.89934 .04578 L
.94097 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool01@000?oo
ooooooooo`1Vo`03oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`050000oooooooooooo06Ko00?oool00`000?ooooooo`05oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo000`oooo00<0I_ooooooool0G?ooo`030000
oooooooo05coool00`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo
05coool00`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo05coool0
0`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo05coool00`1Voooo
ooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`80001Moooo00<0I_ooooooool0;oooo`00<?oo
o`0306Kooooooooo05coool00`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Ko
oooooooo05coool00`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo
05coool00`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo05coool0
0`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo05coool00`000?oo
ooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo05coool20000GOooo`0306Ko
oooooooo02ooool0033oool00`1Vooooooooo`1Loooo00<0003oooooool0G?ooo`0306Kooooooooo
02ooool0033oool00`1Vooooooooo`1Loooo00<0003oooooool0G?ooo`0306Kooooooooo02ooool0
033oool00`1Vooooooooo`1Loooo00<0003oooooool0G?ooo`0306Kooooooooo02ooool0033oool0
0`1Vooooooooo`1Loooo00<0003oooooool0G?ooo`0306Kooooooooo02ooool0033oool00`1Voooo
ooooo`1Loooo00<0003oooooool0G?ooo`0306Kooooooooo02ooool0033oool00`1Vooooooooo`1L
oooo0P0005goool00`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo
05coool00`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo05coool0
0`1Vooooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo05coool00`1Voooo
ooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo05coool00`1Vooooooooo`0_
oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo05coool00`1Vooooooooo`0_oooo000`
oooo00<0I_ooooooool0G?ooo`80001Moooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo
05coool00`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo05coool0
0`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo05coool00`000?oo
ooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo04Woool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`1Loooo00<0I_ooooooool0;oooo`00<?ooo`0306Kooooooooo
04Soool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Loooo00<0
I_ooooooool0;oooo`00<?ooo`@0I_m7oooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0001Joooo0`1Voc7oool003Coool206KoAOooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0Eoooo`<0I_l2oooo00?o09Woooooool0;oooo`00=_ooo`80I_m3oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo05Coool306Ko1Oooo`03o`2Ioooooooo
02ooool003Soool206Ko@_ooo`80000:oooo0`0000Coool00`000?ooooooo`1Boooo0P1Vo`Soool0
0ol0VOooooooo`0_oooo000joooo0P1Voe?oool00`000?ooooooo`1@oooo0P1Vo`[oool00ol0VOoo
ooooo`0_oooo000loooo0`1Voe3oool00`000?ooooooo`1>oooo0P1Vo`coool00ol0VOooooooo`0_
oooo000ooooo0P1Vodkoool20000COooo`80I_l>oooo00?o09Woooooool0;oooo`00@Oooo`<0I_m;
oooo00<0003oooooool0B_ooo`80I_l@oooo00?o09Woooooool0;oooo`00A?ooo`80I_m9oooo00<0
003oooooool0B?ooo`80I_lBoooo00?o09Woooooool0;oooo`00A_ooo`80I_m7oooo00<0003ooooo
ool0AOooo`<0I_lDoooo00?o09Woooooool0;oooo`00B?ooo`80I_m5oooo00<0003oooooool0@ooo
o`80I_lGoooo00?o09Woooooool0;oooo`00B_ooo`80I_m3oooo0P0004;oool206Ko6Oooo`03o`2I
oooooooo02ooool004coool206Ko@Oooo`030000oooooooo03ooool206Ko6oooo`03o`2Ioooooooo
02ooool004koool206Ko?oooo`030000oooooooo03goool206Ko7Oooo`03o`2Ioooooooo02ooool0
053oool206Ko?Oooo`030000oooooooo03_oool206Ko7oooo`03o`2Ioooooooo02ooool005;oool2
06Ko>oooo`030000oooooooo03Woool206Ko8Oooo`03o`2Ioooooooo02ooool005Coool206Ko>Ooo
o`030000oooooooo03Ooool206Ko8oooo`03o`2Ioooooooo02ooool005Koool00`1Vooooooooo`0f
oooo0P0003Ooool00`1Vooooooooo`0Soooo00?o09Woooooool0;oooo`00Eoooo`80I_lfoooo00<0
003oooooool0=?ooo`80I_lVoooo00?o09Woooooool0;oooo`00FOooo`80I_ldoooo00<0003ooooo
ool0<_ooo`80I_lXoooo00?o09Woooooool0;oooo`00Foooo`0306Kooooooooo037oool00`000?oo
ooooo`0aoooo00<0I_ooooooool0:?ooo`03o`2Ioooooooo02ooool005coool206Ko<Oooo`030000
oooooooo02ooool206Ko:oooo`03o`2Ioooooooo02ooool005koool00`1Vooooooooo`0^oooo00<0
003oooooool0;_ooo`0306Kooooooooo02_oool00ol0VOooooooo`0_oooo001Ooooo0P1Vobkoool2
0000;_ooo`0306Kooooooooo02coool00ol0VOooooooo`0_oooo001Qoooo0P1Vobcoool00`000?oo
ooooo`0[oooo0P1Vobooool00ol0VOooooooo`0_oooo001Soooo00<0I_ooooooool0:Oooo`030000
oooooooo02[oool00`1Vooooooooo`0_oooo00?o09Woooooool0;oooo`00I?ooo`80I_lYoooo00<0
003oooooool0:?ooo`80I_lboooo00?o09Woooooool0;oooo`00I_ooo`0306Kooooooooo01koool5
00000oooo`030000oooooooo02Ooool00`1Vooooooooo`0boooo00?o09Woooooool0;oooo`00Iooo
o`80I_lPoooo00<0003oooooool00oooo`030000oooooooo02Goool206Ko=Oooo`03o`2Ioooooooo
02ooool006Woool00`1Vooooooooo`0Moooo00<0003oooooool00oooo`<0000Toooo00<0I_oooooo
ool0=Oooo`03o`2Ioooooooo02ooool006[oool00`1Vooooooooo`0Loooo00<0003oooooool00ooo
o`030000oooooooo02;oool206Ko>?ooo`03o`2Ioooooooo02ooool006_oool206Ko7?ooo`030000
oooooooo00?oool00`000?ooooooo`0Poooo0P1Voc[oool00ol0VOooooooo`0_oooo001]oooo00<0
I_ooooooool06?ooo`800005oooo00<0003oooooool07oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0_oooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01goool206Ko?Oooo`03o`2I
oooooooo02ooool006ooool206Ko7_ooo`030000oooooooo01coool00`1Vooooooooo`0moooo00?o
09Woooooool0;oooo`00LOooo`0306Kooooooooo01_oool200007?ooo`0306Kooooooooo03koool0
0ol0VOooooooo`0_oooo001boooo00<0I_ooooooool06_ooo`030000oooooooo01[oool00`1Voooo
ooooo`0ooooo00?o09Woooooool0;oooo`00Loooo`80I_lJoooo00<0003oooooool06Oooo`0306Ko
oooooooo043oool00ol0VOooooooo`0_oooo001eoooo00<0I_ooooooool05oooo`030000oooooooo
01Soool00`1Vooooooooo`11oooo00?o09Woooooool0;oooo`00M_ooo`0306Kooooooooo01Koool0
0`000?ooooooo`0Foooo0P1VodCoool00ol0VOooooooo`0_oooo001goooo00<0I_ooooooool05Ooo
o`030000oooooooo01Goool00`1Vooooooooo`14oooo00?o09Woooooool0;oooo`00N?ooo`80I_lE
oooo0P0001Goool00`1Vooooooooo`15oooo00?o09Woooooool0;oooo`00N_ooo`0306Kooooooooo
01;oool00`000?ooooooo`0Coooo00<0I_ooooooool0A_ooo`03o`2Ioooooooo02ooool007_oool0
0`1Vooooooooo`0Aoooo00<0003oooooool04_ooo`0306Kooooooooo04Ooool00ol0VOooooooo`0_
oooo001loooo00<0I_ooooooool04?ooo`030000oooooooo017oool00`1Vooooooooo`18oooo00?o
09Woooooool0;oooo`00OOooo`0306Kooooooooo00ooool00`000?ooooooo`0@oooo00<0I_oooooo
ool0BOooo`03o`2Ioooooooo02ooool007koool00`1Vooooooooo`0>oooo00<0003oooooool03ooo
o`0306Kooooooooo04[oool00ol0VOooooooo`0_oooo001ooooo00<0I_ooooooool03Oooo`80000?
oooo00<0I_ooooooool0Boooo`03o`2Ioooooooo02ooool0083oool00`1Vooooooooo`0<oooo00<0
003oooooool03Oooo`0306Kooooooooo04coool00ol0VOooooooo`0_oooo0020oooo00<0I_oooooo
ool03?ooo`030000oooooooo00coool00`1Vooooooooo`1=oooo00?o09Woooooool0;oooo`00POoo
o`0306Kooooooooo00_oool00`000?ooooooo`0;oooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo
02ooool008;oool00`1Vooooooooo`0:oooo00<0003oooooool02_ooo`0306Kooooooooo04ooool0
0ol0VOooooooo`0_oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Voooo
ooooo`1@oooo00?o09Woooooool0;oooo`00Q?ooo`0306Kooooooooo00Soool200002Oooo`0306Ko
oooooooo057oool00ol0VOooooooo`0_oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo
00Ooool00`1Vooooooooo`1Boooo00?o09Woooooool0;oooo`00Q_ooo`0306Kooooooooo00Koool0
0`000?ooooooo`06oooo00<0I_ooooooool0Doooo`03o`2Ioooooooo02ooool008Ooool00`1Voooo
ooooo`05oooo00<0003oooooool01?ooo`80I_mFoooo00?o09Woooooool0;oooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo00?oool00`1Vooooooooo`1Foooo00?o09Wooooo
ool0;oooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`02
oooo00<0I_ooooooool0Eoooo`03o`2Ioooooooo02ooool007goool00`000?ooooooo`0:oooo00<0
0000I_ooool00_ooo`<000000oooo`1Vooooo`1Ioooo00?o09Woooooool0;oooo`00OOooo`030000
oooooooo00Soool2000000?oool0I_ooool00_ooo`040000oooooooo06KoFoooo`03o`2Ioooooooo
02ooool007goool00`000?ooooooo`08oooo00D0003oooooooooool0I_l00_ooo`040000oooooooo
06KoFoooo`03o`2Ioooooooo02ooool007coool200002_ooo`<00002oooo00D0I_ooool0003oool0
I_l0G?ooo`03o`2Ioooooooo02ooool008koool00`1Vo`00001Vo`1Moooo00?o09Woooooool0;ooo
o`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOoo
ooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?oo
ooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_
oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1L
oooo00?o09Woooooool0;oooo`00Soooo`80001Moooo00?o09Woooooool0;oooo`00Soooo`030000
oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo
02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo
05coool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool0
08ooool20000GOooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Wooooo
ool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003ooooo
ool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;ooo
o`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOoo
ooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?oo
ooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_
oooo0027oooo100000Coool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Qoooo`030000
oooooooo00Goool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00R?ooo`030000oooooooo
00Coool30000G?ooo`03o`2Ioooooooo02ooool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0G?ooo`03o`2Ioooooooo02ooool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`1L
oooo00?o09Woooooool0;oooo`00R?ooo`800005oooo00<0003oooooool0G?ooo`03o`2Ioooooooo
02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo
05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_oooo002?oooo00<0
003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Wooooo
ool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003ooooo
ool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;ooo
o`00Soooo`80001Moooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOoo
ooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?oo
ooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_
oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool20000GOooo`03o`2I
oooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000
oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo
02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo
05coool00ol0VOooooooo`0_oooo002?oooo0P0005goool00ol0VOooooooo`0_oooo002?oooo00<0
003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Wooooo
ool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo001koooo100000?oool2
00001?ooo`800005oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool007_oool00`000?oo
ooooo`09oooo00@0003oooooool00004oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool0
07coool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0001Loooo00?o09Woooooool0;ooo
o`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007coool0
0`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?oo
ooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?oo
ooooo`1joooo001koooo00<0003oooooool01@0000ooool00`000?ooooooo`09oooo00D0003ooooo
ooooool00000OOooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:
oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.83996 .04578 L
.84911 .04578 L
.85916 .04578 L
.86384 .04578 L
.86642 .04578 L
.86886 .04578 L
.87112 .04578 L
.8724 .04578 L
s
.8724 .04578 m
.8727 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.10458 .04578 L
.11448 .04578 L
.11992 .04578 L
.1226 .04578 L
.12377 .04578 L
.12507 .04578 L
.12627 .04578 L
.12739 .16038 L
.12858 .16081 L
.12986 .16127 L
.13506 .16318 L
.14415 .16659 L
.18538 .18334 L
.22508 .20167 L
.26328 .2216 L
.30392 .24562 L
.34305 .27183 L
.38463 .30347 L
.4247 .33813 L
.46325 .37588 L
.4828 .39684 L
.48815 .40281 L
.4939 .40933 L
.49668 .41253 L
.49805 .41412 L
.49931 .41559 L
.50046 .41585 L
.50168 .41443 L
.50426 .41145 L
.54374 .36868 L
.58149 .33248 L
.6217 .29838 L
.66038 .2694 L
.70152 .24222 L
.74115 .21917 L
.77926 .19955 L
.81982 .18111 L
.83855 .17336 L
.85886 .16545 L
.86426 .16343 L
.86721 .16234 L
.86997 .16133 L
.87117 .1609 L
.87232 .16048 L
.87364 .04578 L
.87484 .04578 L
.88021 .04578 L
Mistroke
.90036 .04578 L
.93861 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
o`1Vo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00?oool00`1Vooooo`000007oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool0
0`1Vooooooooo`0]oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool00`1Voooo
ooooo`0]oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool00`1Vooooooooo`0]
oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool00`1Vooooooooo`0]oooo000^
oooo00<0I_ooooooool0G_ooo`80001Ooooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo
05koool00`000?ooooooo`1Noooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool0
0`000?ooooooo`1Noooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool00`000?oo
ooooo`1Noooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool00`000?ooooooo`1N
oooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool00`000?ooooooo`1Noooo00<0
I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool20000Goooo`0306Kooooooooo02goool0
02koool00`1Vooooooooo`1Noooo00<0003oooooool0G_ooo`0306Kooooooooo02goool002koool0
0`1Vooooooooo`1Noooo00<0003oooooool0G_ooo`0306Kooooooooo02goool002koool00`1Voooo
ooooo`1Noooo00<0003oooooool0G_ooo`0306Kooooooooo02goool002koool00`1Vooooooooo`1N
oooo00<0003oooooool0G_ooo`0306Kooooooooo02goool002koool00`1Vooooooooo`1Noooo00<0
003oooooool0G_ooo`0306Kooooooooo02goool002koool00`1Vooooooooo`1Noooo0P0005ooool0
0`1Vooooooooo`0]oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool00`1Voooo
ooooo`0]oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool00`1Vooooooooo`0]
oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool00`1Vooooooooo`0]oooo000^
oooo00<0I_ooooooool0G_ooo`030000oooooooo05koool00`1Vooooooooo`0]oooo000^oooo00<0
I_ooooooool0G_ooo`030000oooooooo05koool00`1Vooooooooo`0]oooo000^oooo00<0I_oooooo
ool0G_ooo`80001Ooooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool00`000?oo
ooooo`1Noooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool00`000?ooooooo`1N
oooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo05koool00`000?ooooooo`1Noooo00<0
I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo04_oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Noooo00<0I_ooooooool0;Oooo`00;_ooo`0306Kooooooooo04[oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Noooo00<0I_ooooooool0;Ooo
o`00;_ooo`<0I_m:oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Loooo0`1V
obooool0037oool306KoAoooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0FOoo
o`<0I_l2oooo00?o09Woooooool0;Oooo`00=?ooo`80I_m5oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo05Ooool206Ko1Oooo`03o`2Ioooooooo02goool003Koool2
06KoA?ooo`80000:oooo0`0000Coool00`000?ooooooo`1Doooo0`1Vo`Ooool00ol0VOooooooo`0]
oooo000hoooo0P1VoeGoool00`000?ooooooo`1Boooo0P1Vo`[oool00ol0VOooooooo`0]oooo000j
oooo0P1Voe?oool00`000?ooooooo`1@oooo0P1Vo`coool00ol0VOooooooo`0]oooo000loooo0`1V
oe3oool20000Coooo`80I_l>oooo00?o09Woooooool0;Oooo`00?oooo`80I_m>oooo00<0003ooooo
ool0C?ooo`80I_l@oooo00?o09Woooooool0;Oooo`00@Oooo`<0I_m;oooo00<0003oooooool0B_oo
o`80I_lBoooo00?o09Woooooool0;Oooo`00A?ooo`80I_m9oooo00<0003oooooool0B?ooo`80I_lD
oooo00?o09Woooooool0;Oooo`00A_ooo`80I_m7oooo00<0003oooooool0A_ooo`80I_lFoooo00?o
09Woooooool0;Oooo`00B?ooo`80I_m5oooo0P0004Goool206Ko6?ooo`03o`2Ioooooooo02goool0
04[oool206Ko@oooo`030000oooooooo04;oool206Ko6_ooo`03o`2Ioooooooo02goool004coool0
0`1Vooooooooo`10oooo00<0003oooooool0@?ooo`80I_lLoooo00?o09Woooooool0;Oooo`00COoo
o`80I_m0oooo00<0003oooooool0?_ooo`80I_lNoooo00?o09Woooooool0;Oooo`00Coooo`80I_ln
oooo00<0003oooooool0??ooo`80I_lPoooo00?o09Woooooool0;Oooo`00DOooo`0306Kooooooooo
03_oool00`000?ooooooo`0joooo0P1Vob;oool00ol0VOooooooo`0]oooo001Boooo0P1Voc_oool2
0000>Oooo`80I_lToooo00?o09Woooooool0;Oooo`00E?ooo`80I_lioooo00<0003oooooool0=_oo
o`80I_lVoooo00?o09Woooooool0;Oooo`00E_ooo`80I_lgoooo00<0003oooooool0=?ooo`80I_lX
oooo00?o09Woooooool0;Oooo`00F?ooo`80I_leoooo00<0003oooooool0<_ooo`80I_lZoooo00?o
09Woooooool0;Oooo`00F_ooo`80I_lcoooo00<0003oooooool0<Oooo`0306Kooooooooo02[oool0
0ol0VOooooooo`0]oooo001Loooo00<0I_ooooooool0<?ooo`030000oooooooo02ooool206Ko;Ooo
o`03o`2Ioooooooo02goool005goool206Ko<?ooo`80000_oooo00<0I_ooooooool0;Oooo`03o`2I
oooooooo02goool005ooool00`1Vooooooooo`0]oooo00<0003oooooool0;Oooo`0306Kooooooooo
02koool00ol0VOooooooo`0]oooo001Poooo00<0I_ooooooool0;?ooo`030000oooooooo02_oool2
06Ko<Oooo`03o`2Ioooooooo02goool0067oool206Ko;?ooo`030000oooooooo02[oool00`1Voooo
ooooo`0aoooo00?o09Woooooool0;Oooo`00Hoooo`0306Kooooooooo027oool500000oooo`030000
oooooooo02Soool206Ko=?ooo`03o`2Ioooooooo02goool006Coool206Ko8oooo`030000oooooooo
00?oool00`000?ooooooo`0Woooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo02goool006Koool0
0`1Vooooooooo`0Poooo00<0003oooooool00oooo`<0000Voooo00<0I_ooooooool0=Oooo`03o`2I
oooooooo02goool006Ooool206Ko8?ooo`030000oooooooo00?oool00`000?ooooooo`0Toooo0P1V
ocSoool00ol0VOooooooo`0]oooo001Yoooo00<0I_ooooooool07Oooo`030000oooooooo00?oool0
0`000?ooooooo`0Soooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo02goool006[oool00`1Voooo
ooooo`0Koooo0P0000Goool00`000?ooooooo`0Roooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02goool006_oool206Ko8_ooo`030000oooooooo027oool00`1Vooooooooo`0joooo00?o09Wooooo
ool0;Oooo`00KOooo`0306Kooooooooo01ooool00`000?ooooooo`0Ooooo0P1Vocgoool00ol0VOoo
ooooo`0]oooo001^oooo00<0I_ooooooool07_ooo`80000Ooooo00<0I_ooooooool0?Oooo`03o`2I
oooooooo02goool006ooool206Ko7_ooo`030000oooooooo01goool00`1Vooooooooo`0noooo00?o
09Woooooool0;Oooo`00LOooo`0306Kooooooooo01_oool00`000?ooooooo`0Koooo0P1Vod7oool0
0ol0VOooooooo`0]oooo001boooo00<0I_ooooooool06_ooo`030000oooooooo01[oool00`1Voooo
ooooo`11oooo00?o09Woooooool0;Oooo`00Loooo`0306Kooooooooo01Woool00`000?ooooooo`0I
oooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo02goool007Coool00`1Vooooooooo`0Hoooo00<0
003oooooool05oooo`80I_m5oooo00?o09Woooooool0;Oooo`00MOooo`0306Kooooooooo01Ooool2
00005oooo`0306Kooooooooo04Goool00ol0VOooooooo`0]oooo001foooo0P1VoaOoool00`000?oo
ooooo`0Eoooo00<0I_ooooooool0A_ooo`03o`2Ioooooooo02goool007Soool00`1Vooooooooo`0D
oooo00<0003oooooool04oooo`80I_m9oooo00?o09Woooooool0;Oooo`00NOooo`0306Kooooooooo
01?oool00`000?ooooooo`0Boooo00<0I_ooooooool0BOooo`03o`2Ioooooooo02goool007[oool0
0`1Vooooooooo`0Boooo00<0003oooooool04Oooo`0306Kooooooooo04[oool00ol0VOooooooo`0]
oooo001koooo00<0I_ooooooool04Oooo`030000oooooooo013oool00`1Vooooooooo`1;oooo00?o
09Woooooool0;Oooo`00O?ooo`0306Kooooooooo013oool200004?ooo`0306Kooooooooo04coool0
0ol0VOooooooo`0]oooo001moooo00<0I_ooooooool03oooo`030000oooooooo00koool00`1Voooo
ooooo`1=oooo00?o09Woooooool0;Oooo`00O_ooo`0306Kooooooooo00koool00`000?ooooooo`0=
oooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo02goool007ooool00`1Vooooooooo`0=oooo00<0
003oooooool03?ooo`0306Kooooooooo04ooool00ol0VOooooooo`0]oooo0020oooo00<0I_oooooo
ool03?ooo`030000oooooooo00_oool00`1Vooooooooo`1@oooo00?o09Woooooool0;Oooo`00POoo
o`0306Kooooooooo00_oool00`000?ooooooo`0:oooo00<0I_ooooooool0DOooo`03o`2Ioooooooo
02goool008;oool00`1Vooooooooo`0:oooo0P0000[oool00`1Vooooooooo`1Boooo00?o09Wooooo
ool0;Oooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`08oooo00<0I_ooooooool0Dooo
o`03o`2Ioooooooo02goool008Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`0306Ko
oooooooo05Coool00ol0VOooooooo`0]oooo0025oooo00<0I_ooooooool01oooo`030000oooooooo
00Koool00`1Vooooooooo`1Eoooo00?o09Woooooool0;Oooo`00Noooo`D00002oooo0P0000;oool0
101Vooooo`00000000Goool00`000?ooooooo`05oooo00<0I_ooooooool0E_ooo`03o`2Ioooooooo
02goool007goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool01?oo
o`0306Kooooooooo05Ooool00ol0VOooooooo`0]oooo001moooo00<0003oooooool02?ooo`0306Ko
oooo000000Coool300000oooo`0306Kooooooooo05Soool00ol0VOooooooo`0]oooo001moooo00<0
003oooooool02?ooo`800005oooo00<0003oooooool00oooo`0306Kooooooooo05Soool00ol0VOoo
ooooo`0]oooo001moooo00<0003oooooool02?ooo`030000oooo06Ko00Coool00`000?ooooooo`02
oooo00<0I_ooooooool0FOooo`03o`2Ioooooooo02goool007coool200002_ooo`<000001@1Voooo
ooooooooo`000003oooo00<0I_ooooooool0F_ooo`03o`2Ioooooooo02goool008coool0101Voooo
ooooo`0000;oool00`1Vooooooooo`1Koooo00?o09Woooooool0;Oooo`00SOooo`0506Kooooo0000
oooo06Ko05koool00ol0VOooooooo`0]oooo002>oooo00<0I_l000000000Goooo`03o`2Ioooooooo
02goool008koool00`1Vo`000?ooo`1Ooooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo
05koool00ol0VOooooooo`0]oooo002?oooo00<0003oooooool0G_ooo`03o`2Ioooooooo02goool0
08ooool00`000?ooooooo`1Noooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo05koool0
0ol0VOooooooo`0]oooo002?oooo0P0005ooool00ol0VOooooooo`0]oooo002?oooo00<0003ooooo
ool0G_ooo`03o`2Ioooooooo02goool008ooool00`000?ooooooo`1Noooo00?o09Woooooool0;Ooo
o`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]oooo002?oooo00<0003oooooool0G_oo
o`03o`2Ioooooooo02goool008ooool00`000?ooooooo`1Noooo00?o09Woooooool0;Oooo`00Sooo
o`80001Ooooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]
oooo002?oooo00<0003oooooool0G_ooo`03o`2Ioooooooo02goool008ooool00`000?ooooooo`1N
oooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]oooo002?
oooo00<0003oooooool0G_ooo`03o`2Ioooooooo02goool008ooool20000Goooo`03o`2Ioooooooo
02goool008ooool00`000?ooooooo`1Noooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo
05koool00ol0VOooooooo`0]oooo002?oooo00<0003oooooool0G_ooo`03o`2Ioooooooo02goool0
08Ooool400001?ooo`030000oooooooo05koool00ol0VOooooooo`0]oooo0027oooo00<0003ooooo
ool01Oooo`030000oooooooo05koool00ol0VOooooooo`0]oooo0028oooo00<0003oooooool01?oo
o`<0001Noooo00?o09Woooooool0;Oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1N
oooo00?o09Woooooool0;Oooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo05koool0
0ol0VOooooooo`0]oooo0028oooo0P0000Goool00`000?ooooooo`1Noooo00?o09Woooooool0;Ooo
o`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]oooo002?oooo00<0003oooooool0G_oo
o`03o`2Ioooooooo02goool008ooool20000Goooo`03o`2Ioooooooo02goool008ooool00`000?oo
ooooo`1Noooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]
oooo002?oooo00<0003oooooool0G_ooo`03o`2Ioooooooo02goool008ooool00`000?ooooooo`1N
oooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]oooo002?
oooo0P0005ooool00ol0VOooooooo`0]oooo002?oooo00<0003oooooool0G_ooo`03o`2Ioooooooo
02goool008ooool00`000?ooooooo`1Noooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo
05koool00ol0VOooooooo`0]oooo002?oooo00<0003oooooool0G_ooo`03o`2Ioooooooo02goool0
08ooool00`000?ooooooo`1Noooo00?o09Woooooool0;Oooo`00Soooo`80001Ooooo00?o09Wooooo
ool0;Oooo`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]oooo002?oooo00<0003ooooo
ool0G_ooo`03o`2Ioooooooo02goool008ooool00`000?ooooooo`1Noooo00?o09Woooooool0;Ooo
o`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]oooo002?oooo00<0003oooooool0G_oo
o`03o`2Ioooooooo02goool008ooool20000Goooo`03o`2Ioooooooo02goool008ooool00`000?oo
ooooo`1Noooo00?o09Woooooool0;Oooo`00Soooo`030000oooooooo05koool00ol0VOooooooo`0]
oooo002?oooo00<0003oooooool0G_ooo`03o`2Ioooooooo02goool007_oool400000oooo`800004
oooo0P0000Goool00`000?ooooooo`1Noooo00?o09Woooooool0;Oooo`00Noooo`030000oooooooo
00Woool010000?ooooooo`0000Coool00`000?ooooooo`1Noooo00?o09Woooooool0;Oooo`00O?oo
o`030000oooooooo00_oool00`000?ooooooo`02oooo0`0005koool00ol0VOooooooo`0]oooo001m
oooo00<0003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003ooooo
ool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000
oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo
01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003ooooo
ool01oooo`800004oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo00000oooo`030000oooooooo
07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?oo
ooooo`0500003oooo`030000oooooooo00Woool010000?ooooooooooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo
017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.83996 .04578 L
.85916 .04578 L
.86886 .04578 L
.87359 .04578 L
.87791 .04578 L
.87903 .04578 L
.88025 .04578 L
s
.88025 .04578 m
.88053 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.0932 .04578 L
.10458 .04578 L
.11009 .04578 L
.1128 .04578 L
.11531 .04578 L
.11758 .04578 L
.11872 .04578 L
.11999 .16057 L
.12125 .16103 L
.12261 .16152 L
.12507 .16242 L
.14415 .16965 L
.18538 .18683 L
.22508 .20562 L
.26328 .22605 L
.30392 .25068 L
.34305 .27755 L
.38463 .30999 L
.4247 .34553 L
.46325 .38423 L
.4828 .40573 L
.48815 .41185 L
.4939 .41853 L
.49668 .42182 L
.49805 .42344 L
.49931 .42495 L
.50046 .42522 L
.50168 .42376 L
.50426 .42071 L
.54374 .37686 L
.58149 .33974 L
.6217 .30477 L
.66038 .27506 L
.70152 .24719 L
.74115 .22356 L
.77926 .20345 L
.81982 .18454 L
.85886 .16848 L
.86911 .16458 L
.8745 .16258 L
.87745 .1615 L
.87889 .16098 L
.88021 .1605 L
.88144 .04578 L
.88262 .04578 L
.8852 .04578 L
.89069 .04578 L
Mistroke
.90036 .04578 L
.93861 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo063oool0
0`1Vooooooooo`0[oooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo063oool00`1Voooo
ooooo`0[oooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo063oool00`1Vooooooooo`0[
oooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo063oool00`1Vooooooooo`0[oooo000/
oooo00<0I_ooooooool0H?ooo`80001Qoooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo
063oool00`000?ooooooo`1Poooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo063oool0
0`000?ooooooo`1Poooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo063oool00`000?oo
ooooo`1Poooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo063oool00`000?ooooooo`1P
oooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo063oool00`000?ooooooo`1Poooo00<0
I_ooooooool0:oooo`00;?ooo`0306Kooooooooo063oool20000HOooo`0306Kooooooooo02_oool0
02coool00`1Vooooooooo`1Poooo00<0003oooooool0H?ooo`0306Kooooooooo02_oool002coool0
0`1Vooooooooo`1Poooo00<0003oooooool0H?ooo`0306Kooooooooo02_oool002coool00`1Voooo
ooooo`1Poooo00<0003oooooool0H?ooo`0306Kooooooooo02_oool002coool00`1Vooooooooo`1P
oooo00<0003oooooool0H?ooo`0306Kooooooooo02_oool002coool00`1Vooooooooo`1Poooo00<0
003oooooool0H?ooo`0306Kooooooooo02_oool002coool00`1Vooooooooo`1Poooo0P00067oool0
0`1Vooooooooo`0[oooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo063oool00`1Voooo
ooooo`0[oooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo063oool00`1Vooooooooo`0[
oooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo063oool00`1Vooooooooo`0[oooo000/
oooo00<0I_ooooooool0H?ooo`030000oooooooo063oool00`1Vooooooooo`0[oooo000/oooo00<0
I_ooooooool0H?ooo`030000oooooooo063oool00`1Vooooooooo`0[oooo000/oooo00<0I_oooooo
ool0H?ooo`80001Qoooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo063oool00`000?oo
ooooo`1Poooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo063oool00`000?ooooooo`1P
oooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo063oool00`000?ooooooo`1Poooo00<0
I_ooooooool0:oooo`00;?ooo`0306Kooooooooo04goool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Poooo00<0I_ooooooool0:oooo`00;?ooo`0306Kooooooooo04coool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Poooo00<0I_ooooooool0:ooo
o`00;?ooo`<0I_m<oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Noooo0`1V
obgoool002ooool206KoB_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0G?oo
o`80I_l2oooo00?o09Woooooool0:oooo`00<Oooo`<0I_m7oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo05Woool306Ko1?ooo`03o`2Ioooooooo02_oool003Coool2
06KoA_ooo`80000:oooo0`0000Coool00`000?ooooooo`1Goooo0P1Vo`Ooool00ol0VOooooooo`0[
oooo000foooo0P1VoeOoool00`000?ooooooo`1Doooo0`1Vo`Woool00ol0VOooooooo`0[oooo000h
oooo0P1VoeGoool00`000?ooooooo`1Boooo0P1Vo`coool00ol0VOooooooo`0[oooo000joooo0P1V
oe?oool20000DOooo`80I_l>oooo00?o09Woooooool0:oooo`00??ooo`<0I_m@oooo00<0003ooooo
ool0C_ooo`80I_l@oooo00?o09Woooooool0:oooo`00?oooo`80I_m>oooo00<0003oooooool0C?oo
o`80I_lBoooo00?o09Woooooool0:oooo`00@Oooo`<0I_m;oooo00<0003oooooool0B_ooo`80I_lD
oooo00?o09Woooooool0:oooo`00A?ooo`80I_m9oooo00<0003oooooool0B?ooo`80I_lFoooo00?o
09Woooooool0:oooo`00A_ooo`80I_m7oooo0P0004Ooool206Ko6?ooo`03o`2Ioooooooo02_oool0
04Soool206KoAOooo`030000oooooooo04Coool206Ko6_ooo`03o`2Ioooooooo02_oool004[oool2
06Ko@oooo`030000oooooooo04;oool206Ko7?ooo`03o`2Ioooooooo02_oool004coool00`1Voooo
ooooo`10oooo00<0003oooooool0@?ooo`80I_lNoooo00?o09Woooooool0:oooo`00COooo`80I_m0
oooo00<0003oooooool0?_ooo`80I_lPoooo00?o09Woooooool0:oooo`00Coooo`80I_lnoooo00<0
003oooooool0??ooo`80I_lRoooo00?o09Woooooool0:oooo`00DOooo`0306Kooooooooo03_oool2
0000>oooo`80I_lToooo00?o09Woooooool0:oooo`00D_ooo`80I_lkoooo00<0003oooooool0>?oo
o`80I_lVoooo00?o09Woooooool0:oooo`00E?ooo`80I_lioooo00<0003oooooool0=_ooo`80I_lX
oooo00?o09Woooooool0:oooo`00E_ooo`80I_lgoooo00<0003oooooool0=?ooo`80I_lZoooo00?o
09Woooooool0:oooo`00F?ooo`80I_leoooo00<0003oooooool0<_ooo`80I_l/oooo00?o09Wooooo
ool0:oooo`00F_ooo`80I_lcoooo00<0003oooooool0<Oooo`0306Kooooooooo02coool00ol0VOoo
ooooo`0[oooo001Loooo00<0I_ooooooool0<?ooo`80000`oooo0P1Vobooool00ol0VOooooooo`0[
oooo001Moooo0P1Voc3oool00`000?ooooooo`0^oooo00<0I_ooooooool0;oooo`03o`2Ioooooooo
02_oool005ooool00`1Vooooooooo`0]oooo00<0003oooooool0;Oooo`0306Kooooooooo033oool0
0ol0VOooooooo`0[oooo001Poooo00<0I_ooooooool0;?ooo`030000oooooooo02_oool206Ko<ooo
o`03o`2Ioooooooo02_oool0067oool206Ko9?ooo`D00003oooo00<0003oooooool0:_ooo`0306Ko
oooooooo03?oool00ol0VOooooooo`0[oooo001Soooo00<0I_ooooooool08oooo`030000oooooooo
00?oool00`000?ooooooo`0Xoooo0P1VocKoool00ol0VOooooooo`0[oooo001Toooo0P1Vob?oool0
0`000?ooooooo`03oooo0`0002Ooool00`1Vooooooooo`0foooo00?o09Woooooool0:oooo`00I_oo
o`0306Kooooooooo023oool00`000?ooooooo`03oooo00<0003oooooool09_ooo`0306Kooooooooo
03Ooool00ol0VOooooooo`0[oooo001Woooo00<0I_ooooooool07oooo`030000oooooooo00?oool0
0`000?ooooooo`0Toooo0P1Voc[oool00ol0VOooooooo`0[oooo001Xoooo0P1Voakoool200001Ooo
o`030000oooooooo02?oool00`1Vooooooooo`0joooo00?o09Woooooool0:oooo`00J_ooo`0306Ko
oooooooo02;oool00`000?ooooooo`0Roooo00<0I_ooooooool0>oooo`03o`2Ioooooooo02_oool0
06_oool00`1Vooooooooo`0Qoooo00<0003oooooool08Oooo`0306Kooooooooo03coool00ol0VOoo
ooooo`0[oooo001/oooo00<0I_ooooooool08?ooo`80000Poooo0P1Vocooool00ol0VOooooooo`0[
oooo001]oooo00<0I_ooooooool07oooo`030000oooooooo01koool00`1Vooooooooo`0ooooo00?o
09Woooooool0:oooo`00K_ooo`80I_lOoooo00<0003oooooool07Oooo`0306Kooooooooo043oool0
0ol0VOooooooo`0[oooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01coool00`1Voooo
ooooo`11oooo00?o09Woooooool0:oooo`00LOooo`0306Kooooooooo01_oool00`000?ooooooo`0J
oooo0P1VodCoool00ol0VOooooooo`0[oooo001boooo00<0I_ooooooool06_ooo`030000oooooooo
01Woool00`1Vooooooooo`14oooo00?o09Woooooool0:oooo`00Loooo`0306Kooooooooo01Woool2
00006Oooo`0306Kooooooooo04Goool00ol0VOooooooo`0[oooo001doooo00<0I_ooooooool06?oo
o`030000oooooooo01Ooool00`1Vooooooooo`16oooo00?o09Woooooool0:oooo`00MOooo`0306Ko
oooooooo01Ooool00`000?ooooooo`0Foooo00<0I_ooooooool0Aoooo`03o`2Ioooooooo02_oool0
07Koool206Ko5oooo`030000oooooooo01Coool206KoB_ooo`03o`2Ioooooooo02_oool007Soool0
0`1Vooooooooo`0Doooo00<0003oooooool04oooo`0306Kooooooooo04[oool00ol0VOooooooo`0[
oooo001ioooo00<0I_ooooooool04oooo`030000oooooooo01;oool00`1Vooooooooo`1;oooo00?o
09Woooooool0:oooo`00N_ooo`0306Kooooooooo01;oool200004_ooo`0306Kooooooooo04coool0
0ol0VOooooooo`0[oooo001koooo00<0I_ooooooool04Oooo`030000oooooooo013oool00`1Voooo
ooooo`1=oooo00?o09Woooooool0:oooo`00O?ooo`0306Kooooooooo013oool00`000?ooooooo`0?
oooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo02_oool007goool00`1Vooooooooo`0?oooo00<0
003oooooool03_ooo`0306Kooooooooo04ooool00ol0VOooooooo`0[oooo001noooo00<0I_oooooo
ool03_ooo`030000oooooooo00goool00`1Vooooooooo`1@oooo00?o09Woooooool0:oooo`00Oooo
o`0306Kooooooooo00goool00`000?ooooooo`0<oooo00<0I_ooooooool0DOooo`03o`2Ioooooooo
02_oool0083oool00`1Vooooooooo`0<oooo0P0000coool00`1Vooooooooo`1Boooo00?o09Wooooo
ool0:oooo`00POooo`0306Kooooooooo00_oool00`000?ooooooo`0:oooo00<0I_ooooooool0Dooo
o`03o`2Ioooooooo02_oool008;oool00`1Vooooooooo`0:oooo00<0003oooooool02Oooo`0306Ko
oooooooo05Coool00ol0VOooooooo`0[oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo
00Soool00`1Vooooooooo`1Eoooo00?o09Woooooool0:oooo`00Noooo`D00002oooo0P00000406Ko
oooooooooooo0P0000Goool00`000?ooooooo`07oooo00<0I_ooooooool0E_ooo`03o`2Ioooooooo
02_oool007goool00`000?ooooooo`05oooo00<0I_ooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`06oooo00<0I_ooooooool0Eoooo`03o`2Ioooooooo02_oool007goool00`000?oo
ooooo`06oooo00D0I_ooooooooooool000001?ooo`<00005oooo00<0I_ooooooool0F?ooo`03o`2I
oooooooo02_oool007goool00`000?ooooooo`07oooo00<0I_l0000000001Oooo`030000oooooooo
00Coool00`1Vooooooooo`1Ioooo00?o09Woooooool0:oooo`00OOooo`030000oooooooo00Soool0
0`000?ooooooo`04oooo00<0003oooooool00oooo`0306Kooooooooo05[oool00ol0VOooooooo`0[
oooo001loooo0P0000[oool300001?ooo`030000oooooooo00?oool00`1Vooooooooo`1Joooo00?o
09Woooooool0:oooo`00R_ooo`0306Kooooooooo00;oool00`000?ooooooo`02oooo00<0I_oooooo
ool0Foooo`03o`2Ioooooooo02_oool008_oool01@1Vooooooooooooo`000003oooo00<0I_oooooo
ool0G?ooo`03o`2Ioooooooo02_oool008coool00`1Vooooooooo`02000000?oool0I_ooool0G_oo
o`03o`2Ioooooooo02_oool008coool01P1Vooooooooo`000?ooo`1Vof3oool00ol0VOooooooo`0[
oooo002=oooo00@0I_ooool00000I_mQoooo00?o09Woooooool0:oooo`00S_ooo`0306Ko0000oooo
067oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool0
08ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Wooooo
ool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?oooo00<0003ooooo
ool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:ooo
o`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?oo
o`03o`2Ioooooooo02_oool008ooool20000HOooo`03o`2Ioooooooo02_oool008ooool00`000?oo
ooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[
oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1P
oooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?
oooo0P00067oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo
02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo
063oool00ol0VOooooooo`0[oooo0027oooo100000Coool00`000?ooooooo`1Poooo00?o09Wooooo
ool0:oooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`1Poooo00?o09Woooooool0:ooo
o`00R?ooo`030000oooooooo00Coool30000H?ooo`03o`2Ioooooooo02_oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008Ooool010000?ooooooo`00
00Coool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00R?ooo`800005oooo00<0003ooooo
ool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:ooo
o`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?oooo0P00067oool00ol0VOoo
ooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?oo
ooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[
oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1P
oooo00?o09Woooooool0:oooo`00Soooo`80001Qoooo00?o09Woooooool0:oooo`00Soooo`030000
oooooooo063oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo
02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo
063oool00ol0VOooooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool0
08ooool20000HOooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Wooooo
ool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?oooo00<0003ooooo
ool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?ooooooo`1Poooo00?o09Woooooool0:ooo
o`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[oooo002?oooo0P00067oool00ol0VOoo
ooooo`0[oooo002?oooo00<0003oooooool0H?ooo`03o`2Ioooooooo02_oool008ooool00`000?oo
ooooo`1Poooo00?o09Woooooool0:oooo`00Soooo`030000oooooooo063oool00ol0VOooooooo`0[
oooo001koooo100000?oool200001?ooo`800005oooo00<0003oooooool0H?ooo`03o`2Ioooooooo
02_oool007_oool00`000?ooooooo`09oooo00@0003oooooool00004oooo00<0003oooooool0H?oo
o`03o`2Ioooooooo02_oool007coool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0001P
oooo00?o09Woooooool0:oooo`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000
oooooooo00002Oooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Ooo
o`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000
oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo0`0000;oool00`000?oo
ooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`05oooo00@0003oooooool0000;oooo00D0003oooooooooool00000OOooo`00N_ooo`030000
oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`D00003oooo00<0003ooooo
ool0N_ooo`00Noooo`030000oooooooo00D0000?oooo00<0003oooooool01_ooo`040000oooooooo
00000oooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00009oooo00<0003oool000000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0A
oooo0P0000_oool200000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.83996 .04578 L
.85916 .04578 L
.87791 .04578 L
.88246 .04578 L
.88497 .04578 L
.88735 .04578 L
.888 .04578 L
.88869 .04578 L
s
.88869 .04578 m
.88888 .61803 L
s
0 .4 1 r
.02381 .04578 m
.06244 .04578 L
.08255 .04578 L
.0932 .04578 L
.09905 .04578 L
.10458 .04578 L
.10708 .04578 L
.10972 .04578 L
.11039 .04578 L
.1111 .04578 L
.11189 .16051 L
.11263 .16078 L
.11531 .16175 L
.12507 .16537 L
.14415 .17278 L
.18538 .1904 L
.22508 .20966 L
.26328 .23062 L
.30392 .25586 L
.34305 .28342 L
.38463 .31668 L
.4247 .35312 L
.46325 .3928 L
.4828 .41484 L
.48815 .42112 L
.4939 .42797 L
.49668 .43133 L
.49805 .433 L
.49931 .43455 L
.50046 .43482 L
.50168 .43333 L
.50426 .4302 L
.54374 .38524 L
.58149 .34718 L
.6217 .31133 L
.66038 .28086 L
.70152 .25229 L
.74115 .22806 L
.77926 .20744 L
.81982 .18805 L
.85886 .17158 L
.86911 .16759 L
.8745 .16554 L
.88021 .1634 L
.8852 .16157 L
.88657 .16107 L
.88732 .1608 L
.88804 .16054 L
.8887 .1603 L
.88943 .04578 L
Mistroke
.89069 .04578 L
.90036 .04578 L
.94106 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00?oool00`1Voooo
o`000007oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooo`1Vo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool0
0`1Vooooooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool00`1Voooo
ooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool00`1Vooooooooo`0Y
oooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool00`1Vooooooooo`0Yoooo000Z
oooo00<0I_ooooooool0H_ooo`80001Soooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo
06;oool00`000?ooooooo`1Roooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool0
0`000?ooooooo`1Roooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?oo
ooooo`1Roooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`1R
oooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`1Roooo00<0
I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool20000Hoooo`0306Kooooooooo02Woool0
02[oool00`1Vooooooooo`1Roooo00<0003oooooool0H_ooo`0306Kooooooooo02Woool002[oool0
0`1Vooooooooo`1Roooo00<0003oooooool0H_ooo`0306Kooooooooo02Woool002[oool00`1Voooo
ooooo`1Roooo00<0003oooooool0H_ooo`0306Kooooooooo02Woool002[oool00`1Vooooooooo`1R
oooo00<0003oooooool0H_ooo`0306Kooooooooo02Woool002[oool00`1Vooooooooo`1Roooo00<0
003oooooool0H_ooo`0306Kooooooooo02Woool002[oool00`1Vooooooooo`1Roooo0P0006?oool0
0`1Vooooooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool00`1Voooo
ooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool00`1Vooooooooo`0Y
oooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool00`1Vooooooooo`0Yoooo000Z
oooo00<0I_ooooooool0H_ooo`030000oooooooo06;oool00`1Vooooooooo`0Yoooo000Zoooo00<0
I_ooooooool0H_ooo`030000oooooooo06;oool00`1Vooooooooo`0Yoooo000Zoooo00<0I_oooooo
ool0H_ooo`80001Soooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?oo
ooooo`1Roooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`1R
oooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`1Roooo00<0
I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo04ooool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Roooo00<0I_ooooooool0:Oooo`00:_ooo`0306Kooooooooo04koool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Roooo00<0I_ooooooool0:Ooo
o`00:_ooo`80I_m?oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Poooo0`1V
ob_oool002coool306KoC?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0G_oo
o`80I_l2oooo00?o09Woooooool0:Oooo`00;oooo`80I_m:oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo05coool206Ko1?ooo`03o`2Ioooooooo02Woool0037oool3
06KoB?ooo`80000:oooo0`0000Coool00`000?ooooooo`1Ioooo0`1Vo`Koool00ol0VOooooooo`0Y
oooo000doooo0`1VoeSoool00`000?ooooooo`1Goooo0P1Vo`Woool00ol0VOooooooo`0Yoooo000g
oooo0P1VoeKoool00`000?ooooooo`1Doooo0`1Vo`_oool00ol0VOooooooo`0Yoooo000ioooo0`1V
oe?oool20000Doooo`80I_l>oooo00?o09Woooooool0:Oooo`00??ooo`80I_mAoooo00<0003ooooo
ool0D?ooo`80I_l@oooo00?o09Woooooool0:Oooo`00?_ooo`80I_m?oooo00<0003oooooool0C_oo
o`80I_lBoooo00?o09Woooooool0:Oooo`00@?ooo`80I_m=oooo00<0003oooooool0C?ooo`80I_lD
oooo00?o09Woooooool0:Oooo`00@_ooo`80I_m;oooo00<0003oooooool0B_ooo`80I_lFoooo00?o
09Woooooool0:Oooo`00A?ooo`80I_m9oooo0P0004Woool206Ko6?ooo`03o`2Ioooooooo02Woool0
04Koool206KoAoooo`030000oooooooo04Koool206Ko6_ooo`03o`2Ioooooooo02Woool004Soool2
06KoAOooo`030000oooooooo04Coool206Ko7?ooo`03o`2Ioooooooo02Woool004[oool206Ko@ooo
o`030000oooooooo04;oool206Ko7_ooo`03o`2Ioooooooo02Woool004coool00`1Vooooooooo`10
oooo00<0003oooooool0@?ooo`80I_lPoooo00?o09Woooooool0:Oooo`00COooo`80I_m0oooo00<0
003oooooool0?_ooo`80I_lRoooo00?o09Woooooool0:Oooo`00Coooo`80I_lnoooo0P0003goool2
06Ko9?ooo`03o`2Ioooooooo02Woool0057oool00`1Vooooooooo`0koooo00<0003oooooool0>_oo
o`80I_lVoooo00?o09Woooooool0:Oooo`00D_ooo`80I_lkoooo00<0003oooooool0>Oooo`0306Ko
oooooooo02Koool00ol0VOooooooo`0Yoooo001Doooo0P1VocWoool00`000?ooooooo`0goooo0P1V
obWoool00ol0VOooooooo`0Yoooo001Foooo0P1VocOoool00`000?ooooooo`0eoooo0P1Vob_oool0
0ol0VOooooooo`0Yoooo001Hoooo0P1VocGoool00`000?ooooooo`0doooo00<0I_ooooooool0:ooo
o`03o`2Ioooooooo02Woool005[oool206Ko<oooo`80000coooo0P1Vobkoool00ol0VOooooooo`0Y
oooo001Loooo00<0I_ooooooool0<?ooo`030000oooooooo037oool00`1Vooooooooo`0^oooo00?o
09Woooooool0:Oooo`00GOooo`0306Kooooooooo02ooool00`000?ooooooo`0_oooo0P1Voc7oool0
0ol0VOooooooo`0Yoooo001Noooo0P1Vobooool00`000?ooooooo`0^oooo00<0I_ooooooool0<Ooo
o`03o`2Ioooooooo02Woool0063oool00`1Vooooooooo`0Toooo1@0000?oool00`000?ooooooo`0]
oooo00<0I_ooooooool0<_ooo`03o`2Ioooooooo02Woool0067oool00`1Vooooooooo`0Uoooo00<0
003oooooool00oooo`030000oooooooo02_oool206Ko=Oooo`03o`2Ioooooooo02Woool006;oool0
0`1Vooooooooo`0Toooo00<0003oooooool00oooo`<0000Zoooo00<0I_ooooooool0=Oooo`03o`2I
oooooooo02Woool006?oool206Ko9?ooo`030000oooooooo00?oool00`000?ooooooo`0Xoooo0P1V
ocSoool00ol0VOooooooo`0Yoooo001Uoooo00<0I_ooooooool08Oooo`030000oooooooo00?oool0
0`000?ooooooo`0Woooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo02Woool006Koool00`1Voooo
ooooo`0Ooooo0P0000Goool00`000?ooooooo`0Voooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02Woool006Ooool206Ko9_ooo`030000oooooooo02Coool206Ko??ooo`03o`2Ioooooooo02Woool0
06Woool00`1Vooooooooo`0Soooo00<0003oooooool08oooo`0306Kooooooooo03coool00ol0VOoo
ooooo`0Yoooo001Zoooo00<0I_ooooooool08_ooo`80000Soooo00<0I_ooooooool0?Oooo`03o`2I
oooooooo02Woool006_oool206Ko8_ooo`030000oooooooo027oool00`1Vooooooooo`0noooo00?o
09Woooooool0:Oooo`00KOooo`0306Kooooooooo01ooool00`000?ooooooo`0Ooooo0P1Vod7oool0
0ol0VOooooooo`0Yoooo001^oooo00<0I_ooooooool07_ooo`030000oooooooo01koool00`1Voooo
ooooo`11oooo00?o09Woooooool0:Oooo`00Koooo`80I_lNoooo00<0003oooooool07Oooo`0306Ko
oooooooo04;oool00ol0VOooooooo`0Yoooo001aoooo00<0I_ooooooool06oooo`030000oooooooo
01coool00`1Vooooooooo`13oooo00?o09Woooooool0:Oooo`00L_ooo`0306Kooooooooo01[oool2
00006oooo`80I_m6oooo00?o09Woooooool0:Oooo`00Loooo`0306Kooooooooo01Woool00`000?oo
ooooo`0Ioooo00<0I_ooooooool0A_ooo`03o`2Ioooooooo02Woool007Coool00`1Vooooooooo`0H
oooo00<0003oooooool06?ooo`0306Kooooooooo04Ooool00ol0VOooooooo`0Yoooo001eoooo00<0
I_ooooooool05oooo`030000oooooooo01Ooool00`1Vooooooooo`18oooo00?o09Woooooool0:Ooo
o`00M_ooo`0306Kooooooooo01Koool00`000?ooooooo`0Foooo00<0I_ooooooool0BOooo`03o`2I
oooooooo02Woool007Ooool00`1Vooooooooo`0Eoooo00<0003oooooool05?ooo`80I_m<oooo00?o
09Woooooool0:Oooo`00N?ooo`0306Kooooooooo01Coool200005?ooo`0306Kooooooooo04coool0
0ol0VOooooooo`0Yoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo01;oool00`1Voooo
ooooo`1=oooo00?o09Woooooool0:Oooo`00N_ooo`0306Kooooooooo01;oool00`000?ooooooo`0A
oooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo02Woool007_oool00`1Vooooooooo`0Aoooo00<0
003oooooool04?ooo`0306Kooooooooo04ooool00ol0VOooooooo`0Yoooo001loooo00<0I_oooooo
ool04?ooo`030000oooooooo00ooool00`1Vooooooooo`1@oooo00?o09Woooooool0:Oooo`00OOoo
o`0306Kooooooooo00ooool00`000?ooooooo`0>oooo00<0I_ooooooool0DOooo`03o`2Ioooooooo
02Woool007koool00`1Vooooooooo`0>oooo0P0000koool00`1Vooooooooo`1Boooo00?o09Wooooo
ool0:Oooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0<oooo00<0I_ooooooool0Dooo
o`03o`2Ioooooooo02Woool0083oool00`1Vooooooooo`0<oooo00<0003oooooool02oooo`0306Ko
oooooooo05Coool00ol0VOooooooo`0Yoooo0021oooo00<0I_ooooooool02oooo`030000oooooooo
00[oool00`1Vooooooooo`1Eoooo00?o09Woooooool0:Oooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo00Woool00`1Vooooooooo`1Foooo00?o09Woooooool0:Oooo`00OOoo
o`030000oooooooo00?oool01@1Vooooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Soool00`1Vooooooooo`1Goooo00?o09Woooooool0:Oooo`00OOooo`030000oooooooo
00Coool00`1Vooooooooo`03oooo00<0003oooooool00_ooo`<00007oooo00<0I_ooooooool0F?oo
o`03o`2Ioooooooo02Woool007goool00`000?ooooooo`05oooo00<0I_ooooooool00P0000Goool0
0`000?ooooooo`06oooo00<0I_ooooooool0FOooo`03o`2Ioooooooo02Woool007goool00`000?oo
ooooo`06oooo00<0I_ooool000001_ooo`030000oooooooo00Goool00`1Vooooooooo`1Joooo00?o
09Woooooool0:Oooo`00O?ooo`800009oooo00@0I_l0000000000004oooo00<0003oooooool01Ooo
o`0306Kooooooooo05[oool00ol0VOooooooo`0Yoooo0027oooo00<0I_ooooooool01Oooo`030000
oooooooo00Coool00`1Vooooooooo`1Koooo00?o09Woooooool0:Oooo`00R?ooo`0306Kooooooooo
00Coool00`000?ooooooo`03oooo00<0I_ooooooool0G?ooo`03o`2Ioooooooo02Woool008Woool0
0`1Vooooooooo`03oooo0P0000?oool00`1Vooooooooo`1Moooo00?o09Woooooool0:Oooo`00R_oo
o`0306Kooooooooo00;oool01@000?ooooooooooo`1Vo`1Poooo00?o09Woooooool0:Oooo`00Rooo
o`80I_l2oooo00@0003oooooool0I_mQoooo00?o09Woooooool0:Oooo`00S?ooo`0406Kooooooooo
00000_ooo`0306Kooooooooo05ooool00ol0VOooooooo`0Yoooo002=oooo00D0I_ooool0003oool0
I_l0H_ooo`03o`2Ioooooooo02Woool008koool00`1Vo`00001Vo`1Soooo00?o09Woooooool0:Ooo
o`00S_ooo`0306Ko0000000006?oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_oo
o`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001S
oooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?
oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o
09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0
003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool20000Hoooo`03o`2Ioooooooo02Woool0
08ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool0
0ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008Ooool4
00001?ooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo0027oooo00<0003oooooool01Ooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo0028oooo00<0003oooooool01?ooo`<0001R
oooo00?o09Woooooool0:Oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Roooo00?o
09Woooooool0:Oooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo0028oooo0P0000Goool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool20000Hoooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1R
oooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?
oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o
09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo0P00
06?oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool0
08ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool0
0ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool0
0`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Woooooool0:Ooo
o`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_oo
o`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool20000Hoooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1R
oooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?
oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool007_oool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Noooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00O?ooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0006;oool00ol0VOooooooo`0Yoooo001moooo00<0
003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Goool300000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002oooo`040000oooooooo00000_ooo`050000oooooooooooo000007[oool007Ooool00`000?oo
ooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Ooool500001?ooo`030000oooooooo
00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000ooool00`000?ooooooo`06
oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000003oooo`040000oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002oooo`800003oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.83996 .04578 L
.85916 .04578 L
.87791 .04578 L
.88735 .04578 L
.88993 .04578 L
.89271 .04578 L
.89405 .04578 L
.89533 .04578 L
.89647 .04578 L
s
.89647 .04578 m
.89678 .61803 L
s
0 .4 1 r
.02381 .04578 m
.04262 .04578 L
.06244 .04578 L
.08255 .04578 L
.08806 .04578 L
.09396 .04578 L
.09682 .04578 L
.09952 .04578 L
.1007 .04578 L
.10195 .04578 L
.1026 .04578 L
.10332 .16028 L
.10458 .16074 L
.14487 .17629 L
.18364 .19325 L
.22486 .2137 L
.26457 .23607 L
.30277 .2604 L
.34341 .28971 L
.38254 .32171 L
.42412 .36033 L
.46419 .40264 L
.48257 .42391 L
.4876 .42995 L
.493 .43654 L
.49562 .43977 L
.49809 .44286 L
.49917 .44421 L
.50032 .44485 L
.50158 .44327 L
.50274 .44182 L
.52268 .41771 L
.54374 .39383 L
.58149 .35481 L
.6217 .31805 L
.66038 .28681 L
.70152 .25752 L
.74115 .23267 L
.77926 .21153 L
.81982 .19165 L
.85886 .17477 L
.86911 .17067 L
.88021 .16638 L
.8853 .16446 L
.89069 .16246 L
.89291 .16165 L
.8953 .16078 L
.896 .16053 L
.89666 .16029 L
.89791 .04578 L
Mistroke
.89908 .04578 L
.90036 .04578 L
.94106 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`050000oooooooooooo06Ko00?oool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool01@000?ooooooooooo`1Vo`03oooo00<0003oooooool01_oo
o`030000oooooooo00Goool00`000?ooooooo`0Boooo000Xoooo00<0I_ooooooool0I?ooo`030000
oooooooo06Coool00`1Vooooooooo`0Woooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo
06Coool00`1Vooooooooo`0Woooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo06Coool0
0`1Vooooooooo`0Woooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo06Coool00`1Voooo
ooooo`0Woooo000Xoooo00<0I_ooooooool0I?ooo`80001Uoooo00<0I_ooooooool09oooo`00:?oo
o`0306Kooooooooo06Coool00`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Ko
oooooooo06Coool00`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo
06Coool00`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo06Coool0
0`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo06Coool00`000?oo
ooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo06Coool20000IOooo`0306Ko
oooooooo02Ooool002Soool00`1Vooooooooo`1Toooo00<0003oooooool0I?ooo`0306Kooooooooo
02Ooool002Soool00`1Vooooooooo`1Toooo00<0003oooooool0I?ooo`0306Kooooooooo02Ooool0
02Soool00`1Vooooooooo`1Toooo00<0003oooooool0I?ooo`0306Kooooooooo02Ooool002Soool0
0`1Vooooooooo`1Toooo00<0003oooooool0I?ooo`0306Kooooooooo02Ooool002Soool00`1Voooo
ooooo`1Toooo00<0003oooooool0I?ooo`0306Kooooooooo02Ooool002Soool00`1Vooooooooo`1T
oooo0P0006Goool00`1Vooooooooo`0Woooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo
06Coool00`1Vooooooooo`0Woooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo06Coool0
0`1Vooooooooo`0Woooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo06Coool00`1Voooo
ooooo`0Woooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo06Coool00`1Vooooooooo`0W
oooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo06Coool00`1Vooooooooo`0Woooo000X
oooo00<0I_ooooooool0I?ooo`80001Uoooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo
06Coool00`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo06Coool0
0`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo06Coool00`000?oo
ooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo057oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`1Toooo00<0I_ooooooool09oooo`00:?ooo`0306Kooooooooo
053oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Toooo00<0
I_ooooooool09oooo`00:?ooo`80I_mAoooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0001Soooo0P1VobWoool002[oool306KoC_ooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0Goooo`@0I_l00oooool0VOooo`0Xoooo000]oooo0P1Vodcoool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool0G?ooo`<0I_l5oooo00?o09Woooooool09ooo
o`00;oooo`<0I_m:oooo0P0000[oool300001?ooo`030000oooooooo05[oool206Ko2?ooo`03o`2I
oooooooo02Ooool003;oool306KoF_ooo`030000oooooooo05Soool206Ko2_ooo`03o`2Ioooooooo
02Ooool003Goool206KoF?ooo`030000oooooooo05Koool206Ko3?ooo`03o`2Ioooooooo02Ooool0
03Ooool306KoEOooo`80001Eoooo0P1Vo`koool00ol0VOooooooo`0Woooo000joooo0P1Voe?oool0
0`000?ooooooo`1Boooo0P1Voa3oool00ol0VOooooooo`0Woooo000loooo0P1Voe7oool00`000?oo
ooooo`1@oooo0P1Voa;oool00ol0VOooooooo`0Woooo000noooo0P1Vodooool00`000?ooooooo`1>
oooo0P1VoaCoool00ol0VOooooooo`0Woooo0010oooo0P1Vodgoool00`000?ooooooo`1<oooo0P1V
oaKoool00ol0VOooooooo`0Woooo0012oooo0P1Vod_oool20000Boooo`80I_lHoooo00?o09Wooooo
ool09oooo`00A?ooo`80I_m9oooo00<0003oooooool0B?ooo`80I_lJoooo00?o09Woooooool09ooo
o`00A_ooo`80I_m7oooo00<0003oooooool0A_ooo`80I_lLoooo00?o09Woooooool09oooo`00B?oo
o`80I_m5oooo00<0003oooooool0A?ooo`80I_lNoooo00?o09Woooooool09oooo`00B_ooo`80I_m3
oooo00<0003oooooool0@_ooo`80I_lPoooo00?o09Woooooool09oooo`00C?ooo`80I_m1oooo00<0
003oooooool0@?ooo`80I_lRoooo00?o09Woooooool09oooo`00C_ooo`80I_looooo0P0003ooool2
06Ko9?ooo`03o`2Ioooooooo02Ooool0053oool206Ko?Oooo`030000oooooooo03coool206Ko9_oo
o`03o`2Ioooooooo02Ooool005;oool00`1Vooooooooo`0joooo00<0003oooooool0>_ooo`80I_lX
oooo00?o09Woooooool09oooo`00Doooo`80I_ljoooo00<0003oooooool0>Oooo`0306Kooooooooo
02Soool00ol0VOooooooo`0Woooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool2
06Ko:oooo`03o`2Ioooooooo02Ooool005Koool00`1Vooooooooo`0foooo00<0003oooooool0=Ooo
o`80I_l]oooo00?o09Woooooool09oooo`00Eoooo`80I_lfoooo0P0003Goool00`1Vooooooooo`0]
oooo00?o09Woooooool09oooo`00FOooo`0306Kooooooooo03?oool00`000?ooooooo`0boooo0P1V
oc3oool00ol0VOooooooo`0Woooo001Joooo0P1Voc?oool00`000?ooooooo`0aoooo00<0I_oooooo
ool0<?ooo`03o`2Ioooooooo02Ooool005coool00`1Vooooooooo`0`oooo00<0003oooooool0<?oo
o`0306Kooooooooo037oool00ol0VOooooooo`0Woooo001Moooo0P1VobSoool500000oooo`030000
oooooooo02koool206Ko=?ooo`03o`2Ioooooooo02Ooool005ooool00`1Vooooooooo`0Woooo00<0
003oooooool00oooo`030000oooooooo02goool00`1Vooooooooo`0doooo00?o09Woooooool09ooo
o`00H?ooo`0306Kooooooooo02Koool00`000?ooooooo`03oooo0`0002coool00`1Vooooooooo`0e
oooo00?o09Woooooool09oooo`00HOooo`80I_lVoooo00<0003oooooool00oooo`030000oooooooo
02_oool00`1Vooooooooo`0foooo00?o09Woooooool09oooo`00Hoooo`0306Kooooooooo02?oool0
0`000?ooooooo`03oooo00<0003oooooool0:Oooo`80I_lioooo00?o09Woooooool09oooo`00I?oo
o`80I_lRoooo0P0000Goool00`000?ooooooo`0Xoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02Ooool006Koool00`1Vooooooooo`0Voooo00<0003oooooool09oooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Woooo001Woooo00<0I_ooooooool09Oooo`030000oooooooo02Koool00`1Voooo
ooooo`0koooo00?o09Woooooool09oooo`00J?ooo`0306Kooooooooo02Coool200009Oooo`80I_ln
oooo00?o09Woooooool09oooo`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0
I_ooooooool0?_ooo`03o`2Ioooooooo02Ooool006[oool00`1Vooooooooo`0Roooo00<0003ooooo
ool08_ooo`0306Kooooooooo03ooool00ol0VOooooooo`0Woooo001[oooo0P1Vob;oool00`000?oo
ooooo`0Qoooo00<0I_ooooooool0@?ooo`03o`2Ioooooooo02Ooool006goool00`1Vooooooooo`0O
oooo00<0003oooooool07oooo`80I_m3oooo00?o09Woooooool09oooo`00K_ooo`0306Kooooooooo
01koool00`000?ooooooo`0Noooo00<0I_ooooooool0@oooo`03o`2Ioooooooo02Ooool006ooool0
0`1Vooooooooo`0Moooo0P0001koool00`1Vooooooooo`14oooo00?o09Woooooool09oooo`00L?oo
o`0306Kooooooooo01coool00`000?ooooooo`0Loooo00<0I_ooooooool0AOooo`03o`2Ioooooooo
02Ooool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06_ooo`80I_m8oooo00?o09Wooooo
ool09oooo`00L_ooo`0306Kooooooooo01[oool00`000?ooooooo`0Ioooo00<0I_ooooooool0B?oo
o`03o`2Ioooooooo02Ooool007?oool00`1Vooooooooo`0Ioooo00<0003oooooool06?ooo`0306Ko
oooooooo04Woool00ol0VOooooooo`0Woooo001doooo00<0I_ooooooool06?ooo`030000oooooooo
01Ooool00`1Vooooooooo`1:oooo00?o09Woooooool09oooo`00MOooo`80I_lHoooo0P0001Ooool0
0`1Vooooooooo`1;oooo00?o09Woooooool09oooo`00Moooo`0306Kooooooooo01Goool00`000?oo
ooooo`0Doooo0P1Vodkoool00ol0VOooooooo`0Woooo001hoooo00<0I_ooooooool05?ooo`030000
oooooooo01?oool00`1Vooooooooo`1>oooo00?o09Woooooool09oooo`00NOooo`0306Kooooooooo
01?oool00`000?ooooooo`0Boooo00<0I_ooooooool0Coooo`03o`2Ioooooooo02Ooool007[oool0
0`1Vooooooooo`0Boooo00<0003oooooool04Oooo`0306Kooooooooo053oool00ol0VOooooooo`0W
oooo001koooo00<0I_ooooooool04Oooo`030000oooooooo013oool00`1Vooooooooo`1Aoooo00?o
09Woooooool09oooo`00O?ooo`0306Kooooooooo013oool200004?ooo`0306Kooooooooo05;oool0
0ol0VOooooooo`0Woooo001moooo00<0I_ooooooool03oooo`030000oooooooo00koool00`1Voooo
ooooo`1Coooo00?o09Woooooool09oooo`00O_ooo`0306Kooooooooo00koool00`000?ooooooo`0=
oooo00<0I_ooooooool0E?ooo`03o`2Ioooooooo02Ooool007ooool00`1Vooooooooo`0=oooo00<0
003oooooool03?ooo`0306Kooooooooo05Goool00ol0VOooooooo`0Woooo001koooo1@00000406Ko
oooo000000001?ooo`800005oooo00<0003oooooool02oooo`0306Kooooooooo05Koool00ol0VOoo
ooooo`0Woooo001moooo00D0003oooooooooool0I_l01Oooo`040000oooooooo00001?ooo`030000
oooooooo00[oool00`1Vooooooooo`1Goooo00?o09Woooooool09oooo`00OOooo`030000oooooooo
00;oool00`1Vooooooooo`05oooo00<0003oooooool00_ooo`<00009oooo00<0I_ooooooool0F?oo
o`03o`2Ioooooooo02Ooool007goool00`000?ooooooo`03oooo00<0I_ooooooool00_ooo`800005
oooo00<0003oooooool02?ooo`0306Kooooooooo05Woool00ol0VOooooooo`0Woooo001moooo00<0
003oooooool01?ooo`0506Kooooooooooooo000000Koool00`000?ooooooo`07oooo00<0I_oooooo
ool0F_ooo`03o`2Ioooooooo02Ooool007coool200001oooo`0306Kooooooooo00<00004oooo00<0
003oooooool01oooo`0306Kooooooooo05[oool00ol0VOooooooo`0Woooo0026oooo00<0I_oooooo
ool01_ooo`030000oooooooo00Koool00`1Vooooooooo`1Koooo00?o09Woooooool09oooo`00Qooo
o`0306Kooooooooo00Goool00`000?ooooooo`05oooo00<0I_ooooooool0G?ooo`03o`2Ioooooooo
02Ooool008Soool00`1Vooooooooo`04oooo0P0000Goool00`1Vooooooooo`1Moooo00?o09Wooooo
ool09oooo`00R?ooo`0306Kooooooooo00Coool00`000?ooooooo`04oooo00<0I_ooooooool0GOoo
o`03o`2Ioooooooo02Ooool008Woool00`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Ko
oooooooo05koool00ol0VOooooooo`0Woooo002:oooo00<0I_ooooooool00_ooo`030000oooooooo
00;oool00`1Vooooooooo`1Ooooo00?o09Woooooool09oooo`00Roooo`0506Kooooooooooooo0000
00?oool00`1Vooooooooo`1Poooo00?o09Woooooool09oooo`00S?ooo`0406Kooooooooo00000_oo
o`0306Kooooooooo067oool00ol0VOooooooo`0Woooo002=oooo00H0I_ooool00000003oool0I_mS
oooo00?o09Woooooool09oooo`00S_ooo`0406Ko0000oooo06KoI?ooo`03o`2Ioooooooo02Ooool0
08koool00`1Vo`00001Vo`1Uoooo00?o09Woooooool09oooo`00Soooo`030000oooooooo06Coool0
0ol0VOooooooo`0Woooo002?oooo00<0003oooooool0I?ooo`03o`2Ioooooooo02Ooool008ooool0
0`000?ooooooo`1Toooo00?o09Woooooool09oooo`00Soooo`80001Uoooo00?o09Woooooool09ooo
o`00Soooo`030000oooooooo06Coool00ol0VOooooooo`0Woooo002?oooo00<0003oooooool0I?oo
o`03o`2Ioooooooo02Ooool008ooool00`000?ooooooo`1Toooo00?o09Woooooool09oooo`00Sooo
o`030000oooooooo06Coool00ol0VOooooooo`0Woooo002?oooo00<0003oooooool0I?ooo`03o`2I
oooooooo02Ooool008ooool20000IOooo`03o`2Ioooooooo02Ooool008ooool00`000?ooooooo`1T
oooo00?o09Woooooool09oooo`00Soooo`030000oooooooo06Coool00ol0VOooooooo`0Woooo002?
oooo00<0003oooooool0I?ooo`03o`2Ioooooooo02Ooool008Ooool400001?ooo`030000oooooooo
06Coool00ol0VOooooooo`0Woooo0027oooo00<0003oooooool01Oooo`030000oooooooo06Coool0
0ol0VOooooooo`0Woooo0028oooo00<0003oooooool01?ooo`<0001Toooo00?o09Woooooool09ooo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Toooo00?o09Woooooool09oooo`00Qooo
o`040000oooooooo00001?ooo`030000oooooooo06Coool00ol0VOooooooo`0Woooo0028oooo0P00
00Goool00`000?ooooooo`1Toooo00?o09Woooooool09oooo`00Soooo`030000oooooooo06Coool0
0ol0VOooooooo`0Woooo002?oooo00<0003oooooool0I?ooo`03o`2Ioooooooo02Ooool008ooool2
0000IOooo`03o`2Ioooooooo02Ooool008ooool00`000?ooooooo`1Toooo00?o09Woooooool09ooo
o`00Soooo`030000oooooooo06Coool00ol0VOooooooo`0Woooo002?oooo00<0003oooooool0I?oo
o`03o`2Ioooooooo02Ooool008ooool00`000?ooooooo`1Toooo00?o09Woooooool09oooo`00Sooo
o`030000oooooooo06Coool00ol0VOooooooo`0Woooo002?oooo0P0006Goool00ol0VOooooooo`0W
oooo002?oooo00<0003oooooool0I?ooo`03o`2Ioooooooo02Ooool008ooool00`000?ooooooo`1T
oooo00?o09Woooooool09oooo`00Soooo`030000oooooooo06Coool00ol0VOooooooo`0Woooo002?
oooo00<0003oooooool0I?ooo`03o`2Ioooooooo02Ooool008ooool00`000?ooooooo`1Toooo00?o
09Woooooool09oooo`00Soooo`80001Uoooo00?o09Woooooool09oooo`00Soooo`030000oooooooo
06Coool00ol0VOooooooo`0Woooo002?oooo00<0003oooooool0I?ooo`03o`2Ioooooooo02Ooool0
08ooool00`000?ooooooo`1Toooo00?o09Woooooool09oooo`00Soooo`030000oooooooo06Coool0
0ol0VOooooooo`0Woooo002?oooo00<0003oooooool0I?ooo`03o`2Ioooooooo02Ooool008ooool2
0000IOooo`03o`2Ioooooooo02Ooool008ooool00`000?ooooooo`1Toooo00?o09Woooooool09ooo
o`00Soooo`030000oooooooo06Coool00ol0VOooooooo`0Woooo002?oooo00<0003oooooool0I?oo
o`03o`2Ioooooooo02Ooool007_oool400000oooo`800004oooo0P0000Goool00`000?ooooooo`1T
oooo00?o09Woooooool09oooo`00Noooo`030000oooooooo00Woool010000?ooooooo`0000Coool0
0`000?ooooooo`1Toooo00?o09Woooooool09oooo`00O?ooo`030000oooooooo00_oool00`000?oo
ooooo`02oooo0`0006Coool00ol0VOooooooo`0Woooo001moooo00<0003oooooool02?ooo`80002F
oooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`00
09Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`0:oooo00<0003oooooool00_ooo`030000oooooooo07[oool007_oool00`000?ooooooo`05
00003oooo`030000oooooooo00Ooool200001?ooo`030000oooooooo07_oool007_oool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.87754 .04578 L
.88797 .04578 L
.89307 .04578 L
.89771 .04578 L
.90008 .04578 L
.90133 .04578 L
.90265 .04578 L
.90381 .04578 L
s
.90381 .04578 m
.90413 .61803 L
s
0 .4 1 r
.02381 .04578 m
.04262 .04578 L
.06244 .04578 L
.08255 .04578 L
.08806 .04578 L
.09109 .04578 L
.09258 .04578 L
.09324 .04578 L
.09396 .04578 L
.09525 .16024 L
.09596 .16049 L
.09662 .16073 L
.09952 .16178 L
.10458 .16365 L
.14335 .17896 L
.18458 .19743 L
.22428 .21763 L
.26248 .2396 L
.30312 .26608 L
.34225 .29498 L
.38383 .32985 L
.4239 .36806 L
.46245 .40968 L
.482 .43279 L
.49235 .44562 L
.49534 .44939 L
.4968 .45126 L
.49816 .453 L
.49939 .45458 L
.5007 .45447 L
.50201 .45278 L
.50346 .45093 L
.52388 .42569 L
.54294 .40354 L
.58315 .36099 L
.62183 .32482 L
.66297 .29091 L
.7026 .26214 L
.74071 .23767 L
.78127 .21465 L
.82031 .19511 L
.86181 .17681 L
.88261 .1685 L
.89175 .16502 L
.89659 .16322 L
.89926 .16223 L
.90179 .16131 L
.90296 .16088 L
.90421 .16043 L
.90492 .04578 L
Mistroke
.90557 .04578 L
.90684 .04578 L
.91144 .04578 L
.92048 .04578 L
.94026 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`03000006Kooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`03oooo00<0I_ooool000002?ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo06Koool0
0`1Vooooooooo`0Uoooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo06Koool00`1Voooo
ooooo`0Uoooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo06Koool00`1Vooooooooo`0U
oooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo06Koool00`1Vooooooooo`0Uoooo000U
oooo00<0I_ooooooool0Ioooo`80001Woooo00<0I_ooooooool09Oooo`009Oooo`0306Kooooooooo
06Ooool00`000?ooooooo`1Voooo00<0I_ooooooool09Oooo`009Oooo`0306Kooooooooo06Ooool0
0`000?ooooooo`1Voooo00<0I_ooooooool09Oooo`009Oooo`0306Kooooooooo06Ooool00`000?oo
ooooo`1Voooo00<0I_ooooooool09Oooo`009Oooo`0306Kooooooooo06Ooool00`000?ooooooo`1V
oooo00<0I_ooooooool09Oooo`009Oooo`0306Kooooooooo06Ooool00`000?ooooooo`1Voooo00<0
I_ooooooool09Oooo`009Oooo`0306Kooooooooo06Ooool20000Ioooo`0306Kooooooooo02Goool0
02Goool00`1Vooooooooo`1Woooo00<0003oooooool0I_ooo`0306Kooooooooo02Goool002Goool0
0`1Vooooooooo`1Woooo00<0003oooooool0I_ooo`0306Kooooooooo02Goool002Goool00`1Voooo
ooooo`1Woooo00<0003oooooool0I_ooo`0306Kooooooooo02Goool002Koool00`1Vooooooooo`1V
oooo00<0003oooooool0I_ooo`0306Kooooooooo02Goool002Koool00`1Vooooooooo`1Voooo00<0
003oooooool0I_ooo`0306Kooooooooo02Goool002Koool00`1Vooooooooo`1Voooo0P0006Ooool0
0`1Vooooooooo`0Uoooo000Voooo00<0I_ooooooool0I_ooo`030000oooooooo06Koool00`1Voooo
ooooo`0Uoooo000Voooo00<0I_ooooooool0I_ooo`030000oooooooo06Koool00`1Vooooooooo`0U
oooo000Voooo00<0I_ooooooool0I_ooo`030000oooooooo06Koool00`1Vooooooooo`0Uoooo000V
oooo00<0I_ooooooool0I_ooo`030000oooooooo06Koool00`1Vooooooooo`0Uoooo000Voooo00<0
I_ooooooool0I_ooo`030000oooooooo06Koool00`1Vooooooooo`0Uoooo000Voooo00<0I_oooooo
ool0I_ooo`80001Woooo00<0I_ooooooool09Oooo`009_ooo`0306Kooooooooo06Koool00`000?oo
ooooo`1Voooo00<0I_ooooooool09Oooo`009_ooo`0306Kooooooooo06Koool00`000?ooooooo`1V
oooo00<0I_ooooooool09Oooo`009_ooo`0306Kooooooooo06Koool00`000?ooooooo`1Voooo00<0
I_ooooooool09Oooo`009_ooo`0306Kooooooooo05?oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Voooo00<0I_ooooooool09Oooo`009_ooo`0306Kooooooooo05;oool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Voooo00<0I_ooooooool09Ooo
o`009_ooo`@0I_mAoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Toooo0`1V
obOoool002[oool206KoCoooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0Hooo
o`0406Koooooooooo`2I9oooo`00;?ooo`<0I_m<oooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo063oool306Ko0oooo`03o`2Ioooooooo02Goool002ooool206KoBooo
o`80000:oooo0`0000Coool00`000?ooooooo`1Moooo0`1Vo`Koool00ol0VOooooooo`0Uoooo000a
oooo0`1Voe_oool00`000?ooooooo`1Joooo0`1Vo`Woool00ol0VOooooooo`0Uoooo000doooo0P1V
oeWoool00`000?ooooooo`1Hoooo0P1Vo`coool00ol0VOooooooo`0Uoooo000foooo0P1VoeOoool2
0000Eoooo`80I_l>oooo00?o09Woooooool09Oooo`00>?ooo`80I_mEoooo00<0003oooooool0E?oo
o`80I_l@oooo00?o09Woooooool09Oooo`00>_ooo`80I_mCoooo00<0003oooooool0D_ooo`80I_lB
oooo00?o09Woooooool09Oooo`00??ooo`80I_mAoooo00<0003oooooool0D?ooo`80I_lDoooo00?o
09Woooooool09Oooo`00?_ooo`80I_m?oooo00<0003oooooool0C_ooo`80I_lFoooo00?o09Wooooo
ool09Oooo`00@?ooo`80I_m=oooo0P0004goool206Ko6?ooo`03o`2Ioooooooo02Goool004;oool0
0`1Vooooooooo`1:oooo00<0003oooooool0B_ooo`80I_lJoooo00?o09Woooooool09Oooo`00@ooo
o`80I_m:oooo00<0003oooooool0B?ooo`80I_lLoooo00?o09Woooooool09Oooo`00AOooo`80I_m8
oooo00<0003oooooool0A_ooo`80I_lNoooo00?o09Woooooool09Oooo`00Aoooo`0306Kooooooooo
04Goool00`000?ooooooo`14oooo0P1Vob3oool00ol0VOooooooo`0Uoooo0018oooo0P1VodGoool0
0`000?ooooooo`12oooo0P1Vob;oool00ol0VOooooooo`0Uoooo001:oooo0P1Vod?oool20000@_oo
o`0306Kooooooooo02;oool00ol0VOooooooo`0Uoooo001<oooo0P1Vod7oool00`000?ooooooo`0o
oooo0P1VobGoool00ol0VOooooooo`0Uoooo001>oooo0P1Vocooool00`000?ooooooo`0moooo0P1V
obOoool00ol0VOooooooo`0Uoooo001@oooo0P1Vocgoool00`000?ooooooo`0loooo00<0I_oooooo
ool09oooo`03o`2Ioooooooo02Goool005;oool206Ko>oooo`030000oooooooo03[oool206Ko:_oo
o`03o`2Ioooooooo02Goool005Coool00`1Vooooooooo`0hoooo00<0003oooooool0>?ooo`80I_l/
oooo00?o09Woooooool09Oooo`00EOooo`80I_lhoooo0P0003Soool00`1Vooooooooo`0/oooo00?o
09Woooooool09Oooo`00Eoooo`80I_lfoooo00<0003oooooool0=Oooo`80I_l_oooo00?o09Wooooo
ool09Oooo`00FOooo`0306Kooooooooo03?oool00`000?ooooooo`0coooo0P1Voc7oool00ol0VOoo
ooooo`0Uoooo001Joooo0P1Voc?oool00`000?ooooooo`0boooo00<0I_ooooooool0<Oooo`03o`2I
oooooooo02Goool005coool00`1Vooooooooo`0Xoooo1@0000?oool00`000?ooooooo`0`oooo0P1V
ocCoool00ol0VOooooooo`0Uoooo001Moooo00<0I_ooooooool0:Oooo`030000oooooooo00?oool0
0`000?ooooooo`0_oooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo02Goool005koool206Ko:Ooo
o`030000oooooooo00?oool30000;_ooo`0306Kooooooooo03Goool00ol0VOooooooo`0Uoooo001P
oooo00<0I_ooooooool09_ooo`030000oooooooo00?oool00`000?ooooooo`0/oooo0P1VocSoool0
0ol0VOooooooo`0Uoooo001Qoooo00<0I_ooooooool09Oooo`030000oooooooo00?oool00`000?oo
ooooo`0[oooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo02Goool006;oool00`1Vooooooooo`0S
oooo0P0000Goool00`000?ooooooo`0Zoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Goool0
06?oool206Ko:_ooo`030000oooooooo02Soool206Ko??ooo`03o`2Ioooooooo02Goool006Goool0
0`1Vooooooooo`0Woooo00<0003oooooool09oooo`0306Kooooooooo03coool00ol0VOooooooo`0U
oooo001Voooo00<0I_ooooooool09_ooo`80000Woooo00<0I_ooooooool0?Oooo`03o`2Ioooooooo
02Goool006Ooool00`1Vooooooooo`0Uoooo00<0003oooooool09?ooo`80I_m0oooo00?o09Wooooo
ool09Oooo`00J?ooo`80I_lUoooo00<0003oooooool08oooo`0306Kooooooooo043oool00ol0VOoo
ooooo`0Uoooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo02;oool00`1Vooooooooo`11
oooo00?o09Woooooool09Oooo`00Joooo`0306Kooooooooo027oool00`000?ooooooo`0Qoooo00<0
I_ooooooool0@_ooo`03o`2Ioooooooo02Goool006coool00`1Vooooooooo`0Poooo00<0003ooooo
ool07oooo`80I_m5oooo00?o09Woooooool09Oooo`00KOooo`0306Kooooooooo01ooool200007ooo
o`0306Kooooooooo04Goool00ol0VOooooooo`0Uoooo001^oooo0P1Voaooool00`000?ooooooo`0M
oooo00<0I_ooooooool0A_ooo`03o`2Ioooooooo02Goool0073oool00`1Vooooooooo`0Loooo00<0
003oooooool07?ooo`0306Kooooooooo04Ooool00ol0VOooooooo`0Uoooo001aoooo00<0I_oooooo
ool06oooo`030000oooooooo01_oool00`1Vooooooooo`18oooo00?o09Woooooool09Oooo`00L_oo
o`0306Kooooooooo01[oool00`000?ooooooo`0Joooo00<0I_ooooooool0BOooo`03o`2Ioooooooo
02Goool007?oool00`1Vooooooooo`0Ioooo00<0003oooooool06Oooo`0306Kooooooooo04[oool0
0ol0VOooooooo`0Uoooo001doooo00<0I_ooooooool06?ooo`80000Ioooo00<0I_ooooooool0Booo
o`03o`2Ioooooooo02Goool007Goool00`1Vooooooooo`0Goooo00<0003oooooool05oooo`0306Ko
oooooooo04coool00ol0VOooooooo`0Uoooo001foooo00<0I_ooooooool05_ooo`030000oooooooo
01Koool00`1Vooooooooo`1=oooo00?o09Woooooool09Oooo`00Moooo`0306Kooooooooo01Goool0
0`000?ooooooo`0Eoooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo02Goool007Soool00`1Voooo
ooooo`0Doooo00<0003oooooool05?ooo`0306Kooooooooo04ooool00ol0VOooooooo`0Uoooo001i
oooo00<0I_ooooooool04oooo`030000oooooooo01?oool00`1Vooooooooo`1@oooo00?o09Wooooo
ool09Oooo`00N_ooo`0306Kooooooooo01;oool200004oooo`0306Kooooooooo057oool00ol0VOoo
ooooo`0Uoooo001koooo00<0I_ooooooool04Oooo`030000oooooooo017oool00`1Vooooooooo`1B
oooo00?o09Woooooool09Oooo`00O?ooo`0306Kooooooooo013oool00`000?ooooooo`0@oooo00<0
I_ooooooool0Doooo`03o`2Ioooooooo02Goool007goool00`1Vooooooooo`0?oooo00<0003ooooo
ool03oooo`0306Kooooooooo05Coool00ol0VOooooooo`0Uoooo001koooo1@0000;oool200001?oo
o`800005oooo00<0003oooooool03_ooo`0306Kooooooooo05Goool00ol0VOooooooo`0Uoooo001m
oooo00<0003oool0I_l01oooo`040000oooooooo00001?ooo`030000oooooooo00goool00`1Voooo
ooooo`1Foooo00?o09Woooooool09Oooo`00OOooo`040000oooooooo06Ko2Oooo`030000oooooooo
00;oool300003?ooo`0306Kooooooooo05Ooool00ol0VOooooooo`0Uoooo001moooo00D0003ooooo
ooooool0I_l01_ooo`800005oooo00<0003oooooool02oooo`0306Kooooooooo05Soool00ol0VOoo
ooooo`0Uoooo001moooo00<0003oooooool00_ooo`0306Kooooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool02_ooo`0306Kooooooooo05Woool00ol0VOooooooo`0Uoooo001loooo0P00
00Goool00`1Vooooooooo`02oooo0`0000Coool00`000?ooooooo`09oooo00<0I_ooooooool0F_oo
o`03o`2Ioooooooo02Goool008Coool00`1Vooooooooo`08oooo00<0003oooooool02?ooo`0306Ko
oooooooo05_oool00ol0VOooooooo`0Uoooo0025oooo00<0I_ooooooool01oooo`030000oooooooo
00Ooool00`1Vooooooooo`1Loooo00?o09Woooooool09Oooo`00Q_ooo`0306Kooooooooo00Koool2
00001oooo`0306Kooooooooo05goool00ol0VOooooooo`0Uoooo0027oooo00<0I_ooooooool01Ooo
o`030000oooooooo00Goool00`1Vooooooooo`1Noooo00?o09Woooooool09Oooo`00Qoooo`0306Ko
oooooooo00Goool00`000?ooooooo`05oooo00<0I_ooooooool0G_ooo`03o`2Ioooooooo02Goool0
08Soool00`1Vooooooooo`04oooo00<0003oooooool01?ooo`0306Kooooooooo05ooool00ol0VOoo
ooooo`0Uoooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`1P
oooo00?o09Woooooool09Oooo`00R_ooo`0306Kooooooooo00;oool00`000?ooooooo`02oooo00<0
I_ooooooool0HOooo`03o`2Ioooooooo02Goool008_oool0101Vooooooooooooo`800002oooo00<0
I_ooooooool0H_ooo`03o`2Ioooooooo02Goool008_oool01@1Vooooooooooooo`000002oooo00<0
I_ooooooool0Hoooo`03o`2Ioooooooo02Goool008coool0101Vooooooooo`0000;oool00`1Voooo
ooooo`1Soooo00?o09Woooooool09Oooo`00SOooo`0506Kooooo0000oooo06Ko06Koool00ol0VOoo
ooooo`0Uoooo002>oooo00<0I_l00000I_l0Ioooo`03o`2Ioooooooo02Goool008koool00`1Vo`00
0?ooo`1Woooo00?o09Woooooool09Oooo`00Soooo`80001Woooo00?o09Woooooool09Oooo`00Sooo
o`030000oooooooo06Koool00ol0VOooooooo`0Uoooo002?oooo00<0003oooooool0I_ooo`03o`2I
oooooooo02Goool008ooool00`000?ooooooo`1Voooo00?o09Woooooool09Oooo`00Soooo`030000
oooooooo06Koool00ol0VOooooooo`0Uoooo002?oooo00<0003oooooool0I_ooo`03o`2Ioooooooo
02Goool008ooool20000Ioooo`03o`2Ioooooooo02Goool008ooool00`000?ooooooo`1Voooo00?o
09Woooooool09Oooo`00Soooo`030000oooooooo06Koool00ol0VOooooooo`0Uoooo002?oooo00<0
003oooooool0I_ooo`03o`2Ioooooooo02Goool008Ooool400001?ooo`030000oooooooo06Koool0
0ol0VOooooooo`0Uoooo0027oooo00<0003oooooool01Oooo`030000oooooooo06Koool00ol0VOoo
ooooo`0Uoooo0028oooo00<0003oooooool01?ooo`<0001Voooo00?o09Woooooool09Oooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`1Voooo00?o09Woooooool09Oooo`00Qoooo`040000
oooooooo00001?ooo`030000oooooooo06Koool00ol0VOooooooo`0Uoooo0028oooo0P0000Goool0
0`000?ooooooo`1Voooo00?o09Woooooool09Oooo`00Soooo`030000oooooooo06Koool00ol0VOoo
ooooo`0Uoooo002?oooo00<0003oooooool0I_ooo`03o`2Ioooooooo02Goool008ooool20000Iooo
o`03o`2Ioooooooo02Goool008ooool00`000?ooooooo`1Voooo00?o09Woooooool09Oooo`00Sooo
o`030000oooooooo06Koool00ol0VOooooooo`0Uoooo002?oooo00<0003oooooool0I_ooo`03o`2I
oooooooo02Goool008ooool00`000?ooooooo`1Voooo00?o09Woooooool09Oooo`00Soooo`030000
oooooooo06Koool00ol0VOooooooo`0Uoooo002?oooo0P0006Ooool00ol0VOooooooo`0Uoooo002?
oooo00<0003oooooool0I_ooo`03o`2Ioooooooo02Goool008ooool00`000?ooooooo`1Voooo00?o
09Woooooool09Oooo`00Soooo`030000oooooooo06Koool00ol0VOooooooo`0Uoooo002?oooo00<0
003oooooool0I_ooo`03o`2Ioooooooo02Goool008ooool00`000?ooooooo`1Voooo00?o09Wooooo
ool09Oooo`00Soooo`80001Woooo00?o09Woooooool09Oooo`00Soooo`030000oooooooo06Koool0
0ol0VOooooooo`0Uoooo002?oooo00<0003oooooool0I_ooo`03o`2Ioooooooo02Goool008ooool0
0`000?ooooooo`1Voooo00?o09Woooooool09Oooo`00Soooo`030000oooooooo06Koool00ol0VOoo
ooooo`0Uoooo002?oooo00<0003oooooool0I_ooo`03o`2Ioooooooo02Goool008ooool20000Iooo
o`03o`2Ioooooooo02Goool008ooool00`000?ooooooo`1Voooo00?o09Woooooool09Oooo`00Sooo
o`030000oooooooo06Koool00ol0VOooooooo`0Uoooo002?oooo00<0003oooooool0I_ooo`03o`2I
oooooooo02Goool007_oool400000oooo`800004oooo0P0000Goool00`000?ooooooo`1Voooo00?o
09Woooooool09Oooo`00Noooo`030000oooooooo00Woool010000?ooooooo`0000Coool00`000?oo
ooooo`1Voooo00?o09Woooooool09Oooo`00O?ooo`030000oooooooo00_oool00`000?ooooooo`02
oooo0`0006Koool00ol0VOooooooo`0Uoooo001moooo00<0003oooooool02?ooo`80002Foooo001k
oooo00@0003oooooool00009oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000_oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0
003oooooool03oooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003oooo`030000oooooooo00Ooool2
00001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool0
10000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool300000oooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.87754 .04578 L
.88797 .04578 L
.89771 .04578 L
.90265 .04578 L
.90733 .04578 L
.90992 .04578 L
.91063 .04578 L
.91138 .04578 L
.91202 .04578 L
s
.91202 .04578 m
.9122 .61803 L
s
0 .4 1 r
.02381 .04578 m
.04262 .04578 L
.06244 .04578 L
.07216 .04578 L
.0775 .04578 L
.08255 .04578 L
.08542 .04578 L
.0862 .04578 L
.08703 .04578 L
.08774 .16039 L
.08852 .16067 L
.09396 .16266 L
.10458 .16663 L
.14487 .18299 L
.18364 .20081 L
.22486 .22231 L
.26457 .24583 L
.30277 .2714 L
.34341 .30222 L
.38254 .33586 L
.42412 .37645 L
.46419 .42094 L
.48257 .44329 L
.4876 .44965 L
.493 .45658 L
.49562 .45997 L
.49809 .46322 L
.49917 .46464 L
.50032 .46531 L
.50158 .46365 L
.50274 .46213 L
.52268 .43678 L
.54374 .41168 L
.58149 .37066 L
.6217 .33201 L
.66038 .29917 L
.70152 .26837 L
.74115 .24225 L
.77926 .22003 L
.81982 .19913 L
.85886 .18138 L
.87877 .17314 L
.88926 .169 L
.90036 .16477 L
.90514 .16299 L
.90777 .16202 L
.91027 .16111 L
.91167 .1606 L
.91247 .16031 L
.91321 .04578 L
Mistroke
.91451 .04578 L
.9159 .04578 L
.92116 .04578 L
.94034 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`0Boooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool0
0`1Vooooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Voooo
ooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Vooooooooo`0S
oooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Vooooooooo`0Soooo000T
oooo00<0I_ooooooool0J?ooo`80001Yoooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo
06Soool00`000?ooooooo`1Xoooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo06Soool0
0`000?ooooooo`1Xoooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo06Soool00`000?oo
ooooo`1Xoooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo06Soool00`000?ooooooo`1X
oooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo06Soool00`000?ooooooo`1Xoooo00<0
I_ooooooool08oooo`009?ooo`0306Kooooooooo06Soool20000JOooo`0306Kooooooooo02?oool0
02Coool00`1Vooooooooo`1Xoooo00<0003oooooool0J?ooo`0306Kooooooooo02?oool002Coool0
0`1Vooooooooo`1Xoooo00<0003oooooool0J?ooo`0306Kooooooooo02?oool002Coool00`1Voooo
ooooo`1Xoooo00<0003oooooool0J?ooo`0306Kooooooooo02?oool002Coool00`1Vooooooooo`1X
oooo00<0003oooooool0J?ooo`0306Kooooooooo02?oool002Coool00`1Vooooooooo`1Xoooo00<0
003oooooool0J?ooo`0306Kooooooooo02?oool002Coool00`1Vooooooooo`1Xoooo0P0006Woool0
0`1Vooooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Voooo
ooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Vooooooooo`0S
oooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Vooooooooo`0Soooo000T
oooo00<0I_ooooooool0J?ooo`030000oooooooo06Soool00`1Vooooooooo`0Soooo000Toooo00<0
I_ooooooool0J?ooo`030000oooooooo06Soool00`1Vooooooooo`0Soooo000Toooo00<0I_oooooo
ool0J?ooo`80001Yoooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo06Soool00`000?oo
ooooo`1Xoooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo06Soool00`000?ooooooo`1X
oooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo06Soool00`000?ooooooo`1Xoooo00<0
I_ooooooool08oooo`009?ooo`0306Kooooooooo05Goool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1Xoooo00<0I_ooooooool08oooo`009?ooo`0306Kooooooooo05Coool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1Xoooo00<0I_ooooooool08ooo
o`009?ooo`<0I_mDoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001Voooo0`1V
obGoool002Ooool306KoDOooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0I?oo
o`80I_l2oooo00?o09Woooooool08oooo`00:_ooo`80I_m?oooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo06;oool206Ko1?ooo`03o`2Ioooooooo02?oool002coool2
06KoC_ooo`80000:oooo0`0000Coool00`000?ooooooo`1Ooooo0`1Vo`Koool00ol0VOooooooo`0S
oooo000^oooo0P1Voeooool00`000?ooooooo`1Loooo0`1Vo`Woool00ol0VOooooooo`0Soooo000`
oooo0P1Voegoool00`000?ooooooo`1Joooo0P1Vo`coool00ol0VOooooooo`0Soooo000boooo0`1V
oe[oool20000FOooo`80I_l>oooo00?o09Woooooool08oooo`00=Oooo`80I_mHoooo00<0003ooooo
ool0E_ooo`80I_l@oooo00?o09Woooooool08oooo`00=oooo`<0I_mEoooo00<0003oooooool0E?oo
o`80I_lBoooo00?o09Woooooool08oooo`00>_ooo`80I_mCoooo00<0003oooooool0D_ooo`80I_lD
oooo00?o09Woooooool08oooo`00??ooo`80I_mAoooo00<0003oooooool0D?ooo`80I_lFoooo00?o
09Woooooool08oooo`00?_ooo`80I_m?oooo0P0004ooool206Ko6?ooo`03o`2Ioooooooo02?oool0
043oool206KoCOooo`030000oooooooo04coool206Ko6_ooo`03o`2Ioooooooo02?oool004;oool0
0`1Vooooooooo`1:oooo00<0003oooooool0B_ooo`80I_lLoooo00?o09Woooooool08oooo`00@ooo
o`80I_m:oooo00<0003oooooool0B?ooo`80I_lNoooo00?o09Woooooool08oooo`00AOooo`80I_m8
oooo00<0003oooooool0A_ooo`80I_lPoooo00?o09Woooooool08oooo`00Aoooo`0306Kooooooooo
04Goool00`000?ooooooo`14oooo0P1Vob;oool00ol0VOooooooo`0Soooo0018oooo0P1VodGoool2
0000@oooo`80I_lToooo00?o09Woooooool08oooo`00B_ooo`80I_m3oooo00<0003oooooool0@Ooo
o`0306Kooooooooo02Coool00ol0VOooooooo`0Soooo001<oooo0P1Vod7oool00`000?ooooooo`0o
oooo0P1VobOoool00ol0VOooooooo`0Soooo001>oooo0P1Vocooool00`000?ooooooo`0moooo0P1V
obWoool00ol0VOooooooo`0Soooo001@oooo0P1Vocgoool00`000?ooooooo`0loooo00<0I_oooooo
ool0:Oooo`03o`2Ioooooooo02?oool005;oool00`1Vooooooooo`0joooo00<0003oooooool0>_oo
o`80I_l/oooo00?o09Woooooool08oooo`00Doooo`80I_ljoooo0P0003[oool00`1Vooooooooo`0/
oooo00?o09Woooooool08oooo`00EOooo`0306Kooooooooo03Ooool00`000?ooooooo`0goooo0P1V
obooool00ol0VOooooooo`0Soooo001Foooo00<0I_ooooooool0=_ooo`030000oooooooo03Goool2
06Ko<Oooo`03o`2Ioooooooo02?oool005Ooool206Ko=_ooo`030000oooooooo03Coool00`1Voooo
ooooo`0aoooo00?o09Woooooool08oooo`00FOooo`0306Kooooooooo02_oool500000oooo`030000
oooooooo03;oool206Ko=?ooo`03o`2Ioooooooo02?oool005[oool206Ko;Oooo`030000oooooooo
00?oool00`000?ooooooo`0aoooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo02?oool005coool0
0`1Vooooooooo`0Zoooo00<0003oooooool00oooo`<0000`oooo00<0I_ooooooool0=Oooo`03o`2I
oooooooo02?oool005goool00`1Vooooooooo`0Yoooo00<0003oooooool00oooo`030000oooooooo
02koool206Ko>?ooo`03o`2Ioooooooo02?oool005koool206Ko:Oooo`030000oooooooo00?oool0
0`000?ooooooo`0]oooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo02?oool0063oool00`1Voooo
ooooo`0Uoooo0P0000Goool00`000?ooooooo`0/oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02?oool0067oool00`1Vooooooooo`0[oooo00<0003oooooool0:oooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Soooo001Roooo00<0I_ooooooool0:_ooo`030000oooooooo02Woool206Ko?Ooo
o`03o`2Ioooooooo02?oool006?oool206Ko:_ooo`80000Yoooo00<0I_ooooooool0?Oooo`03o`2I
oooooooo02?oool006Goool00`1Vooooooooo`0Woooo00<0003oooooool09oooo`0306Kooooooooo
03koool00ol0VOooooooo`0Soooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool0
0`1Vooooooooo`0ooooo00?o09Woooooool08oooo`00Ioooo`0306Kooooooooo02Goool00`000?oo
ooooo`0Toooo0P1Vod;oool00ol0VOooooooo`0Soooo001Xoooo0P1VobGoool00`000?ooooooo`0S
oooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo02?oool006[oool00`1Vooooooooo`0Roooo00<0
003oooooool08_ooo`0306Kooooooooo04?oool00ol0VOooooooo`0Soooo001[oooo00<0I_oooooo
ool08Oooo`80000Roooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo02?oool006coool00`1Voooo
ooooo`0Poooo00<0003oooooool07oooo`80I_m7oooo00?o09Woooooool08oooo`00KOooo`80I_lP
oooo00<0003oooooool07_ooo`0306Kooooooooo04Ooool00ol0VOooooooo`0Soooo001_oooo00<0
I_ooooooool07Oooo`030000oooooooo01goool00`1Vooooooooo`18oooo00?o09Woooooool08ooo
o`00L?ooo`0306Kooooooooo01coool00`000?ooooooo`0Loooo00<0I_ooooooool0BOooo`03o`2I
oooooooo02?oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06oooo`0306Kooooooooo
04[oool00ol0VOooooooo`0Soooo001boooo00<0I_ooooooool06_ooo`80000Koooo00<0I_oooooo
ool0Boooo`03o`2Ioooooooo02?oool007?oool00`1Vooooooooo`0Ioooo00<0003oooooool06Ooo
o`0306Kooooooooo04coool00ol0VOooooooo`0Soooo001doooo00<0I_ooooooool06?ooo`030000
oooooooo01Ooool206KoCoooo`03o`2Ioooooooo02?oool007Goool00`1Vooooooooo`0Goooo00<0
003oooooool05_ooo`0306Kooooooooo04ooool00ol0VOooooooo`0Soooo001foooo00<0I_oooooo
ool05_ooo`030000oooooooo01Goool00`1Vooooooooo`1@oooo00?o09Woooooool08oooo`00Mooo
o`0306Kooooooooo01Goool00`000?ooooooo`0Doooo00<0I_ooooooool0DOooo`03o`2Ioooooooo
02?oool007Soool00`1Vooooooooo`0Doooo0P0001Coool00`1Vooooooooo`1Boooo00?o09Wooooo
ool08oooo`00NOooo`0306Kooooooooo01?oool00`000?ooooooo`0Boooo00<0I_ooooooool0Dooo
o`03o`2Ioooooooo02?oool007[oool00`1Vooooooooo`0Boooo00<0003oooooool04Oooo`0306Ko
oooooooo05Coool00ol0VOooooooo`0Soooo001koooo00<0I_ooooooool04Oooo`030000oooooooo
013oool00`1Vooooooooo`1Eoooo00?o09Woooooool08oooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo00ooool00`1Vooooooooo`1Foooo00?o09Woooooool08oooo`00OOoo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0>oooo00<0I_oooooo
ool0Eoooo`03o`2Ioooooooo02?oool007goool00`00001Vooooo`0:oooo00<0003oooooool00_oo
o`<0000=oooo00<0I_ooooooool0F?ooo`03o`2Ioooooooo02?oool007goool00`000?ooo`1Vo`08
oooo0P0000Goool00`000?ooooooo`0=oooo00<0I_ooooooool0F?ooo`03o`2Ioooooooo02?oool0
07goool010000?ooooooo`1Vo`Ooool00`000?ooooooo`04oooo00<0003oooooool03?ooo`0306Ko
oooooooo05Woool00ol0VOooooooo`0Soooo001loooo0P0000?oool00`1Vooooooooo`04oooo0`00
00Coool00`000?ooooooo`0;oooo00<0I_ooooooool0F_ooo`03o`2Ioooooooo02?oool008;oool0
0`1Vooooooooo`0:oooo00<0003oooooool02_ooo`0306Kooooooooo05_oool00ol0VOooooooo`0S
oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Vooooooooo`1Loooo00?o
09Woooooool08oooo`00Q?ooo`0306Kooooooooo00Soool200002Oooo`0306Kooooooooo05goool0
0ol0VOooooooo`0Soooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Ooool00`1Voooo
ooooo`1Noooo00?o09Woooooool08oooo`00Q_ooo`0306Kooooooooo00Koool00`000?ooooooo`07
oooo00<0I_ooooooool0G_ooo`03o`2Ioooooooo02?oool008Ooool00`1Vooooooooo`05oooo00<0
003oooooool01_ooo`0306Kooooooooo05ooool00ol0VOooooooo`0Soooo0027oooo00<0I_oooooo
ool01Oooo`030000oooooooo00Goool00`1Vooooooooo`1Poooo00?o09Woooooool08oooo`00R?oo
o`0306Kooooooooo00Coool00`000?ooooooo`04oooo00<0I_ooooooool0HOooo`03o`2Ioooooooo
02?oool008Woool00`1Vooooooooo`03oooo0P0000Goool00`1Vooooooooo`1Qoooo00?o09Wooooo
ool08oooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03oooo00<0I_ooooooool0H_oo
o`03o`2Ioooooooo02?oool008[oool00`1Vooooooooo`02oooo00<0003oooooool00_ooo`0306Ko
oooooooo06?oool00ol0VOooooooo`0Soooo002;oooo00D0I_ooooooooooool000000oooo`0306Ko
oooooooo06Coool00ol0VOooooooo`0Soooo002<oooo00@0I_ooooooool00002oooo00<0I_oooooo
ool0IOooo`03o`2Ioooooooo02?oool008coool0101Vooooooooo`0000;oool00`1Vooooooooo`1U
oooo00?o09Woooooool08oooo`00SOooo`0506Kooooo0000000006Ko06Soool00ol0VOooooooo`0S
oooo002>oooo00<0I_l00000I_l0JOooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1X
oooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?
oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o
09Woooooool08oooo`00Soooo`80001Yoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo
06Soool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool0
08ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Qoooo`@00004oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool008Ooool00`000?ooooooo`05oooo00<0003oooooool0J?oo
o`03o`2Ioooooooo02?oool008Soool00`000?ooooooo`04oooo0`0006Soool00ol0VOooooooo`0S
oooo0029oooo00<0003oooooool00oooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo0027
oooo00@0003oooooool00004oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008Soool2
00001Oooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?oo
o`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Sooo
o`80001Yoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0S
oooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1X
oooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?
oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool20000JOooo`03o`2Ioooooooo
02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo
06Soool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool0
08ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool0
0ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08ooo
o`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?oo
o`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Sooo
o`80001Yoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0S
oooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1X
oooo00?o09Woooooool08oooo`00Noooo`@00003oooo0P0000Coool200001Oooo`030000oooooooo
06Soool00ol0VOooooooo`0Soooo001koooo00<0003oooooool02Oooo`040000oooooooo00001?oo
o`030000oooooooo06Soool00ol0VOooooooo`0Soooo001loooo00<0003oooooool02oooo`030000
oooooooo00;oool30000J?ooo`03o`2Ioooooooo02?oool007goool00`000?ooooooo`08oooo0P00
09Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo
07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool0
07_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000ooo
o`<00004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001koooo00<0003ooooo
ool01@0000ooool00`000?ooooooo`06oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000003oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1l
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.90802 .04578 L
.91306 .04578 L
.91765 .04578 L
.91884 .04578 L
.92014 .04578 L
s
.92014 .04578 m
.92045 .61803 L
s
0 .4 1 r
.02381 .04578 m
.04262 .04578 L
.06244 .04578 L
.06747 .04578 L
.07286 .04578 L
.07547 .04578 L
.07675 .04578 L
.07793 .04578 L
.07901 .04578 L
.08015 .16051 L
.08129 .16093 L
.08255 .16139 L
.10458 .16969 L
.14487 .18646 L
.18364 .20473 L
.22486 .22677 L
.26457 .25089 L
.30277 .27711 L
.34341 .30871 L
.38254 .3432 L
.42412 .38482 L
.46419 .43043 L
.48257 .45336 L
.4876 .45987 L
.493 .46697 L
.49562 .47046 L
.49809 .47379 L
.49917 .47525 L
.50032 .47593 L
.50158 .47423 L
.50274 .47267 L
.52268 .44668 L
.54374 .42094 L
.58149 .37888 L
.6217 .33926 L
.66038 .30559 L
.70152 .27401 L
.74115 .24723 L
.77926 .22444 L
.81982 .20301 L
.85886 .18482 L
.87877 .17636 L
.88926 .17212 L
.90036 .16778 L
.91027 .16403 L
.91298 .16302 L
.9159 .16195 L
.91731 .16144 L
.91865 .16095 L
.91985 .16051 L
Mistroke
.92116 .04578 L
.92247 .04578 L
.92369 .04578 L
.92598 .04578 L
.93111 .04578 L
.94034 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool00oooo`0406Kooooooooo00001oooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool010000?ooool0V@1Vo`Goool00`000?oo
ooooo`05oooo00<0003oooooool04_ooo`008Oooo`0306Kooooooooo06_oool00`000?ooooooo`1Z
oooo00?o09T0I_ooool08Oooo`008Oooo`0306Kooooooooo06_oool00`000?ooooooo`1Zoooo00?o
09T0I_ooool08Oooo`008Oooo`0306Kooooooooo06_oool00`000?ooooooo`1Zoooo00?o09T0I_oo
ool08Oooo`008Oooo`0306Kooooooooo06_oool00`000?ooooooo`1Zoooo00?o09T0I_ooool08Ooo
o`008Oooo`0306Kooooooooo06_oool20000Joooo`03o`2I06Kooooo027oool0027oool00`1Voooo
ooooo`1[oooo00<0003oooooool0J_ooo`03o`2I06Kooooo027oool0027oool00`1Vooooooooo`1[
oooo00<0003oooooool0J_ooo`03o`2I06Kooooo027oool0027oool00`1Vooooooooo`1[oooo00<0
003oooooool0J_ooo`03o`2I06Kooooo027oool0027oool00`1Vooooooooo`1[oooo00<0003ooooo
ool0J_ooo`03o`2I06Kooooo027oool0027oool00`1Vooooooooo`1[oooo00<0003oooooool0J_oo
o`03o`2I06Kooooo027oool0027oool00`1Vooooooooo`1[oooo0P0006_oool00ol0V@1Vooooo`0Q
oooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo06[oool00ol0V@1Vooooo`0Qoooo000Q
oooo00<0I_ooooooool0Joooo`030000oooooooo06[oool00ol0V@1Vooooo`0Qoooo000Qoooo00<0
I_ooooooool0Joooo`030000oooooooo06[oool00`1Vooooooooo`0Qoooo000Roooo00<0I_oooooo
ool0J_ooo`030000oooooooo06[oool00`1Vooooooooo`0Qoooo000Roooo00<0I_ooooooool0J_oo
o`030000oooooooo06[oool00`1Vooooooooo`0Qoooo000Roooo00<0I_ooooooool0J_ooo`80001[
oooo00<0I_ooooooool08Oooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`1Zoooo00<0
I_ooooooool08Oooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`1Zoooo00<0I_oooooo
ool08Oooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`1Zoooo00<0I_ooooooool08Ooo
o`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`1Zoooo00<0I_ooooooool08Oooo`008_oo
o`0306Kooooooooo06[oool00`000?ooooooo`1Zoooo00<0I_ooooooool08Oooo`008_ooo`0306Ko
oooooooo06[oool20000Joooo`0306Kooooooooo027oool002;oool00`1Vooooooooo`1Zoooo00<0
003oooooool0J_ooo`0306Kooooooooo027oool002;oool00`1Vooooooooo`1Zoooo00<0003ooooo
ool0J_ooo`0306Kooooooooo027oool002;oool00`1Vooooooooo`1Zoooo00<0003oooooool0J_oo
o`0306Kooooooooo027oool002;oool00`1Vooooooooo`1Goooo0P0000Coool200001?ooo`800005
oooo00<0003oooooool0J_ooo`0306Kooooooooo027oool002;oool00`1Vooooooooo`1Foooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool0J_ooo`0306Kooooooooo
027oool002;oool206KoEoooo`040000oooooooo00002oooo`030000oooooooo00;oool30000J?oo
o`<0I_lSoooo000Toooo0`1VoeCoool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
06Ooool206Ko00?ooooo09Woool08_ooo`009oooo`<0I_mAoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo06Coool306Ko0oooo`03o`2Ioooooooo027oool002[oool3
06KoCoooo`80000:oooo0`0000Coool00`000?ooooooo`1Roooo0P1Vo`Koool00ol0VOooooooo`0Q
oooo000]oooo0P1Vof3oool00`000?ooooooo`1Ooooo0`1Vo`Soool00ol0VOooooooo`0Qoooo000_
oooo0`1Voegoool00`000?ooooooo`1Loooo0`1Vo`_oool00ol0VOooooooo`0Qoooo000boooo0P1V
oe_oool20000Foooo`80I_l>oooo00?o09Woooooool08Oooo`00=?ooo`80I_mIoooo00<0003ooooo
ool0F?ooo`80I_l@oooo00?o09Woooooool08Oooo`00=_ooo`80I_mGoooo00<0003oooooool0E_oo
o`80I_lBoooo00?o09Woooooool08Oooo`00>?ooo`80I_mEoooo00<0003oooooool0E?ooo`80I_lD
oooo00?o09Woooooool08Oooo`00>_ooo`80I_mCoooo00<0003oooooool0D_ooo`80I_lFoooo00?o
09Woooooool08Oooo`00??ooo`80I_mAoooo0P00057oool206Ko6?ooo`03o`2Ioooooooo027oool0
03koool206KoCoooo`030000oooooooo04koool206Ko6_ooo`03o`2Ioooooooo027oool0043oool2
06KoCOooo`030000oooooooo04coool206Ko7?ooo`03o`2Ioooooooo027oool004;oool00`1Voooo
ooooo`1:oooo00<0003oooooool0B_ooo`80I_lNoooo00?o09Woooooool08Oooo`00@oooo`80I_m:
oooo00<0003oooooool0B?ooo`80I_lPoooo00?o09Woooooool08Oooo`00AOooo`80I_m8oooo00<0
003oooooool0A_ooo`80I_lRoooo00?o09Woooooool08Oooo`00Aoooo`0306Kooooooooo04Goool2
0000AOooo`80I_lToooo00?o09Woooooool08Oooo`00B?ooo`80I_m5oooo00<0003oooooool0@_oo
o`80I_lVoooo00?o09Woooooool08Oooo`00B_ooo`80I_m3oooo00<0003oooooool0@Oooo`0306Ko
oooooooo02Koool00ol0VOooooooo`0Qoooo001<oooo0P1Vod7oool00`000?ooooooo`0ooooo0P1V
obWoool00ol0VOooooooo`0Qoooo001>oooo0P1Vocooool00`000?ooooooo`0moooo0P1Vob_oool0
0ol0VOooooooo`0Qoooo001@oooo0P1Vocgoool00`000?ooooooo`0loooo00<0I_ooooooool0:ooo
o`03o`2Ioooooooo027oool005;oool00`1Vooooooooo`0joooo0P0003_oool206Ko;_ooo`03o`2I
oooooooo027oool005?oool206Ko>_ooo`030000oooooooo03Woool00`1Vooooooooo`0^oooo00?o
09Woooooool08Oooo`00EOooo`0306Kooooooooo03Ooool00`000?ooooooo`0goooo0P1Voc7oool0
0ol0VOooooooo`0Qoooo001Foooo00<0I_ooooooool0=_ooo`030000oooooooo03Goool206Ko<ooo
o`03o`2Ioooooooo027oool005Ooool206Ko;_ooo`D00003oooo00<0003oooooool0=?ooo`0306Ko
oooooooo03?oool00ol0VOooooooo`0Qoooo001Ioooo00<0I_ooooooool0;Oooo`030000oooooooo
00?oool00`000?ooooooo`0boooo0P1VocKoool00ol0VOooooooo`0Qoooo001Joooo0P1Vobgoool0
0`000?ooooooo`03oooo0`00037oool00`1Vooooooooo`0foooo00?o09Woooooool08Oooo`00G?oo
o`0306Kooooooooo02[oool00`000?ooooooo`03oooo00<0003oooooool0<?ooo`0306Kooooooooo
03Ooool00ol0VOooooooo`0Qoooo001Moooo00<0I_ooooooool0:Oooo`030000oooooooo00?oool0
0`000?ooooooo`0^oooo0P1Voc[oool00ol0VOooooooo`0Qoooo001Noooo0P1VobSoool200001Ooo
o`030000oooooooo02goool00`1Vooooooooo`0joooo00?o09Woooooool08Oooo`00H?ooo`0306Ko
oooooooo02coool00`000?ooooooo`0/oooo00<0I_ooooooool0>oooo`03o`2Ioooooooo027oool0
067oool00`1Vooooooooo`0[oooo00<0003oooooool0:oooo`0306Kooooooooo03coool00ol0VOoo
ooooo`0Qoooo001Roooo00<0I_ooooooool0:_ooo`80000Zoooo0P1Vocooool00ol0VOooooooo`0Q
oooo001Soooo0P1Vob[oool00`000?ooooooo`0Xoooo00<0I_ooooooool0?oooo`03o`2Ioooooooo
027oool006Goool00`1Vooooooooo`0Woooo00<0003oooooool09oooo`0306Kooooooooo043oool0
0ol0VOooooooo`0Qoooo001Voooo00<0I_ooooooool09_ooo`030000oooooooo02Koool00`1Voooo
ooooo`11oooo00?o09Woooooool08Oooo`00Ioooo`0306Kooooooooo02Goool00`000?ooooooo`0U
oooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo027oool006Soool00`1Vooooooooo`0Toooo00<0
003oooooool09?ooo`0306Kooooooooo04?oool00ol0VOooooooo`0Qoooo001Yoooo00<0I_oooooo
ool08oooo`80000Toooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo027oool006[oool00`1Voooo
ooooo`0Roooo00<0003oooooool08Oooo`80I_m7oooo00?o09Woooooool08Oooo`00Joooo`80I_lR
oooo00<0003oooooool08?ooo`0306Kooooooooo04Ooool00ol0VOooooooo`0Qoooo001]oooo00<0
I_ooooooool07oooo`030000oooooooo01ooool00`1Vooooooooo`18oooo00?o09Woooooool08Ooo
o`00K_ooo`0306Kooooooooo01koool00`000?ooooooo`0Noooo00<0I_ooooooool0BOooo`03o`2I
oooooooo027oool006ooool00`1Vooooooooo`0Moooo00<0003oooooool07Oooo`0306Kooooooooo
04[oool00ol0VOooooooo`0Qoooo001`oooo00<0I_ooooooool07?ooo`80000Moooo00<0I_oooooo
ool0Boooo`03o`2Ioooooooo027oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06ooo
o`0306Kooooooooo04coool00ol0VOooooooo`0Qoooo001boooo00<0I_ooooooool06_ooo`030000
oooooooo01[oool00`1Vooooooooo`1=oooo00?o09Woooooool08Oooo`00Loooo`0306Kooooooooo
01Woool00`000?ooooooo`0Ioooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo027oool007Coool0
0`1Vooooooooo`0Hoooo00<0003oooooool05oooo`80I_mAoooo00?o09Woooooool08Oooo`00MOoo
o`0306Kooooooooo01Ooool00`000?ooooooo`0Foooo00<0I_ooooooool0DOooo`03o`2Ioooooooo
027oool007Koool00`1Vooooooooo`0Foooo0P0001Koool00`1Vooooooooo`1Boooo00?o09Wooooo
ool08Oooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Doooo00<0I_ooooooool0Dooo
o`03o`2Ioooooooo027oool007Soool00`1Vooooooooo`0Doooo00<0003oooooool04oooo`0306Ko
oooooooo05Coool00ol0VOooooooo`0Qoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo
01;oool00`1Vooooooooo`1Eoooo00?o09Woooooool08Oooo`00N_ooo`0306Ko0000000000<00002
oooo0P0000Coool200001Oooo`030000oooooooo017oool00`1Vooooooooo`1Foooo00?o09Wooooo
ool08Oooo`00Noooo`0306Kooooo000000Woool010000?ooooooo`0000Coool00`000?ooooooo`0@
oooo00<0I_ooooooool0Eoooo`03o`2Ioooooooo027oool007coool00`1Vo`000?ooo`0;oooo00<0
003oooooool00_ooo`<0000?oooo00<0I_ooooooool0F?ooo`03o`2Ioooooooo027oool007goool0
0`000?ooooooo`08oooo0P0000Goool00`000?ooooooo`0>oooo00<0I_ooooooool0FOooo`03o`2I
oooooooo027oool007goool00`00001Vooooo`08oooo00<0003oooooool01?ooo`030000oooooooo
00goool00`1Vooooooooo`1Joooo00?o09Woooooool08Oooo`00O?ooo`8000000oooo`1Vooooo`07
oooo0`0000Coool00`000?ooooooo`0=oooo00<0I_ooooooool0F_ooo`03o`2Ioooooooo027oool0
083oool00`1Vooooooooo`0<oooo00<0003oooooool03?ooo`0306Kooooooooo05_oool00ol0VOoo
ooooo`0Qoooo0020oooo00<0I_ooooooool03?ooo`030000oooooooo00_oool00`1Vooooooooo`1L
oooo00?o09Woooooool08Oooo`00POooo`0306Kooooooooo00_oool200002oooo`0306Kooooooooo
05goool00ol0VOooooooo`0Qoooo0022oooo00<0I_ooooooool02_ooo`030000oooooooo00Woool0
0`1Vooooooooo`1Noooo00?o09Woooooool08Oooo`00Poooo`0306Kooooooooo00Woool00`000?oo
ooooo`08oooo00<0I_ooooooool0Goooo`03o`2Ioooooooo027oool008Coool00`1Vooooooooo`08
oooo00<0003oooooool01oooo`0306Kooooooooo063oool00ol0VOooooooo`0Qoooo0025oooo00<0
I_ooooooool01oooo`030000oooooooo00Ooool00`1Vooooooooo`1Poooo00?o09Woooooool08Ooo
o`00Q_ooo`0306Kooooooooo00Koool00`000?ooooooo`06oooo00<0I_ooooooool0HOooo`03o`2I
oooooooo027oool008Ooool00`1Vooooooooo`05oooo0P0000Koool00`1Vooooooooo`1Roooo00?o
09Woooooool08Oooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`04oooo00<0I_oooooo
ool0Hoooo`03o`2Ioooooooo027oool008Soool00`1Vooooooooo`04oooo00<0003oooooool01?oo
o`0306Kooooooooo06?oool00ol0VOooooooo`0Qoooo0029oooo00<0I_ooooooool00oooo`030000
oooooooo00?oool00`1Vooooooooo`1Toooo00?o09Woooooool08Oooo`00ROooo`0306Kooooooooo
00?oool00`000?ooooooo`02oooo00<0I_ooooooool0IOooo`03o`2Ioooooooo027oool008[oool0
0`1Vooooooooo`02oooo00<0003oooooool00_ooo`0306Kooooooooo06Goool00ol0VOooooooo`0Q
oooo002;oooo00@0I_ooooooooooool200000_ooo`0306Kooooooooo06Koool00ol0VOooooooo`0Q
oooo002<oooo00@0I_ooooooool00002oooo00<0I_ooooooool0Ioooo`03o`2Ioooooooo027oool0
08goool01@1Vooooo`000?ooo`1Vo`1Zoooo00?o09Woooooool08Oooo`00S_ooo`0406Ko0000oooo
06KoJ_ooo`03o`2Ioooooooo027oool008koool00`1Vo`00001Vo`1[oooo00?o09Woooooool08Ooo
o`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOoo
ooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?oo
ooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Q
oooo0027oooo100000Coool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Qoooo`030000
oooooooo00Goool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00R?ooo`030000oooooooo
00Coool30000J_ooo`03o`2Ioooooooo027oool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0J_ooo`03o`2Ioooooooo027oool008Ooool010000?ooooooo`0000Coool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00R?ooo`800005oooo00<0003oooooool0J_ooo`03o`2Ioooooooo
027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0
003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003ooooo
ool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Ooo
o`00Soooo`80001[oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOoo
ooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?oo
ooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Q
oooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool20000Joooo`03o`2I
oooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000
oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo
027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0
003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Wooooo
ool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo001koooo100000?oool2
00001?ooo`800005oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool007_oool00`000?oo
ooooo`09oooo00@0003oooooool00004oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool0
07coool00`000?ooooooo`0;oooo00<0003oooooool00_ooo`<0001Zoooo00?o09Woooooool08Ooo
o`00OOooo`030000oooooooo00Soool20000U_ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800003oooo0`0000Coool200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`07
oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003oooo`030000oooooooo00Koool300001?ooo`800004oooo00<0003ooooo
ool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0A
oooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.91765 .04578 L
.9225 .04578 L
.92516 .04578 L
.92648 .04578 L
.92769 .04578 L
.92838 .04578 L
s
.92838 .04578 m
.92857 .61803 L
s
0 .4 1 r
.02381 .04578 m
.04262 .04578 L
.0522 .04578 L
.06244 .04578 L
.06525 .04578 L
.0679 .04578 L
.06905 .04578 L
.07027 .04578 L
.07091 .04578 L
.07162 .1603 L
.07286 .16075 L
.08255 .16431 L
.10458 .17283 L
.14487 .19002 L
.18364 .20876 L
.22486 .23136 L
.26457 .25608 L
.30277 .28297 L
.34341 .31537 L
.38254 .35073 L
.42412 .39341 L
.46419 .44017 L
.48257 .46368 L
.4876 .47036 L
.493 .47764 L
.49562 .48121 L
.49809 .48462 L
.49917 .48612 L
.50032 .48682 L
.50158 .48508 L
.50274 .48347 L
.52268 .45683 L
.54374 .43044 L
.58149 .38731 L
.6217 .34669 L
.66038 .31216 L
.70152 .27979 L
.74115 .25233 L
.77926 .22896 L
.81982 .20699 L
.85886 .18834 L
.87877 .17967 L
.90036 .17087 L
.91046 .16695 L
.91599 .16486 L
.92116 .16293 L
.92557 .16132 L
.92683 .16086 L
.92804 .16042 L
.92912 .04578 L
Mistroke
.9303 .04578 L
.94034 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00D0003oooooooooool0I_l01?ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00H0003ooooooooooooo09T0I_l3
oooo00<0003oooooool01Oooo`030000oooooooo01;oool001ooool00`1Vooooooooo`1]oooo00<0
003oooooool0K?ooo`03o`2I06Kooooo01ooool001ooool00`1Vooooooooo`1]oooo00<0003ooooo
ool0K?ooo`03o`2I06Kooooo01ooool001ooool00`1Vooooooooo`1]oooo00<0003oooooool0K?oo
o`03o`2I06Kooooo01ooool001ooool00`1Vooooooooo`1]oooo00<0003oooooool0K?ooo`03o`2I
06Kooooo01ooool001ooool00`1Vooooooooo`1]oooo0P0006goool00ol0V@1Vooooo`0Ooooo000O
oooo00<0I_ooooooool0KOooo`030000oooooooo06coool00ol0V@1Vooooo`0Ooooo000Ooooo00<0
I_ooooooool0KOooo`030000oooooooo06coool00ol0V@1Vooooo`0Ooooo000Ooooo00<0I_oooooo
ool0KOooo`030000oooooooo06coool00ol0V@1Vooooo`0Ooooo000Ooooo00<0I_ooooooool0KOoo
o`030000oooooooo06coool00ol0V@1Vooooo`0Ooooo000Ooooo00<0I_ooooooool0KOooo`030000
oooooooo06coool00ol0V@1Vooooo`0Ooooo000Ooooo00<0I_ooooooool0KOooo`80001]oooo00?o
09T0I_ooool07oooo`007oooo`0306Kooooooooo06goool00`000?ooooooo`1/oooo00?o09T0I_oo
ool07oooo`007oooo`0306Kooooooooo06goool00`000?ooooooo`1/oooo00?o09T0I_ooool07ooo
o`007oooo`0306Kooooooooo06goool00`000?ooooooo`1/oooo00<0I_ooooooool07oooo`008?oo
o`0306Kooooooooo06coool00`000?ooooooo`1/oooo00<0I_ooooooool07oooo`008?ooo`0306Ko
oooooooo06coool00`000?ooooooo`1/oooo00<0I_ooooooool07oooo`008?ooo`0306Kooooooooo
06coool20000KOooo`0306Kooooooooo01ooool0023oool00`1Vooooooooo`1/oooo00<0003ooooo
ool0K?ooo`0306Kooooooooo01ooool0023oool00`1Vooooooooo`1/oooo00<0003oooooool0K?oo
o`0306Kooooooooo01ooool0023oool00`1Vooooooooo`1/oooo00<0003oooooool0K?ooo`0306Ko
oooooooo01ooool0023oool00`1Vooooooooo`1/oooo00<0003oooooool0K?ooo`0306Kooooooooo
01ooool0023oool00`1Vooooooooo`1/oooo00<0003oooooool0K?ooo`0306Kooooooooo01ooool0
023oool00`1Vooooooooo`1/oooo0P0006goool00`1Vooooooooo`0Ooooo000Poooo00<0I_oooooo
ool0K?ooo`030000oooooooo06coool00`1Vooooooooo`0Ooooo000Poooo00<0I_ooooooool0K?oo
o`030000oooooooo06coool00`1Vooooooooo`0Ooooo000Poooo00<0I_ooooooool0K?ooo`030000
oooooooo06coool00`1Vooooooooo`0Ooooo000Poooo00<0I_ooooooool0FOooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo06coool00`1Vooooooooo`0Ooooo000Poooo00<0I_oooooo
ool0F?ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo06coool0
0`1Vooooooooo`0Ooooo000Poooo00<0I_ooooooool0F?ooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000Joooo`80I_lQoooo000Qoooo0`1VoeOoool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo06Ooool406Ko00?ooooo09Woool08?ooo`009?ooo`<0I_mDoooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo06Goool206Ko1Oooo`03o`2I
oooooooo01ooool002Ooool306KoD_ooo`80000:oooo0`0000Coool00`000?ooooooo`1Soooo0P1V
o`Ooool00ol0VOooooooo`0Ooooo000Zoooo0`1Vof;oool00`000?ooooooo`1Qoooo0P1Vo`Woool0
0ol0VOooooooo`0Ooooo000]oooo0P1Vof3oool00`000?ooooooo`1Ooooo0P1Vo`_oool00ol0VOoo
ooooo`0Ooooo000_oooo0`1Voegoool20000GOooo`<0I_l=oooo00?o09Woooooool07oooo`00<_oo
o`80I_mKoooo00<0003oooooool0F_ooo`80I_l@oooo00?o09Woooooool07oooo`00=?ooo`80I_mI
oooo00<0003oooooool0F?ooo`80I_lBoooo00?o09Woooooool07oooo`00=_ooo`80I_mGoooo00<0
003oooooool0E_ooo`80I_lDoooo00?o09Woooooool07oooo`00>?ooo`80I_mEoooo00<0003ooooo
ool0E?ooo`80I_lFoooo00?o09Woooooool07oooo`00>_ooo`80I_mCoooo0P0005?oool206Ko6?oo
o`03o`2Ioooooooo01ooool003coool206KoDOooo`030000oooooooo053oool206Ko6_ooo`03o`2I
oooooooo01ooool003koool206KoCoooo`030000oooooooo04koool206Ko7?ooo`03o`2Ioooooooo
01ooool0043oool206KoCOooo`030000oooooooo04coool206Ko7_ooo`03o`2Ioooooooo01ooool0
04;oool00`1Vooooooooo`1:oooo00<0003oooooool0B_ooo`80I_lPoooo00?o09Woooooool07ooo
o`00@oooo`80I_m:oooo00<0003oooooool0B?ooo`80I_lRoooo00?o09Woooooool07oooo`00AOoo
o`80I_m8oooo0P0004Ooool206Ko9?ooo`03o`2Ioooooooo01ooool004Ooool00`1Vooooooooo`15
oooo00<0003oooooool0A?ooo`80I_lVoooo00?o09Woooooool07oooo`00B?ooo`80I_m5oooo00<0
003oooooool0@oooo`0306Kooooooooo02Koool00ol0VOooooooo`0Ooooo001:oooo00<0I_oooooo
ool0@_ooo`030000oooooooo04;oool00`1Vooooooooo`0Woooo00?o09Woooooool07oooo`00Booo
o`80I_m2oooo00<0003oooooool0@?ooo`80I_lZoooo00?o09Woooooool07oooo`00COooo`80I_m0
oooo00<0003oooooool0?oooo`0306Kooooooooo02[oool00ol0VOooooooo`0Ooooo001?oooo00<0
I_ooooooool0?Oooo`80000noooo0P1Vobgoool00ol0VOooooooo`0Ooooo001@oooo0P1Vocgoool0
0`000?ooooooo`0loooo00<0I_ooooooool0;Oooo`03o`2Ioooooooo01ooool005;oool00`1Voooo
ooooo`0joooo00<0003oooooool0>_ooo`80I_l`oooo00?o09Woooooool07oooo`00Doooo`80I_lj
oooo00<0003oooooool0>Oooo`0306Kooooooooo033oool00ol0VOooooooo`0Ooooo001Eoooo00<0
I_ooooooool0;oooo`D00003oooo00<0003oooooool0=oooo`80I_lcoooo00?o09Woooooool07ooo
o`00E_ooo`0306Kooooooooo033oool00`000?ooooooo`03oooo00<0003oooooool0=Oooo`80I_le
oooo00?o09Woooooool07oooo`00Eoooo`80I_l`oooo00<0003oooooool00oooo`<0000doooo00<0
I_ooooooool0=Oooo`03o`2Ioooooooo01ooool005Woool00`1Vooooooooo`0]oooo00<0003ooooo
ool00oooo`030000oooooooo03;oool206Ko>?ooo`03o`2Ioooooooo01ooool005[oool206Ko;Ooo
o`030000oooooooo00?oool00`000?ooooooo`0aoooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo
01ooool005coool00`1Vooooooooo`0Yoooo0P0000Goool00`000?ooooooo`0`oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo01ooool005goool00`1Vooooooooo`0_oooo00<0003oooooool0;_oo
o`80I_lloooo00?o09Woooooool07oooo`00G_ooo`80I_l_oooo00<0003oooooool0;Oooo`0306Ko
oooooooo03coool00ol0VOooooooo`0Ooooo001Poooo00<0I_ooooooool0;?ooo`80000]oooo00<0
I_ooooooool0?Oooo`03o`2Ioooooooo01ooool0067oool00`1Vooooooooo`0[oooo00<0003ooooo
ool0:oooo`0306Kooooooooo03koool00ol0VOooooooo`0Ooooo001Roooo00<0I_ooooooool0:_oo
o`030000oooooooo02Woool206Ko@Oooo`03o`2Ioooooooo01ooool006?oool206Ko:_ooo`030000
oooooooo02Soool00`1Vooooooooo`11oooo00?o09Woooooool07oooo`00IOooo`0306Kooooooooo
02Ooool00`000?ooooooo`0Woooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo01ooool006Koool0
0`1Vooooooooo`0Voooo00<0003oooooool09_ooo`0306Kooooooooo04?oool00ol0VOooooooo`0O
oooo001Woooo00<0I_ooooooool09Oooo`80000Voooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo
01ooool006Soool00`1Vooooooooo`0Toooo00<0003oooooool09?ooo`0306Kooooooooo04Goool0
0ol0VOooooooo`0Ooooo001Yoooo00<0I_ooooooool08oooo`030000oooooooo02?oool00`1Voooo
ooooo`16oooo00?o09Woooooool07oooo`00J_ooo`0306Kooooooooo02;oool00`000?ooooooo`0Q
oooo0P1VodWoool00ol0VOooooooo`0Ooooo001[oooo0P1Vob;oool00`000?ooooooo`0Poooo00<0
I_ooooooool0BOooo`03o`2Ioooooooo01ooool006goool00`1Vooooooooo`0Ooooo00<0003ooooo
ool07oooo`0306Kooooooooo04[oool00ol0VOooooooo`0Ooooo001^oooo00<0I_ooooooool07_oo
o`80000Ooooo00<0I_ooooooool0Boooo`03o`2Ioooooooo01ooool006ooool00`1Vooooooooo`0M
oooo00<0003oooooool07Oooo`0306Kooooooooo04coool00ol0VOooooooo`0Ooooo001`oooo00<0
I_ooooooool07?ooo`030000oooooooo01coool00`1Vooooooooo`1=oooo00?o09Woooooool07ooo
o`00LOooo`0306Kooooooooo01_oool00`000?ooooooo`0Koooo00<0I_ooooooool0C_ooo`03o`2I
oooooooo01ooool007;oool00`1Vooooooooo`0Joooo00<0003oooooool06_ooo`0306Kooooooooo
04ooool00ol0VOooooooo`0Ooooo001coooo00<0I_ooooooool06Oooo`030000oooooooo01Woool0
0`1Vooooooooo`1@oooo00?o09Woooooool07oooo`00M?ooo`0306Kooooooooo01Soool200006Ooo
o`0306Kooooooooo057oool00ol0VOooooooo`0Ooooo001eoooo00<0I_ooooooool05oooo`030000
oooooooo01Ooool00`1Vooooooooo`1Boooo00?o09Woooooool07oooo`00M_ooo`0306Kooooooooo
01Koool00`000?ooooooo`0Foooo00<0I_ooooooool0Doooo`03o`2Ioooooooo01ooool007Ooool0
0`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`0306Kooooooooo05Coool00ol0VOooooooo`0O
oooo001hoooo00<0I_ooooooool01@0000;oool200001?ooo`800005oooo00<0003oooooool05?oo
o`0306Kooooooooo05Goool00ol0VOooooooo`0Ooooo001ioooo00D0I_ooooooooooool000002Ooo
o`040000oooooooo00001?ooo`030000oooooooo01?oool00`1Vooooooooo`1Foooo00?o09Wooooo
ool07oooo`00N_ooo`0406Kooooooooo00003?ooo`030000oooooooo00;oool300004_ooo`0306Ko
oooooooo05Ooool00ol0VOooooooo`0Ooooo001koooo00<0I_ooool000002_ooo`800005oooo00<0
003oooooool04Oooo`0306Kooooooooo05Soool00ol0VOooooooo`0Ooooo001loooo00<0I_l0003o
ool02Oooo`030000oooooooo00Coool00`000?ooooooo`0@oooo00<0I_ooooooool0FOooo`03o`2I
oooooooo01ooool007coool200002_ooo`<00004oooo00<0003oooooool03oooo`0306Kooooooooo
05[oool00ol0VOooooooo`0Ooooo001noooo00<0I_ooooooool03_ooo`030000oooooooo00koool0
0`1Vooooooooo`1Koooo00?o09Woooooool07oooo`00Ooooo`0306Kooooooooo00goool00`000?oo
ooooo`0=oooo00<0I_ooooooool0G?ooo`03o`2Ioooooooo01ooool0083oool00`1Vooooooooo`0<
oooo0P0000koool00`1Vooooooooo`1Loooo00?o09Woooooool07oooo`00P?ooo`0306Kooooooooo
00coool00`000?ooooooo`0<oooo00<0I_ooooooool0GOooo`03o`2Ioooooooo01ooool0087oool0
0`1Vooooooooo`0;oooo00<0003oooooool02oooo`0306Kooooooooo05koool00ol0VOooooooo`0O
oooo0022oooo00<0I_ooooooool02_ooo`030000oooooooo00[oool00`1Vooooooooo`1Ooooo00?o
09Woooooool07oooo`00Poooo`0306Kooooooooo00Woool00`000?ooooooo`09oooo00<0I_oooooo
ool0H?ooo`03o`2Ioooooooo01ooool008Coool00`1Vooooooooo`08oooo00<0003oooooool02?oo
o`0306Kooooooooo067oool00ol0VOooooooo`0Ooooo0025oooo00<0I_ooooooool01oooo`800008
oooo00<0I_ooooooool0H_ooo`03o`2Ioooooooo01ooool008Koool00`1Vooooooooo`06oooo00<0
003oooooool01oooo`0306Kooooooooo06;oool00ol0VOooooooo`0Ooooo0027oooo00<0I_oooooo
ool01Oooo`030000oooooooo00Koool00`1Vooooooooo`1Soooo00?o09Woooooool07oooo`00Qooo
o`0306Kooooooooo00Goool00`000?ooooooo`05oooo00<0I_ooooooool0I?ooo`03o`2Ioooooooo
01ooool008Soool00`1Vooooooooo`04oooo00<0003oooooool01?ooo`0306Kooooooooo06Goool0
0ol0VOooooooo`0Ooooo0028oooo00<0I_ooooooool01?ooo`030000oooooooo00Coool00`1Voooo
ooooo`1Uoooo00?o09Woooooool07oooo`00ROooo`0306Kooooooooo00?oool200001?ooo`0306Ko
oooooooo06Koool00ol0VOooooooo`0Ooooo0029oooo00<0I_ooooooool00oooo`030000oooooooo
00;oool00`1Vooooooooo`1Woooo00?o09Woooooool07oooo`00R_ooo`0306Kooooooooo00;oool0
0`000?ooooooo`02oooo00<0I_ooooooool0Ioooo`03o`2Ioooooooo01ooool008_oool206Ko0_oo
o`050000oooooooooooo06Ko06[oool00ol0VOooooooo`0Ooooo002<oooo00@0I_ooooooool00002
oooo00<0I_ooooooool0JOooo`03o`2Ioooooooo01ooool008goool01@1Vooooo`000?ooo`1Vo`1/
oooo00?o09Woooooool07oooo`00S_ooo`0406Ko0000000006KoK?ooo`03o`2Ioooooooo01ooool0
08koool00`1Vo`00001Vo`1]oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool0
0ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool008Ooool4
00001?ooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo0027oooo00<0003oooooool01Ooo
o`030000oooooooo06coool00ol0VOooooooo`0Ooooo0028oooo00<0003oooooool01?ooo`<0001/
oooo00?o09Woooooool07oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1/oooo00?o
09Woooooool07oooo`00Qoooo`040000oooooooo00001?ooo`030000oooooooo06coool00ol0VOoo
ooooo`0Ooooo0028oooo0P0000Goool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Sooo
o`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2I
oooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/
oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?
oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/oooo00?o
09Woooooool07oooo`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?oooo0P00
06goool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool0
08ooool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool0
0ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool008ooool0
0`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Soooo`80001]oooo00?o09Woooooool07ooo
o`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?oo
o`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Sooo
o`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?oooo00<0003oooooool0K?ooo`03o`2I
oooooooo01ooool008ooool20000KOooo`03o`2Ioooooooo01ooool008ooool00`000?ooooooo`1/
oooo00?o09Woooooool07oooo`00Soooo`030000oooooooo06coool00ol0VOooooooo`0Ooooo002?
oooo00<0003oooooool0K?ooo`03o`2Ioooooooo01ooool007_oool400000oooo`800004oooo0P00
00Goool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00Noooo`030000oooooooo00Woool0
10000?ooooooo`0000Coool00`000?ooooooo`1/oooo00?o09Woooooool07oooo`00O?ooo`030000
oooooooo00_oool00`000?ooooooo`02oooo0`0006coool00ol0VOooooooo`0Ooooo001moooo00<0
003oooooool02?ooo`80002Foooo001koooo00@0003oooooool00009oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool00oooo`030000oooooooo
07[oool007_oool00`000?ooooooo`0500003oooo`030000oooooooo00Woool01@000?oooooooooo
o`00001moooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000Woool4
00000_ooo`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.91765 .04578 L
.92769 .04578 L
.93044 .04578 L
.93339 .04578 L
.93482 .04578 L
.93553 .04578 L
.93618 .04578 L
s
.93618 .04578 m
.93648 .61803 L
s
0 .4 1 r
.02381 .04578 m
.04262 .04578 L
.0522 .04578 L
.05746 .04578 L
.06005 .04578 L
.06119 .04578 L
.06244 .04578 L
.06371 .16031 L
.06441 .16056 L
.06506 .1608 L
.0679 .16183 L
.07286 .16366 L
.08255 .16731 L
.10458 .17605 L
.14335 .19297 L
.18458 .21338 L
.22428 .23571 L
.26248 .25999 L
.30312 .28925 L
.34225 .32118 L
.38383 .35973 L
.4239 .40196 L
.46245 .44795 L
.482 .47349 L
.49235 .48767 L
.49534 .49184 L
.4968 .49391 L
.49816 .49583 L
.49939 .49757 L
.5007 .49745 L
.50201 .49559 L
.50346 .49354 L
.52388 .46564 L
.54294 .44117 L
.58315 .39414 L
.62183 .35417 L
.66297 .31669 L
.7026 .2849 L
.74071 .25785 L
.78127 .23242 L
.82031 .21082 L
.86181 .19059 L
.88261 .18141 L
.90179 .17346 L
.92048 .16616 L
.9299 .16264 L
.93248 .16169 L
.9339 .16118 L
.93525 .16069 L
.9365 .16023 L
Mistroke
.93721 .04578 L
.93787 .04578 L
.94026 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oool0I_l01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool00oooo`04o`2I06Kooooo
00001oooo`030000oooooooo01;oool001goool00`1Vooooooooo`1_oooo00<0003oooooool0K_oo
o`03o`2I06Kooooo01goool001goool00`1Vooooooooo`1_oooo00<0003oooooool0K_ooo`03o`2I
06Kooooo01goool001goool00`1Vooooooooo`1_oooo00<0003oooooool0K_ooo`03o`2I06Kooooo
01goool001goool00`1Vooooooooo`1_oooo00<0003oooooool0K_ooo`03o`2I06Kooooo01goool0
01goool00`1Vooooooooo`1_oooo0P0006ooool00ol0V@1Vooooo`0Moooo000Moooo00<0I_oooooo
ool0Koooo`030000oooooooo06koool00ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Kooo
o`030000oooooooo06koool00ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Koooo`030000
oooooooo06koool00ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Koooo`030000oooooooo
06koool00ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Koooo`030000oooooooo06koool0
0ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Koooo`80001_oooo00?o09T0I_ooool07Ooo
o`007Oooo`0306Kooooooooo06ooool00`000?ooooooo`1^oooo00?o09T0I_ooool07Oooo`007Ooo
o`0306Kooooooooo06ooool00`000?ooooooo`1^oooo00?o09T0I_ooool07Oooo`007Oooo`0306Ko
oooooooo06ooool00`000?ooooooo`1^oooo00?o09T0I_ooool07Oooo`007Oooo`0306Kooooooooo
06ooool00`000?ooooooo`1^oooo00?o09T0I_ooool07Oooo`007Oooo`0306Kooooooooo06ooool0
0`000?ooooooo`1^oooo00?o09T0I_ooool07Oooo`007Oooo`0306Kooooooooo06ooool20000Kooo
o`03o`2I06Kooooo01goool001goool00`1Vooooooooo`1_oooo00<0003oooooool0K_ooo`03o`2I
06Kooooo01goool001goool00`1Vooooooooo`1_oooo00<0003oooooool0K_ooo`03o`2I06Kooooo
01goool001goool00`1Vooooooooo`1_oooo00<0003oooooool0K_ooo`03o`2I06Kooooo01goool0
01goool00`1Vooooooooo`1_oooo00<0003oooooool0K_ooo`03o`2I06Kooooo01goool001goool0
0`1Vooooooooo`1_oooo00<0003oooooool0K_ooo`03o`2I06Kooooo01goool001goool00`1Voooo
ooooo`1_oooo0P0006ooool00ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Koooo`030000
oooooooo06koool00ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Koooo`030000oooooooo
06koool00ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Koooo`030000oooooooo06koool0
0ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0G?ooo`800004oooo0P0000Coool200001Ooo
o`030000oooooooo06koool00ol0V@1Vooooo`0Moooo000Moooo00<0I_ooooooool0Foooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo06koool00ol0V@1Vooooo`0M
oooo000Moooo101Voe[oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0006coool4
06Ko7_ooo`008Oooo`80I_mHoooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`1Y
oooo0`1Vo`;oool00ol0VOooooooo`0Moooo000Soooo0P1VoeKoool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool0Ioooo`80I_l5oooo00?o09Woooooool07Oooo`009Ooo
o`80I_mEoooo0P0000[oool300001?ooo`030000oooooooo06Goool206Ko1oooo`03o`2Ioooooooo
01goool002Ooool306KoIOooo`030000oooooooo06?oool206Ko2Oooo`03o`2Ioooooooo01goool0
02[oool206KoHoooo`030000oooooooo063oool306Ko2oooo`03o`2Ioooooooo01goool002coool3
06KoH?ooo`80001Noooo0`1Vo`koool00ol0VOooooooo`0Moooo000_oooo0P1Voekoool00`000?oo
ooooo`1Koooo0P1Voa7oool00ol0VOooooooo`0Moooo000aoooo0`1Voe_oool00`000?ooooooo`1I
oooo0P1Voa?oool00ol0VOooooooo`0Moooo000doooo0P1VoeWoool00`000?ooooooo`1Goooo0P1V
oaGoool00ol0VOooooooo`0Moooo000foooo0P1VoeOoool00`000?ooooooo`1Eoooo0P1VoaOoool0
0ol0VOooooooo`0Moooo000hoooo0P1VoeGoool20000E?ooo`80I_lIoooo00?o09Woooooool07Ooo
o`00>_ooo`80I_mCoooo00<0003oooooool0DOooo`80I_lKoooo00?o09Woooooool07Oooo`00??oo
o`80I_mAoooo00<0003oooooool0D?ooo`0306Kooooooooo01_oool00ol0VOooooooo`0Moooo000n
oooo0P1Vodooool00`000?ooooooo`1>oooo0P1Voakoool00ol0VOooooooo`0Moooo0010oooo0P1V
odgoool00`000?ooooooo`1<oooo0P1Vob3oool00ol0VOooooooo`0Moooo0012oooo00<0I_oooooo
ool0B_ooo`030000oooooooo04[oool206Ko8_ooo`03o`2Ioooooooo01goool004?oool206KoB_oo
o`800019oooo0P1VobCoool00ol0VOooooooo`0Moooo0015oooo0P1VodSoool00`000?ooooooo`16
oooo0P1VobKoool00ol0VOooooooo`0Moooo0017oooo00<0I_ooooooool0AOooo`030000oooooooo
04Coool206Ko:?ooo`03o`2Ioooooooo01goool004Soool206KoAOooo`030000oooooooo04?oool0
0`1Vooooooooo`0Xoooo00?o09Woooooool07Oooo`00B_ooo`0306Kooooooooo04;oool00`000?oo
ooooo`12oooo00<0I_ooooooool0:Oooo`03o`2Ioooooooo01goool004_oool00`1Vooooooooo`11
oooo00<0003oooooool0@?ooo`80I_l/oooo00?o09Woooooool07Oooo`00C?ooo`80I_m1oooo0P00
043oool00`1Vooooooooo`0/oooo00?o09Woooooool07Oooo`00C_ooo`0306Kooooooooo03koool0
0`000?ooooooo`0moooo0P1Vobooool00ol0VOooooooo`0Moooo001?oooo0P1Vockoool00`000?oo
ooooo`0loooo00<0I_ooooooool0;oooo`03o`2Ioooooooo01goool0057oool00`1Vooooooooo`0k
oooo00<0003oooooool0>_ooo`80I_lboooo00?o09Woooooool07Oooo`00D_ooo`80I_lcoooo1@00
00?oool00`000?ooooooo`0ioooo00<0I_ooooooool0<_ooo`03o`2Ioooooooo01goool005Coool0
0`1Vooooooooo`0boooo00<0003oooooool00oooo`030000oooooooo03Soool00`1Vooooooooo`0c
oooo00?o09Woooooool07Oooo`00EOooo`80I_lboooo00<0003oooooool00oooo`<0000foooo0P1V
ocKoool00ol0VOooooooo`0Moooo001Goooo0P1Voc3oool00`000?ooooooo`03oooo00<0003ooooo
ool0=Oooo`0306Kooooooooo03Koool00ol0VOooooooo`0Moooo001Ioooo00<0I_ooooooool0;Ooo
o`030000oooooooo00?oool00`000?ooooooo`0coooo0P1VocWoool00ol0VOooooooo`0Moooo001J
oooo0P1Vobcoool200001Oooo`030000oooooooo03;oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool07Oooo`00G?ooo`0306Kooooooooo033oool00`000?ooooooo`0`oooo0P1Voccoool00ol0VOoo
ooooo`0Moooo001Moooo00<0I_ooooooool0;oooo`030000oooooooo02ooool00`1Vooooooooo`0l
oooo00?o09Woooooool07Oooo`00G_ooo`80I_l_oooo0P0002ooool00`1Vooooooooo`0moooo00?o
09Woooooool07Oooo`00H?ooo`0306Kooooooooo02coool00`000?ooooooo`0/oooo0P1Vod3oool0
0ol0VOooooooo`0Moooo001Qoooo00<0I_ooooooool0:oooo`030000oooooooo02_oool00`1Voooo
ooooo`10oooo00?o09Woooooool07Oooo`00H_ooo`0306Kooooooooo02[oool00`000?ooooooo`0Z
oooo00<0I_ooooooool0@Oooo`03o`2Ioooooooo01goool006?oool206Ko:_ooo`030000oooooooo
02Soool206KoA?ooo`03o`2Ioooooooo01goool006Goool00`1Vooooooooo`0Woooo00<0003ooooo
ool09oooo`0306Kooooooooo04Coool00ol0VOooooooo`0Moooo001Voooo00<0I_ooooooool09_oo
o`80000Woooo00<0I_ooooooool0AOooo`03o`2Ioooooooo01goool006Ooool00`1Vooooooooo`0U
oooo00<0003oooooool09Oooo`0306Kooooooooo04Koool00ol0VOooooooo`0Moooo001Xoooo00<0
I_ooooooool09?ooo`030000oooooooo02Coool00`1Vooooooooo`17oooo00?o09Woooooool07Ooo
o`00JOooo`0306Kooooooooo02?oool00`000?ooooooo`0Soooo00<0I_ooooooool0B?ooo`03o`2I
oooooooo01goool006[oool00`1Vooooooooo`0Roooo00<0003oooooool08_ooo`0306Kooooooooo
04[oool00ol0VOooooooo`0Loooo001[oooo0P1Vob;oool00`000?ooooooo`0Qoooo00<0I_oooooo
ool0Boooo`03o`2Ioooooooo01coool006goool00`1Vooooooooo`0Ooooo0P00027oool00`1Voooo
ooooo`1<oooo00?o09Woooooool07?ooo`00K_ooo`0306Kooooooooo01koool00`000?ooooooo`0O
oooo00<0I_ooooooool0COooo`03o`2Ioooooooo01coool006ooool00`1Vooooooooo`0Moooo00<0
003oooooool07_ooo`0306Kooooooooo04koool00ol0VOooooooo`0Loooo001`oooo00<0I_oooooo
ool07?ooo`030000oooooooo01goool00`1Vooooooooo`1?oooo00?o09Woooooool07?ooo`00LOoo
o`0306Kooooooooo01_oool00`000?ooooooo`0Loooo00<0I_ooooooool0D?ooo`03o`2Ioooooooo
01coool007;oool00`1Vooooooooo`0Joooo00<0003oooooool06oooo`0306Kooooooooo057oool0
0ol0VOooooooo`0Loooo001coooo00<0I_ooooooool06Oooo`80000Koooo00<0I_ooooooool0D_oo
o`03o`2Ioooooooo01coool007Coool00`1Vooooooooo`0Hoooo00<0003oooooool06Oooo`0306Ko
oooooooo05?oool00ol0VOooooooo`0Loooo001eoooo00<0I_ooooooool05oooo`030000oooooooo
01Soool00`1Vooooooooo`1Doooo00?o09Woooooool07?ooo`00M_ooo`0306Kooooooooo01Koool0
0`000?ooooooo`0Goooo00<0I_ooooooool0EOooo`03o`2Ioooooooo01coool007Koool00`1Voooo
ooooo`02oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool05_ooo`0306Kooooooooo
05Koool00ol0VOooooooo`0Loooo001goooo00<0I_ooooooool00oooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`0Eoooo00<0I_ooooooool0Eoooo`03o`2Ioooooooo
01coool007Soool00`1Vooooooooo`02oooo00<0003oooooool02_ooo`030000oooooooo00;oool3
00005?ooo`0306Kooooooooo05Soool00ol0VOooooooo`0Loooo001ioooo00D0I_ooooooooooool0
00002_ooo`800005oooo00<0003oooooool04oooo`0306Kooooooooo05Woool00ol0VOooooooo`0L
oooo001joooo00@0I_ooooooool0000:oooo00<0003oooooool01?ooo`030000oooooooo01;oool0
0`1Vooooooooo`1Joooo00?o09Woooooool07?ooo`00Noooo`0306Ko0000000000[oool300001?oo
o`030000oooooooo017oool00`1Vooooooooo`1Koooo00?o09Woooooool07?ooo`00O?ooo`0306Ko
oooooooo013oool00`000?ooooooo`0@oooo00<0I_ooooooool0G?ooo`03o`2Ioooooooo01coool0
07goool00`1Vooooooooo`0?oooo00<0003oooooool04?ooo`0306Kooooooooo05coool00ol0VOoo
ooooo`0Loooo001moooo00<0I_ooooooool03oooo`80000@oooo00<0I_ooooooool0GOooo`03o`2I
oooooooo01coool007koool00`1Vooooooooo`0>oooo00<0003oooooool03_ooo`0306Kooooooooo
05koool00ol0VOooooooo`0Loooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo00goool0
0`1Vooooooooo`1Ooooo00?o09Woooooool07?ooo`00P?ooo`0306Kooooooooo00coool00`000?oo
ooooo`0<oooo00<0I_ooooooool0H?ooo`03o`2Ioooooooo01coool0087oool00`1Vooooooooo`0;
oooo00<0003oooooool02oooo`0306Kooooooooo067oool00ol0VOooooooo`0Loooo0022oooo00<0
I_ooooooool02_ooo`030000oooooooo00_oool00`1Vooooooooo`1Qoooo00?o09Woooooool07?oo
o`00P_ooo`0306Kooooooooo00[oool200002oooo`0306Kooooooooo06;oool00ol0VOooooooo`0L
oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Vooooooooo`1Soooo00?o
09Woooooool07?ooo`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`08oooo00<0I_oooooo
ool0I?ooo`03o`2Ioooooooo01coool008Goool00`1Vooooooooo`07oooo00<0003oooooool01ooo
o`0306Kooooooooo06Goool00ol0VOooooooo`0Loooo0026oooo00<0I_ooooooool01_ooo`030000
oooooooo00Koool00`1Vooooooooo`1Voooo00?o09Woooooool07?ooo`00Q_ooo`0306Kooooooooo
00Koool00`000?ooooooo`05oooo00<0I_ooooooool0Ioooo`03o`2Ioooooooo01coool008Ooool0
0`1Vooooooooo`05oooo0P0000Koool00`1Vooooooooo`1Woooo00?o09Woooooool07?ooo`00R?oo
o`0306Kooooooooo00Coool00`000?ooooooo`04oooo00<0I_ooooooool0J?ooo`03o`2Ioooooooo
01coool008Woool00`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo06Woool0
0ol0VOooooooo`0Loooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00;oool00`1Voooo
ooooo`1Zoooo00?o09Woooooool07?ooo`00R_ooo`0306Kooooooooo00;oool00`000?ooooooo`02
oooo00<0I_ooooooool0J_ooo`03o`2Ioooooooo01coool008_oool01@1Vooooooooooooo`000003
oooo00<0I_ooooooool0Joooo`03o`2Ioooooooo01coool008_oool0101Vooooooooooooo`800000
0oooo`1Vooooo`1]oooo00?o09Woooooool07?ooo`00S?ooo`0606Kooooooooo0000oooo06KoKooo
o`03o`2Ioooooooo01coool008goool01@1Vooooo`000?ooo`1Vo`1_oooo00?o09Woooooool07?oo
o`00S_ooo`0306Ko000006Ko073oool00ol0VOooooooo`0Loooo0027oooo100000?oool00`1Vo`00
0?ooo`1`oooo00?o09Woooooool07?ooo`00Qoooo`030000oooooooo00Goool00`000?ooooooo`1_
oooo00?o09Woooooool07?ooo`00R?ooo`030000oooooooo00Coool30000Koooo`03o`2Ioooooooo
01coool008Woool00`000?ooooooo`03oooo00<0003oooooool0Koooo`03o`2Ioooooooo01coool0
08Ooool010000?ooooooo`0000Coool00`000?ooooooo`1_oooo00?o09Woooooool07?ooo`00R?oo
o`800005oooo00<0003oooooool0Koooo`03o`2Ioooooooo01coool008ooool00`000?ooooooo`1_
oooo00?o09Woooooool07?ooo`00Soooo`030000oooooooo06ooool00ol0VOooooooo`0Loooo002?
oooo0P00073oool00ol0VOooooooo`0Loooo002?oooo00<0003oooooool0Koooo`03o`2Ioooooooo
01coool008ooool00`000?ooooooo`1_oooo00?o09Woooooool07?ooo`00Soooo`030000oooooooo
06ooool00ol0VOooooooo`0Loooo002?oooo00<0003oooooool0Koooo`03o`2Ioooooooo01coool0
08ooool00`000?ooooooo`1_oooo00?o09Woooooool07?ooo`00Soooo`80001`oooo00?o09Wooooo
ool07?ooo`00Soooo`030000oooooooo06ooool00ol0VOooooooo`0Loooo002?oooo00<0003ooooo
ool0Koooo`03o`2Ioooooooo01coool008ooool00`000?ooooooo`1_oooo00?o09Woooooool07?oo
o`00Soooo`030000oooooooo06ooool00ol0VOooooooo`0Loooo002?oooo00<0003oooooool0Kooo
o`03o`2Ioooooooo01coool008ooool20000L?ooo`03o`2Ioooooooo01coool008ooool00`000?oo
ooooo`1_oooo00?o09Woooooool07?ooo`00Soooo`030000oooooooo06ooool00ol0VOooooooo`0L
oooo002?oooo00<0003oooooool0Koooo`03o`2Ioooooooo01coool008ooool00`000?ooooooo`1_
oooo00?o09Woooooool07?ooo`00Soooo`030000oooooooo06ooool00ol0VOooooooo`0Loooo002?
oooo0P00073oool00ol0VOooooooo`0Loooo002?oooo00<0003oooooool0Koooo`03o`2Ioooooooo
01coool008ooool00`000?ooooooo`1_oooo00?o09Woooooool07?ooo`00Soooo`030000oooooooo
06ooool00ol0VOooooooo`0Loooo001koooo100000?oool200001?ooo`800005oooo00<0003ooooo
ool0Koooo`03o`2Ioooooooo01coool007_oool00`000?ooooooo`09oooo00@0003oooooool00004
oooo00<0003oooooool0Koooo`03o`2Ioooooooo01coool007coool00`000?ooooooo`0;oooo00<0
003oooooool00_ooo`<0001_oooo00?o09Woooooool07?ooo`00OOooo`030000oooooooo00Soool2
0000U_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0003ooooo
ool00_ooo`030000oooooooo00ooool00`000?ooooooo`09oooo00<0003oooooool01?ooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000ooool00`000?oo
ooooo`09oooo00@0003oooooooooool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003ooooo
ool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000Woool400000ooo
o`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.91726 .04578 L
.92761 .04578 L
.93331 .04578 L
.93871 .04578 L
.94107 .04578 L
.94236 .04578 L
.94357 .04578 L
s
.94357 .04578 m
.9439 .61803 L
s
0 .4 1 r
.02381 .04578 m
.03279 .04578 L
.04262 .04578 L
.04758 .04578 L
.0503 .04578 L
.05288 .04578 L
.05405 .04578 L
.05528 .04578 L
.05593 .16037 L
.05664 .16062 L
.05789 .16108 L
.06244 .16274 L
.10458 .17934 L
.14487 .19742 L
.18364 .21711 L
.22486 .24087 L
.26457 .26687 L
.30277 .29513 L
.34341 .32919 L
.38254 .36636 L
.42412 .41123 L
.46419 .46039 L
.48257 .4851 L
.4876 .49212 L
.493 .49978 L
.49562 .50354 L
.49809 .50712 L
.49917 .50869 L
.50032 .50943 L
.50158 .5076 L
.50274 .50591 L
.52268 .4779 L
.54374 .45016 L
.58149 .40482 L
.6217 .36211 L
.66038 .32582 L
.70152 .29178 L
.74115 .26292 L
.77926 .23836 L
.81982 .21526 L
.85886 .19564 L
.90036 .17728 L
.92116 .16894 L
.9303 .16545 L
.93514 .16364 L
.93781 .16265 L
.94034 .16172 L
.94259 .1609 L
.94386 .16044 L
.94504 .04578 L
Mistroke
.94614 .04578 L
.94712 .04578 L
.94934 .04578 L
.95776 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`03o`2I0000oooo
00Koool00`000?ooooooo`0Boooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo073oool0
0ol0V@1Vooooo`0Koooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo073oool00ol0V@1V
ooooo`0Koooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo073oool00ol0V@1Vooooo`0K
oooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo073oool00ol0V@1Vooooo`0Koooo000K
oooo00<0I_ooooooool0LOooo`80001aoooo00?o09T0I_ooool06oooo`006oooo`0306Kooooooooo
077oool00`000?ooooooo`1`oooo00?o09T0I_ooool06oooo`006oooo`0306Kooooooooo077oool0
0`000?ooooooo`1`oooo00?o09T0I_ooool06oooo`006oooo`0306Kooooooooo077oool00`000?oo
ooooo`1`oooo00?o09T0I_ooool06oooo`006oooo`0306Kooooooooo077oool00`000?ooooooo`1`
oooo00?o09T0I_ooool06oooo`006oooo`0306Kooooooooo077oool00`000?ooooooo`1`oooo00?o
09T0I_ooool06oooo`006oooo`0306Kooooooooo077oool20000LOooo`03o`2I06Kooooo01_oool0
01_oool00`1Vooooooooo`1aoooo00<0003oooooool0L?ooo`03o`2I06Kooooo01_oool001_oool0
0`1Vooooooooo`1aoooo00<0003oooooool0L?ooo`03o`2I06Kooooo01_oool001_oool00`1Voooo
ooooo`1aoooo00<0003oooooool0L?ooo`0306Kooooooooo01_oool001_oool00`1Vooooooooo`1a
oooo00<0003oooooool0L?ooo`0306Kooooooooo01_oool001_oool00`1Vooooooooo`1aoooo00<0
003oooooool0L?ooo`0306Kooooooooo01_oool001_oool00`1Vooooooooo`1aoooo0P00077oool0
0`1Vooooooooo`0Koooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo073oool00`1Voooo
ooooo`0Koooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo073oool00`1Vooooooooo`0K
oooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo073oool00`1Vooooooooo`0Koooo000K
oooo00<0I_ooooooool0LOooo`030000oooooooo073oool00`1Vooooooooo`0Koooo000Koooo00<0
I_ooooooool0LOooo`030000oooooooo073oool00`1Vooooooooo`0Koooo000Koooo00<0I_oooooo
ool0LOooo`80001aoooo00<0I_ooooooool06oooo`006oooo`0306Kooooooooo077oool00`000?oo
ooooo`1`oooo00<0I_ooooooool06oooo`006oooo`0306Kooooooooo077oool00`000?ooooooo`1`
oooo00<0I_ooooooool06oooo`006oooo`0306Kooooooooo077oool00`000?ooooooo`1`oooo00<0
I_ooooooool06oooo`006oooo`0306Kooooooooo05koool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1`oooo00<0I_ooooooool06oooo`006oooo`0306Kooooooooo05goool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1`oooo00<0I_ooooooool06ooo
o`006oooo`@0I_mLoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001^oooo0`1V
oagoool001ooool206KoF_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0KOoo
o`0406Koooooooooo`2I7Oooo`008Oooo`80I_mHoooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo06[oool306Ko0oooo`03o`2Ioooooooo01_oool002?oool206KoEooo
o`80000:oooo0`0000Coool00`000?ooooooo`1Woooo0`1Vo`Koool00ol0VOooooooo`0Koooo000U
oooo0P1VofSoool00`000?ooooooo`1Toooo0`1Vo`Woool00ol0VOooooooo`0Koooo000Woooo0`1V
ofGoool00`000?ooooooo`1Roooo0P1Vo`coool00ol0VOooooooo`0Koooo000Zoooo0`1Vof;oool2
0000HOooo`80I_l>oooo00?o09Woooooool06oooo`00;Oooo`80I_mPoooo00<0003oooooool0G_oo
o`80I_l@oooo00?o09Woooooool06oooo`00;oooo`<0I_mMoooo00<0003oooooool0G?ooo`80I_lB
oooo00?o09Woooooool06oooo`00<_ooo`80I_mKoooo00<0003oooooool0F_ooo`80I_lDoooo00?o
09Woooooool06oooo`00=?ooo`80I_mIoooo00<0003oooooool0F?ooo`80I_lFoooo00?o09Wooooo
ool06oooo`00=_ooo`80I_mGoooo0P0005Ooool206Ko6?ooo`03o`2Ioooooooo01_oool003Soool2
06KoEOooo`030000oooooooo05Coool206Ko6_ooo`03o`2Ioooooooo01_oool003[oool206KoDooo
o`030000oooooooo05;oool206Ko7?ooo`03o`2Ioooooooo01_oool003coool206KoDOooo`030000
oooooooo053oool206Ko7_ooo`03o`2Ioooooooo01_oool003koool206KoCoooo`030000oooooooo
04koool206Ko8?ooo`03o`2Ioooooooo01_oool0043oool00`1Vooooooooo`1<oooo00<0003ooooo
ool0C?ooo`80I_lRoooo00?o09Woooooool06oooo`00@Oooo`0306Kooooooooo04_oool20000C?oo
o`0306Kooooooooo02;oool00ol0VOooooooo`0Koooo0012oooo0P1Vod_oool00`000?ooooooo`19
oooo0P1VobGoool00ol0VOooooooo`0Koooo0014oooo00<0I_ooooooool0B?ooo`030000oooooooo
04Ooool206Ko9oooo`03o`2Ioooooooo01_oool004Goool206KoB?ooo`030000oooooooo04Koool0
0`1Vooooooooo`0Woooo00?o09Woooooool06oooo`00Aoooo`0306Kooooooooo04Goool00`000?oo
ooooo`14oooo0P1Vob[oool00ol0VOooooooo`0Koooo0018oooo0P1VodGoool00`000?ooooooo`12
oooo0P1Vobcoool00ol0VOooooooo`0Koooo001:oooo0P1Vod?oool20000@_ooo`0306Kooooooooo
02coool00ol0VOooooooo`0Koooo001<oooo0P1Vod7oool00`000?ooooooo`0ooooo0P1Vobooool0
0ol0VOooooooo`0Koooo001>oooo0P1Vocooool00`000?ooooooo`0moooo0P1Voc7oool00ol0VOoo
ooooo`0Koooo001@oooo0P1Vocgoool00`000?ooooooo`0loooo00<0I_ooooooool0<Oooo`03o`2I
oooooooo01_oool005;oool00`1Vooooooooo`0boooo1@0000?oool00`000?ooooooo`0joooo0P1V
ocCoool00ol0VOooooooo`0Koooo001Coooo00<0I_ooooooool0<oooo`030000oooooooo00?oool0
0`000?ooooooo`0ioooo00<0I_ooooooool0=?ooo`03o`2Ioooooooo01_oool005Coool206Ko<ooo
o`030000oooooooo00?oool30000>?ooo`0306Kooooooooo03Goool00ol0VOooooooo`0Koooo001F
oooo00<0I_ooooooool0<?ooo`030000oooooooo00?oool00`000?ooooooo`0foooo0P1VocSoool0
0ol0VOooooooo`0Koooo001Goooo00<0I_ooooooool0;oooo`030000oooooooo00?oool00`000?oo
ooooo`0eoooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo01_oool005Soool00`1Vooooooooo`0]
oooo0P0000Goool00`000?ooooooo`0doooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01_oool0
05Woool206Ko=?ooo`030000oooooooo03;oool206Ko??ooo`03o`2Ioooooooo01_oool005_oool0
0`1Vooooooooo`0aoooo00<0003oooooool0<Oooo`0306Kooooooooo03coool00ol0VOooooooo`0K
oooo001Loooo00<0I_ooooooool0<?ooo`80000aoooo00<0I_ooooooool0?Oooo`03o`2Ioooooooo
01_oool005goool00`1Vooooooooo`0_oooo00<0003oooooool0;oooo`0306Kooooooooo03koool0
0ol0VOooooooo`0Koooo001Noooo00<0I_ooooooool0;_ooo`030000oooooooo02koool00`1Voooo
ooooo`0ooooo00?o09Woooooool06oooo`00Goooo`0306Kooooooooo02goool00`000?ooooooo`0]
oooo00<0I_ooooooool0@?ooo`03o`2Ioooooooo01_oool0063oool00`1Vooooooooo`0/oooo00<0
003oooooool0:oooo`80I_m3oooo00?o09Woooooool06oooo`00HOooo`80I_l/oooo00<0003ooooo
ool0:_ooo`0306Kooooooooo04?oool00ol0VOooooooo`0Koooo001Soooo00<0I_ooooooool0:Ooo
o`80000Zoooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo01_oool006Coool00`1Vooooooooo`0X
oooo00<0003oooooool0:?ooo`0306Kooooooooo04Goool00ol0VOooooooo`0Koooo001Uoooo00<0
I_ooooooool09oooo`030000oooooooo02Ooool00`1Vooooooooo`16oooo00?o09Woooooool06ooo
o`00I_ooo`0306Kooooooooo02Koool00`000?ooooooo`0Voooo00<0I_ooooooool0Aoooo`03o`2I
oooooooo01_oool006Ooool00`1Vooooooooo`0Uoooo00<0003oooooool09Oooo`0306Kooooooooo
04Soool00ol0VOooooooo`0Koooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool0
0`1Vooooooooo`19oooo00?o09Woooooool06oooo`00JOooo`0306Kooooooooo02?oool200009?oo
o`0306Kooooooooo04[oool00ol0VOooooooo`0Koooo001Zoooo00<0I_ooooooool08_ooo`030000
oooooooo027oool206KoCOooo`03o`2Ioooooooo01_oool006_oool206Ko8_ooo`030000oooooooo
023oool00`1Vooooooooo`1=oooo00?o09Woooooool06oooo`00KOooo`0306Kooooooooo01ooool0
0`000?ooooooo`0Ooooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo01_oool006koool00`1Voooo
ooooo`0Noooo00<0003oooooool07_ooo`0306Kooooooooo04ooool00ol0VOooooooo`0Koooo001_
oooo00<0I_ooooooool07Oooo`030000oooooooo01goool00`1Vooooooooo`1@oooo00?o09Wooooo
ool06oooo`00L?ooo`0306Kooooooooo01coool200007Oooo`0306Kooooooooo057oool00ol0VOoo
ooooo`0Koooo001aoooo00<0I_ooooooool06oooo`030000oooooooo01_oool00`1Vooooooooo`1B
oooo00?o09Woooooool06oooo`00L_ooo`0306Kooooooooo01[oool00`000?ooooooo`0Joooo00<0
I_ooooooool0Doooo`03o`2Ioooooooo01_oool007?oool00`1Vooooooooo`0Ioooo00<0003ooooo
ool06Oooo`0306Kooooooooo05Coool00ol0VOooooooo`0Koooo001doooo00<0I_ooooooool01?oo
o`D00002oooo0P0000Coool200001Oooo`030000oooooooo01Soool00`1Vooooooooo`1Eoooo00?o
09Woooooool06oooo`00MOooo`0306Kooooooooo00Goool00`000?ooooooo`07oooo00@0003ooooo
ool00004oooo00<0003oooooool05oooo`0306Kooooooooo05Koool00ol0VOooooooo`0Koooo001e
oooo00<0I_ooooooool01Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0001Koool0
0`1Vooooooooo`1Goooo00?o09Woooooool06oooo`00M_ooo`0306Kooooooooo00Coool00`000?oo
ooooo`08oooo0P0000Goool00`000?ooooooo`0Eoooo00<0I_ooooooool0F?ooo`03o`2Ioooooooo
01_oool007Ooool00`1Vooooooooo`03oooo00<0003oooooool02?ooo`030000oooooooo00Coool0
0`000?ooooooo`0Doooo00<0I_ooooooool0FOooo`03o`2Ioooooooo01_oool007Soool0101Voooo
ooooooooo`80000:oooo0`0000Coool00`000?ooooooo`0Coooo00<0I_ooooooool0F_ooo`03o`2I
oooooooo01_oool007Woool00`1Vooooooooo`0Coooo00<0003oooooool04_ooo`0306Kooooooooo
05_oool00ol0VOooooooo`0Koooo001joooo00<0I_ooooooool04_ooo`030000oooooooo017oool0
0`1Vooooooooo`1Loooo00?o09Woooooool06oooo`00Noooo`0306Kooooooooo017oool200004Ooo
o`0306Kooooooooo05goool00ol0VOooooooo`0Koooo001loooo00<0I_ooooooool04?ooo`030000
oooooooo00ooool00`1Vooooooooo`1Noooo00?o09Woooooool06oooo`00OOooo`0306Kooooooooo
00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0G_ooo`03o`2Ioooooooo01_oool007koool0
0`1Vooooooooo`0>oooo00<0003oooooool03_ooo`0306Kooooooooo05ooool00ol0VOooooooo`0K
oooo001noooo00<0I_ooooooool03_ooo`030000oooooooo00goool00`1Vooooooooo`1Poooo00?o
09Woooooool06oooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0<oooo00<0I_oooooo
ool0HOooo`03o`2Ioooooooo01_oool0083oool00`1Vooooooooo`0<oooo0P0000coool00`1Voooo
ooooo`1Roooo00?o09Woooooool06oooo`00POooo`0306Kooooooooo00_oool00`000?ooooooo`0:
oooo00<0I_ooooooool0Hoooo`03o`2Ioooooooo01_oool008;oool00`1Vooooooooo`0:oooo00<0
003oooooool02_ooo`0306Kooooooooo06?oool00ol0VOooooooo`0Koooo0023oooo00<0I_oooooo
ool02Oooo`030000oooooooo00Woool00`1Vooooooooo`1Toooo00?o09Woooooool06oooo`00Pooo
o`0306Kooooooooo00Woool00`000?ooooooo`08oooo00<0I_ooooooool0IOooo`03o`2Ioooooooo
01_oool008Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`0306Kooooooooo06Koool0
0ol0VOooooooo`0Koooo0025oooo00<0I_ooooooool01oooo`800008oooo00<0I_ooooooool0I_oo
o`03o`2Ioooooooo01_oool008Koool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`0306Ko
oooooooo06Ooool00ol0VOooooooo`0Koooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo
00Goool00`1Vooooooooo`1Xoooo00?o09Woooooool06oooo`00Qoooo`0306Kooooooooo00Goool0
0`000?ooooooo`04oooo00<0I_ooooooool0JOooo`03o`2Ioooooooo01_oool008Soool00`1Voooo
ooooo`04oooo00<0003oooooool01?ooo`0306Kooooooooo06Woool00ol0VOooooooo`0Koooo0029
oooo00<0I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`1Zoooo00?o09Wooooo
ool06oooo`00ROooo`0306Kooooooooo00?oool200000oooo`0306Kooooooooo06_oool00ol0VOoo
ooooo`0Koooo002:oooo00<0I_ooooooool00_ooo`030000oooooooo00;oool00`1Vooooooooo`1[
oooo00?o09Woooooool06oooo`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`1/
oooo00?o09Woooooool06oooo`00S?ooo`0406Kooooooooo00000_ooo`0306Kooooooooo06goool0
0ol0VOooooooo`0Koooo0027oooo10000005oooo06Kooooooooo000000;oool00`1Vooooooooo`1]
oooo00?o09Woooooool06oooo`00Qoooo`030000oooooooo00?oool01@1Vooooo`000?ooo`1Vo`1`
oooo00?o09Woooooool06oooo`00R?ooo`030000oooooooo00?oool0101Vo`0000000000073oool0
0ol0VOooooooo`0Koooo0029oooo00<0003oooooool00_ooo`0306Ko000006Ko077oool00ol0VOoo
ooooo`0Koooo0027oooo00@0003oooooool00004oooo00<0003oooooool0L?ooo`03o`2Ioooooooo
01_oool008Soool200001Oooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0
003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Wooooo
ool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool0
0ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool0
0`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOoo
ooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool20000LOoo
o`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Sooo
o`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2I
oooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`030000
oooooooo073oool00ol0VOooooooo`0Koooo002?oooo0P00077oool00ol0VOooooooo`0Koooo002?
oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o
09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0
003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Wooooo
ool06oooo`00Soooo`80001aoooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool0
0ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool0
0`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Noooo`@00003oooo0P0000Coool200001Ooo
o`030000oooooooo073oool00ol0VOooooooo`0Koooo001koooo00<0003oooooool02Oooo`040000
oooooooo00001?ooo`030000oooooooo073oool00ol0VOooooooo`0Koooo001loooo00<0003ooooo
ool02oooo`030000oooooooo00;oool30000L?ooo`03o`2Ioooooooo01_oool007goool00`000?oo
ooooo`08oooo0P0009Koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001l
oooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P00
00Coool200001?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003ooooo
ool03oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001k
oooo00<0003oooooool01@0000ooool00`000?ooooooo`07oooo0P0000Coool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000ooo
o`030000oooooooo07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.91726 .04578 L
.92761 .04578 L
.93871 .04578 L
.94392 .04578 L
.94648 .04578 L
.94885 .04578 L
.951 .04578 L
.95208 .04578 L
s
.95208 .04578 m
.95238 .61803 L
s
0 .4 1 r
.02381 .04578 m
.03279 .04578 L
.04262 .04578 L
.04517 .04578 L
.04642 .04578 L
.04758 .04578 L
.04822 .16045 L
.04891 .1607 L
.05035 .16122 L
.05288 .16214 L
.06244 .1657 L
.10458 .18272 L
.14241 .20006 L
.1827 .22093 L
.22147 .24369 L
.2627 .27113 L
.30241 .30115 L
.3406 .3338 L
.38125 .37314 L
.42038 .41609 L
.46196 .46791 L
.48283 .49659 L
.49198 .50978 L
.49449 .51345 L
.49717 .51743 L
.49848 .51937 L
.49971 .52122 L
.50082 .52042 L
.50202 .51863 L
.52077 .49151 L
.54057 .46456 L
.58136 .41407 L
.62062 .37122 L
.65837 .33473 L
.69858 .30036 L
.73726 .27115 L
.7784 .24376 L
.81803 .22053 L
.85614 .20076 L
.8967 .18217 L
.91543 .17436 L
.93574 .16639 L
.941 .16441 L
.94657 .16235 L
.94886 .16151 L
.95012 .16105 L
.95132 .16061 L
.952 .16037 L
.95273 .04578 L
.95402 .04578 L
Mistroke
.95655 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool00`000?ooooooo`03oooo00<0I_ooool000002?ooo`030000oooooooo00Goool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooooooo
00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?oo
ooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05oooo00<0
003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003oooooool01Ooo
o`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000oooo06Ko
00Goool00`000?ooooooo`0Boooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo07?oool0
0`1Vooooooooo`0Hoooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo07?oool00`1Voooo
ooooo`0Hoooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo07?oool00`1Vooooooooo`0H
oooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo07?oool00`1Vooooooooo`0Hoooo000I
oooo00<0I_ooooooool0Loooo`80001doooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo
07?oool00`000?ooooooo`1coooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo07?oool0
0`000?ooooooo`1coooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?oo
ooooo`1coooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`1c
oooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`1coooo00<0
I_ooooooool06?ooo`006Oooo`0306Kooooooooo07?oool20000M?ooo`0306Kooooooooo01Soool0
01Woool00`1Vooooooooo`1coooo00<0003oooooool0Loooo`0306Kooooooooo01Soool001Woool0
0`1Vooooooooo`1coooo00<0003oooooool0Loooo`0306Kooooooooo01Soool001Woool00`1Voooo
ooooo`1coooo00<0003oooooool0Loooo`0306Kooooooooo01Soool001Woool00`1Vooooooooo`1c
oooo00<0003oooooool0Loooo`0306Kooooooooo01Soool001Woool00`1Vooooooooo`1coooo00<0
003oooooool0Loooo`0306Kooooooooo01Soool001Woool00`1Vooooooooo`1coooo0P0007Coool0
0`1Vooooooooo`0Hoooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo07?oool00`1Voooo
ooooo`0Hoooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo07?oool00`1Vooooooooo`0H
oooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo07?oool00`1Vooooooooo`0Hoooo000I
oooo00<0I_ooooooool0Loooo`030000oooooooo07?oool00`1Vooooooooo`0Hoooo000Ioooo00<0
I_ooooooool0Loooo`030000oooooooo07?oool00`1Vooooooooo`0Hoooo000Ioooo00<0I_oooooo
ool0Loooo`80001doooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?oo
ooooo`1coooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`1c
oooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`1coooo00<0
I_ooooooool06?ooo`006Oooo`0306Kooooooooo063oool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`1coooo00<0I_ooooooool06?ooo`006Oooo`0306Kooooooooo05ooool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1coooo00<0I_ooooooool06?oo
o`006Oooo`<0I_mOoooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0001aoooo0`1V
oa[oool001coool306KoG?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0KOoo
o`@0I_l2oooo00?o09Woooooool06?ooo`007oooo`<0I_mIoooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo06_oool206Ko1_ooo`03o`2Ioooooooo01Soool002;oool2
06KoF?ooo`80000:oooo0`0000Coool00`000?ooooooo`1Xoooo0`1Vo`Soool00ol0VOooooooo`0H
oooo000Toooo0`1VofSoool00`000?ooooooo`1Voooo0P1Vo`_oool00ol0VOooooooo`0Hoooo000W
oooo0P1VofKoool00`000?ooooooo`1Toooo0P1Vo`goool00ol0VOooooooo`0Hoooo000Yoooo0P1V
ofCoool20000Hoooo`80I_l?oooo00?o09Woooooool06?ooo`00:oooo`80I_mRoooo00<0003ooooo
ool0H?ooo`80I_lAoooo00?o09Woooooool06?ooo`00;Oooo`80I_mPoooo00<0003oooooool0G_oo
o`80I_lCoooo00?o09Woooooool06?ooo`00;oooo`80I_mNoooo00<0003oooooool0G?ooo`80I_lE
oooo00?o09Woooooool06?ooo`00<Oooo`80I_mLoooo00<0003oooooool0F_ooo`80I_lGoooo00?o
09Woooooool06?ooo`00<oooo`80I_mJoooo0P0005Woool206Ko6Oooo`03o`2Ioooooooo01Soool0
03Goool206KoF?ooo`030000oooooooo05Koool206Ko6oooo`03o`2Ioooooooo01Soool003Ooool2
06KoE_ooo`030000oooooooo05Coool206Ko7Oooo`03o`2Ioooooooo01Soool003Woool206KoE?oo
o`030000oooooooo05;oool206Ko7oooo`03o`2Ioooooooo01Soool003_oool206KoD_ooo`030000
oooooooo053oool206Ko8Oooo`03o`2Ioooooooo01Soool003goool206KoD?ooo`030000oooooooo
04koool206Ko8oooo`03o`2Ioooooooo01Soool003ooool206KoC_ooo`80001=oooo0P1VobGoool0
0ol0VOooooooo`0Hoooo0011oooo0P1Vodcoool00`000?ooooooo`1:oooo0P1VobOoool00ol0VOoo
ooooo`0Hoooo0013oooo0P1Vod[oool00`000?ooooooo`18oooo0P1VobWoool00ol0VOooooooo`0H
oooo0015oooo0P1VodSoool00`000?ooooooo`16oooo0P1Vob_oool00ol0VOooooooo`0Hoooo0017
oooo00<0I_ooooooool0AOooo`030000oooooooo04Goool00`1Vooooooooo`0[oooo00?o09Wooooo
ool06?ooo`00B?ooo`80I_m5oooo00<0003oooooool0@oooo`80I_l^oooo00?o09Woooooool06?oo
o`00B_ooo`0306Kooooooooo04;oool20000@oooo`0306Kooooooooo02koool00ol0VOooooooo`0H
oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo047oool00`1Vooooooooo`0_oooo00?o
09Woooooool06?ooo`00C?ooo`80I_m1oooo00<0003oooooool0?oooo`80I_lboooo00?o09Wooooo
ool06?ooo`00C_ooo`0306Kooooooooo03koool00`000?ooooooo`0noooo00<0I_ooooooool0<_oo
o`03o`2Ioooooooo01Soool004ooool206Ko=_ooo`D00003oooo00<0003oooooool0??ooo`80I_le
oooo00?o09Woooooool06?ooo`00DOooo`0306Kooooooooo03Goool00`000?ooooooo`03oooo00<0
003oooooool0>oooo`0306Kooooooooo03Goool00ol0VOooooooo`0Hoooo001Boooo0P1VocGoool0
0`000?ooooooo`03oooo0`0003[oool00`1Vooooooooo`0foooo00?o09Woooooool06?ooo`00E?oo
o`0306Kooooooooo03;oool00`000?ooooooo`03oooo00<0003oooooool0>?ooo`80I_lioooo00?o
09Woooooool06?ooo`00EOooo`0306Kooooooooo037oool00`000?ooooooo`03oooo00<0003ooooo
ool0=oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Hoooo001Foooo0P1Voc3oool200001Ooo
o`030000oooooooo03Koool00`1Vooooooooo`0joooo00?o09Woooooool06?ooo`00F?ooo`0306Ko
oooooooo03Coool00`000?ooooooo`0eoooo00<0I_ooooooool0>oooo`03o`2Ioooooooo01Soool0
05Woool00`1Vooooooooo`0coooo00<0003oooooool0<oooo`80I_lnoooo00?o09Woooooool06?oo
o`00F_ooo`80I_lcoooo0P0003?oool00`1Vooooooooo`0noooo00?o09Woooooool06?ooo`00G?oo
o`0306Kooooooooo033oool00`000?ooooooo`0aoooo00<0I_ooooooool0?oooo`03o`2Ioooooooo
01Soool005goool00`1Vooooooooo`0_oooo00<0003oooooool0<?ooo`0306Kooooooooo043oool0
0ol0VOooooooo`0Hoooo001Noooo00<0I_ooooooool0;_ooo`030000oooooooo02koool206Ko@ooo
o`03o`2Ioooooooo01Soool005ooool00`1Vooooooooo`0]oooo00<0003oooooool0;Oooo`0306Ko
oooooooo04?oool00ol0VOooooooo`0Hoooo001Poooo00<0I_ooooooool0;?ooo`030000oooooooo
02coool00`1Vooooooooo`14oooo00?o09Woooooool06?ooo`00HOooo`80I_l/oooo0P0002coool0
0`1Vooooooooo`15oooo00?o09Woooooool06?ooo`00Hoooo`0306Kooooooooo02Woool00`000?oo
ooooo`0Zoooo00<0I_ooooooool0A_ooo`03o`2Ioooooooo01Soool006Coool00`1Vooooooooo`0X
oooo00<0003oooooool0:?ooo`80I_m9oooo00?o09Woooooool06?ooo`00IOooo`0306Kooooooooo
02Ooool00`000?ooooooo`0Woooo00<0I_ooooooool0BOooo`03o`2Ioooooooo01Soool006Koool0
0`1Vooooooooo`0Voooo00<0003oooooool09_ooo`0306Kooooooooo04[oool00ol0VOooooooo`0H
oooo001Woooo00<0I_ooooooool09Oooo`030000oooooooo02Goool00`1Vooooooooo`1;oooo00?o
09Woooooool06?ooo`00J?ooo`0306Kooooooooo02Coool200009Oooo`0306Kooooooooo04coool0
0ol0VOooooooo`0Hoooo001Yoooo00<0I_ooooooool08oooo`030000oooooooo02?oool00`1Voooo
ooooo`1=oooo00?o09Woooooool06?ooo`00J_ooo`0306Kooooooooo02;oool00`000?ooooooo`0R
oooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo01Soool006_oool00`1Vooooooooo`0Qoooo00<0
003oooooool08?ooo`80I_mAoooo00?o09Woooooool06?ooo`00K?ooo`0306Kooooooooo023oool0
0`000?ooooooo`0Ooooo00<0I_ooooooool0DOooo`03o`2Ioooooooo01Soool006goool00`1Voooo
ooooo`0Ooooo00<0003oooooool07_ooo`0306Kooooooooo05;oool00ol0VOooooooo`0Hoooo001^
oooo00<0I_ooooooool07_ooo`80000Noooo00<0I_ooooooool0Doooo`03o`2Ioooooooo01Soool0
06ooool00`1Vooooooooo`0Moooo00<0003oooooool07?ooo`0306Kooooooooo05Coool00ol0VOoo
ooooo`0Hoooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01_oool00`1Vooooooooo`1E
oooo00?o09Woooooool06?ooo`00LOooo`0306Kooooooooo01_oool00`000?ooooooo`0Joooo00<0
I_ooooooool0E_ooo`03o`2Ioooooooo01Soool007;oool00`1Vooooooooo`06oooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool06Oooo`0306Kooooooooo05Ooool00ol0VOooooooo`0H
oooo001coooo00<0I_ooooooool01oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`0Ioooo00<0I_ooooooool0Eoooo`03o`2Ioooooooo01Soool007Coool00`1Voooo
ooooo`06oooo00<0003oooooool02_ooo`030000oooooooo00;oool300006?ooo`0306Kooooooooo
05Soool00ol0VOooooooo`0Hoooo001eoooo00<0I_ooooooool01Oooo`030000oooooooo00Soool2
00001Oooo`030000oooooooo01Ooool00`1Vooooooooo`1Ioooo00?o09Woooooool06?ooo`00MOoo
o`0306Kooooooooo00Goool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo
01Koool00`1Vooooooooo`1Joooo00?o09Woooooool06?ooo`00M_ooo`0306Kooooooooo00?oool2
00002_ooo`<00004oooo00<0003oooooool05Oooo`0306Kooooooooo05_oool00ol0VOooooooo`0H
oooo001goooo00<0I_ooooooool05Oooo`030000oooooooo01Coool00`1Vooooooooo`1Loooo00?o
09Woooooool06?ooo`00N?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Doooo00<0I_oooooo
ool0G?ooo`03o`2Ioooooooo01Soool007Woool00`1Vooooooooo`0Coooo0P0001Coool00`1Voooo
ooooo`1Moooo00?o09Woooooool06?ooo`00N_ooo`0306Kooooooooo01;oool00`000?ooooooo`0B
oooo00<0I_ooooooool0G_ooo`03o`2Ioooooooo01Soool007_oool00`1Vooooooooo`0Aoooo00<0
003oooooool04Oooo`0306Kooooooooo05ooool00ol0VOooooooo`0Hoooo001loooo00<0I_oooooo
ool04?ooo`030000oooooooo013oool00`1Vooooooooo`1Poooo00?o09Woooooool06?ooo`00O?oo
o`0306Kooooooooo013oool00`000?ooooooo`0@oooo00<0I_ooooooool0H?ooo`03o`2Ioooooooo
01Soool007goool00`1Vooooooooo`0?oooo00<0003oooooool03oooo`0306Kooooooooo067oool0
0ol0VOooooooo`0Hoooo001noooo00<0I_ooooooool03_ooo`80000?oooo00<0I_ooooooool0H_oo
o`03o`2Ioooooooo01Soool007ooool00`1Vooooooooo`0=oooo00<0003oooooool03Oooo`0306Ko
oooooooo06?oool00ol0VOooooooo`0Hoooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo
00goool00`1Vooooooooo`1Soooo00?o09Woooooool06?ooo`00P?ooo`0306Kooooooooo00coool0
0`000?ooooooo`0<oooo00<0I_ooooooool0I?ooo`03o`2Ioooooooo01Soool0087oool00`1Voooo
ooooo`0;oooo00<0003oooooool02oooo`0306Kooooooooo06Goool00ol0VOooooooo`0Hoooo0022
oooo00<0I_ooooooool02_ooo`030000oooooooo00[oool00`1Vooooooooo`1Voooo00?o09Wooooo
ool06?ooo`00Poooo`0306Kooooooooo00Woool200002oooo`0306Kooooooooo06Koool00ol0VOoo
ooooo`0Hoooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Woool00`1Vooooooooo`1W
oooo00?o09Woooooool06?ooo`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`08oooo00<0
I_ooooooool0J?ooo`03o`2Ioooooooo01Soool008Goool00`1Vooooooooo`07oooo00<0003ooooo
ool01oooo`0306Kooooooooo06Woool00ol0VOooooooo`0Hoooo0026oooo00<0I_ooooooool01_oo
o`030000oooooooo00Koool00`1Vooooooooo`1Zoooo00?o09Woooooool06?ooo`00Qoooo`0306Ko
oooooooo00Goool00`000?ooooooo`05oooo00<0I_ooooooool0Joooo`03o`2Ioooooooo01Soool0
08Soool00`1Vooooooooo`04oooo0P0000Koool00`1Vooooooooo`1[oooo00?o09Woooooool06?oo
o`00R?ooo`0306Kooooooooo00Coool00`000?ooooooo`04oooo00<0I_ooooooool0K?ooo`03o`2I
oooooooo01Soool008Woool00`1Vooooooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo
06goool00ol0VOooooooo`0Hoooo002:oooo00<0I_ooooooool00_ooo`030000oooooooo00;oool0
0`1Vooooooooo`1^oooo00?o09Woooooool06?ooo`00Qoooo`@000001@1Vooooooooooooo`000003
oooo00<0I_ooooooool0Koooo`03o`2Ioooooooo01Soool008Ooool01@000?ooooooooooo`1Vo`03
oooo00D0003oooooooooool0I_l0LOooo`03o`2Ioooooooo01Soool008Soool01@000?oooooooooo
o`1Vo`02oooo0`00000306Kooooooooo073oool00ol0VOooooooo`0Hoooo0029oooo00@0003ooooo
ool0I_l2oooo00<0003oool0I_l0Loooo`03o`2Ioooooooo01Soool008Ooool010000?ooooooo`00
00;oool206Ko00<00000I_ooool0Loooo`03o`2Ioooooooo01Soool008Soool200001?ooo`0306Ko
000006Ko07Coool00ol0VOooooooo`0Hoooo002>oooo00<0I_l0003oool0M?ooo`03o`2Ioooooooo
01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001doooo00?o
09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0
003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Wooooo
ool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003ooooo
ool0Loooo`03o`2Ioooooooo01Soool008ooool20000M?ooo`03o`2Ioooooooo01Soool008ooool0
0`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOoo
ooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?oo
ooooo`1coooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0H
oooo002?oooo0P0007Coool00ol0VOooooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2I
oooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`030000
oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2Ioooooooo
01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00Soooo`80001doooo00?o
09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0
003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Wooooo
ool06?ooo`00Noooo`@00003oooo0P0000Coool200001Oooo`030000oooooooo07?oool00ol0VOoo
ooooo`0Hoooo001koooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000oooooooo
07?oool00ol0VOooooooo`0Hoooo001loooo00<0003oooooool02oooo`030000oooooooo00;oool3
0000Loooo`03o`2Ioooooooo01Soool007goool00`000?ooooooo`08oooo0P0009Koool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001Oooo`030000oooooooo00;oool0
0`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000ooool00`000?ooooooo`07oooo0P00
00Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo
07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0003ooooo
ool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
.2 1 0 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
.97619 .04578 L
.02381 .04578 L
F
0 g
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.93871 .04578 L
.97619 .04578 L
s
1 0 .6 r
.02381 .04578 m
.06244 .04578 L
.10458 .04578 L
.14415 .04578 L
.18221 .04578 L
.22272 .04578 L
.26171 .04578 L
.30316 .04578 L
.34309 .04578 L
.3815 .04578 L
.42237 .04578 L
.46172 .04578 L
.49955 .04578 L
.53984 .04578 L
.57861 .04578 L
.61984 .04578 L
.65954 .04578 L
.69774 .04578 L
.73838 .04578 L
.77751 .04578 L
.81909 .04578 L
.85916 .04578 L
.89771 .04578 L
.91726 .04578 L
.93871 .04578 L
.94807 .04578 L
.95322 .04578 L
.95575 .04578 L
.9581 .04578 L
.95923 .04578 L
.96029 .04578 L
s
.96029 .04578 m
.96057 .61803 L
s
0 .4 1 r
.02381 .04578 m
.02846 .04578 L
.03279 .04578 L
.03523 .04578 L
.03754 .04578 L
.03881 .04578 L
.03953 .04578 L
.0402 .16042 L
.04137 .16084 L
.04262 .16129 L
.06244 .16874 L
.10458 .18619 L
.14241 .20396 L
.1827 .22537 L
.22147 .2487 L
.2627 .27683 L
.30241 .30762 L
.3406 .34109 L
.38125 .38143 L
.42038 .42546 L
.46196 .4786 L
.48283 .508 L
.49198 .52152 L
.49449 .52529 L
.49717 .52937 L
.49848 .53136 L
.49971 .53325 L
.50082 .53244 L
.50202 .5306 L
.52077 .5028 L
.54057 .47516 L
.58136 .42339 L
.62062 .37946 L
.65837 .34205 L
.69858 .30681 L
.73726 .27686 L
.7784 .24877 L
.81803 .22495 L
.85614 .20469 L
.8967 .18563 L
.93574 .16944 L
.94573 .16561 L
.95098 .16365 L
.95386 .16258 L
.95655 .1616 L
.95889 .16075 L
.96021 .16027 L
.96142 .04578 L
.96273 .04578 L
.96416 .04578 L
Mistroke
.96677 .04578 L
.97619 .04578 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0457803 0.228901 [
[.02381 .03328 -6 -9 ]
[.02381 .03328 6 0 ]
[.18254 .03328 -6 -9 ]
[.18254 .03328 6 0 ]
[.34127 .03328 -6 -9 ]
[.34127 .03328 6 0 ]
[.65873 .03328 -3 -9 ]
[.65873 .03328 3 0 ]
[.81746 .03328 -3 -9 ]
[.81746 .03328 3 0 ]
[.97619 .03328 -3 -9 ]
[.97619 .03328 3 0 ]
[.4875 .16023 -18 -4.5 ]
[.4875 .16023 0 4.5 ]
[.4875 .27468 -6 -4.5 ]
[.4875 .27468 0 4.5 ]
[.4875 .38913 -18 -4.5 ]
[.4875 .38913 0 4.5 ]
[.4875 .50358 -6 -4.5 ]
[.4875 .50358 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .04578 m
.02381 .05203 L
s
[(-3)] .02381 .03328 0 1 Mshowa
.18254 .04578 m
.18254 .05203 L
s
[(-2)] .18254 .03328 0 1 Mshowa
.34127 .04578 m
.34127 .05203 L
s
[(-1)] .34127 .03328 0 1 Mshowa
.65873 .04578 m
.65873 .05203 L
s
[(1)] .65873 .03328 0 1 Mshowa
.81746 .04578 m
.81746 .05203 L
s
[(2)] .81746 .03328 0 1 Mshowa
.97619 .04578 m
.97619 .05203 L
s
[(3)] .97619 .03328 0 1 Mshowa
.125 Mabswid
.05556 .04578 m
.05556 .04953 L
s
.0873 .04578 m
.0873 .04953 L
s
.11905 .04578 m
.11905 .04953 L
s
.15079 .04578 m
.15079 .04953 L
s
.21429 .04578 m
.21429 .04953 L
s
.24603 .04578 m
.24603 .04953 L
s
.27778 .04578 m
.27778 .04953 L
s
.30952 .04578 m
.30952 .04953 L
s
.37302 .04578 m
.37302 .04953 L
s
.40476 .04578 m
.40476 .04953 L
s
.43651 .04578 m
.43651 .04953 L
s
.46825 .04578 m
.46825 .04953 L
s
.53175 .04578 m
.53175 .04953 L
s
.56349 .04578 m
.56349 .04953 L
s
.59524 .04578 m
.59524 .04953 L
s
.62698 .04578 m
.62698 .04953 L
s
.69048 .04578 m
.69048 .04953 L
s
.72222 .04578 m
.72222 .04953 L
s
.75397 .04578 m
.75397 .04953 L
s
.78571 .04578 m
.78571 .04953 L
s
.84921 .04578 m
.84921 .04953 L
s
.88095 .04578 m
.88095 .04953 L
s
.9127 .04578 m
.9127 .04953 L
s
.94444 .04578 m
.94444 .04953 L
s
.25 Mabswid
0 .04578 m
1 .04578 L
s
.5 .16023 m
.50625 .16023 L
s
[(0.5)] .4875 .16023 1 0 Mshowa
.5 .27468 m
.50625 .27468 L
s
[(1)] .4875 .27468 1 0 Mshowa
.5 .38913 m
.50625 .38913 L
s
[(1.5)] .4875 .38913 1 0 Mshowa
.5 .50358 m
.50625 .50358 L
s
[(2)] .4875 .50358 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(2.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .06867 m
.50375 .06867 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11445 m
.50375 .11445 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .18312 m
.50375 .18312 L
s
.5 .20601 m
.50375 .20601 L
s
.5 .2289 m
.50375 .2289 L
s
.5 .25179 m
.50375 .25179 L
s
.5 .29757 m
.50375 .29757 L
s
.5 .32046 m
.50375 .32046 L
s
.5 .34335 m
.50375 .34335 L
s
.5 .36624 m
.50375 .36624 L
s
.5 .41202 m
.50375 .41202 L
s
.5 .43491 m
.50375 .43491 L
s
.5 .4578 m
.50375 .4578 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .52647 m
.50375 .52647 L
s
.5 .54936 m
.50375 .54936 L
s
.5 .57225 m
.50375 .57225 L
s
.5 .59514 m
.50375 .59514 L
s
.5 .02289 m
.50375 .02289 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oSoooo`030000
oooooooo08koool001Goool200009_ooo`@0000Voooo1@0002?oool00`000?ooooooo`0Toooo1@00
02Goool400009_ooo`80000Doooo000Doooo00@0003oooooool0000Uoooo00<0003oooooool0:Ooo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09Oooo`030000oooooooo
02Koool010000?ooooooo`0001?oool001Koool00`000?ooooooo`0Uoooo00<0003oooooool0:?oo
o`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0003oooooool09_ooo`030000oooooooo
02Ooool00`000?ooooooo`0Boooo000>oooo100000Goool00`000?ooooooo`0Moooo100000Coool0
0`000?ooooooo`0Ooooo100000Coool00`000?ooooooo`0Soooo00<0003oooooool09_ooo`030000
oooooooo02Ooool00`000?ooooooo`0Woooo00<0003oooooool04Oooo`005?ooo`040000oooooooo
00009Oooo`040000oooooooo0000:?ooo`030000oooooooo02?oool00`000?ooooooo`0Voooo00<0
003oooooool09Oooo`040000oooooooo00009Oooo`040000oooooooo00004oooo`005Oooo`80000W
oooo0P0002Soool200009Oooo`80000Voooo0P0002Soool200009oooo`80000Doooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool000gooooo00001P0000koool0
01?oool01@000?ooooooooooo`1Vo`03oooo00<0003oooooool01_ooo`030000oooooooo00Goool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`030000
oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool0
0`000?ooooooo`05oooo00<0003oooooool01Oooo`030000oooooooo00Koool00`000?ooooooo`05
oooo00<0003oooooool01Oooo`030000oooooooo00Goool00`000?ooooooo`06oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool00`000?ooooooo`05oooo00<0003oooooool01_ooo`050000
oooooooooooo06Ko00?oool00`000?ooooooo`0Boooo000Goooo00<0I_ooooooool0MOooo`030000
oooooooo07Goool00`1Vooooooooo`0Foooo000Goooo00<0I_ooooooool0MOooo`030000oooooooo
07Goool00`1Vooooooooo`0Foooo000Goooo00<0I_ooooooool0MOooo`030000oooooooo07Goool0
0`1Vooooooooo`0Foooo000Goooo00<0I_ooooooool0MOooo`030000oooooooo07Goool00`1Voooo
ooooo`0Foooo000Goooo00<0I_ooooooool0MOooo`80001foooo00<0I_ooooooool05_ooo`005ooo
o`0306Kooooooooo07Goool00`000?ooooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Ko
oooooooo07Goool00`000?ooooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo
07Goool00`000?ooooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo07Goool0
0`000?ooooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo07Goool00`000?oo
ooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo07Goool20000M_ooo`0306Ko
oooooooo01Koool001Ooool00`1Vooooooooo`1eoooo00<0003oooooool0MOooo`0306Kooooooooo
01Koool001Ooool00`1Vooooooooo`1eoooo00<0003oooooool0MOooo`0306Kooooooooo01Koool0
01Ooool00`1Vooooooooo`1eoooo00<0003oooooool0MOooo`0306Kooooooooo01Koool001Ooool0
0`1Vooooooooo`1eoooo00<0003oooooool0MOooo`0306Kooooooooo01Koool001Ooool00`1Voooo
ooooo`1eoooo00<0003oooooool0MOooo`0306Kooooooooo01Koool001Ooool00`1Vooooooooo`1e
oooo0P0007Koool00`1Vooooooooo`0Foooo000Goooo00<0I_ooooooool0MOooo`030000oooooooo
07Goool00`1Vooooooooo`0Foooo000Goooo00<0I_ooooooool0MOooo`030000oooooooo07Goool0
0`1Vooooooooo`0Foooo000Goooo00<0I_ooooooool0MOooo`030000oooooooo07Goool00`1Voooo
ooooo`0Foooo000Goooo00<0I_ooooooool0MOooo`030000oooooooo07Goool00`1Vooooooooo`0F
oooo000Goooo00<0I_ooooooool0MOooo`030000oooooooo07Goool00`1Vooooooooo`0Foooo000G
oooo00<0I_ooooooool0MOooo`80001foooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo
07Goool00`000?ooooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo07Goool0
0`000?ooooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo07Goool00`000?oo
ooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo06;oool200001?ooo`800004
oooo0P0000Goool00`000?ooooooo`1eoooo00<0I_ooooooool05_ooo`005oooo`0306Kooooooooo
067oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`1eoooo00<0
I_ooooooool05_ooo`005oooo`<0I_mQoooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0001boooo101VoaSoool001[oool206KoGoooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool0L?ooo`80I_l3oooo00?o09Woooooool05_ooo`007?ooo`<0I_mLoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo06goool306Ko1Oooo`03o`2Ioooooooo
01Koool001ooool306KoF_ooo`80000:oooo0`0000Coool00`000?ooooooo`1[oooo0P1Vo`Soool0
0ol0VOooooooo`0Foooo000Roooo0P1Vof_oool00`000?ooooooo`1Xoooo0`1Vo`[oool00ol0VOoo
ooooo`0Foooo000Toooo0`1VofSoool00`000?ooooooo`1Voooo0P1Vo`goool00ol0VOooooooo`0F
oooo000Woooo0P1VofKoool20000IOooo`80I_l?oooo00?o09Woooooool05_ooo`00:Oooo`80I_mT
oooo00<0003oooooool0H_ooo`80I_lAoooo00?o09Woooooool05_ooo`00:oooo`80I_mRoooo00<0
003oooooool0H?ooo`80I_lCoooo00?o09Woooooool05_ooo`00;Oooo`80I_mPoooo00<0003ooooo
ool0G_ooo`80I_lEoooo00?o09Woooooool05_ooo`00;oooo`80I_mNoooo00<0003oooooool0G?oo
o`80I_lGoooo00?o09Woooooool05_ooo`00<Oooo`80I_mLoooo0P0005_oool206Ko6Oooo`03o`2I
oooooooo01Koool003?oool206KoF_ooo`030000oooooooo05Soool206Ko6oooo`03o`2Ioooooooo
01Koool003Goool206KoF?ooo`030000oooooooo05Koool206Ko7Oooo`03o`2Ioooooooo01Koool0
03Ooool00`1Vooooooooo`1Eoooo00<0003oooooool0E?ooo`80I_lOoooo00?o09Woooooool05_oo
o`00>?ooo`80I_mEoooo00<0003oooooool0D_ooo`80I_lQoooo00?o09Woooooool05_ooo`00>_oo
o`80I_mCoooo00<0003oooooool0D?ooo`80I_lSoooo00?o09Woooooool05_ooo`00??ooo`0306Ko
oooooooo053oool20000Coooo`80I_lUoooo00?o09Woooooool05_ooo`00?Oooo`80I_m@oooo00<0
003oooooool0COooo`0306Kooooooooo02Goool00ol0VOooooooo`0Foooo000ooooo0P1Vodkoool0
0`000?ooooooo`1;oooo0P1VobSoool00ol0VOooooooo`0Foooo0011oooo0P1Vodcoool00`000?oo
ooooo`19oooo0P1Vob[oool00ol0VOooooooo`0Foooo0013oooo0P1Vod[oool00`000?ooooooo`18
oooo00<0I_ooooooool0:_ooo`03o`2Ioooooooo01Koool004Goool206KoB?ooo`030000oooooooo
04Koool206Ko;Oooo`03o`2Ioooooooo01Koool004Ooool00`1Vooooooooo`15oooo0P0004Koool0
0`1Vooooooooo`0]oooo00?o09Woooooool05_ooo`00B?ooo`80I_m5oooo00<0003oooooool0@ooo
o`80I_l`oooo00?o09Woooooool05_ooo`00B_ooo`0306Kooooooooo04;oool00`000?ooooooo`12
oooo00<0I_ooooooool0<?ooo`03o`2Ioooooooo01Koool004_oool00`1Vooooooooo`11oooo00<0
003oooooool0@Oooo`0306Kooooooooo037oool00ol0VOooooooo`0Foooo001<oooo0P1VocWoool5
00000oooo`030000oooooooo03ooool206Ko=?ooo`03o`2Ioooooooo01Koool004koool00`1Voooo
ooooo`0hoooo00<0003oooooool00oooo`030000oooooooo03koool00`1Vooooooooo`0doooo00?o
09Woooooool05_ooo`00Coooo`80I_lhoooo00<0003oooooool00oooo`<0000loooo0P1VocOoool0
0ol0VOooooooo`0Foooo001Aoooo00<0I_ooooooool0=Oooo`030000oooooooo00?oool00`000?oo
ooooo`0koooo00<0I_ooooooool0=oooo`03o`2Ioooooooo01Koool005;oool206Ko=Oooo`030000
oooooooo00?oool00`000?ooooooo`0joooo00<0I_ooooooool0>?ooo`03o`2Ioooooooo01Koool0
05Coool00`1Vooooooooo`0aoooo0P0000Goool00`000?ooooooo`0hoooo0P1Voc_oool00ol0VOoo
ooooo`0Foooo001Eoooo00<0I_ooooooool0=oooo`030000oooooooo03Ooool00`1Vooooooooo`0k
oooo00?o09Woooooool05_ooo`00E_ooo`80I_lgoooo00<0003oooooool0=_ooo`0306Kooooooooo
03coool00ol0VOooooooo`0Foooo001Hoooo00<0I_ooooooool0=?ooo`80000foooo00<0I_oooooo
ool0?Oooo`03o`2Ioooooooo01Koool005Woool00`1Vooooooooo`0coooo00<0003oooooool0<ooo
o`80I_m0oooo00?o09Woooooool05_ooo`00F_ooo`80I_lcoooo00<0003oooooool0<_ooo`0306Ko
oooooooo043oool00ol0VOooooooo`0Foooo001Loooo00<0I_ooooooool0<?ooo`030000oooooooo
037oool00`1Vooooooooo`11oooo00?o09Woooooool05_ooo`00GOooo`0306Kooooooooo02ooool0
0`000?ooooooo`0`oooo00<0I_ooooooool0@_ooo`03o`2Ioooooooo01Koool005koool00`1Voooo
ooooo`0^oooo00<0003oooooool0;_ooo`80I_m5oooo00?o09Woooooool05_ooo`00Goooo`0306Ko
oooooooo02goool20000;_ooo`0306Kooooooooo04Goool00ol0VOooooooo`0Foooo001Poooo00<0
I_ooooooool0;?ooo`030000oooooooo02coool00`1Vooooooooo`16oooo00?o09Woooooool05_oo
o`00HOooo`80I_l/oooo00<0003oooooool0:oooo`0306Kooooooooo04Ooool00ol0VOooooooo`0F
oooo001Soooo00<0I_ooooooool0:Oooo`030000oooooooo02[oool00`1Vooooooooo`18oooo00?o
09Woooooool05_ooo`00I?ooo`0306Kooooooooo02Soool00`000?ooooooo`0Xoooo0P1Vod_oool0
0ol0VOooooooo`0Foooo001Uoooo00<0I_ooooooool09oooo`030000oooooooo02Ooool00`1Voooo
ooooo`1;oooo00?o09Woooooool05_ooo`00I_ooo`0306Kooooooooo02Koool200009oooo`0306Ko
oooooooo04coool00ol0VOooooooo`0Foooo001Woooo00<0I_ooooooool09Oooo`030000oooooooo
02Goool00`1Vooooooooo`1=oooo00?o09Woooooool05_ooo`00J?ooo`0306Kooooooooo02Coool0
0`000?ooooooo`0Toooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo01Koool006Woool00`1Voooo
ooooo`0Soooo00<0003oooooool08oooo`0306Kooooooooo04ooool00ol0VOooooooo`0Foooo001Z
oooo00<0I_ooooooool08_ooo`030000oooooooo02;oool00`1Vooooooooo`1@oooo00?o09Wooooo
ool05_ooo`00Joooo`0306Kooooooooo027oool00`000?ooooooo`0Qoooo00<0I_ooooooool0DOoo
o`03o`2Ioooooooo01Koool006coool00`1Vooooooooo`0Poooo0P00027oool00`1Vooooooooo`1B
oooo00?o09Woooooool05_ooo`00KOooo`0306Kooooooooo01ooool00`000?ooooooo`0Ooooo00<0
I_ooooooool0Doooo`03o`2Ioooooooo01Koool006koool00`1Vooooooooo`0Noooo00<0003ooooo
ool07_ooo`0306Kooooooooo05Coool00ol0VOooooooo`0Foooo001_oooo00<0I_ooooooool07Ooo
o`030000oooooooo01goool00`1Vooooooooo`1Eoooo00?o09Woooooool05_ooo`00L?ooo`0306Ko
oooooooo00Soool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0Loooo00<0I_oooooo
ool0E_ooo`03o`2Ioooooooo01Koool0077oool00`1Vooooooooo`09oooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo01_oool00`1Vooooooooo`1Goooo00?o09Wooooo
ool05_ooo`00L_ooo`0306Kooooooooo00Soool00`000?ooooooo`0:oooo00<0003oooooool00_oo
o`<0000Joooo00<0I_ooooooool0F?ooo`03o`2Ioooooooo01Koool007;oool00`1Vooooooooo`08
oooo00<0003oooooool02?ooo`800005oooo00<0003oooooool06Oooo`0306Kooooooooo05Woool0
0ol0VOooooooo`0Foooo001coooo00<0I_ooooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`04oooo00<0003oooooool06?ooo`0306Kooooooooo05[oool00ol0VOooooooo`0Foooo001d
oooo00<0I_ooooooool01Oooo`80000:oooo0`0000Coool00`000?ooooooo`0Goooo00<0I_oooooo
ool0Foooo`03o`2Ioooooooo01Koool007Goool00`1Vooooooooo`0Goooo00<0003oooooool05ooo
o`0306Kooooooooo05_oool00ol0VOooooooo`0Foooo001foooo00<0I_ooooooool05_ooo`030000
oooooooo01Koool00`1Vooooooooo`1Loooo00?o09Woooooool05_ooo`00Moooo`0306Kooooooooo
01Goool200005_ooo`0306Kooooooooo05goool00ol0VOooooooo`0Foooo001goooo00<0I_oooooo
ool05Oooo`030000oooooooo01Coool00`1Vooooooooo`1Noooo00?o09Woooooool05_ooo`00N?oo
o`0306Kooooooooo01Coool00`000?ooooooo`0Coooo00<0I_ooooooool0Goooo`03o`2Ioooooooo
01Koool007Woool00`1Vooooooooo`0Coooo00<0003oooooool04_ooo`0306Kooooooooo063oool0
0ol0VOooooooo`0Foooo001joooo00<0I_ooooooool04_ooo`030000oooooooo017oool00`1Voooo
ooooo`1Qoooo00?o09Woooooool05_ooo`00Noooo`0306Kooooooooo017oool00`000?ooooooo`0A
oooo00<0I_ooooooool0HOooo`03o`2Ioooooooo01Koool007coool00`1Vooooooooo`0@oooo0P00
017oool00`1Vooooooooo`1Roooo00?o09Woooooool05_ooo`00OOooo`0306Kooooooooo00ooool0
0`000?ooooooo`0?oooo00<0I_ooooooool0Hoooo`03o`2Ioooooooo01Koool007goool00`1Voooo
ooooo`0?oooo00<0003oooooool03_ooo`0306Kooooooooo06Coool00ol0VOooooooo`0Foooo001n
oooo00<0I_ooooooool03_ooo`030000oooooooo00koool00`1Vooooooooo`1Toooo00?o09Wooooo
ool05_ooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0=oooo00<0I_ooooooool0IOoo
o`03o`2Ioooooooo01Koool0083oool00`1Vooooooooo`0<oooo00<0003oooooool03?ooo`0306Ko
oooooooo06Koool00ol0VOooooooo`0Foooo0021oooo00<0I_ooooooool02oooo`80000=oooo00<0
I_ooooooool0I_ooo`03o`2Ioooooooo01Koool008;oool00`1Vooooooooo`0:oooo00<0003ooooo
ool02oooo`0306Kooooooooo06Ooool00ol0VOooooooo`0Foooo0022oooo00<0I_ooooooool02_oo
o`030000oooooooo00[oool00`1Vooooooooo`1Xoooo00?o09Woooooool05_ooo`00Poooo`0306Ko
oooooooo00Woool00`000?ooooooo`09oooo00<0I_ooooooool0JOooo`03o`2Ioooooooo01Koool0
08Coool00`1Vooooooooo`08oooo00<0003oooooool02Oooo`0306Kooooooooo06Woool00ol0VOoo
ooooo`0Foooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Soool00`1Vooooooooo`1Z
oooo00?o09Woooooool05_ooo`00Q_ooo`0306Kooooooooo00Koool200002?ooo`0306Kooooooooo
06_oool00ol0VOooooooo`0Foooo0026oooo00<0I_ooooooool01_ooo`030000oooooooo00Koool0
0`1Vooooooooo`1/oooo00?o09Woooooool05_ooo`00Qoooo`0306Kooooooooo00Goool00`000?oo
ooooo`05oooo00<0I_ooooooool0KOooo`03o`2Ioooooooo01Koool008Soool00`1Vooooooooo`04
oooo00<0003oooooool01Oooo`0306Kooooooooo06goool00ol0VOooooooo`0Foooo0027oooo1000
00Coool00`000?ooooooo`04oooo00<0I_ooooooool0K_ooo`03o`2Ioooooooo01Koool008Ooool0
0`000?ooo`1Vo`05oooo00<0003oooooool00oooo`0306Kooooooooo06ooool00ol0VOooooooo`0F
oooo0028oooo00<0003oool0I_l01?ooo`<00002oooo00<0I_ooooooool0L?ooo`03o`2Ioooooooo
01Koool008Woool00`000?ooo`1Vo`03oooo00D0003oooooooooool0I_l0Loooo`03o`2Ioooooooo
01Koool008Ooool01@000?ooooooo`00001Vo`03oooo00D0003oooooooooool0I_l0Loooo`03o`2I
oooooooo01Koool008Soool200000_ooo`0406Kooooooooo00000_ooo`0306Kooooooooo07;oool0
0ol0VOooooooo`0Foooo002<oooo00H0I_ooooooool0003oool0I_meoooo00?o09Woooooool05_oo
o`00SOooo`0406Kooooo000006KoM_ooo`03o`2Ioooooooo01Koool008koool00`1Vo`000000001f
oooo00?o09Woooooool05_ooo`00S_ooo`0306Ko0000oooo07Koool00ol0VOooooooo`0Foooo002?
oooo00<0003oooooool0MOooo`03o`2Ioooooooo01Koool008ooool00`000?ooooooo`1eoooo00?o
09Woooooool05_ooo`00Soooo`030000oooooooo07Goool00ol0VOooooooo`0Foooo002?oooo00<0
003oooooool0MOooo`03o`2Ioooooooo01Koool008ooool20000M_ooo`03o`2Ioooooooo01Koool0
08ooool00`000?ooooooo`1eoooo00?o09Woooooool05_ooo`00Soooo`030000oooooooo07Goool0
0ol0VOooooooo`0Foooo002?oooo00<0003oooooool0MOooo`03o`2Ioooooooo01Koool008ooool0
0`000?ooooooo`1eoooo00?o09Woooooool05_ooo`00Soooo`030000oooooooo07Goool00ol0VOoo
ooooo`0Foooo002?oooo0P0007Koool00ol0VOooooooo`0Foooo002?oooo00<0003oooooool0MOoo
o`03o`2Ioooooooo01Koool008ooool00`000?ooooooo`1eoooo00?o09Woooooool05_ooo`00Sooo
o`030000oooooooo07Goool00ol0VOooooooo`0Foooo002?oooo00<0003oooooool0MOooo`03o`2I
oooooooo01Koool008ooool00`000?ooooooo`1eoooo00?o09Woooooool05_ooo`00Soooo`80001f
oooo00?o09Woooooool05_ooo`00Soooo`030000oooooooo07Goool00ol0VOooooooo`0Foooo002?
oooo00<0003oooooool0MOooo`03o`2Ioooooooo01Koool008ooool00`000?ooooooo`1eoooo00?o
09Woooooool05_ooo`00Noooo`@00003oooo0P0000Coool200001Oooo`030000oooooooo07Goool0
0ol0VOooooooo`0Foooo001koooo00<0003oooooool02Oooo`040000oooooooo00001?ooo`030000
oooooooo07Goool00ol0VOooooooo`0Foooo001loooo00<0003oooooool02oooo`030000oooooooo
00;oool30000MOooo`03o`2Ioooooooo01Koool007goool00`000?ooooooo`08oooo0P0009Koool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200000oooo`<00004
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08
oooo0`0000Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000ooool00`000?oo
ooooo`06oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0`0000;oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-3.47438, \
-0.205761, 0.024217, 0.0167931}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-3.47438, -0.205761, 0.024217, 0.0167931}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{757, 792},
WindowMargins->{{119, Automatic}, {Automatic, -32}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 217, 6, 96, "Title"],
Cell[1947, 60, 1021, 26, 258, "Text"],
Cell[2971, 88, 120, 4, 49, "Text"],
Cell[3094, 94, 344, 6, 19, "Input",
  CellOpen->False],
Cell[3441, 102, 185, 5, 68, "Text"],
Cell[3629, 109, 98, 2, 30, "Input"],
Cell[3730, 113, 108, 1, 49, "Text"],
Cell[3841, 116, 404, 10, 19, "Input",
  CellOpen->False],
Cell[4248, 128, 74, 2, 19, "Input",
  CellOpen->False],
Cell[4325, 132, 75, 2, 19, "Input",
  CellOpen->False],
Cell[4403, 136, 373, 12, 49, "Text"],

Cell[CellGroupData[{
Cell[4801, 152, 665, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[5491, 167, 23138, 902, 186, 11810, 758, "GraphicsData", "PostScript", \
"Graphics"],
Cell[28632, 1071, 23202, 902, 186, 11797, 757, "GraphicsData", "PostScript", \
"Graphics"],
Cell[51837, 1975, 23134, 903, 186, 11826, 759, "GraphicsData", "PostScript", \
"Graphics"],
Cell[74974, 2880, 23225, 903, 186, 11812, 758, "GraphicsData", "PostScript", \
"Graphics"],
Cell[98202, 3785, 23157, 904, 186, 11841, 760, "GraphicsData", "PostScript", \
"Graphics"],
Cell[121362, 4691, 23250, 905, 186, 11845, 760, "GraphicsData", "PostScript", \
"Graphics"],
Cell[144615, 5598, 23145, 904, 186, 11841, 760, "GraphicsData", "PostScript", \
"Graphics"],
Cell[167763, 6504, 23246, 905, 186, 11845, 760, "GraphicsData", "PostScript", \
"Graphics"],
Cell[191012, 7411, 23180, 906, 186, 11872, 762, "GraphicsData", "PostScript", \
"Graphics"],
Cell[214195, 8319, 23246, 906, 186, 11857, 761, "GraphicsData", "PostScript", \
"Graphics"],
Cell[237444, 9227, 23145, 905, 186, 11857, 761, "GraphicsData", "PostScript", \
"Graphics"],
Cell[260592, 10134, 23273, 906, 186, 11860, 761, "GraphicsData", \
"PostScript", "Graphics"],
Cell[283868, 11042, 23183, 906, 186, 11875, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[307054, 11950, 23289, 907, 186, 11876, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[330346, 12859, 23170, 905, 186, 11858, 761, "GraphicsData", \
"PostScript", "Graphics"],
Cell[353519, 13766, 23276, 907, 186, 11875, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[376798, 14675, 23174, 905, 186, 11858, 761, "GraphicsData", \
"PostScript", "Graphics"],
Cell[399975, 15582, 23298, 907, 186, 11877, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[423276, 16491, 23060, 904, 186, 11857, 761, "GraphicsData", \
"PostScript", "Graphics"],
Cell[446339, 17397, 23282, 907, 186, 11877, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[469624, 18306, 23215, 907, 186, 11891, 763, "GraphicsData", \
"PostScript", "Graphics"],
Cell[492842, 19215, 23281, 906, 186, 11860, 761, "GraphicsData", \
"PostScript", "Graphics"],
Cell[516126, 20123, 23190, 906, 186, 11874, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[539319, 21031, 23314, 908, 186, 11893, 763, "GraphicsData", \
"PostScript", "Graphics"],
Cell[562636, 21941, 23203, 906, 186, 11875, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[585842, 22849, 23305, 908, 186, 11892, 763, "GraphicsData", \
"PostScript", "Graphics"],
Cell[609150, 23759, 23223, 908, 186, 11907, 764, "GraphicsData", \
"PostScript", "Graphics"],
Cell[632376, 24669, 23338, 910, 186, 11925, 765, "GraphicsData", \
"PostScript", "Graphics"],
Cell[655717, 25581, 23210, 907, 186, 11890, 763, "GraphicsData", \
"PostScript", "Graphics"],
Cell[678930, 26490, 23322, 910, 186, 11925, 765, "GraphicsData", \
"PostScript", "Graphics"],
Cell[702255, 27402, 23207, 908, 186, 11907, 764, "GraphicsData", \
"PostScript", "Graphics"],
Cell[725465, 28312, 23330, 909, 186, 11909, 764, "GraphicsData", \
"PostScript", "Graphics"],
Cell[748798, 29223, 23226, 908, 186, 11906, 764, "GraphicsData", \
"PostScript", "Graphics"],
Cell[772027, 30133, 23359, 911, 186, 11938, 766, "GraphicsData", \
"PostScript", "Graphics"],
Cell[795389, 31046, 23246, 909, 186, 11922, 765, "GraphicsData", \
"PostScript", "Graphics"],
Cell[818638, 31957, 23354, 911, 186, 11941, 766, "GraphicsData", \
"PostScript", "Graphics"],
Cell[841995, 32870, 23267, 910, 186, 11939, 766, "GraphicsData", \
"PostScript", "Graphics"],
Cell[865265, 33782, 23370, 911, 186, 11941, 766, "GraphicsData", \
"PostScript", "Graphics"],
Cell[888638, 34695, 26340, 1006, 186, 14163, 851, "GraphicsData", \
"PostScript", "Graphics"],
Cell[914981, 35703, 23000, 898, 186, 11579, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[937984, 36603, 22893, 897, 186, 11577, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[960880, 37502, 22964, 897, 186, 11563, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[983847, 38401, 22889, 897, 186, 11577, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1006739, 39300, 23007, 899, 186, 11594, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1029749, 40201, 22899, 898, 186, 11591, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1052651, 41101, 22991, 898, 186, 11578, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1075645, 42001, 22848, 896, 186, 11560, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1098496, 42899, 22914, 897, 186, 11578, 753, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1121413, 43798, 22681, 895, 186, 11592, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1144097, 44695, 22687, 896, 186, 11610, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1166787, 45593, 22657, 896, 186, 11608, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1189447, 46491, 22837, 898, 186, 11610, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1212287, 47391, 22875, 899, 186, 11624, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1235165, 48292, 22930, 900, 186, 11626, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1258098, 49194, 22442, 893, 186, 11608, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1280543, 50089, 22448, 894, 186, 11626, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1302994, 50985, 21091, 877, 186, 11622, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1324088, 51864, 20097, 865, 186, 11624, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1344188, 52731, 19599, 858, 186, 11604, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1363790, 53591, 20787, 894, 186, 12039, 782, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1384580, 54487, 22272, 915, 186, 12078, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1406855, 55404, 24034, 936, 186, 12066, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1430892, 56342, 23961, 935, 186, 12066, 784, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1454856, 57279, 24150, 940, 186, 12121, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1479009, 58221, 24054, 939, 186, 12114, 787, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1503066, 59162, 24161, 939, 186, 12100, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1527230, 60103, 24107, 941, 186, 12151, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1551340, 61046, 24207, 943, 186, 12162, 790, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1575550, 61991, 24103, 938, 186, 12082, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1599656, 62931, 24327, 945, 186, 12181, 791, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1623986, 63878, 24169, 939, 186, 12100, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1648158, 64819, 24376, 945, 186, 12161, 790, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1672537, 65766, 24296, 943, 186, 12146, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1696836, 66711, 24601, 956, 186, 12325, 800, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1721440, 67669, 24343, 946, 186, 12176, 791, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1745786, 68617, 24417, 944, 186, 12129, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1770206, 69563, 24444, 948, 186, 12209, 793, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1794653, 70513, 24584, 951, 186, 12227, 794, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1819240, 71466, 24315, 943, 186, 12128, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1843558, 72411, 24584, 948, 186, 12183, 791, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1868145, 73361, 24527, 948, 186, 12174, 791, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1892675, 74311, 24652, 949, 186, 12165, 790, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1917330, 75262, 24611, 948, 186, 12161, 790, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1941944, 76212, 24720, 949, 186, 12148, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1966667, 77163, 24739, 953, 186, 12224, 794, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1991409, 78118, 24854, 953, 186, 12210, 793, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2016266, 79073, 24753, 951, 186, 12194, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2041022, 80026, 24872, 953, 186, 12195, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2065897, 80981, 24846, 953, 186, 12206, 793, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2090746, 81936, 24975, 953, 186, 12181, 791, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2115724, 82891, 24920, 954, 186, 12190, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2140647, 83847, 25193, 959, 186, 12241, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2165843, 84808, 25154, 958, 186, 12230, 794, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2191000, 85768, 25429, 965, 186, 12303, 799, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2216432, 86735, 25231, 957, 186, 12173, 791, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2241666, 87694, 25433, 960, 186, 12197, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2267102, 88656, 25442, 962, 186, 12239, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2292547, 89620, 25605, 962, 186, 12191, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2318155, 90584, 25523, 965, 186, 12263, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2343681, 91551, 25759, 964, 186, 12199, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2369443, 92517, 25814, 967, 186, 12238, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2395260, 93486, 25910, 966, 186, 12196, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2421173, 94454, 25913, 967, 186, 12207, 793, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2447089, 95423, 26169, 973, 186, 12269, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2473261, 96398, 26124, 972, 186, 12273, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2499388, 97372, 26278, 973, 186, 12240, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2525669, 98347, 26244, 971, 186, 12223, 794, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2551916, 99320, 26496, 976, 186, 12248, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2578415, 100298, 26566, 978, 186, 12269, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2604984, 101278, 26776, 982, 186, 12305, 799, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2631763, 102262, 26768, 982, 186, 12301, 799, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2658534, 103246, 26975, 984, 186, 12293, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2685512, 104232, 26974, 981, 186, 12240, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2712489, 105215, 27251, 986, 186, 12270, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2739743, 106203, 27336, 988, 186, 12286, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2767082, 107193, 27453, 988, 186, 12253, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2794538, 108183, 27439, 988, 186, 12251, 796, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

