(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2167348,      82647]*)
(*NotebookOutlinePosition[   2168092,      82672]*)
(*  CellTagsIndexPosition[   2168048,      82668]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["FOCUSING BEHIND A NEGATIVE DELTA-FUNCTION \
NONHOMOGENEITY", "Text",
  CellFrame->True,
  FontSize->14,
  Background->None]], "Title",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  StyleBox["The wavefront  and the tail  are incident from the left.\n\nThe \
nonhomogeneity  v[x]  ",
    FontSize->12],
  StyleBox["is a delta-function of strength  c0, positive or negative, \
located at  x=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"],
  StyleBox["  The potential has one bound state if  c0<0  and no bound states \
if  c0>0.\n\nThe focusing location,  ",
    FontSize->12],
  StyleBox["x0",
    FontSize->12,
    FontVariations->{"CompatibilityType"->0},
    CharacterEncoding->"WindowsANSI"],
  StyleBox[" >0, is behind the nonhomogeneity and needs to be specified. ",
    FontSize->12],
  StyleBox["\n\nThe transmission coefficient, left reflection coefficient, \
and right reflection coefficient, respectively, are denoted by  T[k],  L[k],  \
R[k].\n\nThe tail of the wave is denoted by  g[x,t].\n\nThe focusing moment \
is chosen as  t=0.",
    FontSize->12,
    CharacterEncoding->"WindowsANSI"]
}], "Text",
  FontSize->18,
  Background->RGBColor[1, 1, 0]],

Cell["\<\
The potential and the scattering coefficients are given next:\
\>", \
"Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(Clear[v, T, L, R, c0, x0, g];\)\), "\[IndentingNewLine]", 
    \(\(v[x_] = \ c0\ \ DiracDelta[x]\ ;\)\), "\n", 
    \(\(T[k_] = k/\((k + I\ \ c0/2)\);\)\), "\n", 
    \(\(L[k_] = \((\(-I\)\ c0/2)\)/\((k + I\ \ c0/2)\);\)\), "\n", 
    \(\(R[k_] = \((\(-I\)\ c0/2)\)/\((k + I\ \ c0/2)\);\)\)}], "Input",
  CellOpen->False],

Cell["\<\
Specify the strength of the potential, c0, a negative number;
also specify the focusing location  x0, a positive number, next:\
\>", "Text",\

  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(c0 = \(-1\)\)\(;\)\(\ \ \)\(\(x0 = 1\) \)\(;\)\(\ \)\)\)], "Input"],

Cell["The tail  g[x,t]  of the focusing  wave is evaluated  next:", "Text",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(\(\n\)\(g[x_, 
          t_] = \ \(-\ \((c0/2)\)\)\ UnitStep[
              x]\ \ UnitStep[\(-x\) - x0 + 
                t]\ E^\((c0 \((x + x0 - t)\)/2)\) + \((c0/2)\) 
            UnitStep[\(-x\)]\ \((UnitStep[\(-x\) + x0 + t]\  - \ 
                UnitStep[\(-x\) - x0 + t]\  - \ UnitStep[x + x0 + t] + \ 
                UnitStep[x - x0 + t] - \ 
                UnitStep[
                    x - x0 + 
                      t]\ E^\((c0 \((\(-x\) + x0 - t)\)/
                          2)\))\);\)\)\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  CellOpen->False],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input",
  CellOpen->False],

Cell[TextData[{
  "The focusing wave is animated  next. The wavefront (",
  StyleBox["magenta",
    FontColor->RGBColor[1, 0, 1]],
  ") and the tail (",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  ") are incident from the left onto the nonhomogeneity (",
  StyleBox["green",
    FontColor->RGBColor[0, 1, 0]],
  "):"
}], "Text",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Animate[{FilledPlot\[IndentingNewLine][{v[x]}, \ {x, \ \(-4\), \ 
              4}, \ PlotRange -> {\(-1\), 1.5}, \ 
            Fills \[Rule] {Hue[ .3]}], \[IndentingNewLine]\ \ \ \ \ \ \ \
Plot[{10\ UnitStep[x - x0 - t]}, \ {x, \ \(-4\), \ 4}, \ 
            PlotStyle \[Rule] \ Hue[ .9], 
            PlotRange -> {\(-1\), 
                1.5}], \[IndentingNewLine]\ \ \ \ \ \ \ Plot[{g[x, 
                t]}, {x, \ \(-4\), \ 4}, \ PlotStyle \[Rule] \ Hue[ .6], \ 
            PlotRange -> {\(-1\), 
                1.5}]}, \[IndentingNewLine]\ {t, \ \(-2\), \ 2.9, 0.05}, 
        PlotLabel \[Rule] {"\<t\>", t}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.34309 .24721 L
.36173 .24721 L
.37114 .24721 L
.37372 .24721 L
.37649 .24721 L
.37783 .24721 L
.3791 .24721 L
.38025 .24721 L
s
.38025 .24721 m
.38044 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.08255 .24721 L
.10458 .24721 L
.11448 .24721 L
.12507 .24721 L
.1302 .24721 L
.13506 .24721 L
.13942 .24721 L
.14061 .24721 L
.14188 .24721 L
.14296 .12361 L
.14415 .12361 L
.18444 .12361 L
.22321 .12361 L
.26444 .12361 L
.30414 .12361 L
.34234 .12361 L
.36201 .12361 L
.36767 .12361 L
.37301 .12361 L
.3778 .12361 L
.37911 .12361 L
.37983 .12361 L
.3805 .12361 L
.38168 .24721 L
.38298 .24721 L
.42189 .24721 L
.46325 .24721 L
.5031 .24721 L
.54143 .24721 L
.58221 .24721 L
.62148 .24721 L
.65923 .24721 L
.69943 .24721 L
.73812 .24721 L
.77926 .24721 L
.81888 .24721 L
.85699 .24721 L
.89755 .24721 L
.9366 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -22.0938 0 ]
[.5 .63053 22.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -83.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
97.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00=?oooch0I_l9oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo000doooo00<0I_ooooooool0>_ooo`0406Kooooooooo
oooo100000;oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool003Coool0
0`1Vooooooooo`0joooo00<0I_ooooooool01oooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Soool2
00002_ooo`<00004oooo00<0003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Koooo00<0003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0K
oooo00<0003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo00<0
003oooooool0S_ooo`00=?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Koooo0P0008ooool0
03Coool00`1Vooooooooo`0joooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool0
0`1Vooooooooo`0joooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Voooo
ooooo`0joooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Vooooooooo`0j
oooo00<0I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Vooooooooo`0joooo00<0
I_ooooooool06oooo`030000oooooooo08koool003Coool00`1Vooooooooo`0joooo00<0I_oooooo
ool06oooo`80002?oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?oo
ooooo`2>oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>
oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000d
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000doooo00<0
I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000doooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo01_oool20000Soooo`00=?ooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Koooo00<0003oooooool0S_ooo`006Oooo`<0000Hoooo00<0I_ooooooool07Oooo`@0000I
oooo00<0I_ooooooool06oooo`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0
003oooooool05oooo`0306Kooooooooo01goool00`000?ooooooo`0Joooo00<0I_ooooooool06ooo
o`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000H
oooo00<0I_ooooooool07_ooo`030000oooooooo01Woool00`1Vooooooooo`0Koooo00<0003ooooo
ool0>?ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool0000I
oooo00<0I_ooooooool05oooo`@00004oooo00<0003oooooool06?ooo`0306Kooooooooo01_oool0
0`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000
oooo000001Woool00`1Vooooooooo`0Moooo00@0003oooooool0000Ioooo00<0I_ooooooool06ooo
o`80000hoooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000Ioooo00<0
I_ooooooool07_ooo`80000Joooo00<0I_ooooooool06oooo`030000oooooooo03Soool20000??oo
o`80000Foooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>
oooo000doooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000d
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000doooo00<0
I_ooooooool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000doooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo01_oool00`000?ooooooo`2>oooo000@ooooo`00017oool001Koool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`00LOooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOoo
ooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>
oooo001aoooo00?o09Woooooool06oooo`80002?oooo001aoooo00?o09Woooooool06oooo`030000
oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo
08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo
01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003ooooo
ool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Wooooo
ool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_oo
o`00LOooo`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOoo
ooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>
oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0K
oooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo
08koool0077oool00ol0VOooooooo`08oooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0S_ooo`00LOooo`03o`2Ioooooooo00Ooool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool01oooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000S_ooo`00LOooo`03o`2Ioooooooo00Ooool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo08koool0077oool00ol0VOooooooo`07oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0077oool00ol0VOooooooo`08
oooo0P0000[oool300001?ooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0
003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool06oooo`80002?oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0
077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool0
0`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool0
0ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`2>oooo001aoooo00?o09Woooooool06oooo`80002?oooo001aoooo00?o09Woooooool06ooo
o`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOoo
o`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000
oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001a
oooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0
003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo0P0008ooool0
077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool0
0`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool0
0ol0VOooooooo`0Coooo1@0000?oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool05Ooo
o`030000oooooooo00?oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool05Oooo`030000
oooooooo00?oool30000S_ooo`00LOooo`03o`2Ioooooooo01Goool00`000?ooooooo`03oooo00<0
003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01Goool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00LOooo`03o`2Ioooooooo01Coool200001Oooo`030000oooooooo08koool0077oool0
0ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOoo
ooooo`0Koooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOoo
o`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000
oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`80002?oooo001a
oooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0
003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003ooooo
ool0S_ooo`00LOooo`03o`2Ioooooooo01_oool20000Soooo`00LOooo`03o`2Ioooooooo01_oool0
0`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool0
0ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2Ioooooooo01_oool00`000?oo
ooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000oooooooo08koool0077oool00ol0VOoo
ooooo`0Koooo0P0008ooool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOoo
o`03o`2Ioooooooo01_oool00`000?ooooooo`2>oooo001aoooo00?o09Woooooool06oooo`030000
oooooooo08koool0077oool00ol0VOooooooo`0Koooo00<0003oooooool0S_ooo`00LOooo`03o`2I
oooooooo00Ooool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`2>oooo001aoooo00?o
09Woooooool02Oooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`2>
oooo001aoooo00?o09Woooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
08koool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0
003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00Oooo
o`030000oooooooo01coool00`000?ooooooo`1ooooo001noooo00<0003oooooool02?ooo`030000
oooooooo01?oool00`000?ooooooo`1noooo001noooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03?ooo`@00003oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00<0003oooooool01?oo
o`030000oooooooo07koool007goool00`000?ooooooo`02oooo00<0003oooooool05?ooo`030000
oooooooo00Coool00`000?ooooooo`1moooo001noooo00<0003oooooool01@0001Coool00`000?oo
ooooo`02oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooooooo000001Goool010000?oo
ooooo`0000?oool00`000?ooooooo`1noooo001ooooo00<0003oooooool05oooo`800003oooo00<0
003oooooool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{79.5625, 308.938}, {290.125, 148.813}} -> {-0.349561, \
1.05307, 0.00349883, 0.00566123}, {{79.875, 308.563}, {290.125, 148.813}} -> \
{-8.05779, 1.90119, 0.0331906, 0.0159832}, {{79.875, 308.563}, {290.125, \
148.813}} -> {-8.05779, 1.90119, 0.0331906, 0.0159832}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.36136 .24721 L
.37176 .24721 L
.37685 .24721 L
.3815 .24721 L
.38384 .24721 L
.38508 .24721 L
.3864 .24721 L
s
.3864 .24721 m
.38659 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.13506 .24721 L
.14415 .24721 L
.14635 .24721 L
.14756 .24721 L
.14868 .24721 L
.1499 .12361 L
.15055 .12361 L
.15124 .12361 L
.1536 .12361 L
.16254 .12361 L
.18221 .12361 L
.22343 .12361 L
.26314 .12361 L
.30133 .12361 L
.34198 .12361 L
.36078 .12361 L
.37066 .12361 L
.38111 .12361 L
.38367 .12361 L
.38509 .12361 L
.38578 .12361 L
.38643 .12361 L
.38718 .24721 L
.388 .24721 L
.38944 .24721 L
.39226 .24721 L
.40252 .24721 L
.42269 .24721 L
.46196 .24721 L
.49971 .24721 L
.53991 .24721 L
.5786 .24721 L
.61974 .24721 L
.65936 .24721 L
.69747 .24721 L
.73803 .24721 L
.77708 .24721 L
.81858 .24721 L
.85856 .24721 L
.89702 .24721 L
.93794 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00=_ooocd0I_l8oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo
00@00002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo000foooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00Koool010000?ooooooo`0000Woool00`000?ooooooo`04
oooo00<0003oooooool0S_ooo`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`07oooo0P00
00[oool300001?ooo`030000oooooooo08koool003Koool00`1Vooooooooo`0ioooo00<0I_oooooo
ool06_ooo`030000oooooooo08koool003Koool00`1Vooooooooo`0ioooo00<0I_ooooooool06_oo
o`030000oooooooo08koool003Koool00`1Vooooooooo`0ioooo00<0I_ooooooool06_ooo`030000
oooooooo08koool003Koool00`1Vooooooooo`0ioooo00<0I_ooooooool06_ooo`80002?oooo000f
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo01[oool00`000?ooooooo`2>oooo000foooo00<0
I_ooooooool0>Oooo`0306Kooooooooo01[oool00`000?ooooooo`2>oooo000foooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo01[oool00`000?ooooooo`2>oooo000foooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo01[oool00`000?ooooooo`2>oooo000foooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo01[oool00`000?ooooooo`2>oooo000foooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01[oool20000Soooo`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003ooooo
ool0S_ooo`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_oo
o`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_oo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Joooo0P0008ooool003Koool00`1Vooooooooo`0ioooo00<0I_oooooo
ool06_ooo`030000oooooooo08koool001Woool300006_ooo`0306Kooooooooo01_oool400006_oo
o`0306Kooooooooo01[oool00`000?ooooooo`0goooo100003_oool300005Oooo`006_ooo`030000
oooooooo01Woool00`1Vooooooooo`0Koooo00<0003oooooool06oooo`0306Kooooooooo01[oool0
0`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool500006_oo
o`0306Kooooooooo01coool00`000?ooooooo`0Joooo00<0I_ooooooool06_ooo`030000oooooooo
03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo00006ooo
o`0306Kooooooooo01Goool400001?ooo`030000oooooooo01Woool00`1Vooooooooo`0Joooo00<0
003oooooool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?oo
o`00000Koooo00<0I_ooooooool06oooo`040000oooooooo00006_ooo`0306Kooooooooo01[oool2
0000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool200006oooo`0306Ko
oooooooo01coool200006oooo`0306Kooooooooo01[oool00`000?ooooooo`0hoooo0P0003coool2
00005_ooo`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_oo
o`00=_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_oo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`00=_ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Joooo00<0003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003o09Woool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo01Goool007;oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Wooooo
ool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_oo
o`00L_ooo`03o`2Ioooooooo01[oool20000Soooo`00L_ooo`03o`2Ioooooooo01[oool00`000?oo
ooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOoo
ooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>
oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0J
oooo0P0008ooool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2I
oooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo
08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo
01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool0
07;oool00ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Wooooo
ool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_oo
o`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_oo
o`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOoo
ooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>
oooo001boooo00?o09Woooooool01oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo
08koool007;oool00ol0VOooooooo`06oooo00@0003oooooool00008oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo00Koool010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0008koool007;oool00ol0VOooooooo`06oooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`2>oooo001boooo00?o09Woooooool01_ooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001boooo00?o09Woooooool01ooo
o`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2I
oooooooo01[oool20000Soooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001b
oooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0
003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o
09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool20000Soooo`00L_ooo`03o`2Ioooooooo01[oool0
0`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?oo
ooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOoo
ooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_oo
o`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2I
oooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`80002?oooo001b
oooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0
003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o
09Woooooool04_ooo`D00003oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01Coool0
0`000?ooooooo`03oooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`03oooo0`0008koool007;oool00ol0VOooooooo`0Doooo00<0003oooooool00oooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Doooo00<0003oooooool00oooo`030000oooooooo
08koool007;oool00ol0VOooooooo`0Coooo0P0000Goool00`000?ooooooo`2>oooo001boooo00?o
09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Wooooo
ool06_ooo`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?oo
ooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOoo
ooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool20000Soooo`00L_oo
o`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000
oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2I
oooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo
08koool007;oool00ol0VOooooooo`0Joooo0P0008ooool007;oool00ol0VOooooooo`0Joooo00<0
003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o
09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOooooooo`0Joooo00<0003ooooo
ool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?ooooooo`2>oooo001boooo00?o09Wooooo
ool06_ooo`80002?oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool0
0ol0VOooooooo`0Joooo00<0003oooooool0S_ooo`00L_ooo`03o`2Ioooooooo01[oool00`000?oo
ooooo`2>oooo001boooo00?o09Woooooool06_ooo`030000oooooooo08koool007;oool00ol0VOoo
ooooo`06oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00L_ooo`03o`2I
oooooooo00Soool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_oo
o`00L_ooo`03o`2Ioooooooo00Soool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>
oooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000
oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Koool0
0`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?oo
ooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00coool500000_ooo`800003oooo0`0000Coool200001?ooo`030000oooooooo07Goool0
07Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00001Oooo`030000oooooooo00Woool01@000?ooooooooooo`000002oooo00D0003oooooooooool0
0000Moooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02?oo
o`<00005oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`05
00005?ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool200001?ooo`030000oooooooo
07Goool007Goool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05ooo
o`80000:oooo0`0000?oool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.36136 .24721 L
.37176 .24721 L
.3815 .24721 L
.3864 .24721 L
.38881 .24721 L
.39106 .24721 L
.3923 .24721 L
s
.3923 .24721 m
.3924 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.13506 .24721 L
.14415 .24721 L
.14868 .24721 L
.15107 .24721 L
.15238 .24721 L
.1536 .24721 L
.15467 .24721 L
.15581 .12361 L
.15709 .12361 L
.15825 .12361 L
.16254 .12361 L
.18221 .12361 L
.22192 .12361 L
.26011 .12361 L
.30075 .12361 L
.33988 .12361 L
.35986 .12361 L
.37037 .12361 L
.38147 .12361 L
.38627 .12361 L
.38891 .12361 L
.39141 .12361 L
.3921 .12361 L
.39283 .12361 L
.39363 .24721 L
.39437 .24721 L
.39706 .24721 L
.40233 .24721 L
.42153 .24721 L
.45928 .24721 L
.49949 .24721 L
.53817 .24721 L
.57931 .24721 L
.61894 .24721 L
.65705 .24721 L
.69761 .24721 L
.73665 .24721 L
.77815 .24721 L
.81813 .24721 L
.8566 .24721 L
.89752 .24721 L
.93692 .24721 L
.97481 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00>?ooocd0I_l6oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo000hoooo00<0I_ooooooool0>Oooo`0306Ko00000000
00800002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo000hoooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00Coool010000?ooooooo`0000Woool00`000?ooooooo`04
oooo00<0003oooooool0S_ooo`00>?ooo`0306Kooooooooo03Woool00`1Vooooooooo`05oooo0P00
00[oool300001?ooo`030000oooooooo08koool003Soool00`1Vooooooooo`0ioooo00<0I_oooooo
ool06?ooo`030000oooooooo08koool003Soool00`1Vooooooooo`0ioooo00<0I_ooooooool06?oo
o`030000oooooooo08koool003Soool00`1Vooooooooo`0ioooo00<0I_ooooooool06?ooo`030000
oooooooo08koool003Soool00`1Vooooooooo`0ioooo00<0I_ooooooool06?ooo`80002?oooo000h
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000hoooo00<0
I_ooooooool0>Oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000hoooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000hoooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo01Soool00`000?ooooooo`2>oooo000hoooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo01Soool00`000?ooooooo`2>oooo000hoooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01Soool20000Soooo`00>?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Hoooo00<0003ooooo
ool0S_ooo`00>?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Hoooo00<0003oooooool0S_oo
o`00=oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00=ooo
o`0306Kooooooooo03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00=oooo`0306Ko
oooooooo03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00=oooo`0306Kooooooooo
03[oool00`1Vooooooooo`0Hoooo0P0008ooool003Ooool00`1Vooooooooo`0joooo00<0I_oooooo
ool06?ooo`030000oooooooo08koool001Woool300006oooo`0306Kooooooooo01[oool400007?oo
o`0306Kooooooooo01Soool00`000?ooooooo`0goooo100003_oool300005Oooo`006_ooo`030000
oooooooo01[oool00`1Vooooooooo`0Joooo00<0003oooooool07Oooo`0306Kooooooooo01Soool0
0`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool500006ooo
o`0306Kooooooooo01_oool00`000?ooooooo`0Loooo00<0I_ooooooool06?ooo`030000oooooooo
03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo00007?oo
o`0306Kooooooooo01Coool400001?ooo`030000oooooooo01_oool00`1Vooooooooo`0Hoooo00<0
003oooooool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?oo
o`00000Loooo00<0I_ooooooool06_ooo`040000oooooooo00007?ooo`0306Kooooooooo01Soool2
0000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool200007?ooo`0306Ko
oooooooo01_oool200007Oooo`0306Kooooooooo01Soool00`000?ooooooo`0hoooo0P0003coool2
00005_ooo`00=oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_oo
o`00=oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00=ooo
o`0306Kooooooooo03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00=oooo`0306Ko
oooooooo03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00=oooo`0306Kooooooooo
03[oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00@0003ooooooooo09T;oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>
oooo001doooo00?o09Woooooool06?ooo`80002?oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo
08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo
01Soool20000Soooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003ooooo
ool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Wooooo
ool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_oo
o`00M?ooo`03o`2Ioooooooo01Soool20000Soooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>
oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0H
oooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo
08koool007Coool00ol0VOooooooo`05oooo0P0000Coool200001?ooo`800005oooo00<0003ooooo
ool0S_ooo`00M?ooo`03o`2Ioooooooo00Coool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001doooo00?o09Woooooool01?ooo`040000oooooooo00002ooo
o`030000oooooooo00;oool30000S_ooo`00M?ooo`03o`2Ioooooooo00Coool010000?ooooooo`00
00Woool200001Oooo`030000oooooooo08koool007Coool00ol0VOooooooo`04oooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`05
oooo0P0000[oool300001?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`80002?oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool0
07Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`80002?oooo001doooo00?o09Woooooool06?oo
o`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool20000Soooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001d
oooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo0P0008ooool0
07Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0@oooo1@0000?oool00`000?ooooooo`2>oooo001doooo00?o09Woooooool04_oo
o`030000oooooooo00?oool00`000?ooooooo`2>oooo001doooo00?o09Woooooool04_ooo`030000
oooooooo00?oool30000S_ooo`00M?ooo`03o`2Ioooooooo01;oool00`000?ooooooo`03oooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01;oool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00M?ooo`03o`2Ioooooooo017oool200001Oooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`80002?oooo001d
oooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0
003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003ooooo
ool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool20000Soooo`00M?ooo`03o`2Ioooooooo01Soool0
0`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool0
0ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2Ioooooooo01Soool00`000?oo
ooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000oooooooo08koool007Coool00ol0VOoo
ooooo`0Hoooo0P0008ooool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?oo
o`03o`2Ioooooooo01Soool00`000?ooooooo`2>oooo001doooo00?o09Woooooool06?ooo`030000
oooooooo08koool007Coool00ol0VOooooooo`0Hoooo00<0003oooooool0S_ooo`00M?ooo`03o`2I
oooooooo00Coool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`2>oooo001doooo00?o
09Woooooool01_ooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`2>
oooo001doooo00?o09Woooooool01_ooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
08koool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0
003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03?ooo`D00002oooo0P0000?oool300001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Ooo
o`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0Eoooo00<0003oooooool02?ooo`<00004oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Goooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0G
oooo0P0000[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.36136 .24721 L
.37176 .24721 L
.3815 .24721 L
.39106 .24721 L
.39381 .24721 L
.39642 .24721 L
.39756 .24721 L
.39877 .24721 L
s
.39877 .24721 m
.39888 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.13506 .24721 L
.14415 .24721 L
.14868 .24721 L
.1536 .24721 L
.15586 .24721 L
.15825 .24721 L
.15923 .24721 L
.16029 .24721 L
.16145 .12361 L
.16254 .12361 L
.18221 .12361 L
.22343 .12361 L
.26314 .12361 L
.30133 .12361 L
.34198 .12361 L
.36078 .12361 L
.38111 .12361 L
.38653 .12361 L
.39226 .12361 L
.39462 .12361 L
.39715 .12361 L
.3979 .12361 L
.3986 .12361 L
.39924 .24721 L
.39993 .24721 L
.40252 .24721 L
.42269 .24721 L
.46347 .24721 L
.50274 .24721 L
.54049 .24721 L
.58069 .24721 L
.61938 .24721 L
.66052 .24721 L
.70014 .24721 L
.73825 .24721 L
.77881 .24721 L
.81786 .24721 L
.85936 .24721 L
.89934 .24721 L
.93781 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00>Oooocd0I_l5oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo000ioooo00<0I_ooooooool0>Oooo`@00002oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo00?oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00>Oooo`0306Kooooooooo03Woool00`1Vooooooooo`04oooo0P0000[oool300001?oo
o`030000oooooooo08koool003Woool00`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000
oooooooo08koool003Woool00`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000oooooooo
08koool003Woool00`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000oooooooo08koool0
03Woool00`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`80002?oooo000ioooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo01Ooool00`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo01Ooool00`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo01Ooool00`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01Ooool00`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Ooool0
0`000?ooooooo`2>oooo000ioooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Ooool20000Sooo
o`00>Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Ooo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Goooo0P0008ooool003Woool00`1Vooooooooo`0ioooo00<0I_ooooooool05oooo`030000
oooooooo08koool001Woool300007Oooo`0306Kooooooooo01Soool400007Oooo`0306Kooooooooo
01Ooool00`000?ooooooo`0goooo100003_oool300005Oooo`006_ooo`030000oooooooo01coool0
0`1Vooooooooo`0Hoooo00<0003oooooool07_ooo`0306Kooooooooo01Ooool00`000?ooooooo`0g
oooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool500007Oooo`0306Kooooooooo
01Woool00`000?ooooooo`0Moooo00<0I_ooooooool05oooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo00007_ooo`0306Kooooooooo
01;oool400001?ooo`030000oooooooo01coool00`1Vooooooooo`0Goooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000Noooo00<0
I_ooooooool06?ooo`040000oooooooo00007Oooo`0306Kooooooooo01Ooool20000>?ooo`040000
oooooooo0000>_ooo`030000oooo000001Koool001Woool200007_ooo`0306Kooooooooo01Woool2
00007_ooo`0306Kooooooooo01Ooool00`000?ooooooo`0hoooo0P0003coool200005_ooo`00>Ooo
o`0306Kooooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00>Oooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Goooo00<0003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00D0003ooooooooooooo09T02_ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo01Goool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05ooo
o`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOoo
o`03o`2Ioooooooo01Ooool20000Soooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>
oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0G
oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001e
oooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo0P00
08ooool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo
01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool0
07Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool0
0`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool0
0ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05ooo
o`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOoo
o`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`80002?
oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0G
oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001e
oooo00?o09Woooooool01?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo08koool0
07Goool00ol0VOooooooo`03oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0
003oooooool0S_ooo`00MOooo`03o`2Ioooooooo00?oool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`0008koool007Goool00ol0VOooooooo`03oooo00@0003oooooool00009oooo0P00
00Goool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool00oooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool01?ooo`80000:
oooo0`0000Coool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo
08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo
01Ooool20000Soooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o
09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003ooooo
ool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Wooooo
ool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2Ioooooooo01Ooool20000Soooo`00MOooo`03o`2Ioooooooo01Ooool00`000?oo
ooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOoo
ooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>
oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0G
oooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2I
oooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo
08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo
01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`80002?oooo001eoooo00?o
09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003ooooo
ool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Wooooo
ool03oooo`D00003oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo017oool00`000?oo
ooooo`03oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo017oool00`000?ooooooo`03
oooo0`0008koool007Goool00ol0VOooooooo`0Aoooo00<0003oooooool00oooo`030000oooooooo
08koool007Goool00ol0VOooooooo`0Aoooo00<0003oooooool00oooo`030000oooooooo08koool0
07Goool00ol0VOooooooo`0@oooo0P0000Goool00`000?ooooooo`2>oooo001eoooo00?o09Wooooo
ool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05ooo
o`80002?oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOoo
ooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>
oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0G
oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool20000Soooo`00MOooo`03o`2I
oooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo
08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo
01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool0
07Goool00ol0VOooooooo`0Goooo0P0008ooool007Goool00ol0VOooooooo`0Goooo00<0003ooooo
ool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Wooooo
ool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`0Goooo00<0003oooooool0S_oo
o`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>oooo001eoooo00?o09Woooooool05ooo
o`80002?oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOoo
ooooo`0Goooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo01Ooool00`000?ooooooo`2>
oooo001eoooo00?o09Woooooool05oooo`030000oooooooo08koool007Goool00ol0VOooooooo`03
oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00MOooo`03o`2Ioooooooo
00Goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00MOoo
o`03o`2Ioooooooo00Goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001m
oooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo
09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Koool00`000?oo
ooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0U
oooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool500000_ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Ooo
o`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`07
oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool0
0`000?ooooooo`0500005?ooo`030000oooooooo00Soool200001?ooo`800004oooo00<0003ooooo
ool0MOooo`00MOooo`050000oooooooooooo000001Ooool00`000?ooooooo`07oooo00@0003ooooo
ool00003oooo00<0003oooooool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0G
oooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.39174 .24721 L
.39675 .24721 L
.40134 .24721 L
.40252 .24721 L
.40381 .24721 L
s
.40381 .24721 m
.40399 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.14415 .24721 L
.1536 .24721 L
.15825 .24721 L
.16254 .24721 L
.16494 .24721 L
.16615 .24721 L
.16683 .12361 L
.16748 .12361 L
.17284 .12361 L
.18221 .12361 L
.22098 .12361 L
.2622 .12361 L
.30191 .12361 L
.34011 .12361 L
.36142 .12361 L
.38075 .12361 L
.39043 .12361 L
.39552 .12361 L
.3983 .12361 L
.4009 .12361 L
.40317 .12361 L
.40445 .12361 L
.40561 .24721 L
.40688 .24721 L
.40827 .24721 L
.41079 .24721 L
.41988 .24721 L
.46066 .24721 L
.49993 .24721 L
.53768 .24721 L
.57788 .24721 L
.61657 .24721 L
.65771 .24721 L
.69733 .24721 L
.73544 .24721 L
.776 .24721 L
.81505 .24721 L
.85655 .24721 L
.89653 .24721 L
.935 .24721 L
.97591 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00>_oooch0I_l3oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo000joooo00<0I_ooooooool0>?ooo`@00002oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo000joooo00<0I_ooooooool0>_oo
o`0506Kooooooooooooo000000;oool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000
oooooooo08koool003[oool00`1Vooooooooo`0joooo00<0I_ooooooool00_ooo`80000:oooo0`00
00Coool00`000?ooooooo`2>oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool0
0`000?ooooooo`2>oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool00`000?oo
ooooo`2>oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool00`000?ooooooo`2>
oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool20000Soooo`00>_ooo`0306Ko
oooooooo03[oool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo
03[oool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool0
0`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Eoooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0E
oooo00<0003oooooool0S_ooo`00>_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0Eoooo0P00
08ooool003[oool00`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool0
03[oool00`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool0
0`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Voooo
ooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Vooooooooo`0j
oooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Vooooooooo`0joooo00<0
I_ooooooool05Oooo`80002?oooo000joooo00<0I_ooooooool0>_ooo`0306Kooooooooo01Goool0
0`000?ooooooo`2>oooo000Ioooo0`0001koool00`1Vooooooooo`0Goooo100001ooool00`1Voooo
ooooo`0Eoooo00<0003oooooool0=oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0M
oooo00<0I_ooooooool05oooo`030000oooooooo023oool00`1Vooooooooo`0Eoooo00<0003ooooo
ool0=oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@0001koool00`1Voooo
ooooo`0Hoooo00<0003oooooool07oooo`0306Kooooooooo01Goool00`000?ooooooo`0hoooo00<0
003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0001ooool00`1Voooo
ooooo`0Aoooo100000Coool00`000?ooooooo`0Noooo00<0I_ooooooool05Oooo`030000oooooooo
03Woool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool000007ooo
o`0306Kooooooooo01Ooool010000?ooooooo`0001ooool00`1Vooooooooo`0Eoooo0P0003Soool0
10000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0001ooool00`1Vooooooooo`0H
oooo0P00023oool00`1Vooooooooo`0Eoooo00<0003oooooool0>?ooo`80000loooo0P0001Koool0
03[oool00`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool0
0`1Vooooooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Voooo
ooooo`0joooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Vooooooooo`0j
oooo00<0I_ooooooool05Oooo`030000oooooooo08koool003[oool00`1Vooooooooo`0joooo00<0
I_ooooooool05Oooo`030000oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00?oool00ol0VOooooooo`06oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`00Moooo`03o`2Ioooooooo01Goool0
0`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool0
0ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`2>oooo001goooo00?o09Woooooool05Oooo`80002?oooo001goooo00?o09Woooooool05Ooo
o`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Mooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000
oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2I
oooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001g
oooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0
003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o
09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003ooooo
ool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo01Goool0
0`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool0
0ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOoo
ooooo`0Eoooo0P0008ooool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Mooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000
oooooooo08koool007Ooool00ol0VOooooooo`02oooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00Moooo`05o`2Ioooooooooooo000000;oool00`000?ooooooo`06oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Moooo`05o`2Ioooooooooooo000000;oool0
0`000?ooooooo`09oooo00<0003oooooool00_ooo`<0002>oooo001goooo00Go09Woooooooooool0
00000_ooo`030000oooooooo00Ooool200001Oooo`030000oooooooo08koool007Ooool01Ol0VOoo
ooooooooo`000002oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001goooo00?o09Woooooool00_ooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001g
oooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0
003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo
01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool0
07Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool0
0`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool0
0ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool20000Sooo
o`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Ooo
o`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Mooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000
oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo0P0008ooool007Ooool00ol0VOooooooo`0E
oooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001g
oooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0
003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o
09Woooooool05Oooo`80002?oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool0
07Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool0
0`000?ooooooo`2>oooo001goooo00?o09Woooooool03Oooo`D00003oooo00<0003oooooool0S_oo
o`00Moooo`03o`2Ioooooooo00ooool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00Mooo
o`03o`2Ioooooooo00ooool00`000?ooooooo`03oooo0`0008koool007Ooool00ol0VOooooooo`0?
oooo00<0003oooooool00oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0?oooo00<0
003oooooool00oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0>oooo0P0000Goool0
0`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool0
0ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`2>oooo001goooo00?o09Woooooool05Oooo`80002?oooo001goooo00?o09Woooooool05Ooo
o`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Mooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000
oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2I
oooooooo01Goool20000Soooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001g
oooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0
003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o
09Woooooool05Oooo`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo0P0008ooool0
07Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool0
0`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000oooooooo08koool007Ooool0
0ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Moooo`03o`2Ioooooooo01Goool00`000?oo
ooooo`2>oooo001goooo00?o09Woooooool05Oooo`80002?oooo001goooo00?o09Woooooool05Ooo
o`030000oooooooo08koool007Ooool00ol0VOooooooo`0Eoooo00<0003oooooool0S_ooo`00Mooo
o`03o`2Ioooooooo01Goool00`000?ooooooo`2>oooo001goooo00?o09Woooooool05Oooo`030000
oooooooo08koool007Ooool01?l0VOooooooooooo`D00002oooo0P0000Coool200001Oooo`030000
oooooooo08koool007Ooool00ol0VOooooooo`03oooo00<0003oooooool01oooo`040000oooooooo
00001?ooo`030000oooooooo08koool007Ooool00ol0VOooooooo`03oooo00<0003oooooool02_oo
o`030000oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOoo
o`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00oooo
ob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool0
0`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
01Coool00`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.39174 .24721 L
.40134 .24721 L
.40616 .24721 L
.40755 .24721 L
.40887 .24721 L
.41005 .24721 L
s
.41005 .24721 m
.41024 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.14415 .24721 L
.1536 .24721 L
.16254 .24721 L
.16748 .24721 L
.16883 .24721 L
.17026 .24721 L
.17149 .24721 L
.17219 .24721 L
.17284 .12361 L
.17405 .12361 L
.1752 .12361 L
.17735 .12361 L
.18221 .12361 L
.2204 .12361 L
.26105 .12361 L
.30018 .12361 L
.34176 .12361 L
.36263 .12361 L
.38182 .12361 L
.40057 .12361 L
.40513 .12361 L
.40764 .12361 L
.40887 .12361 L
.41001 .12361 L
.41066 .12361 L
.41135 .24721 L
.41205 .24721 L
.41282 .24721 L
.41537 .24721 L
.42038 .24721 L
.46058 .24721 L
.49927 .24721 L
.54041 .24721 L
.58003 .24721 L
.61814 .24721 L
.6587 .24721 L
.69774 .24721 L
.73924 .24721 L
.77922 .24721 L
.81769 .24721 L
.85861 .24721 L
.89801 .24721 L
.9359 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00??ooocd0I_l2oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo000loooo00<0I_ooooooool0=_ooo`@00002oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo000loooo00<0I_ooooooool0>Ooo
o`0406Kooooooooo00000_ooo`030000oooooooo00Ooool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00??ooo`0306Kooooooooo03Woool0101Vooooooooooooo`80000:oooo0`0000Coool0
0`000?ooooooo`2>oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?oo
ooooo`2>oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?ooooooo`2>
oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?ooooooo`2>oooo000l
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool20000Soooo`00??ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Doooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool00`1Vooooooooo`0D
oooo00<0003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Doooo00<0
003oooooool0S_ooo`00??ooo`0306Kooooooooo03Woool00`1Vooooooooo`0Doooo0P0008ooool0
03coool00`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool0
0`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Voooo
ooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Vooooooooo`0i
oooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Vooooooooo`0ioooo00<0
I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Vooooooooo`0ioooo00<0I_oooooo
ool05?ooo`80002?oooo000loooo00<0I_ooooooool0>Oooo`0306Kooooooooo01Coool00`000?oo
ooooo`2>oooo000Ioooo0`00023oool00`1Vooooooooo`0Eoooo1000023oool00`1Vooooooooo`0D
oooo00<0003oooooool0=oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0Ooooo00<0
I_ooooooool05Oooo`030000oooooooo027oool00`1Vooooooooo`0Doooo00<0003oooooool0=ooo
o`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00023oool00`1Vooooooooo`0F
oooo00<0003oooooool08?ooo`0306Kooooooooo01Coool00`000?ooooooo`0hoooo00<0003ooooo
ool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`00027oool00`1Vooooooooo`0?
oooo100000Coool00`000?ooooooo`0Ooooo00<0I_ooooooool05?ooo`030000oooooooo03Woool0
0`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool000008Oooo`0306Ko
oooooooo01Goool010000?ooooooo`00023oool00`1Vooooooooo`0Doooo0P0003Soool010000?oo
ooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P00027oool00`1Vooooooooo`0Foooo0P00
027oool00`1Vooooooooo`0Doooo00<0003oooooool0>?ooo`80000loooo0P0001Koool003coool0
0`1Vooooooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Voooo
ooooo`0ioooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Vooooooooo`0i
oooo00<0I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Vooooooooo`0ioooo00<0
I_ooooooool05?ooo`030000oooooooo08koool003coool00`1Vooooooooo`0ioooo00<0I_oooooo
ool05?ooo`030000oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00Coool00ol0VOooooooo`05oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool05?ooo`80002?oooo001hoooo00?o09Woooooool05?ooo`030000
oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2I
oooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool20000Soooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o
09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_oo
o`00N?ooo`03o`2Ioooooooo01Coool20000Soooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0D
oooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2I
oooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool01?l0VOooooooooooo`800004oooo0P0000Coool200001Oooo`030000oooooooo
08koool007Soool01?l0VOooooooo`0000;oool00`000?ooooooo`06oooo00@0003oooooool00004
oooo00<0003oooooool0S_ooo`00N?ooo`04o`2Ioooooooo00000_ooo`030000oooooooo00Woool0
0`000?ooooooo`02oooo0`0008koool007Soool01?l0VOooooooo`0000;oool00`000?ooooooo`07
oooo0P0000Goool00`000?ooooooo`2>oooo001hoooo00Co09Woooooool00002oooo00<0003ooooo
ool01oooo`030000oooooooo00Coool00`000?ooooooo`2>oooo001hoooo00Co09Woooooooooool2
00002_ooo`<00004oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?oo
o`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000
oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2I
oooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo0P0008ooool007Soool00ol0VOooooooo`0Doooo00<0
003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o
09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`80002?oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool0
0ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool20000Soooo`00N?oo
o`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000
oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2I
oooooooo00coool500000oooo`030000oooooooo08koool007Soool00ol0VOooooooo`0>oooo00<0
003oooooool00oooo`030000oooooooo08koool007Soool00ol0VOooooooo`0>oooo00<0003ooooo
ool00oooo`<0002>oooo001hoooo00?o09Woooooool03_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool03_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool03Oooo`800005oooo00<0003oooooool0S_ooo`00N?ooo`03o`2I
oooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool20000Soooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o
09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo0P0008ooool007Soool0
0ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?oo
ooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOoo
ooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>
oooo001hoooo00?o09Woooooool05?ooo`80002?oooo001hoooo00?o09Woooooool05?ooo`030000
oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2I
oooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Woooooool05?ooo`030000oooooooo
08koool007Soool00ol0VOooooooo`0Doooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
01Coool20000Soooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o
09Woooooool05?ooo`030000oooooooo08koool007Soool00ol0VOooooooo`0Doooo00<0003ooooo
ool0S_ooo`00N?ooo`03o`2Ioooooooo01Coool00`000?ooooooo`2>oooo001hoooo00?o09Wooooo
ool01@0000;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00N?ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00N?oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001m
oooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo
09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Koool00`000?oo
ooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0U
oooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00coool500000_ooo`800005oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00005oooo00<0003oooooool02Oooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`00001goooo001doooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`09
oooo00<0003oooooool01?ooo`030000oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0
003oooooool01@0001Coool00`000?ooooooo`0:oooo00@0003oooooooooool200001?ooo`030000
oooooooo07Goool007Goool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003ooooo
ool05oooo`800009oooo100000?oool300000_ooo`030000oooooooo07Koool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.40134 .24721 L
.40616 .24721 L
.41134 .24721 L
.41287 .24721 L
.41432 .24721 L
.41562 .24721 L
.41635 .24721 L
s
.41635 .24721 m
.41645 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.14415 .24721 L
.16254 .24721 L
.16783 .24721 L
.17284 .24721 L
.17502 .24721 L
.17733 .24721 L
.17854 .24721 L
.17922 .12361 L
.17987 .12361 L
.18221 .12361 L
.22098 .12361 L
.2622 .12361 L
.30191 .12361 L
.34011 .12361 L
.36142 .12361 L
.38075 .12361 L
.39043 .12361 L
.4009 .12361 L
.40571 .12361 L
.41079 .12361 L
.41288 .12361 L
.41512 .12361 L
.41641 .12361 L
.41758 .24721 L
.41876 .24721 L
.41988 .24721 L
.45821 .24721 L
.49899 .24721 L
.53826 .24721 L
.57601 .24721 L
.61621 .24721 L
.6549 .24721 L
.69604 .24721 L
.73566 .24721 L
.77377 .24721 L
.81433 .24721 L
.85338 .24721 L
.89488 .24721 L
.93486 .24721 L
.97332 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00?_ooocd0I_l010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0008koool003koool00`1Vooooooooo`0doooo10000003oooo06Ko0000
00;oool00`000?ooooooo`07oooo0P0000Goool00`000?ooooooo`2>oooo000noooo00<0I_oooooo
ool0>Oooo`0506Ko0000oooooooo000000Woool00`000?ooooooo`04oooo00<0003oooooool0S_oo
o`00?_ooo`0306Kooooooooo03Woool0101Vooooo`00000000[oool300001?ooo`030000oooooooo
08koool003koool00`1Vooooooooo`0ioooo00<0I_ooooooool04_ooo`030000oooooooo08koool0
03koool00`1Vooooooooo`0ioooo00<0I_ooooooool04_ooo`030000oooooooo08koool003koool0
0`1Vooooooooo`0ioooo00<0I_ooooooool04_ooo`030000oooooooo08koool003koool00`1Voooo
ooooo`0ioooo00<0I_ooooooool04_ooo`80002?oooo000noooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo01;oool00`000?ooooooo`2>oooo000noooo00<0I_ooooooool0>Oooo`0306Kooooooooo
01;oool00`000?ooooooo`2>oooo000noooo00<0I_ooooooool0>Oooo`0306Kooooooooo01;oool0
0`000?ooooooo`2>oooo000noooo00<0I_ooooooool0>Oooo`0306Kooooooooo01;oool00`000?oo
ooooo`2>oooo000noooo00<0I_ooooooool0>Oooo`0306Kooooooooo01;oool00`000?ooooooo`2>
oooo000noooo00<0I_ooooooool0>Oooo`0306Kooooooooo01;oool20000Soooo`00?_ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00?_ooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool0
0`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Boooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Vooooooooo`0B
oooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Boooo0P00
08ooool003goool00`1Vooooooooo`0joooo00<0I_ooooooool04_ooo`030000oooooooo08koool0
01Woool300008Oooo`0306Kooooooooo01Coool400008_ooo`0306Kooooooooo01;oool00`000?oo
ooooo`0goooo100003_oool300005Oooo`006_ooo`030000oooooooo023oool00`1Vooooooooo`0D
oooo00<0003oooooool08oooo`0306Kooooooooo01;oool00`000?ooooooo`0goooo00<0003ooooo
ool0?Oooo`030000oooooooo01Coool001Ooool500008Oooo`0306Kooooooooo01Goool00`000?oo
ooooo`0Roooo00<0I_ooooooool04_ooo`030000oooooooo03Soool00`000?ooooooo`0ioooo1@00
01Goool0017oool400000_ooo`040000oooooooo00008_ooo`0306Kooooooooo00koool400001?oo
o`030000oooooooo027oool00`1Vooooooooo`0Boooo00<0003oooooool0>Oooo`030000oooooooo
03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000Roooo00<0I_ooooooool05?oo
o`040000oooooooo00008_ooo`0306Kooooooooo01;oool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool200008_ooo`0306Kooooooooo01Goool200008oooo`0306Ko
oooooooo01;oool00`000?ooooooo`0hoooo0P0003coool200005_ooo`00?Oooo`0306Kooooooooo
03[oool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool0
0`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0Boooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Vooooooooo`0B
oooo00<0003oooooool0S_ooo`00?Oooo`0306Kooooooooo03[oool00`1Vooooooooo`0Boooo00<0
003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool01_ooo`03o`2Ioooooooo00?oool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0Eoooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo0P0008ooool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_oo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`80002?
oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001j
oooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0
003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o
09Woooooool04_ooo`80002?oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool0
0`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool0
0ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Sooo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_oo
o`04o`2Ioooo000000001?ooo`800004oooo0P0000Goool00`000?ooooooo`2>oooo001joooo00Go
09T0003oooooool000002?ooo`040000oooooooo00001?ooo`030000oooooooo08koool007[oool0
1Ol0V@000?ooooooo`00000;oooo00<0003oooooool00_ooo`<0002>oooo001joooo00Go09T0003o
ooooool000002Oooo`800005oooo00<0003oooooool0S_ooo`00N_ooo`05o`2I0000oooooooo0000
00Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00N_ooo`04o`2Ioooo000000002_oo
o`<00004oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>
oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0B
oooo0P0008ooool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2I
oooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo
08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo
01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo0P0008ooool007[oool00ol0VOooooooo`0Boooo00<0003ooooo
ool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Wooooo
ool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_oo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_oo
o`80002?oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOoo
ooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>
oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool20000Soooo`00N_ooo`03o`2I
oooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo
08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo
00[oool500000oooo`030000oooooooo08koool007[oool00ol0VOooooooo`0<oooo00<0003ooooo
ool00oooo`030000oooooooo08koool007[oool00ol0VOooooooo`0<oooo00<0003oooooool00ooo
o`<0002>oooo001joooo00?o09Woooooool03?ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo001joooo00?o09Woooooool03?ooo`030000oooooooo00?oool00`000?ooooooo`2>oooo001j
oooo00?o09Woooooool02oooo`800005oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo
01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool2
0000Soooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Wooooo
ool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_oo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_oo
o`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo0P0008ooool007[oool00ol0VOoo
ooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>
oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0B
oooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001j
oooo00?o09Woooooool04_ooo`80002?oooo001joooo00?o09Woooooool04_ooo`030000oooooooo
08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo
01;oool00`000?ooooooo`2>oooo001joooo00?o09Woooooool04_ooo`030000oooooooo08koool0
07[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_ooo`00N_ooo`03o`2Ioooooooo01;oool2
0000Soooo`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09Wooooo
ool04_ooo`030000oooooooo08koool007[oool00ol0VOooooooo`0Boooo00<0003oooooool0S_oo
o`00N_ooo`03o`2Ioooooooo01;oool00`000?ooooooo`2>oooo001joooo00?o09T0000000000`00
00;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00N_ooo`04o`2Ioooooooo00002Ooo
o`040000oooooooo00001?ooo`030000oooooooo08koool007[oool01?l0VOooooooo`0000coool0
0`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool007goool0
0`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000Goool00`000?ooooooo`02
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02Oooo`030000oooooooo00;oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?oo
ooooo`09oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005?ooo`030000oooooooo00[oool01@000?ooooooooooo`00001joooo001hoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool05oooo`800009oooo100000;oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.40095 .24721 L
.41127 .24721 L
.41696 .24721 L
.41976 .24721 L
.42113 .24721 L
.42237 .24721 L
s
.42237 .24721 m
.42256 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.16408 .24721 L
.17277 .24721 L
.17735 .24721 L
.17986 .24721 L
.18221 .24721 L
.18341 .24721 L
.1847 .12361 L
.18543 .12361 L
.18613 .12361 L
.18744 .12361 L
.19227 .12361 L
.20178 .12361 L
.22272 .12361 L
.26091 .12361 L
.30156 .12361 L
.34068 .12361 L
.38227 .12361 L
.40313 .12361 L
.41229 .12361 L
.41714 .12361 L
.4198 .12361 L
.42112 .12361 L
.42233 .12361 L
.42351 .24721 L
.42476 .24721 L
.4274 .24721 L
.43203 .24721 L
.44108 .24721 L
.46088 .24721 L
.49863 .24721 L
.53884 .24721 L
.57753 .24721 L
.61867 .24721 L
.65829 .24721 L
.6964 .24721 L
.73696 .24721 L
.776 .24721 L
.8175 .24721 L
.85748 .24721 L
.89595 .24721 L
.93687 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00?ooooc`0I_l010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0008koool003ooool00`1Vooooooooo`0coooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool003ooool00`1Vooooooooo`0ioooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool003ooool00`1Voooo
ooooo`0ioooo00<0I_l0000000002_ooo`<00004oooo00<0003oooooool0S_ooo`00?oooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo
03Woool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00?oooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0Aoooo0P0008ooool003ooool00`1Vooooooooo`0ioooo00<0I_ooooooool04Oooo`030000
oooooooo08koool003ooool00`1Vooooooooo`0ioooo00<0I_ooooooool04Oooo`030000oooooooo
08koool003ooool00`1Vooooooooo`0ioooo00<0I_ooooooool04Oooo`030000oooooooo08koool0
03ooool00`1Vooooooooo`0ioooo00<0I_ooooooool04Oooo`030000oooooooo08koool003ooool0
0`1Vooooooooo`0ioooo00<0I_ooooooool04Oooo`030000oooooooo08koool003ooool00`1Voooo
ooooo`0ioooo00<0I_ooooooool04Oooo`80002?oooo000ooooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo017oool00`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0>Oooo`0306Kooooooooo
017oool00`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0>Oooo`0306Kooooooooo017oool0
0`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0>_ooo`0306Kooooooooo013oool00`000?oo
ooooo`2>oooo000ooooo00<0I_ooooooool0>_ooo`0306Kooooooooo013oool00`000?ooooooo`2>
oooo000ooooo00<0I_ooooooool0>_ooo`0306Kooooooooo013oool20000Soooo`00?oooo`0306Ko
oooooooo03[oool00`1Vooooooooo`0@oooo00<0003oooooool0S_ooo`006Oooo`<0000Soooo00<0
I_ooooooool04_ooo`@0000Toooo00<0I_ooooooool04?ooo`030000oooooooo03Ooool40000>ooo
o`<0000Eoooo000Joooo00<0003oooooool08_ooo`0306Kooooooooo01;oool00`000?ooooooo`0U
oooo00<0I_ooooooool04?ooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000Soooo00<0I_ooooooool04oooo`030000oooooooo02Coool00`1Voooo
ooooo`0@oooo00<0003oooooool0>?ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002
oooo00@0003oooooool0000Toooo00<0I_ooooooool03?ooo`@00004oooo00<0003oooooool08ooo
o`0306Kooooooooo013oool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`030000oooo000002Coool00`1Vooooooooo`0Boooo00@0003oooooool0000T
oooo00<0I_ooooooool04?ooo`80000hoooo00@0003oooooool0000joooo00<0003oool000005_oo
o`006Oooo`80000Toooo00<0I_ooooooool04oooo`80000Uoooo00<0I_ooooooool04?ooo`030000
oooooooo03Soool20000??ooo`80000Foooo000ooooo00<0I_ooooooool0>_ooo`0306Kooooooooo
013oool00`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0>_ooo`0306Kooooooooo013oool0
0`000?ooooooo`2>oooo000ooooo00<0I_ooooooool0>_ooo`0306Kooooooooo013oool00`000?oo
ooooo`2>oooo000ooooo00<0I_ooooooool0>_ooo`0306Kooooooooo013oool00`000?ooooooo`2>
oooo000ooooo00<0I_ooooooool0>_ooo`0306Kooooooooo013oool00`000?ooooooo`2>oooo000@
ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`07oooo00?o09Woooooool00_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
01Goool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo
017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool0
07_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool2
0000Soooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Wooooo
ool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_oo
o`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Ooo
o`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOoo
ooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0A
oooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001k
oooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo0P00
08ooool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo
017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool0
07_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool0
0`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`80002?oooo001koooo00?o09Wooooo
ool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_oo
o`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09T0000000001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003ooooo
ool0S_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001koooo00?o09T0000000002_ooo`<00004oooo00<0003oooooool0S_ooo`00Noooo`03o`2I
oooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo
08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0
003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o
09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003ooooo
ool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Wooooo
ool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo0P0008ooool007_oool0
0ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?oo
ooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOoo
ooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001koooo00?o09Woooooool04Oooo`80002?oooo001koooo00?o09Woooooool04Oooo`030000
oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2I
oooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo
08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo
017oool20000Soooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o
09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003ooooo
ool0S_ooo`00Noooo`03o`2Ioooooooo00Woool500000oooo`030000oooooooo08koool007_oool0
0ol0VOooooooo`0;oooo00<0003oooooool00oooo`030000oooooooo08koool007_oool00ol0VOoo
ooooo`0;oooo00<0003oooooool00oooo`<0002>oooo001koooo00?o09Woooooool02oooo`030000
oooooooo00?oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool02oooo`030000oooooooo
00?oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool02_ooo`800005oooo00<0003ooooo
ool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Wooooo
ool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_oo
o`00Noooo`03o`2Ioooooooo017oool20000Soooo`00Noooo`03o`2Ioooooooo017oool00`000?oo
ooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOoo
ooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0A
oooo0P0008ooool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2I
oooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo
08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo
017oool00`000?ooooooo`2>oooo001koooo00?o09Woooooool04Oooo`80002?oooo001koooo00?o
09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003ooooo
ool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>oooo001koooo00?o09Wooooo
ool04Oooo`030000oooooooo08koool007_oool00ol0VOooooooo`0Aoooo00<0003oooooool0S_oo
o`00Noooo`03o`2Ioooooooo017oool20000Soooo`00Noooo`03o`2Ioooooooo017oool00`000?oo
ooooo`2>oooo001koooo00?o09Woooooool04Oooo`030000oooooooo08koool007_oool00ol0VOoo
ooooo`0Aoooo00<0003oooooool0S_ooo`00Noooo`03o`2Ioooooooo017oool00`000?ooooooo`2>
oooo001koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00Noooo`03o`2I
oooo000000Woool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001koooo00?o09Woool0
00003?ooo`030000oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool0
07Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200000oooo`<00004
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Eoooo00<0003oooooool01oooo`040000oooooooo00001Oooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001Coool00`000?oo
ooooo`07oooo0`0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`00000Goooo00<0003oooooool02?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0
003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`<00003oooo0`0000;oool0
0`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.40095 .24721 L
.41127 .24721 L
.41696 .24721 L
.42237 .24721 L
.42482 .24721 L
.42617 .24721 L
.42744 .24721 L
.42816 .24721 L
s
.42816 .24721 m
.42828 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.16408 .24721 L
.17277 .24721 L
.18221 .24721 L
.18475 .24721 L
.18744 .24721 L
.18855 .24721 L
.18974 .24721 L
.19104 .12361 L
.19227 .12361 L
.20178 .12361 L
.22272 .12361 L
.26394 .12361 L
.30365 .12361 L
.34184 .12361 L
.38249 .12361 L
.40128 .12361 L
.41117 .12361 L
.42162 .12361 L
.42418 .12361 L
.42693 .12361 L
.42774 .12361 L
.42851 .12361 L
.4292 .24721 L
.42995 .24721 L
.43277 .24721 L
.44303 .24721 L
.4632 .24721 L
.50398 .24721 L
.54325 .24721 L
.581 .24721 L
.6212 .24721 L
.65989 .24721 L
.70103 .24721 L
.74065 .24721 L
.77876 .24721 L
.81932 .24721 L
.85837 .24721 L
.89987 .24721 L
.93985 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00@OooocX0I_l01000001Vo`1Vo`0000_oool0
0`000?ooooooo`02oooo0`0008koool0047oool00`1Vooooooooo`0aoooo100000;oool010000?oo
o`1Vo`0000Woool200001Oooo`030000oooooooo08koool0047oool00`1Vooooooooo`0goooo00@0
003oool0I_l00009oooo00<0003oooooool01?ooo`030000oooooooo08koool0047oool00`1Voooo
ooooo`0hoooo0P0000[oool300001?ooo`030000oooooooo08koool0047oool00`1Vooooooooo`0i
oooo00<0I_ooooooool03oooo`030000oooooooo08koool0047oool00`1Vooooooooo`0ioooo00<0
I_ooooooool03oooo`030000oooooooo08koool0047oool00`1Vooooooooo`0ioooo00<0I_oooooo
ool03oooo`030000oooooooo08koool0047oool00`1Vooooooooo`0ioooo00<0I_ooooooool03ooo
o`80002?oooo0011oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>
oooo0011oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo0011
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo0011oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo0011oooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo0011oooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo00ooool20000Soooo`00@Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0?
oooo00<0003oooooool0S_ooo`00@Oooo`0306Kooooooooo03Woool00`1Vooooooooo`0?oooo00<0
003oooooool0S_ooo`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003ooooo
ool0S_ooo`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003oooooool0S_oo
o`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00@?oo
o`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo0P0008ooool0043oool00`1Vooooooooo`0j
oooo00<0I_ooooooool03oooo`030000oooooooo08koool001Woool300009?ooo`0306Kooooooooo
017oool400009Oooo`0306Kooooooooo00ooool00`000?ooooooo`0goooo100003_oool300005Ooo
o`006_ooo`030000oooooooo02?oool00`1Vooooooooo`0Aoooo00<0003oooooool09_ooo`0306Ko
oooooooo00ooool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool500009?ooo`0306Kooooooooo01;oool00`000?ooooooo`0Uoooo00<0I_ooooooool03ooo
o`030000oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000
oooooooo00009Oooo`0306Kooooooooo00_oool400001?ooo`030000oooooooo02Coool00`1Voooo
ooooo`0?oooo00<0003oooooool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool0
01Soool00`000?ooo`00000Uoooo00<0I_ooooooool04Oooo`040000oooooooo00009Oooo`0306Ko
oooooooo00ooool20000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool2
00009Oooo`0306Kooooooooo01;oool200009_ooo`0306Kooooooooo00ooool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0
003oooooool0S_ooo`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003ooooo
ool0S_ooo`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003oooooool0S_oo
o`00@?ooo`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00@?oo
o`0306Kooooooooo03[oool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`004?ooool0000A
oooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02Ooo
o`04o`2Ioooooooo00003_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`00OOooo`03o`2Ioooooooo
00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool0
07goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool0
0`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`80002?oooo001moooo00?o09Wooooo
ool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_oo
o`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03ooo
o`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOoo
o`03o`2Ioooooooo00ooool20000Soooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>
oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?
oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001m
oooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0
003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool20000Soooo`00OOooo`03o`2Ioooooooo
00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool0
07goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool0
0`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool0
0ol0VOooooooo`0?oooo0P0008ooool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_oo
o`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03ooo
o`030000oooooooo08koool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`2>
oooo001koooo00@0003ooooo09T00008oooo00@0003oooooool00004oooo00<0003oooooool0S_oo
o`00Noooo`040000ooooo`2I00002oooo`030000oooooooo00;oool30000S_ooo`00Noooo`040000
ooooo`2I00002Oooo`800005oooo00<0003oooooool0S_ooo`00Noooo`040000ooooo`2I00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001loooo0P0000[oool300001?ooo`030000
oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2I
oooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`80002?oooo001m
oooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0
003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o
09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003ooooo
ool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Wooooo
ool03oooo`80002?oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool0
0ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOoo
ooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool20000Soooo`00OOoo
o`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000
oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2I
oooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo
08koool007goool00ol0VOooooooo`0?oooo0P0008ooool007goool00ol0VOooooooo`0?oooo00<0
003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o
09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`07oooo1@0000?oool0
0`000?ooooooo`2>oooo001moooo00?o09Woooooool02Oooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo001moooo00?o09Woooooool02Oooo`030000oooooooo00?oool30000S_ooo`00OOoo
o`03o`2Ioooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00OOooo`03o`2I
oooooooo00Woool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo
00Soool200001Oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003ooooo
ool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Wooooo
ool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo0P0008ooool007goool0
0ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOoo
ooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>
oooo001moooo00?o09Woooooool03oooo`80002?oooo001moooo00?o09Woooooool03oooo`030000
oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2I
oooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo
08koool007goool00ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo
00ooool20000Soooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o
09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo00<0003ooooo
ool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?ooooooo`2>oooo001moooo00?o09Wooooo
ool03oooo`030000oooooooo08koool007goool00ol0VOooooooo`0?oooo0P0008ooool007goool0
0ol0VOooooooo`0?oooo00<0003oooooool0S_ooo`00OOooo`03o`2Ioooooooo00ooool00`000?oo
ooooo`2>oooo001moooo00?o09Woooooool03oooo`030000oooooooo08koool007goool00ol0VOoo
ooooo`0?oooo00<0003oooooool0S_ooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000
oooooooo08koool007goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003ooooo
ool0S_ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0008koool007goool0
0`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?oo
o`D00002oooo0P0000?oool300001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo
00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_oo
o`030000oooooooo01Goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000Doooo00<0003oooooool01oooo`<00004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Ooool00`000?ooooooo`08oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.40095 .24721 L
.41127 .24721 L
.42237 .24721 L
.42781 .24721 L
.43049 .24721 L
.43179 .24721 L
.43298 .24721 L
.43413 .24721 L
s
.43413 .24721 m
.4343 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.16408 .24721 L
.18221 .24721 L
.18703 .24721 L
.18957 .24721 L
.19227 .24721 L
.19462 .24721 L
.19527 .24721 L
.19596 .24721 L
.19721 .12361 L
.19844 .12361 L
.1996 .12361 L
.20178 .12361 L
.22272 .12361 L
.26091 .12361 L
.30156 .12361 L
.34068 .12361 L
.38227 .12361 L
.40313 .12361 L
.41229 .12361 L
.42233 .12361 L
.42701 .12361 L
.42959 .12361 L
.43203 .12361 L
.43313 .12361 L
.4343 .12361 L
.43558 .24721 L
.43676 .24721 L
.44108 .24721 L
.46088 .24721 L
.49863 .24721 L
.53884 .24721 L
.57753 .24721 L
.61867 .24721 L
.65829 .24721 L
.6964 .24721 L
.73696 .24721 L
.776 .24721 L
.8175 .24721 L
.85748 .24721 L
.89595 .24721 L
.93687 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00@_ooocT0I_l01000001Vo`1Vo`0000_oool0
0`000?ooooooo`02oooo0`0008koool004;oool00`1Vooooooooo`0`oooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool004;oool00`1Vooooooooo`0foooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool004;oool00`1Voooo
ooooo`0goooo0P00000306Kooooooooo00Ooool300001?ooo`030000oooooooo08koool004;oool0
0`1Vooooooooo`0ioooo00<0I_ooooooool03_ooo`030000oooooooo08koool004;oool00`1Voooo
ooooo`0ioooo00<0I_ooooooool03_ooo`030000oooooooo08koool004;oool00`1Vooooooooo`0i
oooo00<0I_ooooooool03_ooo`030000oooooooo08koool004;oool00`1Vooooooooo`0ioooo00<0
I_ooooooool03_ooo`80002?oooo0012oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool0
0`000?ooooooo`2>oooo0012oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool00`000?oo
ooooo`2>oooo0012oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool00`000?ooooooo`2>
oooo0012oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool00`000?ooooooo`2>oooo0012
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00koool00`000?ooooooo`2>oooo0012oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00koool20000Soooo`00@_ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0>oooo00<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0>oooo00<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo03Woool00`1Vooooooooo`0>
oooo00<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0=oooo00<0
003oooooool0S_ooo`00@_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0=oooo00<0003ooooo
ool0S_ooo`00@_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0=oooo0P0008ooool004;oool0
0`1Vooooooooo`0joooo00<0I_ooooooool03Oooo`030000oooooooo08koool001Woool300009_oo
o`0306Kooooooooo00ooool400009oooo`0306Kooooooooo00goool00`000?ooooooo`0goooo1000
03_oool300005Oooo`006_ooo`030000oooooooo02Goool00`1Vooooooooo`0?oooo00<0003ooooo
ool0:?ooo`0306Kooooooooo00goool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000
oooooooo01Coool001Ooool500009_ooo`0306Kooooooooo013oool00`000?ooooooo`0Woooo00<0
I_ooooooool03Oooo`030000oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool4
00000_ooo`040000oooooooo00009oooo`0306Kooooooooo00Woool400001?ooo`030000oooooooo
02Koool00`1Vooooooooo`0=oooo00<0003oooooool0>Oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool00`000?ooo`00000Woooo00<0I_ooooooool03oooo`040000oooooooo
00009oooo`0306Kooooooooo00goool20000>?ooo`040000oooooooo0000>_ooo`030000oooo0000
01Koool001Woool200009oooo`0306Kooooooooo013oool20000:?ooo`0306Kooooooooo00goool0
0`000?ooooooo`0hoooo0P0003coool200005_ooo`00@_ooo`0306Kooooooooo03[oool00`1Voooo
ooooo`0=oooo00<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0=
oooo00<0003oooooool0S_ooo`00@_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0=oooo00<0
003oooooool0S_ooo`00@_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0=oooo00<0003ooooo
ool0S_ooo`00@_ooo`0306Kooooooooo03[oool00`1Vooooooooo`0=oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool02_ooo`03o`2Ioooo000000koool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool007koool0
0ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?oo
ooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOoo
ooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool20000Soooo`00O_oo
o`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000
oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2I
oooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo
08koool007koool00ol0VOooooooo`0>oooo0P0008ooool007koool00ol0VOooooooo`0>oooo00<0
003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o
09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003ooooo
ool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Wooooo
ool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo0P0008ooool007koool0
0ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?oo
ooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOoo
ooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>
oooo001noooo00?o09Woooooool03_ooo`80002?oooo001noooo00?o09Woooooool03_ooo`030000
oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2I
oooooooo00koool00`000?ooooooo`2>oooo001loooo0P000004o`2Ioooooooooooo0P0000Coool2
00001Oooo`030000oooooooo08koool007_oool010000?ooooooo`0000Soool010000?ooooooo`00
00Coool00`000?ooooooo`2>oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0002>oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool007coool2
000000?o09Woooooool01oooo`<00004oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo
00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool0
07koool00ol0VOooooooo`0>oooo0P0008ooool007koool00ol0VOooooooo`0>oooo00<0003ooooo
ool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Wooooo
ool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_oo
o`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_oo
o`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo0P0008ooool007koool00ol0VOoo
ooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>
oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>
oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001n
oooo00?o09Woooooool03_ooo`80002?oooo001noooo00?o09Woooooool03_ooo`030000oooooooo
08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo
00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool0
07koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool2
0000Soooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Wooooo
ool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_oo
o`00O_ooo`03o`2Ioooooooo00Koool500000oooo`030000oooooooo08koool007koool00ol0VOoo
ooooo`08oooo00<0003oooooool00oooo`030000oooooooo08koool007koool00ol0VOooooooo`08
oooo00<0003oooooool00oooo`<0002>oooo001noooo00?o09Woooooool02?ooo`030000oooooooo
00?oool00`000?ooooooo`2>oooo001noooo00?o09Woooooool02?ooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool01oooo`800005oooo00<0003oooooool0S_oo
o`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_oo
o`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_oo
o`03o`2Ioooooooo00koool20000Soooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>
oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>
oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001n
oooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo0P00
08ooool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo
00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool0
07koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool0
0`000?ooooooo`2>oooo001noooo00?o09Woooooool03_ooo`80002?oooo001noooo00?o09Wooooo
ool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_oo
o`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001noooo00?o09Woooooool03_oo
o`030000oooooooo08koool007koool00ol0VOooooooo`0>oooo00<0003oooooool0S_ooo`00O_oo
o`03o`2Ioooooooo00koool20000Soooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>
oooo001noooo00?o09Woooooool03_ooo`030000oooooooo08koool007koool00ol0VOooooooo`0>
oooo00<0003oooooool0S_ooo`00O_ooo`03o`2Ioooooooo00koool00`000?ooooooo`2>oooo001k
oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0S_ooo`00OOooo`030000o`2Ioooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`2>oooo001moooo00<0003o09Woool02_oo
o`030000oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOoo
o`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00oooo
ob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool0
0`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool200001?ooo`800004oooo0P00
00Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00@0003oooooool00002
oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo00;oool0
0`000?ooooooo`0Eoooo00<0003oooooool02_ooo`030000oooooooo00?oool00`000?ooooooo`02
oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000Doooo00<0003oooooool02?oo
o`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005ooo
o`030000oooooooo00Soool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool300000oooo`<00002oooo00<0003ooooo
ool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.40095 .24721 L
.41127 .24721 L
.42237 .24721 L
.42781 .24721 L
.43298 .24721 L
.43762 .24721 L
.43889 .24721 L
.43959 .24721 L
.44024 .24721 L
s
.44024 .24721 m
.44044 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.19227 .24721 L
.19721 .24721 L
.19939 .24721 L
.20054 .24721 L
.20178 .24721 L
.2031 .12361 L
.20433 .12361 L
.20704 .12361 L
.21274 .12361 L
.22272 .12361 L
.26394 .12361 L
.30365 .12361 L
.34184 .12361 L
.38249 .12361 L
.40128 .12361 L
.42162 .12361 L
.42704 .12361 L
.43277 .12361 L
.43766 .12361 L
.439 .12361 L
.43974 .12361 L
.44044 .12361 L
.44109 .24721 L
.44179 .24721 L
.44303 .24721 L
.4632 .24721 L
.50398 .24721 L
.54325 .24721 L
.581 .24721 L
.6212 .24721 L
.65989 .24721 L
.70103 .24721 L
.74065 .24721 L
.77876 .24721 L
.81932 .24721 L
.85837 .24721 L
.89987 .24721 L
.93985 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00A?ooocL0I_l01000001Vo`1Vo`000080I_l9
oooo00<0003oooooool00_ooo`<0002>oooo0014oooo00<0I_ooooooool0;_ooo`@00002oooo00H0
003oooooool0003oool0I_l7oooo0P0000Goool00`000?ooooooo`2>oooo0014oooo00<0I_oooooo
ool0=?ooo`060000oooooooo0000oooo06Ko1oooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo0014oooo00<0I_ooooooool0=Oooo`800002oooo00<0I_ooooooool01Oooo`<00004oooo00<0
003oooooool0S_ooo`00A?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0<oooo00<0003ooooo
ool0S_ooo`00A?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0<oooo00<0003oooooool0S_oo
o`00A?ooo`0306Kooooooooo03Woool00`1Vooooooooo`0<oooo00<0003oooooool0S_ooo`00A?oo
o`0306Kooooooooo03Woool00`1Vooooooooo`0<oooo0P0008ooool004Coool00`1Vooooooooo`0i
oooo00<0I_ooooooool03?ooo`030000oooooooo08koool004Coool00`1Vooooooooo`0ioooo00<0
I_ooooooool03?ooo`030000oooooooo08koool004Coool00`1Vooooooooo`0ioooo00<0I_oooooo
ool03?ooo`030000oooooooo08koool004Coool00`1Vooooooooo`0ioooo00<0I_ooooooool03?oo
o`030000oooooooo08koool004Coool00`1Vooooooooo`0ioooo00<0I_ooooooool03?ooo`030000
oooooooo08koool004Coool00`1Vooooooooo`0ioooo00<0I_ooooooool03?ooo`80002?oooo0014
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo0014oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_ooooooool0>_oo
o`0306Kooooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00coool20000Soooo`00@oooo`0306Kooooooooo03[oool00`1Vooooooooo`0<oooo00<0003ooooo
ool0S_ooo`006Oooo`<0000Woooo00<0I_ooooooool03_ooo`@0000Xoooo00<0I_ooooooool03?oo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool09_ooo`0306Ko
oooooooo00koool00`000?ooooooo`0Yoooo00<0I_ooooooool03?ooo`030000oooooooo03Ooool0
0`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000Woooo00<0I_ooooooool03ooo
o`030000oooooooo02Soool00`1Vooooooooo`0<oooo00<0003oooooool0>?ooo`030000oooooooo
03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool0000Xoooo00<0I_ooooooool02?oo
o`@00004oooo00<0003oooooool09oooo`0306Kooooooooo00coool00`000?ooooooo`0ioooo00<0
003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000002Soool00`1Voooo
ooooo`0>oooo00@0003oooooool0000Xoooo00<0I_ooooooool03?ooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000Xoooo00<0I_ooooooool03oooo`80000Y
oooo00<0I_ooooooool03?ooo`030000oooooooo03Soool20000??ooo`80000Foooo0013oooo00<0
I_ooooooool0>_ooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_ooooooool0>_oo
o`0306Kooooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00coool00`000?ooooooo`2>oooo0013oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00coool00`000?ooooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool05Oooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o
09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003ooooo
ool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Wooooo
ool03?ooo`80002?oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool0
0ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?oo
ooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool20000Soooo`00P?oo
o`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000
oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2I
oooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00coool20000Soooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o
09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003ooooo
ool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Wooooo
ool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool0
0ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?oo
ooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool007coool200000_oo
o`04o`2Ioooo000000001?ooo`800005oooo00<0003oooooool0S_ooo`00Noooo`060000oooooooo
0000ooooo`2I1_ooo`040000oooooooo00001?ooo`030000oooooooo08koool007_oool01P000?oo
ooooo`000?ooool0V@Woool00`000?ooooooo`02oooo0`0008koool007_oool01P000?ooooooo`00
0?ooool0V@Ooool200001Oooo`030000oooooooo08koool007_oool01P000?ooooooo`000?ooool0
V@Ooool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`800002oooo00?o09Wooooo
ool01Oooo`<00004oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?oo
ooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOoo
ooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?oo
o`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000
oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2I
oooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool00ol0VOooooooo`0<oooo00<0
003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o
09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003ooooo
ool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Wooooo
ool03?ooo`80002?oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool0
0ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?oo
ooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool20000Soooo`00P?oo
o`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000
oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2I
oooooooo00Coool500000oooo`030000oooooooo08koool0083oool00ol0VOooooooo`06oooo00<0
003oooooool00oooo`030000oooooooo08koool0083oool00ol0VOooooooo`06oooo00<0003ooooo
ool00oooo`<0002>oooo0020oooo00?o09Woooooool01_ooo`030000oooooooo00?oool00`000?oo
ooooo`2>oooo0020oooo00?o09Woooooool01_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool01Oooo`800005oooo00<0003oooooool0S_ooo`00P?ooo`03o`2I
oooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00coool20000Soooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o
09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003ooooo
ool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Wooooo
ool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo0P0008ooool0083oool0
0ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?oo
ooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOoo
ooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>
oooo0020oooo00?o09Woooooool03?ooo`80002?oooo0020oooo00?o09Woooooool03?ooo`030000
oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2I
oooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o09Woooooool03?ooo`030000oooooooo
08koool0083oool00ol0VOooooooo`0<oooo00<0003oooooool0S_ooo`00P?ooo`03o`2Ioooooooo
00coool20000Soooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo0020oooo00?o
09Woooooool03?ooo`030000oooooooo08koool0083oool00ol0VOooooooo`0<oooo00<0003ooooo
ool0S_ooo`00P?ooo`03o`2Ioooooooo00coool00`000?ooooooo`2>oooo001koooo1@000004o`2I
oooo000000001?ooo`800005oooo00<0003oooooool0S_ooo`00OOooo`040000ooooooooo`2I1_oo
o`040000oooooooo00001?ooo`030000oooooooo08koool007goool010000?ooooooool0V@Woool0
0`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool007goool0
0`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQ
oooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0
003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000Coool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`0:
oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?oo
o`030000oooooooo00Soool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Goooo00<0003oooooool02?ooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool05oooo`80000:oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.40095 .24721 L
.42237 .24721 L
.43215 .24721 L
.43755 .24721 L
.44021 .24721 L
.44268 .24721 L
.44498 .24721 L
.44627 .24721 L
s
.44627 .24721 m
.44644 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.19227 .24721 L
.20178 .24721 L
.20433 .24721 L
.20573 .24721 L
.20704 .24721 L
.20772 .24721 L
.20845 .12361 L
.20926 .12361 L
.21 .12361 L
.21274 .12361 L
.22272 .12361 L
.26243 .12361 L
.30062 .12361 L
.34126 .12361 L
.38039 .12361 L
.40037 .12361 L
.42198 .12361 L
.43212 .12361 L
.43767 .12361 L
.44037 .12361 L
.44284 .12361 L
.44393 .12361 L
.44511 .12361 L
.44623 .12361 L
.44726 .24721 L
.44835 .24721 L
.44956 .24721 L
.452 .24721 L
.46204 .24721 L
.50225 .24721 L
.54093 .24721 L
.58207 .24721 L
.6217 .24721 L
.65981 .24721 L
.70037 .24721 L
.73941 .24721 L
.78091 .24721 L
.82089 .24721 L
.85936 .24721 L
.90028 .24721 L
.93968 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00AOooocH0I_l01000001Vo`1Vo`0000<0I_l8
oooo00<0003oooooool00_ooo`<0002>oooo0015oooo00<0I_ooooooool0;Oooo`@00002oooo00@0
003oooooool00002oooo00<0I_ooooooool01?ooo`800005oooo00<0003oooooool0S_ooo`00AOoo
o`0306Kooooooooo03?oool010000?ooooooo`0000;oool00`1Vooooooooo`04oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool004Goool00`1Vooooooooo`0doooo0P0000?oool00`1Voooo
ooooo`04oooo0`0000Coool00`000?ooooooo`2>oooo0015oooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo00_oool00`000?ooooooo`2>oooo0015oooo00<0I_ooooooool0>Oooo`0306Kooooooooo
00_oool00`000?ooooooo`2>oooo0015oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00_oool0
0`000?ooooooo`2>oooo0015oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00_oool20000Sooo
o`00AOooo`0306Kooooooooo03Woool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00AOoo
o`0306Kooooooooo03Woool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00AOooo`0306Ko
oooooooo03Woool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00AOooo`0306Kooooooooo
03Woool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00AOooo`0306Kooooooooo03Woool0
0`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00AOooo`0306Kooooooooo03Woool00`1Voooo
ooooo`0;oooo0P0008ooool004Goool00`1Vooooooooo`0ioooo00<0I_ooooooool02oooo`030000
oooooooo08koool004Goool00`1Vooooooooo`0ioooo00<0I_ooooooool02oooo`030000oooooooo
08koool004Goool00`1Vooooooooo`0ioooo00<0I_ooooooool02oooo`030000oooooooo08koool0
04Goool00`1Vooooooooo`0joooo00<0I_ooooooool02_ooo`030000oooooooo08koool004Goool0
0`1Vooooooooo`0joooo00<0I_ooooooool02_ooo`030000oooooooo08koool004Goool00`1Voooo
ooooo`0joooo00<0I_ooooooool02_ooo`80002?oooo0015oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00[oool00`000?ooooooo`2>oooo000Ioooo0`0002Woool00`1Vooooooooo`0<oooo1000
02[oool00`1Vooooooooo`0:oooo00<0003oooooool0=oooo`@0000koooo0`0001Goool001[oool0
0`000?ooooooo`0Xoooo00<0I_ooooooool03?ooo`030000oooooooo02_oool00`1Vooooooooo`0:
oooo00<0003oooooool0=oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00
02Woool00`1Vooooooooo`0=oooo00<0003oooooool0:_ooo`0306Kooooooooo00[oool00`000?oo
ooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`00
02[oool00`1Vooooooooo`06oooo100000Coool00`000?ooooooo`0Yoooo00<0I_ooooooool02_oo
o`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0
003oool00000:_ooo`0306Kooooooooo00coool010000?ooooooo`0002[oool00`1Vooooooooo`0:
oooo0P0003Soool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0002[oool0
0`1Vooooooooo`0=oooo0P0002_oool00`1Vooooooooo`0:oooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool004Goool00`1Vooooooooo`0joooo00<0I_ooooooool02_ooo`030000oooooooo
08koool004Goool00`1Vooooooooo`0joooo00<0I_ooooooool02_ooo`030000oooooooo08koool0
04Goool00`1Vooooooooo`0joooo00<0I_ooooooool02_ooo`030000oooooooo08koool004Goool0
0`1Vooooooooo`0joooo00<0I_ooooooool02_ooo`030000oooooooo08koool004Goool00`1Voooo
ooooo`0joooo00<0I_ooooooool02_ooo`030000oooooooo08koool0013ooooo00004Oooo`005_oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?l0
VOooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0Eoooo0021oooo00?o09Woooooool02oooo`030000
oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2I
oooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo
08koool0087oool00ol0VOooooooo`0;oooo0P0008ooool0087oool00ol0VOooooooo`0;oooo00<0
003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o
09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003ooooo
ool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Wooooo
ool02oooo`80002?oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool0
0ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?oo
ooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>
oooo0021oooo00?o09Woooooool02oooo`80002?oooo0021oooo00?o09Woooooool02oooo`030000
oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2I
oooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo
08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo
00_oool20000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o
09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003ooooo
ool0S_ooo`00O?ooo`800003oooo00?o09T0000000001?ooo`800005oooo00<0003oooooool0S_oo
o`00Noooo`040000oooooooo00000_ooo`03o`2Ioooooooo00?oool010000?ooooooo`0000Coool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00002oooo00?o09Woooooool01_ooo`030000
oooooooo00;oool30000S_ooo`00Noooo`040000oooooooo00000_ooo`03o`2Ioooooooo00Coool2
00001Oooo`030000oooooooo08koool007_oool010000?ooooooo`0000;oool00ol0VOooooooo`04
oooo00<0003oooooool01?ooo`030000oooooooo08koool007coool200000oooo`03o`2Ioooooooo
00Coool300001?ooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003ooooo
ool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Wooooo
ool02oooo`80002?oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool0
0ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?oo
ooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>
oooo0021oooo00?o09Woooooool02oooo`80002?oooo0021oooo00?o09Woooooool02oooo`030000
oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2I
oooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo
08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo
00_oool20000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o
09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003ooooo
ool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Wooooo
ool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo0P0008ooool0087oool0
0ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?oo
ooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`03oooo1@0000?oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool01Oooo`030000
oooooooo00?oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool01Oooo`030000oooooooo
00?oool30000S_ooo`00POooo`03o`2Ioooooooo00Goool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00POooo`03o`2Ioooooooo00Goool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00POooo`03o`2Ioooooooo00Coool200001Oooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>
oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;
oooo0P0008ooool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2I
oooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo
08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo
00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`80002?oooo0021oooo00?o
09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003ooooo
ool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Wooooo
ool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_oo
o`00POooo`03o`2Ioooooooo00_oool20000Soooo`00POooo`03o`2Ioooooooo00_oool00`000?oo
ooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOoo
ooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2Ioooooooo00_oool00`000?ooooooo`2>
oooo0021oooo00?o09Woooooool02oooo`030000oooooooo08koool0087oool00ol0VOooooooo`0;
oooo0P0008ooool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00POooo`03o`2I
oooooooo00_oool00`000?ooooooo`2>oooo0021oooo00?o09Woooooool02oooo`030000oooooooo
08koool0087oool00ol0VOooooooo`0;oooo00<0003oooooool0S_ooo`00Noooo`D000001?ooool0
V@00000000Coool200001Oooo`030000oooooooo08koool007goool01@000?ooooooooooool0V@05
oooo00@0003oooooool00004oooo00<0003oooooool0S_ooo`00OOooo`050000ooooooooooooo`2I
00Soool00`000?ooooooo`02oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool0
0?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001e
oooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000Goool300000_oo
o`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02_ooo`040000oooooooo
00000_ooo`050000oooooooooooo000007Ooool007Coool00`000?ooooooo`02oooo00<0003ooooo
ool05Oooo`030000oooooooo00Ooool500001?ooo`030000oooooooo00;oool00`000?ooooooo`1d
oooo001eoooo00<0003oooooool01@0001Coool00`000?ooooooo`07oooo00@0003oooooool00003
oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005oooo`030000
oooooooo00Soool00`000?ooo`000003oooo00<0003oooooool00oooo`030000oooooooo07Goool0
07Koool00`000?ooooooo`0Goooo0P0000_oool200000oooo`<00002oooo00<0003oooooool0M_oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.40095 .24721 L
.42237 .24721 L
.43215 .24721 L
.43755 .24721 L
.44268 .24721 L
.44744 .24721 L
.44874 .24721 L
.45013 .24721 L
.45143 .24721 L
s
.45143 .24721 m
.45161 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20178 .24721 L
.20742 .24721 L
.21019 .24721 L
.2114 .24721 L
.21274 .24721 L
.21394 .24721 L
.21506 .12361 L
.21625 .12361 L
.21753 .12361 L
.22272 .12361 L
.26394 .12361 L
.30365 .12361 L
.34184 .12361 L
.38249 .12361 L
.42162 .12361 L
.4319 .12361 L
.43731 .12361 L
.44303 .12361 L
.44804 .12361 L
.44941 .12361 L
.45088 .12361 L
.45159 .12361 L
.45227 .12361 L
.45353 .24721 L
.4547 .24721 L
.45594 .24721 L
.45816 .24721 L
.4632 .24721 L
.50095 .24721 L
.54115 .24721 L
.57984 .24721 L
.62098 .24721 L
.66061 .24721 L
.69871 .24721 L
.73927 .24721 L
.77832 .24721 L
.81982 .24721 L
.8598 .24721 L
.89827 .24721 L
.93918 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Aooooc@0I_l01000001Vo`1Vo`0000D0I_l6
oooo00<0003oooooool00_ooo`<0002>oooo0017oooo00<0I_ooooooool0:oooo`@00002oooo00@0
003oooooool00004oooo00<0I_ooooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00Aooo
o`0306Kooooooooo037oool010000?ooooooo`0000Coool00`1Vooooooooo`02oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool004Ooool00`1Vooooooooo`0boooo0P0000Goool00`1Voooo
ooooo`02oooo0`0000Coool00`000?ooooooo`2>oooo0017oooo00<0I_ooooooool0>Oooo`0306Ko
oooooooo00Woool00`000?ooooooo`2>oooo0017oooo00<0I_ooooooool0>Oooo`0306Kooooooooo
00Woool00`000?ooooooo`2>oooo0017oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Woool0
0`000?ooooooo`2>oooo0017oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Woool20000Sooo
o`00Aoooo`0306Kooooooooo03Woool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Aooo
o`0306Kooooooooo03Woool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Aoooo`0306Ko
oooooooo03Woool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Aoooo`0306Kooooooooo
03Woool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Aoooo`0306Kooooooooo03Woool0
0`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Aoooo`0306Kooooooooo03Woool00`1Voooo
ooooo`09oooo0P0008ooool004Ooool00`1Vooooooooo`0ioooo00<0I_ooooooool02Oooo`030000
oooooooo08koool004Ooool00`1Vooooooooo`0ioooo00<0I_ooooooool02Oooo`030000oooooooo
08koool004Koool00`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo08koool0
04Koool00`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo08koool004Koool0
0`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo08koool004Koool00`1Voooo
ooooo`0joooo00<0I_ooooooool02Oooo`80002?oooo0016oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00Woool00`000?ooooooo`2>oooo000Ioooo0`0002[oool00`1Vooooooooo`0;oooo1000
02_oool00`1Vooooooooo`09oooo00<0003oooooool0=oooo`@0000koooo0`0001Goool001[oool0
0`000?ooooooo`0Yoooo00<0I_ooooooool02oooo`030000oooooooo02coool00`1Vooooooooo`09
oooo00<0003oooooool0=oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00
02[oool00`1Vooooooooo`0<oooo00<0003oooooool0:oooo`0306Kooooooooo00Woool00`000?oo
ooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`00
02_oool00`1Vooooooooo`05oooo100000Coool00`000?ooooooo`0Zoooo00<0I_ooooooool02Ooo
o`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0
003oool00000:oooo`0306Kooooooooo00_oool010000?ooooooo`0002_oool00`1Vooooooooo`09
oooo0P0003Soool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0002_oool0
0`1Vooooooooo`0<oooo0P0002coool00`1Vooooooooo`09oooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool004Koool00`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo
08koool004Koool00`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo08koool0
04Koool00`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo08koool004Koool0
0`1Vooooooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo08koool004Koool00`1Voooo
ooooo`0joooo00<0I_ooooooool02Oooo`030000oooooooo08koool0013ooooo00004Oooo`005_oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool010000?oo
ooooool0V@_oool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo01Goool008?oool00ol0VOooooooo`09oooo00<0
003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool0
0`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool0
0ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?oo
ooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOoo
ooooo`09oooo0P0008ooool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Pooo
o`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000
oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2I
oooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo
08koool008?oool00ol0VOooooooo`09oooo0P0008ooool008?oool00ol0VOooooooo`09oooo00<0
003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Wooooo
ool02Oooo`80002?oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool0
0ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?oo
ooooo`2>oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool0S_ooo`00Nooo
o`040000oooooooo00001?ooo`05o`2Ioooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool0S_ooo`00Noooo`040000oooooooo00001?ooo`03o`2Ioooooooo00Coool00`000?oo
ooooo`02oooo0`0008koool007_oool010000?ooooooo`0000Coool00ol0VOooooooo`02oooo0P00
00Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00004oooo00?o09Woooooool00_oo
o`030000oooooooo00Coool00`000?ooooooo`2>oooo001loooo0P0000Goool00ol0VOooooooo`02
oooo0`0000Coool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo
08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Wooooo
ool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_oo
o`00Poooo`03o`2Ioooooooo00Woool20000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?oo
ooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOoo
ooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>
oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09
oooo0P0008ooool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2I
oooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo
08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`80002?oooo0023oooo00?o
09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003ooooo
ool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00Co09Wooooo
ooooool500000oooo`030000oooooooo08koool008?oool00ol0VOooooooo`03oooo00<0003ooooo
ool00oooo`030000oooooooo08koool008?oool00ol0VOooooooo`03oooo00<0003oooooool00ooo
o`<0002>oooo0023oooo00?o09Woooooool00oooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo0023oooo00?o09Woooooool00oooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0023
oooo00?o09Woooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool0
08?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool2
0000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Wooooo
ool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_oo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Ooo
o`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo0P0008ooool008?oool00ol0VOoo
ooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>
oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09
oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023
oooo00?o09Woooooool02Oooo`80002?oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo
08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo
00Woool00`000?ooooooo`2>oooo0023oooo00?o09Woooooool02Oooo`030000oooooooo08koool0
08?oool00ol0VOooooooo`09oooo00<0003oooooool0S_ooo`00Poooo`03o`2Ioooooooo00Woool2
0000Soooo`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo0023oooo00?o09Wooooo
ool02Oooo`030000oooooooo08koool008?oool00ol0VOooooooo`09oooo00<0003oooooool0S_oo
o`00Poooo`03o`2Ioooooooo00Woool00`000?ooooooo`2>oooo001koooo1@0000;oool200001?oo
o`800005oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00?oool01Ol0VOoooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo08koool007goool00`000?ooooooo`03
oooo00?o09Woooooool01?ooo`030000oooooooo00;oool30000S_ooo`00OOooo`030000oooooooo
00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P00
00[oool30000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000
oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo
07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0<oooo1@0000;oool2
00001Oooo`<00002oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02_ooo`050000
oooooooooooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000
oooooooo00Ooool500000oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500005?oo
o`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000005oooo`030000oooooooo00Soool00`000?ooo`000003oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo01Ooool200002oooo`800002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.40095 .24721 L
.42237 .24721 L
.43215 .24721 L
.44268 .24721 L
.44778 .24721 L
.45262 .24721 L
.45473 .24721 L
.45697 .24721 L
.45826 .24721 L
s
.45826 .24721 m
.45844 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20178 .24721 L
.20742 .24721 L
.21274 .24721 L
.21753 .24721 L
.21884 .24721 L
.21955 .24721 L
.22022 .24721 L
.22141 .12361 L
.22272 .12361 L
.26149 .12361 L
.30271 .12361 L
.34242 .12361 L
.38061 .12361 L
.40193 .12361 L
.42126 .12361 L
.43094 .12361 L
.44141 .12361 L
.44622 .12361 L
.45129 .12361 L
.45563 .12361 L
.45682 .12361 L
.45809 .12361 L
.45929 .24721 L
.46039 .24721 L
.50023 .24721 L
.53856 .24721 L
.57935 .24721 L
.61861 .24721 L
.65636 .24721 L
.69657 .24721 L
.73525 .24721 L
.77639 .24721 L
.81602 .24721 L
.85413 .24721 L
.89469 .24721 L
.93373 .24721 L
.97523 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00B?oooc<0I_l01000001Vo`1Vo`0000H0I_l5
oooo00<0003oooooool00_ooo`<0002>oooo0018oooo00<0I_ooooooool0:_ooo`@00002oooo00@0
003oooooool00005oooo00@0I_ooooooooooool200001Oooo`030000oooooooo08koool004Soool0
0`1Vooooooooo`0`oooo00@0003oooooool00005oooo00D0I_ooooooooooool000001_ooo`030000
oooooooo08koool004Soool00`1Vooooooooo`0aoooo0P0000Koool0101Vooooooooooooo`<00004
oooo00<0003oooooool0S_ooo`00B?ooo`0306Kooooooooo03Woool00`1Vooooooooo`08oooo00<0
003oooooool0S_ooo`00B?ooo`0306Kooooooooo03Woool00`1Vooooooooo`08oooo00<0003ooooo
ool0S_ooo`00B?ooo`0306Kooooooooo03Woool00`1Vooooooooo`08oooo00<0003oooooool0S_oo
o`00B?ooo`0306Kooooooooo03Woool00`1Vooooooooo`08oooo0P0008ooool004Soool00`1Voooo
ooooo`0ioooo00<0I_ooooooool02?ooo`030000oooooooo08koool004Soool00`1Vooooooooo`0i
oooo00<0I_ooooooool02?ooo`030000oooooooo08koool004Soool00`1Vooooooooo`0ioooo00<0
I_ooooooool02?ooo`030000oooooooo08koool004Soool00`1Vooooooooo`0ioooo00<0I_oooooo
ool02?ooo`030000oooooooo08koool004Soool00`1Vooooooooo`0ioooo00<0I_ooooooool02?oo
o`030000oooooooo08koool004Soool00`1Vooooooooo`0ioooo00<0I_ooooooool02?ooo`80002?
oooo0018oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo0018
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo0018oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo0018oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0>_oo
o`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00Ooool20000Soooo`00B?ooo`0306Kooooooooo03[oool00`1Vooooooooo`07oooo00<0
003oooooool0S_ooo`006Oooo`<0000/oooo00<0I_ooooooool02Oooo`@0000]oooo00<0I_oooooo
ool01oooo`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0:ooo
o`0306Kooooooooo00Woool00`000?ooooooo`0^oooo00<0I_ooooooool01oooo`030000oooooooo
03Ooool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000/oooo00<0I_oooooo
ool02_ooo`030000oooooooo02goool00`1Vooooooooo`07oooo00<0003oooooool0>?ooo`030000
oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool0000]oooo00<0I_oooooo
ool00oooo`@00004oooo00<0003oooooool0;?ooo`0306Kooooooooo00Ooool00`000?ooooooo`0i
oooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000002goool0
0`1Vooooooooo`09oooo00@0003oooooool0000]oooo00<0I_ooooooool01oooo`80000hoooo00@0
003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000]oooo00<0I_ooooooool02_oo
o`80000^oooo00<0I_ooooooool01oooo`030000oooooooo03Soool20000??ooo`80000Foooo0018
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo0018oooo00<0
I_ooooooool0>_ooo`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo0018oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0>_oo
o`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo0018oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00Ooool00`000?ooooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00D0003ooooooooooooo09T02_oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024
oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo
08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool0
08Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool2
0000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_oo
o`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?oo
o`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?oo
o`03o`2Ioooooooo00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024
oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P00
08ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool0
07coool200001?ooo`8000001?l0VOooooooooooo`800005oooo00<0003oooooool0S_ooo`00Nooo
o`040000oooooooo00001Oooo`04o`2Ioooooooo00000_ooo`030000oooooooo00;oool00`000?oo
ooooo`2>oooo001koooo00@0003oooooool00005oooo00?o09Woooooool00oooo`030000oooooooo
00;oool30000S_ooo`00Noooo`040000oooooooo00001Oooo`04o`2Ioooooooooooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00005oooo00Go09Woooooooooool000001_oo
o`030000oooooooo08koool007coool200001_ooo`04o`2Ioooooooooooo0`0000Coool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOoo
ooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool20000Soooo`00Q?oo
o`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000
oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2I
oooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo
08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o
09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003ooooo
ool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P0008ooool008Coool0
0ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOoo
ooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Woooooool02?ooo`030000
oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2I
oooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool01@0000?oool00`000?oo
ooooo`2>oooo0024oooo00?o09Woooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool00_ooo`030000oooooooo00?oool30000S_ooo`00Q?ooo`03o`2I
oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00Q?ooo`04o`2Ioooooooooooo0P00
00Goool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool0
08Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_oo
o`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?oo
o`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?oo
o`03o`2Ioooooooo00Soool20000Soooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>
oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08
oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024
oooo00?o09Woooooool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo0P00
08ooool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo
00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`030000oooooooo08koool0
08Coool00ol0VOooooooo`08oooo00<0003oooooool0S_ooo`00Q?ooo`03o`2Ioooooooo00Soool0
0`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?ooo`80002?oooo0024oooo00?o09Wooooo
ool02?ooo`030000oooooooo08koool008Coool00ol0VOooooooo`08oooo00<0003oooooool0S_oo
o`00Q?ooo`03o`2Ioooooooo00Soool00`000?ooooooo`2>oooo0024oooo00?o09Woooooool02?oo
o`030000oooooooo08koool007_oool500000_ooo`8000001?l0VOooooooooooo`800005oooo00<0
003oooooool0S_ooo`00OOooo`030000oooooooo00Coool01?l0VOooooooo`0000;oool00`000?oo
ooooo`02oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00Coool00ol0VOooooooo`03
oooo00<0003oooooool00_ooo`<0002>oooo001moooo00<0003oooooool02?ooo`80002Foooo001m
oooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003o
oooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOoo
o`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800004oooo0P0000Coool2
00001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`00
00;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_oo
o`030000oooooooo01Goool00`000?ooooooo`09oooo00<0003oooooool01?ooo`030000oooooooo
00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001Coool00`000?ooooooo`0:
oooo00@0003oooooooooool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`00000Goooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1eoooo001foooo00<0003oooooool05oooo`80000:oooo0P0000Coool300000_oo
o`030000oooooooo07Koool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.44268 .24721 L
.45262 .24721 L
.45734 .24721 L
.46172 .24721 L
.46283 .24721 L
.46388 .24721 L
s
.46388 .24721 m
.46406 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.21345 .24721 L
.21786 .24721 L
.22037 .24721 L
.22272 .24721 L
.22387 .24721 L
.22496 .24721 L
.22623 .12361 L
.22738 .12361 L
.23233 .12361 L
.24276 .12361 L
.26171 .12361 L
.2999 .12361 L
.34055 .12361 L
.37968 .12361 L
.42126 .12361 L
.44213 .12361 L
.45128 .12361 L
.45613 .12361 L
.4588 .12361 L
.46133 .12361 L
.4625 .12361 L
.46376 .12361 L
.46441 .24721 L
.46513 .24721 L
.4664 .24721 L
.47102 .24721 L
.48007 .24721 L
.49988 .24721 L
.54008 .24721 L
.57877 .24721 L
.61991 .24721 L
.65953 .24721 L
.69764 .24721 L
.7382 .24721 L
.77725 .24721 L
.81874 .24721 L
.85873 .24721 L
.89719 .24721 L
.93811 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00B_oooc40I_l01000001Vo`1Vo`0000P0I_l3
oooo00<0003oooooool00_ooo`<0002>oooo001:oooo00<0I_ooooooool0:?ooo`@00002oooo00@0
003oooooool00007oooo00@0I_ooool000000005oooo00<0003oooooool0S_ooo`00B_ooo`0306Ko
oooooooo02koool010000?ooooooo`0000Ooool00`1Vooooo`000006oooo00<0003oooooool0S_oo
o`00B_ooo`0306Kooooooooo02ooool200002?ooo`0306Kooooo000000800004oooo00<0003ooooo
ool0S_ooo`00B_ooo`0306Kooooooooo03Woool00`1Vooooooooo`06oooo00<0003oooooool0S_oo
o`00B_ooo`0306Kooooooooo03Woool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00B_oo
o`0306Kooooooooo03Woool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00B_ooo`0306Ko
oooooooo03Woool00`1Vooooooooo`06oooo0P0008ooool004[oool00`1Vooooooooo`0ioooo00<0
I_ooooooool01_ooo`030000oooooooo08koool004[oool00`1Vooooooooo`0ioooo00<0I_oooooo
ool01_ooo`030000oooooooo08koool004[oool00`1Vooooooooo`0ioooo00<0I_ooooooool01_oo
o`030000oooooooo08koool004[oool00`1Vooooooooo`0ioooo00<0I_ooooooool01_ooo`030000
oooooooo08koool004[oool00`1Vooooooooo`0ioooo00<0I_ooooooool01_ooo`030000oooooooo
08koool004[oool00`1Vooooooooo`0ioooo00<0I_ooooooool01_ooo`80002?oooo001:oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001:oooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0>_oo
o`0306Kooooooooo00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Koool2
0000Soooo`00BOooo`0306Kooooooooo03[oool00`1Vooooooooo`06oooo00<0003oooooool0S_oo
o`006Oooo`<0000]oooo00<0I_ooooooool02?ooo`@0000^oooo00<0I_ooooooool01_ooo`030000
oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0;?ooo`0306Kooooooooo
00Soool00`000?ooooooo`0_oooo00<0I_ooooooool01_ooo`030000oooooooo03Ooool00`000?oo
ooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000]oooo00<0I_ooooooool02Oooo`030000
oooooooo02koool00`1Vooooooooo`06oooo00<0003oooooool0>?ooo`030000oooooooo03Woool5
00005Oooo`004Oooo`@00002oooo00@0003oooooool0000^oooo00<0I_ooooooool00_ooo`@00004
oooo00<0003oooooool0;Oooo`0306Kooooooooo00Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000002koool00`1Vooooooooo`08
oooo00@0003oooooool0000^oooo00<0I_ooooooool01_ooo`80000hoooo00@0003oooooool0000j
oooo00<0003oool000005_ooo`006Oooo`80000^oooo00<0I_ooooooool02Oooo`80000_oooo00<0
I_ooooooool01_ooo`030000oooooooo03Soool20000??ooo`80000Foooo0019oooo00<0I_oooooo
ool0>_ooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0>_oo
o`0306Kooooooooo00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0>_ooo`0306Ko
oooooooo00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0>_ooo`0306Kooooooooo
00Koool00`000?ooooooo`2>oooo0019oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Koool0
0`000?ooooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool00oooo`03o`2Ioooooooo00Koool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo01Goool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_oo
o`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_oo
o`03o`2Ioooooooo00Koool20000Soooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>
oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06
oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026
oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo0P00
08ooool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo
00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool0
08Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool0
0`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool0
0ol0VOooooooo`06oooo0P0008ooool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_oo
o`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_oo
o`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`80002?
oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06
oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo001l
oooo0P0000Coool200000_ooo`04o`2Ioooo000000001Oooo`030000oooooooo08koool007_oool0
10000?ooooooo`0000Ooool01Ol0V@000?ooooooo`000004oooo00<0003oooooool0S_ooo`00Nooo
o`040000oooooooo00001oooo`05o`2Ioooooooooooo000000Coool30000S_ooo`00Noooo`040000
oooooooo00001oooo`04o`2Ioooo000000001Oooo`030000oooooooo08koool007_oool010000?oo
ooooo`0000Ooool00ol0VOooo`000006oooo00<0003oooooool0S_ooo`00O?ooo`800008oooo00?o
09Woool000000P0000Coool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000
oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2I
oooooooo00Koool20000Soooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026
oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0
003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o
09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0003ooooo
ool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool20000Soooo`00Q_ooo`03o`2Ioooooooo00Koool0
0`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool0
0ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?oo
ooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOoo
ooooo`06oooo0P0008ooool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_oo
o`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000
oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2I
oooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`80002?oooo0026
oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0
003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o
09T0000000000`0000?oool00`000?ooooooo`2>oooo0026oooo00Co09Woooooool00005oooo00<0
003oooooool0S_ooo`00Q_ooo`04o`2Ioooooooo00001Oooo`<0002>oooo0026oooo00Co09Wooooo
ool00005oooo00<0003oooooool0S_ooo`00Q_ooo`04o`2Ioooooooo00001Oooo`030000oooooooo
08koool008Koool01?l0VOooo`00000000Goool00`000?ooooooo`2>oooo0026oooo00?o09Wooooo
ool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_oo
o`80002?oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOoo
ooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>
oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06
oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool20000Soooo`00Q_ooo`03o`2I
oooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo
08koool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo
00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool0
08Koool00ol0VOooooooo`06oooo0P0008ooool008Koool00ol0VOooooooo`06oooo00<0003ooooo
ool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Wooooo
ool01_ooo`030000oooooooo08koool008Koool00ol0VOooooooo`06oooo00<0003oooooool0S_oo
o`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>oooo0026oooo00?o09Woooooool01_oo
o`80002?oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool008Koool00ol0VOoo
ooooo`06oooo00<0003oooooool0S_ooo`00Q_ooo`03o`2Ioooooooo00Koool00`000?ooooooo`2>
oooo0026oooo00?o09Woooooool01_ooo`030000oooooooo08koool007_oool500000_ooo`800002
oooo00Co09Woool000000005oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00Koool0
1Ol0V@000?ooooooo`000004oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00Koool0
1Ol0VOooooooooooo`000004oooo0`0008koool007goool00`000?ooooooo`08oooo0P0009Koool0
07goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400001Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool0
0`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?oo
ooooo`09oooo00<0003oooooool00oooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00005?ooo`030000oooooooo00[oool01@000?ooooooooooo`00001joooo001hoooo00D0003ooooo
ooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.44268 .24721 L
.45262 .24721 L
.46172 .24721 L
.46618 .24721 L
.46741 .24721 L
.46871 .24721 L
.46994 .24721 L
s
.46994 .24721 m
.47011 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.21345 .24721 L
.22272 .24721 L
.22738 .24721 L
.22974 .24721 L
.23038 .24721 L
.23107 .24721 L
.23233 .12361 L
.23302 .12361 L
.23366 .12361 L
.23512 .12361 L
.23778 .12361 L
.24276 .12361 L
.26171 .12361 L
.30084 .12361 L
.34242 .12361 L
.38249 .12361 L
.42104 .12361 L
.44059 .12361 L
.45094 .12361 L
.45664 .12361 L
.46204 .12361 L
.46716 .12361 L
.46856 .12361 L
.46933 .12361 L
.47005 .12361 L
.47132 .24721 L
.472 .24721 L
.47272 .24721 L
.48246 .24721 L
.50153 .24721 L
.54267 .24721 L
.58229 .24721 L
.6204 .24721 L
.66096 .24721 L
.70001 .24721 L
.74151 .24721 L
.78149 .24721 L
.81995 .24721 L
.86087 .24721 L
.90028 .24721 L
.93816 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Booooc00I_l01000001Vo`1Vo`0000T0I_l2
oooo00<0003oooooool00_ooo`<0002>oooo001;oooo00<0I_ooooooool09oooo`@00002oooo00@0
003oooooool00008oooo00<0I_l0000000001Oooo`030000oooooooo08koool004_oool00`1Voooo
ooooo`0]oooo00@0003oooooool00008oooo00<0I_l0003oool01Oooo`030000oooooooo08koool0
04_oool00`1Vooooooooo`0^oooo0P0000Woool0101Vo`000000000000Coool00`000?ooooooo`2>
oooo001;oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001;
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001;oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001;oooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00Goool20000Soooo`00Boooo`0306Kooooooooo03Woool00`1Voooo
ooooo`05oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03Woool00`1Vooooooooo`05
oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03Woool00`1Vooooooooo`05oooo00<0
003oooooool0S_ooo`00Boooo`0306Kooooooooo03Woool00`1Vooooooooo`05oooo00<0003ooooo
ool0S_ooo`00Boooo`0306Kooooooooo03Woool00`1Vooooooooo`05oooo00<0003oooooool0S_oo
o`00Boooo`0306Kooooooooo03Woool00`1Vooooooooo`05oooo0P0008ooool004_oool00`1Voooo
ooooo`0ioooo00<0I_ooooooool01Oooo`030000oooooooo08koool004_oool00`1Vooooooooo`0i
oooo00<0I_ooooooool01Oooo`030000oooooooo08koool004_oool00`1Vooooooooo`0ioooo00<0
I_ooooooool01Oooo`030000oooooooo08koool004_oool00`1Vooooooooo`0joooo00<0I_oooooo
ool01?ooo`030000oooooooo08koool004_oool00`1Vooooooooo`0joooo00<0I_ooooooool01?oo
o`030000oooooooo08koool004_oool00`1Vooooooooo`0joooo00<0I_ooooooool01?ooo`80002?
oooo001;oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00Coool00`000?ooooooo`2>oooo000I
oooo0`0002ooool00`1Vooooooooo`06oooo1000033oool00`1Vooooooooo`04oooo00<0003ooooo
ool0=oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0^oooo00<0I_ooooooool01_oo
o`030000oooooooo037oool00`1Vooooooooo`04oooo00<0003oooooool0=oooo`030000oooooooo
03goool00`000?ooooooo`0Doooo000Goooo1@0002ooool00`1Vooooooooo`07oooo00<0003ooooo
ool0<?ooo`0306Kooooooooo00Coool00`000?ooooooo`0hoooo00<0003oooooool0>Oooo`D0000E
oooo000Aoooo100000;oool010000?ooooooo`00033oool00`1Vooooooooo`0400001?ooo`030000
oooooooo02ooool00`1Vooooooooo`04oooo00<0003oooooool0>Oooo`030000oooooooo03Soool0
10000?ooooooo`0001Koool001Soool00`000?ooo`00000`oooo00<0I_ooooooool01_ooo`040000
oooooooo0000<?ooo`0306Kooooooooo00Coool20000>?ooo`040000oooooooo0000>_ooo`030000
oooo000001Koool001Woool20000<?ooo`0306Kooooooooo00Ooool20000<Oooo`0306Kooooooooo
00Coool00`000?ooooooo`0hoooo0P0003coool200005_ooo`00Boooo`0306Kooooooooo03[oool0
0`1Vooooooooo`04oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03[oool00`1Voooo
ooooo`04oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03[oool00`1Vooooooooo`04
oooo00<0003oooooool0S_ooo`00Boooo`0306Kooooooooo03[oool00`1Vooooooooo`04oooo00<0
003oooooool0S_ooo`00Boooo`0306Kooooooooo03[oool00`1Vooooooooo`04oooo00<0003ooooo
ool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00Coool00ol0VOooooooo`05oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0Eoooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool0
0ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOoo
ooooo`05oooo0P0008ooool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`80002?oooo0027
oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003ooooo
ool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`80002?oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool0
0ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool20000Soooo`00Qooo
o`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00O?ooo`800004
oooo0P0000?oool00ol0V@0000000005oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo
00002?ooo`040000oooooooo00001?ooo`030000oooooooo08koool007_oool010000?ooooooo`00
00Soool01?l0VOooooooo`0000Coool30000S_ooo`00Noooo`040000oooooooo00002?ooo`03o`2I
0000000000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00?o09T0003o
ool01Oooo`030000oooooooo08koool007coool200002Oooo`04o`2I0000000000001?ooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`80002?oooo0027
oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003ooooo
ool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Wooooo
ool01Oooo`80002?oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool0
0ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOoo
ooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool20000Soooo`00Qooo
o`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000
oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2I
oooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo
08koool008Ooool00ol0VOooooooo`05oooo0P0008ooool008Ooool00ol0VOooooooo`05oooo00<0
003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o
09Woooooool01Oooo`030000oooooooo08koool008Ooool500000oooo`030000oooooooo08koool0
08Ooool00ol0VOooo`000005oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooo000000Goool3
0000S_ooo`00Qoooo`03o`2Ioooo000000Goool00`000?ooooooo`2>oooo0027oooo00?o09Woool0
00001Oooo`030000oooooooo08koool008Ooool00ol0V@0000000005oooo00<0003oooooool0S_oo
o`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2Ioooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>
oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05
oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027
oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo0P00
08ooool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo
00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool0
08Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool0
0`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Oooo`80002?oooo0027oooo00?o09Wooooo
ool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_oo
o`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo0027oooo00?o09Woooooool01Ooo
o`030000oooooooo08koool008Ooool00ol0VOooooooo`05oooo00<0003oooooool0S_ooo`00Qooo
o`03o`2Ioooooooo00Goool20000Soooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>
oooo0027oooo00?o09Woooooool01Oooo`030000oooooooo08koool008Ooool00ol0VOooooooo`05
oooo00<0003oooooool0S_ooo`00Qoooo`03o`2Ioooooooo00Goool00`000?ooooooo`2>oooo001k
oooo1@0000;oool200000oooo`03o`2I0000000000Goool00`000?ooooooo`2>oooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo08koool007goool00`000?oo
ooooo`07oooo00Co09Woooooool00004oooo0`0008koool007goool00`000?ooooooo`08oooo0P00
09Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`00
09Goool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1f
oooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001e
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P0000?oool4
00000oooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool01oooo`030000
oooooooo00?oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0003ooooo
ool00_ooo`030000oooooooo01Goool00`000?ooooooo`08oooo00<0003oooooool01Oooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001Coool00`000?oo
ooooo`09oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000001Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003ooooo
ool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool200001?oo
o`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.44268 .24721 L
.45262 .24721 L
.46172 .24721 L
.46618 .24721 L
.47106 .24721 L
.47329 .24721 L
.47451 .24721 L
.47567 .24721 L
s
.47567 .24721 m
.47583 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.22272 .24721 L
.23233 .24721 L
.23496 .24721 L
.2364 .24721 L
.23711 .24721 L
.23775 .24721 L
.2389 .12361 L
.24014 .12361 L
.24276 .12361 L
.26171 .12361 L
.30142 .12361 L
.33961 .12361 L
.38026 .12361 L
.41939 .12361 L
.43936 .12361 L
.44987 .12361 L
.46097 .12361 L
.46577 .12361 L
.47092 .12361 L
.47243 .12361 L
.47387 .12361 L
.47516 .12361 L
.47589 .12361 L
.47656 .24721 L
.47778 .24721 L
.47912 .24721 L
.48184 .24721 L
.50104 .24721 L
.54124 .24721 L
.57993 .24721 L
.62107 .24721 L
.66069 .24721 L
.6988 .24721 L
.73936 .24721 L
.7784 .24721 L
.8199 .24721 L
.85988 .24721 L
.89835 .24721 L
.93927 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00COooobh0I_l01000001Vo`1Vo`0000/0I_l0
0`000?ooooooo`02oooo0`0008koool004goool00`1Vooooooooo`0Uoooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool004goool00`1Vooooooooo`0[oooo00@0
003oooooool00009oooo00<00000I_ooool01?ooo`030000oooooooo08koool004goool00`1Voooo
ooooo`0/oooo0P0000[oool300001?ooo`030000oooooooo08koool004goool00`1Vooooooooo`0i
oooo00<0I_ooooooool00oooo`030000oooooooo08koool004goool00`1Vooooooooo`0ioooo00<0
I_ooooooool00oooo`030000oooooooo08koool004goool00`1Vooooooooo`0ioooo00<0I_oooooo
ool00oooo`030000oooooooo08koool004goool00`1Vooooooooo`0ioooo00<0I_ooooooool00ooo
o`80002?oooo001=oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>
oooo001=oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001=
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001=oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001=oooo00<0I_oooooo
ool0>Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001=oooo00<0I_ooooooool0>Ooo
o`0306Kooooooooo00?oool20000Soooo`00COooo`0306Kooooooooo03Woool00`1Vooooooooo`03
oooo00<0003oooooool0S_ooo`00COooo`0306Kooooooooo03Woool00`1Vooooooooo`03oooo00<0
003oooooool0S_ooo`00C?ooo`0306Kooooooooo03[oool00`1Vooooooooo`03oooo00<0003ooooo
ool0S_ooo`00C?ooo`0306Kooooooooo03[oool00`1Vooooooooo`03oooo00<0003oooooool0S_oo
o`00C?ooo`0306Kooooooooo03[oool00`1Vooooooooo`03oooo00<0003oooooool0S_ooo`00C?oo
o`0306Kooooooooo03[oool00`1Vooooooooo`03oooo0P0008ooool004coool00`1Vooooooooo`0j
oooo00<0I_ooooooool00oooo`030000oooooooo08koool001Woool30000<?ooo`0306Kooooooooo
00Goool40000<Oooo`0306Kooooooooo00?oool00`000?ooooooo`0goooo100003_oool300005Ooo
o`006_ooo`030000oooooooo02ooool00`1Vooooooooo`05oooo00<0003oooooool0<_ooo`0306Ko
oooooooo00?oool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000<?ooo`0306Kooooooooo00Koool00`000?ooooooo`0aoooo00<0I_ooooooool00ooo
o`030000oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000
oooooooo0000<Oooo`0306Kooooo000000<00004oooo00<0003oooooool0<?ooo`0306Kooooooooo
00?oool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo0000037oool00`1Vooooooooo`05oooo00@0003oooooool0000aoooo00<0I_oooooo
ool00oooo`80000hoooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000a
oooo00<0I_ooooooool01_ooo`80000boooo00<0I_ooooooool00oooo`030000oooooooo03Soool2
0000??ooo`80000Foooo001<oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00?oool00`000?oo
ooooo`2>oooo001<oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00?oool00`000?ooooooo`2>
oooo001<oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001<
oooo00<0I_ooooooool0>_ooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001<oooo00<0
I_ooooooool0>_ooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo000@ooooo`00017oool0
01Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool01_ooo`03o`2Ioooooooo00?oool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool008Woool0
0ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool20000Soooo`00ROoo
o`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000
oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2I
oooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo
08koool008Woool00ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOooooooo`03oooo00<0
003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o
09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003ooooo
ool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo0P0008ooool008Woool0
0ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?oo
ooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOoo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>
oooo0029oooo00?o09Woooooool00oooo`80002?oooo0029oooo00?o09Woooooool00oooo`030000
oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2I
oooooooo00?oool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000ooooo`2I00001?ooo`030000
oooooooo08koool007_oool010000?ooooooo`0000[oool00ol0V@000?ooo`03oooo0`0008koool0
07_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007_oool010000?oo
ooooo`0000Woool00`000?l0VOooo`04oooo00<0003oooooool0S_ooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool2
0000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00ooo
o`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROoo
o`03o`2Ioooooooo00?oool20000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>
oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029
oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo0P00
08ooool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`80002?oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0027oooo1@0000?oool00`000?oo
ooooo`2>oooo0029oooo00<0003oooooool00oooo`030000oooooooo08koool008Woool00`000?oo
ooooo`03oooo0`0008koool008Woool00`000?ooooooo`03oooo00<0003oooooool0S_ooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?ooooooo`2>
oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029
oooo00?o09Woooooool00oooo`80002?oooo0029oooo00?o09Woooooool00oooo`030000oooooooo
08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
08Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool2
0000Soooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Wooooo
ool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00ooo
o`030000oooooooo08koool008Woool00ol0VOooooooo`03oooo0P0008ooool008Woool00ol0VOoo
ooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>
oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool008Woool00ol0VOooooooo`03
oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo00?oool00`000?ooooooo`2>oooo0029
oooo00?o09Woooooool00oooo`80002?oooo0029oooo00?o09Woooooool00oooo`030000oooooooo
08koool008Woool00ol0VOooooooo`03oooo00<0003oooooool0S_ooo`00ROooo`03o`2Ioooooooo
00?oool00`000?ooooooo`2>oooo0029oooo00?o09Woooooool00oooo`030000oooooooo08koool0
07_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`2>oooo001moooo00<0003ooooo
ool01oooo`040000ooooo`2I00001?ooo`030000oooooooo08koool007goool00`000?ooooooo`09
oooo00?o09T0003oool00oooo`<0002>oooo001moooo00<0003oooooool02?ooo`80002Foooo001m
oooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003o
oooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00coool500000_ooo`800003oooo100000?oool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`04oooo100000Goool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000
oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo
00Soool00`000?ooooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000D
oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000005oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.44268 .24721 L
.46172 .24721 L
.47106 .24721 L
.47567 .24721 L
.47791 .24721 L
.47994 .24721 L
.48116 .24721 L
s
.48116 .24721 m
.48134 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.22272 .24721 L
.23233 .24721 L
.23739 .24721 L
.24016 .24721 L
.24152 .24721 L
.24276 .24721 L
.24392 .24721 L
.24502 .12361 L
.24618 .12361 L
.24745 .12361 L
.25261 .12361 L
.26171 .12361 L
.30236 .12361 L
.34148 .12361 L
.38307 .12361 L
.42313 .12361 L
.46168 .12361 L
.472 .12361 L
.47703 .12361 L
.47923 .12361 L
.48039 .12361 L
.48162 .12361 L
.48292 .24721 L
.48411 .24721 L
.48647 .24721 L
.49166 .24721 L
.50269 .24721 L
.54044 .24721 L
.58064 .24721 L
.61933 .24721 L
.66047 .24721 L
.70009 .24721 L
.7382 .24721 L
.77876 .24721 L
.81781 .24721 L
.85931 .24721 L
.89929 .24721 L
.93775 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00C_ooobd0I_l01000001Vo`1Vo`0000/0I_l0
0`000?ooooooo`02oooo0`0008koool004koool00`1Vooooooooo`0Toooo100000;oool010000?oo
ooooo`0000Woool2000000<0I_ooooooool00_ooo`030000oooooooo08koool004koool00`1Voooo
ooooo`0Zoooo00@0003oooooool00009oooo00<0003oool0I_l01?ooo`030000oooooooo08koool0
04koool00`1Vooooooooo`0[oooo0P0000[oool300001?ooo`030000oooooooo08koool004koool0
0`1Vooooooooo`0ioooo00<0I_ooooooool00_ooo`030000oooooooo08koool004koool00`1Voooo
ooooo`0ioooo00<0I_ooooooool00_ooo`030000oooooooo08koool004koool00`1Vooooooooo`0i
oooo00<0I_ooooooool00_ooo`030000oooooooo08koool004koool00`1Vooooooooo`0ioooo00<0
I_ooooooool00_ooo`80002?oooo001>oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00;oool0
0`000?ooooooo`2>oooo001>oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00;oool00`000?oo
ooooo`2>oooo001>oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00;oool00`000?ooooooo`2>
oooo001>oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo001>
oooo00<0I_ooooooool0>Oooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo001>oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo00;oool20000Soooo`00C_ooo`0306Kooooooooo03Woool0
0`1Vooooooooo`02oooo00<0003oooooool0S_ooo`00C_ooo`0306Kooooooooo03Woool00`1Voooo
ooooo`02oooo00<0003oooooool0S_ooo`00C_ooo`0306Kooooooooo03Woool00`1Vooooooooo`02
oooo00<0003oooooool0S_ooo`00C_ooo`0306Kooooooooo03[oool01@1Vooooooooooooo`00002@
oooo001>oooo00<0I_ooooooool0>_ooo`0506Kooooooooooooo0000093oool004koool00`1Voooo
ooooo`0joooo00@0I_ooooooooooool20000Soooo`00C_ooo`0306Kooooooooo03[oool01@1Voooo
ooooooooo`00002@oooo000Ioooo0`0003;oool00`1Vooooooooo`03oooo100003?oool01@1Voooo
ooooooooo`00000ioooo100003_oool300005Oooo`006_ooo`030000oooooooo037oool00`1Voooo
ooooo`03oooo00<0003oooooool0=?ooo`0506Kooooooooooooo000003Woool00`000?ooooooo`0m
oooo00<0003oooooool05?ooo`005oooo`D0000boooo00<0I_ooooooool01?ooo`030000oooooooo
03?oool01@1Vooooooooooooo`00000joooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo1000
00;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo03;oool01@1Voooooooooooo
o`00000koooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo0000
03?oool00`1Vooooooooo`03oooo00@0003oooooool0000coooo00@0I_ooooooooooool20000>?oo
o`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool20000<oooo`0306Kooooooooo
00Coool20000=?ooo`0506Kooooooooooooo000003[oool20000??ooo`80000Foooo001>oooo00<0
I_ooooooool0>_ooo`0506Kooooooooooooo0000093oool004koool00`1Vooooooooo`0joooo00D0
I_ooooooooooool00000T?ooo`00C_ooo`0306Kooooooooo03[oool01@1Vooooooooooooo`00002@
oooo001>oooo00<0I_ooooooool0>_ooo`0506Kooooooooooooo0000093oool004koool00`1Voooo
ooooo`0joooo00D0I_ooooooooooool00000T?ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00Ooool0
0ol0VOooooooo`02oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo002:oooo00?o09Woooooool00_oo
o`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000
oooooooo08koool008[oool00ol0VOooooooo`02oooo0P0008ooool008[oool00ol0VOooooooo`02
oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:
oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0
003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o
09Woooooool00_ooo`80002?oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool0
08[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool0
0`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool0
0ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?oo
ooooo`2>oooo002:oooo00?o09Woooooool00_ooo`80002?oooo002:oooo00?o09Woooooool00_oo
o`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000
oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2I
oooooooo00;oool20000Soooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:
oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0
003oooooool0S_ooo`00O?ooo`800004oooo0P0000Coool2000000?o09Woooooool00_ooo`030000
oooooooo08koool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`2>oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0002>oooo001k
oooo00@0003oooooool00009oooo0P000003o`2Ioooooooo00;oool00`000?ooooooo`2>oooo001k
oooo00@0003oooooool00009oooo00<0003ooooo09T01?ooo`030000oooooooo08koool007coool2
00002_ooo`<00004oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?oo
ooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOoo
ooooo`02oooo0P0008ooool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000
oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2I
oooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo
08koool008[oool00ol0VOooooooo`02oooo0P0008ooool008[oool00ol0VOooooooo`02oooo00<0
003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o
09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003ooooo
ool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Wooooo
ool00_ooo`80002?oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool0
0ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?oo
ooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOoo
ooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool20000Soooo`00R_oo
o`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000
oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00Qoooo`D00003
oooo00<0003oooooool0S_ooo`00ROooo`030000o`2Ioooo00?oool00`000?ooooooo`2>oooo0029
oooo00<0003o09Woool00oooo`<0002>oooo0029oooo00<0003o09Woool00oooo`030000oooooooo
08koool008Woool00`000?l0VOooo`03oooo00<0003oooooool0S_ooo`00R?ooo`8000000ol0VOoo
ooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>
oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02
oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool20000Soooo`00R_ooo`03o`2I
oooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo
08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool0
08[oool00ol0VOooooooo`02oooo0P0008ooool008[oool00ol0VOooooooo`02oooo00<0003ooooo
ool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Wooooo
ool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_oo
o`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_oo
o`80002?oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOoo
ooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool00`000?ooooooo`2>
oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo08koool008[oool00ol0VOooooooo`02
oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo00;oool20000Soooo`00R_ooo`03o`2I
oooooooo00;oool00`000?ooooooo`2>oooo002:oooo00?o09Woooooool00_ooo`030000oooooooo
08koool008[oool00ol0VOooooooo`02oooo00<0003oooooool0S_ooo`00R_ooo`03o`2Ioooooooo
00;oool00`000?ooooooo`2>oooo001koooo1@0000;oool200001?ooo`8000000ol0VOooooooo`02
oooo00<0003oooooool0S_ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`2>oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool30000S_oo
o`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?oo
ooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001foooo00<0
003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003ooooo
ool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`0<oooo1@0000;oool200000oooo`D00002oooo0P0000Coool00`000?ooooooo`1eoooo001e
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00Goool00`000?ooooooo`09oooo00D0003oooooooooool000000_ooo`050000oooooooooooo0000
07Ooool007Coool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo00Woool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?oo
ooooo`0500005?ooo`030000oooooooo00Woool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`1eoooo001eoooo00D0003oooooooooool000005oooo`030000oooooooo00Woool00`000?oo
ooooo`02oooo00<0003oooooool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0G
oooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.44268 .24721 L
.46172 .24721 L
.47106 .24721 L
.47994 .24721 L
.48484 .24721 L
.48618 .24721 L
.48692 .24721 L
.48761 .24721 L
s
.48761 .24721 m
.48771 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.22272 .24721 L
.23233 .24721 L
.23739 .24721 L
.24276 .24721 L
.24502 .24721 L
.24745 .24721 L
.24816 .24721 L
.24884 .24721 L
.25012 .12361 L
.25131 .12361 L
.25261 .12361 L
.26171 .12361 L
.30236 .12361 L
.34148 .12361 L
.38307 .12361 L
.42313 .12361 L
.46168 .12361 L
.472 .12361 L
.48162 .12361 L
.48411 .12361 L
.48647 .12361 L
.48777 .12361 L
.48851 .24721 L
.48919 .24721 L
.49166 .24721 L
.50269 .24721 L
.54195 .24721 L
.5797 .24721 L
.61991 .24721 L
.65859 .24721 L
.69973 .24721 L
.73936 .24721 L
.77747 .24721 L
.81803 .24721 L
.85707 .24721 L
.89857 .24721 L
.93855 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00D?ooob/0I_l01000001Vo`1Vo`0000/0I_l0
0`00001Vo`1Vo`02oooo0`0008koool0053oool00`1Vooooooooo`0Roooo100000;oool010000?oo
ooooo`0000Woool200000_ooo`0406Kooooooooo0000T?ooo`00D?ooo`0306Kooooooooo02Soool0
10000?ooooooo`0000Woool01@000?ooooooooooo`1Vo`02oooo00<0003oooooool0S_ooo`00D?oo
o`0306Kooooooooo02Woool200002_ooo`<000001Oooo`1Vooooooooo`00002@oooo001@oooo00<0
I_ooooooool0>Oooo`0406Kooooooooo0000T?ooo`00D?ooo`0306Kooooooooo03Woool0101Voooo
ooooo`00093oool0053oool00`1Vooooooooo`0ioooo00@0I_ooooooool0002@oooo001@oooo00<0
I_ooooooool0>Oooo`0306Kooooooooo0080002?oooo001@oooo00<0I_ooooooool0>Oooo`0406Ko
oooooooo0000T?ooo`00D?ooo`0306Kooooooooo03Woool0101Vooooooooo`00093oool0053oool0
0`1Vooooooooo`0ioooo00@0I_ooooooool0002@oooo001@oooo00<0I_ooooooool0>Oooo`0406Ko
oooooooo0000T?ooo`00D?ooo`0306Kooooooooo03Woool0101Vooooooooo`00093oool0053oool0
0`1Vooooooooo`0ioooo00<0I_ooooooool00P0008ooool0053oool00`1Vooooooooo`0ioooo00@0
I_ooooooool0002@oooo001@oooo00<0I_ooooooool0>Oooo`0406Kooooooooo0000T?ooo`00Cooo
o`0306Kooooooooo03[oool0101Vooooooooo`00093oool004ooool00`1Vooooooooo`0joooo00@0
I_ooooooool0002@oooo001?oooo00<0I_ooooooool0>_ooo`0406Kooooooooo0000T?ooo`00Cooo
o`0306Kooooooooo03[oool00`1Vooooooooo`020000Soooo`00Coooo`0306Kooooooooo03[oool0
101Vooooooooo`00093oool001Woool30000<oooo`0306Kooooooooo00;oool40000=?ooo`0406Ko
oooooooo0000>Oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0boooo00<0I_oooooo
ool00_ooo`030000oooooooo03Goool0101Vooooooooo`0003Woool00`000?ooooooo`0moooo00<0
003oooooool05?ooo`005oooo`D0000coooo00<0I_ooooooool00oooo`030000oooooooo03Coool0
101Vooooooooo`0003[oool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000
oooooooo0000<oooo`@00004oooo00<0003oooooool0<oooo`0406Kooooooooo0000>oooo`030000
oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000doooo00<0I_oooooo
ool00_ooo`040000oooooooo0000=?ooo`0306Kooooooooo0080000hoooo00@0003oooooool0000j
oooo00<0003oool000005_ooo`006Oooo`80000doooo00<0I_ooooooool00oooo`80000eoooo00@0
I_ooooooool0000joooo0P0003coool200005_ooo`00Coooo`0306Kooooooooo03[oool0101Voooo
ooooo`00093oool004ooool00`1Vooooooooo`0joooo00@0I_ooooooool0002@oooo001?oooo00<0
I_ooooooool0>_ooo`0406Kooooooooo0000T?ooo`00Coooo`0306Kooooooooo03[oool0101Voooo
ooooo`00093oool004ooool00`1Vooooooooo`0joooo00@0I_ooooooool0002@oooo000@ooooo`00
017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool02Oooo`04o`2Ioooooooo00003_ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo002<oooo00Co09Wooooo
ool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<
oooo00Co09Woooooool0002@oooo002<oooo00?o09Woooooool00P0008ooool008coool01?l0VOoo
ooooo`00093oool008coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool0
08coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool008coool00ol0VOoo
ooooo`020000Soooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?oo
o`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2I
oooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`03o`2Ioooooooo0080002?
oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co
09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@
oooo002<oooo00?o09Woooooool00P0008ooool008coool01?l0VOooooooo`00093oool008coool0
1?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool007coool200001?ooo`800004
oooo0P0000;oool01?l0VOooooooo`00093oool007_oool010000?ooooooo`0000Soool01P000?oo
ooooo`000?ooool0V@;oool00`000?ooooooo`2>oooo001koooo00@0003oooooool0000;oooo00<0
003ooooo09T00_ooo`<0002>oooo001koooo00@0003oooooool00009oooo0P0000;oool01?l0VOoo
ooooo`00093oool007_oool010000?ooooooo`0000Woool01@000?ooooooooooool0V@02oooo00<0
003oooooool0S_ooo`00O?ooo`80000:oooo0`000005ooooo`2Ioooooooo0000093oool008coool0
1?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool008coool00ol0VOooooooo`02
0000Soooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?oo
o`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo
0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`03o`2Ioooooooo0080002?oooo002<
oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Wooooo
ool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<
oooo00?o09Woooooool00P0008ooool008coool01?l0VOooooooo`00093oool008coool01?l0VOoo
ooooo`00093oool008coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool0
08coool01?l0VOooooooo`00093oool008coool00ol0VOooooooo`020000Soooo`00S?ooo`04o`2I
oooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?oo
o`00Qoooo`D000001?l0VOooooooo`00093oool008Woool010000?ooooooool0V@;oool00`000?oo
ooooo`2>oooo0029oooo00@0003ooooooooo09T2oooo0`0008koool008Woool010000?ooooooool0
V@;oool00`000?ooooooo`2>oooo0029oooo00@0003ooooooooo09T2oooo00<0003oooooool0S_oo
o`00R?ooo`800002oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<
oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00?o09Wooooo
ool00P0008ooool008coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool0
08coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool008coool01?l0VOoo
ooooo`00093oool008coool00ol0VOooooooo`020000Soooo`00S?ooo`04o`2Ioooooooo0000T?oo
o`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`04o`2I
oooooooo0000T?ooo`00S?ooo`04o`2Ioooooooo0000T?ooo`00S?ooo`03o`2Ioooooooo0080002?
oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co
09Woooooool0002@oooo002<oooo00Co09Woooooool0002@oooo002<oooo00Co09Woooooool0002@
oooo002<oooo00?o09Woooooool00P0008ooool008coool01?l0VOooooooo`00093oool008coool0
1?l0VOooooooo`00093oool008coool01?l0VOooooooo`00093oool008coool01?l0VOooooooo`00
093oool007_oool500000_ooo`800004oooo0P0000;oool01?l0VOooooooo`00093oool007goool0
0`000?ooooooo`07oooo00H0003oooooool0003ooooo09T2oooo00<0003oooooool0S_ooo`00OOoo
o`030000oooooooo00[oool00`000?ooool0V@02oooo0`0008koool007goool00`000?ooooooo`08
oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:
oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?oo
ooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1h
oooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03?ooo`D00002oooo0P00
00?oool500000_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo00Woool00`000?oo
ooooo`02oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0E
oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0001Coool00`000?ooooooo`09oooo00<0003oooooool00_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Goooo00<0003oooooool02Oooo`030000oooooooo
00;oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05oooo`80000:oooo0P0000?oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.44268 .24721 L
.46172 .24721 L
.47994 .24721 L
.48519 .24721 L
.48778 .24721 L
.49018 .24721 L
.49235 .24721 L
.49356 .24721 L
s
.49356 .24721 m
.49373 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.22272 .24721 L
.23233 .24721 L
.24276 .24721 L
.24754 .24721 L
.25016 .24721 L
.25261 .24721 L
.2547 .24721 L
.25587 .24721 L
.25694 .12361 L
.25811 .12361 L
.25939 .12361 L
.26171 .12361 L
.30236 .12361 L
.34148 .12361 L
.38307 .12361 L
.42313 .12361 L
.46168 .12361 L
.48162 .12361 L
.48647 .12361 L
.48914 .12361 L
.49166 .12361 L
.49309 .12361 L
.4939 .12361 L
.49465 .24721 L
.49596 .24721 L
.49737 .24721 L
.50269 .24721 L
.54044 .24721 L
.58064 .24721 L
.61933 .24721 L
.66047 .24721 L
.70009 .24721 L
.7382 .24721 L
.77876 .24721 L
.81781 .24721 L
.85931 .24721 L
.89929 .24721 L
.93775 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00DOooobX0I_l01000001Vo`1Vo`0000/0I_l0
1@00001Vo`1Vo`1Vooooo`030000S_ooo`00DOooo`0306Kooooooooo027oool400000_ooo`040000
oooooooo00002Oooo`800003oooo00<0I_ooool00000T?ooo`00DOooo`0306Kooooooooo02Ooool0
10000?ooooooo`0000Woool00`000?ooooooo`02oooo00<0I_ooool00000T?ooo`00DOooo`0306Ko
oooooooo02Soool200002_ooo`<00002oooo00<0I_ooool00000T?ooo`00DOooo`0306Kooooooooo
03Woool00`1Vooooo`00002@oooo001Aoooo00<0I_ooooooool0>Oooo`0306Kooooo0000093oool0
057oool00`1Vooooooooo`0ioooo00<0I_ooool00000T?ooo`00DOooo`0306Kooooooooo03Woool0
101Vooooo`00000008ooool0057oool00`1Vooooooooo`0ioooo00<0I_ooool00000T?ooo`00DOoo
o`0306Kooooooooo03Woool00`1Vooooo`00002@oooo001Aoooo00<0I_ooooooool0>Oooo`0306Ko
oooo0000093oool0057oool00`1Vooooooooo`0ioooo00<0I_ooool00000T?ooo`00DOooo`0306Ko
oooooooo03Woool00`1Vooooo`00002@oooo001Aoooo00<0I_ooooooool0>Oooo`0406Kooooo0000
0000Soooo`00DOooo`0306Kooooooooo03Woool00`1Vooooo`00002@oooo001Aoooo00<0I_oooooo
ool0>Oooo`0306Kooooo0000093oool0057oool00`1Vooooooooo`0ioooo00<0I_ooool00000T?oo
o`00DOooo`0306Kooooooooo03[oool00`1Vo`000?ooo`2?oooo001Aoooo00<0I_ooooooool0>_oo
o`0306Ko0000oooo08ooool0057oool00`1Vooooooooo`0joooo00<0I_l000000000Soooo`00DOoo
o`0306Kooooooooo03[oool00`1Vo`000?ooo`2?oooo000Ioooo0`0003Goool00`1Vooooooooo`04
0000=_ooo`0306Ko0000oooo03Soool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=?oo
o`0406Kooooooooo0000>Oooo`0306Ko0000oooo03Soool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000eoooo00D0I_ooooooooooool00000>?ooo`0306Ko0000oooo03Woool0
0`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004
oooo00<0003oooooool0=Oooo`0306Ko0000oooo03[oool00`000?ooooooo`0hoooo00@0003ooooo
ool0000Foooo000Hoooo00<0003oool00000=_ooo`0406Kooooooooo00000_ooo`030000oooooooo
03Coool00`1Vo`000000000hoooo00@0003oooooool0000joooo00<0003oool000005_ooo`006Ooo
o`80000foooo00@0I_ooooooooooool20000=oooo`0306Ko0000oooo03Woool20000??ooo`80000F
oooo001Aoooo00<0I_ooooooool0>_ooo`0306Ko0000oooo08ooool0057oool00`1Vooooooooo`0j
oooo00<0I_l0003oool0Soooo`00DOooo`0306Kooooooooo03[oool00`1Vo`000?ooo`2?oooo001A
oooo00<0I_ooooooool0>_ooo`0306Ko0000oooo08ooool0057oool00`1Vooooooooo`0joooo00<0
I_l0003oool0Soooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00[oool00ol0VOooo`00000>oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
01Goool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00Co09Woool00000002?oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@
oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOoo
o`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?oo
o`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOoo
o`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool0
0ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Sooo
o`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool0
0000T?ooo`00O?ooo`800004oooo0P0000Coool200000oooo`03o`2Ioooo0000093oool007_oool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool00ol0VOooo`00002@oooo001koooo00@0
003oooooool0000;oooo00D0003ooooooooo09Woool00`0008koool007_oool010000?ooooooo`00
00Woool200000oooo`03o`2Ioooo0000093oool007_oool010000?ooooooo`0000Woool00`000?oo
ooooo`02oooo00?o09Woool00000T?ooo`00O?ooo`80000:oooo0`0000;oool00ol0VOooo`00002@
oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOoo
o`00000008ooool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?oo
o`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOoo
o`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool0
0ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`04o`2Ioooo00000000Sooo
o`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool0
0000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00Co
09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool0
08goool00ol0VOooo`00002@oooo0027oooo1@000004ooooo`2Ioooo0000T?ooo`00ROooo`070000
ooooooooooooo`2Ioooo0000093oool008Woool01P000?ooooooooooool0VOooo`<0002>oooo0029
oooo00L0003ooooooooooooo09Woool00000T?ooo`00ROooo`070000ooooooooooooo`2Ioooo0000
093oool008Soool200000oooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=
oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`000000
08ooool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2I
oooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`04o`2Ioooo00000000Soooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@
oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool00ol0VOoo
o`00002@oooo002=oooo00Co09Woool00000002?oooo002=oooo00?o09Woool00000T?ooo`00SOoo
o`03o`2Ioooo0000093oool008goool00ol0VOooo`00002@oooo002=oooo00?o09Woool00000T?oo
o`00SOooo`03o`2Ioooo0000093oool008goool01?l0VOooo`00000008ooool008goool00ol0VOoo
o`00002@oooo002=oooo00?o09Woool00000T?ooo`00SOooo`03o`2Ioooo0000093oool008goool0
0ol0VOooo`00002@oooo001koooo1@0000;oool200001?ooo`800003oooo00?o09Woool00000T?oo
o`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000;oool00ol0VOooo`00002@oooo001m
oooo00<0003oooooool02_ooo`050000ooooooooo`2Ioooo00<0002>oooo001moooo00<0003ooooo
ool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool2
00002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0
003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003ooooo
ool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool500000_oo
o`800004oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400001Oooo`030000oooooooo
00Ooool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001d
oooo00<0003oooooool00_ooo`030000oooooooo01Goool00`000?ooooooo`07oooo00@0003ooooo
ool00005oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`05
00005?ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool200001?ooo`030000oooooooo
07Goool007Goool01@000?ooooooooooo`00000Goooo00<0003oooooool01oooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05ooo
o`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.48147 .24721 L
.49012 .24721 L
.49468 .24721 L
.49719 .24721 L
.49842 .24721 L
.49955 .24721 L
s
.49955 .24721 m
.49975 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.24141 .24721 L
.25127 .24721 L
.25666 .24721 L
.2593 .24721 L
.26045 .24721 L
.26171 .24721 L
.26301 .12361 L
.26425 .12361 L
.26698 .12361 L
.27279 .12361 L
.28302 .12361 L
.30316 .12361 L
.3438 .12361 L
.38293 .12361 L
.42451 .12361 L
.44538 .12361 L
.46458 .12361 L
.48333 .12361 L
.49277 .12361 L
.49535 .12361 L
.49678 .12361 L
.49813 .12361 L
.49938 .12361 L
.50009 .24721 L
.50074 .24721 L
.50313 .24721 L
.5424 .24721 L
.58015 .24721 L
.62035 .24721 L
.65904 .24721 L
.70018 .24721 L
.7398 .24721 L
.77791 .24721 L
.81847 .24721 L
.85752 .24721 L
.89901 .24721 L
.939 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -25.0938 0 ]
[.5 .63053 25.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -86.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00DoooobP0I_l01000001Vo`1Vo`0000/0I_l0
0`00001Vo`1Vo`0206Ko0`0008koool005?oool00`1Vooooooooo`0Ooooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0Uoooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool005?oool00`1Voooo
ooooo`0Voooo0P0000[oool300001?ooo`030000oooooooo08koool005?oool00`1Vooooooooo`0i
oooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001C
oooo00<0I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0ioooo0P00
08ooool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo
03Woool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo08koool0
05?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo03Woool0
0`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Oooo`80002?oooo001Coooo00<0I_oooooo
ool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_oo
o`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001Coooo00<0I_ooooooool0>Ooo
o`030000oooooooo08koool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0S_ooo`00Dooo
o`0306Kooooooooo03Woool20000Soooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>
oooo000Ioooo0`0003Ooool00`1Vo`00000000020000=oooo`030000oooooooo03Ooool40000>ooo
o`<0000Eoooo000Joooo00<0003oooooool0=_ooo`0306Ko0000oooo03Woool00`000?ooooooo`0g
oooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000=oooo`0306Kooooo0000
03Woool00`000?ooooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool0
10000?ooooooo`0003?oool4000000Goool0I_ooooooool00000>?ooo`030000oooooooo03Woool0
0`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool00000>?ooo`0506Ko
0000oooooooo000003Ooool20000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool0
01Woool20000>?ooo`0406Kooooo00000000>?ooo`030000oooooooo03Soool20000??ooo`80000F
oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0i
oooo00<0003oooooool0S_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`2>oooo001C
oooo00<0I_ooooooool0>Oooo`030000oooooooo08koool005?oool00`1Vooooooooo`0ioooo00<0
003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
01Goool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo001loooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo08koool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0008koool0
07_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08Ooool500000oooo`030000oooooooo08koool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0S_ooo`00ROooo`030000oooooooo00?oool30000S_ooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`2>oooo0029oooo00<0003oooooool00oooo`030000oooooooo08koool008Soool2
00001Oooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003ooooo
ool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool007_oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`2>oooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
08koool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0002>oooo001moooo00<0
003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool0
07coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0R
oooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0
003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00coool5
00000_ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01?ooo`@00005oooo00<0003oooooool02?ooo`030000
oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool05Oooo`030000oooooooo
00Woool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0001Coool00`000?ooooooo`08
oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000001Ooool00`000?ooooooo`08
oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo01Ooool200002Oooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.48147 .24721 L
.49012 .24721 L
.49955 .24721 L
.50205 .24721 L
.50342 .24721 L
.50471 .24721 L
.50592 .24721 L
s
.50592 .24721 m
.50611 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.24141 .24721 L
.25127 .24721 L
.26171 .24721 L
.26425 .24721 L
.26565 .24721 L
.26698 .24721 L
.26773 .24721 L
.26855 .12361 L
.26929 .12361 L
.26998 .12361 L
.27279 .12361 L
.28302 .12361 L
.30316 .12361 L
.34228 .12361 L
.38387 .12361 L
.42393 .12361 L
.46248 .12361 L
.48242 .12361 L
.48727 .12361 L
.48994 .12361 L
.49246 .12361 L
.49316 .12361 L
.49389 .12361 L
.4947 .24721 L
.49545 .24721 L
.49817 .24721 L
.50349 .24721 L
.54124 .24721 L
.58144 .24721 L
.62013 .24721 L
.66127 .24721 L
.70089 .24721 L
.739 .24721 L
.77956 .24721 L
.81861 .24721 L
.86011 .24721 L
.90009 .24721 L
.93855 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00E?ooobL0I_l01000001Vo`1Vo`0000/0I_l0
1@00001Vo`1Vo`1Vooooo`030000S_ooo`00E?ooo`0306Kooooooooo01koool400000_ooo`040000
oooooooo00002Oooo`800003oooo00<0I_ooool00000T?ooo`00E?ooo`0306Kooooooooo02Coool0
10000?ooooooo`0000Woool00`000?ooooooo`02oooo00<0I_ooool00000T?ooo`00E?ooo`0306Ko
oooooooo02Goool200002_ooo`<00002oooo00<0I_ooool00000T?ooo`00E?ooo`0306Kooooooooo
03Koool00`1Vooooo`00002@oooo001Doooo00<0I_ooooooool0=_ooo`0306Kooooo0000093oool0
05Coool00`1Vooooooooo`0foooo00<0I_ooool00000T?ooo`00E?ooo`0306Kooooooooo03Koool0
101Vooooo`00000008ooool005Coool00`1Vooooooooo`0foooo00<0I_ooool00000T?ooo`00E?oo
o`0306Kooooooooo03Koool00`1Vooooo`00002@oooo001Doooo00<0I_ooooooool0=_ooo`0306Ko
oooo0000093oool005Coool00`1Vooooooooo`0foooo00<0I_ooool00000T?ooo`00E?ooo`0306Ko
oooooooo03Koool00`1Vooooo`00002@oooo001Doooo00<0I_ooooooool0=_ooo`0406Kooooo0000
0000Soooo`00E?ooo`0306Kooooooooo03Koool00`1Vooooo`00002@oooo001Doooo00<0I_oooooo
ool0=_ooo`0306Kooooo0000093oool005Coool00`1Vooooooooo`0foooo00<0I_ooool00000T?oo
o`00E?ooo`0306Kooooooooo03Ooool00`1Vo`000?ooo`2?oooo001Doooo00<0I_ooooooool0=ooo
o`0306Ko0000oooo08ooool005Coool00`1Vooooooooo`0goooo00<0I_l000000000Soooo`00E?oo
o`0306Kooooooooo03Ooool00`1Vo`000?ooo`2?oooo000Ioooo0`0003Soool40000=_ooo`0306Ko
0000oooo03Soool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000oooooooo
03Ooool00`1Vo`000?ooo`0hoooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool5
0000>?ooo`0306Ko0000oooo03Ooool00`1Vo`000?ooo`0ioooo00<0003oooooool0>Oooo`D0000E
oooo000Aoooo100000;oool010000?ooooooo`0003?oool400000_ooo`0306Kooooo000003Ooool0
0`1Vo`000?ooo`0joooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000
oooo000003Woool010000?ooooooo`0003Koool00`1Vo`000000000hoooo00@0003oooooool0000j
oooo00<0003oool000005_ooo`006Oooo`80000ioooo00<0I_l000000000=oooo`0306Ko0000oooo
03Woool20000??ooo`80000Foooo001Doooo00<0I_ooooooool0=oooo`0306Ko0000oooo08ooool0
05Coool00`1Vooooooooo`0goooo00<0I_l0003oool0Soooo`00E?ooo`0306Kooooooooo03Ooool0
0`1Vo`000?ooo`2?oooo001Doooo00<0I_ooooooool0=oooo`0306Ko0000oooo08ooool005Coool0
0`1Vooooooooo`0goooo00<0I_l0003oool0Soooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?l0VOooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo01Goool008ooool00`000?l0VOooo`2>oooo002?oooo00<0003o09Wo
ool0S_ooo`00Soooo`030000o`2Ioooo08koool008ooool00`000?l0VOooo`2>oooo002?oooo0P00
08ooool008ooool00`000?l0VOooo`2>oooo002?oooo00<0003o09Woool0S_ooo`00Soooo`030000
o`2Ioooo08koool008ooool00`000?l0VOooo`2>oooo002?oooo00<0003o09Woool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003o09Woool0S_ooo`00Soooo`030000o`2Ioooo08koool008ooool0
0`000?l0VOooo`2>oooo002?oooo00<0003o09Woool0S_ooo`00Soooo`030000o`2Ioooo08koool0
08ooool00`000?l0VOooo`2>oooo002?oooo0P0008ooool008ooool00`000?l0VOooo`2>oooo002?
oooo00<0003o09Woool0S_ooo`00Soooo`030000o`2Ioooo08koool008ooool00`000?l0VOooo`2>
oooo002?oooo00<0003o09Woool0S_ooo`00Soooo`80002?oooo002?oooo00<0003o09Woool0S_oo
o`00Soooo`030000o`2Ioooo08koool008ooool00`000?l0VOooo`2>oooo001loooo0P0000Coool2
00001?ooo`800005oooo00<0003o09Woool0S_ooo`00Noooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000o`2Ioooo08koool007_oool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`0008koool007_oool010000?ooooooo`0000Woool200001Oooo`030000o`2Ioooo
08koool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003o09Woool0S_oo
o`00O?ooo`80000:oooo0`0000Coool00`000?l0VOooo`2>oooo002?oooo00<0003o09Woool0S_oo
o`00Soooo`030000o`2Ioooo08koool008ooool20000Soooo`00Soooo`030000o`2Ioooo08koool0
08ooool00`000?l0VOooo`2>oooo002?oooo00<0003o09Woool0S_ooo`00Soooo`030000o`2Ioooo
08koool008ooool00`000?l0VOooo`2>oooo002?oooo00<0003o09Woool0S_ooo`00Soooo`80002?
oooo002?oooo00<0003o09Woool0S_ooo`00Soooo`030000o`2Ioooo08koool008ooool00`000?l0
VOooo`2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool2
000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?ooool0V@2>
oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?oo
ool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool008ooool00`000?ooool0V@2>oooo002?
oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008Ooool500000oooo`030000
ooooo`2I08koool008Woool00`000?ooooooo`03oooo00<0003ooooo09T0S_ooo`00ROooo`030000
oooooooo00?oool30000S_ooo`00ROooo`030000oooooooo00?oool00`000?ooool0V@2>oooo0029
oooo00<0003oooooool00oooo`030000ooooo`2I08koool008Soool200001Oooo`030000ooooo`2I
08koool008ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000
ooooo`2I08koool008ooool2000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool0
08ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I
08koool008ooool00`000?ooool0V@2>oooo002?oooo0P000003o`2Ioooooooo08coool008ooool0
0`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool0
08ooool00`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`8000000ol0VOoo
ooooo`2<oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool008ooool0
0`000?ooool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool0
08ooool2000000?o09Woooooool0S?ooo`00Soooo`030000ooooo`2I08koool008ooool00`000?oo
ool0V@2>oooo002?oooo00<0003ooooo09T0S_ooo`00Soooo`030000ooooo`2I08koool007_oool5
00000_ooo`800004oooo0P0000Goool00`000?ooool0V@2>oooo001moooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000ooooo`2I08koool007goool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<0002>oooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0
003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Ooo
o`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000
oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00goool200001?ooo`800003oooo0`0000Coool200001?oo
o`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Coool400000oooo`040000oooooooo00002_ooo`050000oooooooooooo0000
00;oool01@000?ooooooooooo`00001goooo001doooo00<0003oooooool00_ooo`030000oooooooo
01?oool010000?ooooooo`0000Woool300001Oooo`030000oooooooo00;oool00`000?ooooooo`1d
oooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool200001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0
003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo
07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool300000oooo`<00002oooo00<0003ooooo
ool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.48147 .24721 L
.49955 .24721 L
.50431 .24721 L
.50682 .24721 L
.5082 .24721 L
.5095 .24721 L
.51074 .24721 L
.51143 .24721 L
s
.51143 .24721 m
.51153 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.24141 .24721 L
.26171 .24721 L
.26709 .24721 L
.27003 .24721 L
.27147 .24721 L
.27279 .24721 L
.27399 .12361 L
.27513 .12361 L
.27765 .12361 L
.28302 .12361 L
.30316 .12361 L
.34135 .12361 L
.38199 .12361 L
.42112 .12361 L
.4411 .12361 L
.46271 .12361 L
.47285 .12361 L
.4784 .12361 L
.48357 .12361 L
.48584 .12361 L
.48696 .12361 L
.48799 .12361 L
.48918 .24721 L
.49047 .24721 L
.49273 .24721 L
.50277 .24721 L
.54204 .24721 L
.57979 .24721 L
.61999 .24721 L
.65868 .24721 L
.69982 .24721 L
.73944 .24721 L
.77755 .24721 L
.81811 .24721 L
.85716 .24721 L
.89866 .24721 L
.93864 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00E_ooobD0I_l01000001Vo`1Vo`0000/0I_l0
0`00001Vo`1Vo`02oooo0`0008koool005Koool00`1Vooooooooo`0Loooo100000;oool010000?oo
ooooo`0000Woool200000_ooo`0406Kooooooooo0000T?ooo`00E_ooo`0306Kooooooooo02;oool0
10000?ooooooo`0000Woool01@000?ooooooooooo`1Vo`02oooo00<0003oooooool0S_ooo`00E_oo
o`0306Kooooooooo02?oool200002_ooo`<000001Oooo`1Vooooooooo`00002@oooo001Foooo00<0
I_ooooooool0<oooo`0406Kooooooooo0000T?ooo`00E_ooo`0306Kooooooooo03?oool0101Voooo
ooooo`00093oool005Koool00`1Vooooooooo`0coooo00@0I_ooooooool0002@oooo001Foooo00<0
I_ooooooool0<oooo`0306Kooooooooo0080002?oooo001Foooo00<0I_ooooooool0<oooo`0406Ko
oooooooo0000T?ooo`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`00093oool005Koool0
0`1Vooooooooo`0coooo00@0I_ooooooool0002@oooo001Foooo00<0I_ooooooool0<oooo`0406Ko
oooooooo0000T?ooo`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`00093oool005Koool0
0`1Vooooooooo`0coooo00<0I_ooooooool00P0008ooool005Koool00`1Vooooooooo`0coooo00@0
I_ooooooool0002@oooo001Foooo00<0I_ooooooool0<oooo`0406Kooooooooo0000T?ooo`00EOoo
o`0306Kooooooooo03Coool0101Vooooooooo`00093oool005Goool00`1Vooooooooo`0doooo00@0
I_ooooooool0002@oooo001Eoooo00<0I_ooooooool0=?ooo`0406Kooooooooo0000T?ooo`00EOoo
o`0306Kooooooooo03Coool00`1Vooooooooo`020000Soooo`00EOooo`0306Kooooooooo03Coool0
101Vooooooooo`00093oool001Woool30000>?ooo`@0000doooo00@0I_ooooooool0000ioooo1000
03_oool300005Oooo`006_ooo`030000oooooooo03Ooool00`00001Vooooo`0eoooo00@0I_oooooo
ool0000ioooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000>Oooo`030000
oooooooo03Coool0101Vooooooooo`0003[oool00`000?ooooooo`0ioooo1@0001Goool0017oool4
00000_ooo`040000oooooooo0000<oooo`@00003oooo00<0I_l0003oool0=?ooo`0406Kooooooooo
0000>oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000i
oooo00@00000I_ooool0000doooo00<0I_ooooooool00P0003Soool010000?ooooooo`0003[oool0
0`000?ooo`00000Foooo000Ioooo0P0003[oool20000=Oooo`0406Kooooooooo0000>_ooo`80000l
oooo0P0001Koool005Goool00`1Vooooooooo`0doooo00@0I_ooooooool0002@oooo001Eoooo00<0
I_ooooooool0=?ooo`0406Kooooooooo0000T?ooo`00EOooo`0306Kooooooooo03Coool0101Voooo
ooooo`00093oool005Goool00`1Vooooooooo`0doooo00@0I_ooooooool0002@oooo001Eoooo00<0
I_ooooooool0=?ooo`0406Kooooooooo0000T?ooo`004?ooool0000Aoooo000Foooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
10000?ooooooool0V@_oool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool05Oooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000
ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOoo
o`00Soooo`8000000oooool0VOooo`2<oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0
003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=
oooo002?oooo00@0003ooooooooo09V=oooo002?oooo0P000003ooooo`2Ioooo08coool008ooool0
10000?ooooooool0VHgoool008ooool010000?ooooooool0VHgoool008ooool010000?ooooooool0
VHgoool008ooool010000?ooooooool0VHgoool008ooool010000?ooooooool0VHgoool008ooool0
10000?ooooooool0VHgoool008ooool2000000?ooooo09Woool0S?ooo`00Soooo`040000oooooooo
o`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Sooo
o`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`8000000oooool0
VOooo`2<oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?
oooo00@0003ooooooooo09V=oooo001loooo0P0000Coool200001?ooo`800005oooo00@0003ooooo
oooo09V=oooo001koooo00@0003oooooool00008oooo00@0003oooooool00004oooo00@0003ooooo
oooo09V=oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<000000ol0VOoo
ooooo`2;oooo001koooo00@0003oooooool00009oooo0P0000Goool010000?ooooooool0VHgoool0
07_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00@0003ooooooooo09V=oooo001l
oooo0P0000[oool300001?ooo`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOoo
o`00Soooo`040000ooooooooo`2ISOooo`00Soooo`8000000oooool0VOooo`2<oooo002?oooo00@0
003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=
oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0
003ooooooooo09V=oooo002?oooo0P000003ooooo`2Ioooo08coool008ooool010000?ooooooool0
VHgoool008ooool010000?ooooooool0VHgoool008ooool010000?ooooooool0VHgoool008ooool0
10000?ooooooool0VHgoool008ooool010000?ooooooool0VHgoool008ooool2000000?ooooo09Wo
ool0S?ooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Sooo
o`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000oooooooo
o`2ISOooo`00Soooo`8000000oooool0VOooo`2<oooo002?oooo00@0003ooooooooo09V=oooo002?
oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo0027oooo1@0000?oool0
10000?ooooooool0VHgoool008Woool00`000?ooooooo`03oooo00@0003ooooooooo09V=oooo0029
oooo00<0003oooooool00oooo`<000000ol0VOooooooo`2;oooo0029oooo00<0003oooooool00ooo
o`040000ooooooooo`2ISOooo`00ROooo`030000oooooooo00?oool010000?ooooooool0VHgoool0
08Soool200001Oooo`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Sooo
o`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`8000000oooool0
VOooo`2<oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?
oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooo
oooo09V=oooo002?oooo0P000003ooooo`2Ioooo08coool008ooool010000?ooooooool0VHgoool0
08ooool010000?ooooooool0VHgoool008ooool010000?ooooooool0VHgoool008ooool010000?oo
ooooool0VHgoool008ooool010000?ooooooool0VHgoool008ooool2000000?ooooo09Woool0S?oo
o`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000
ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOooo`00Soooo`040000ooooooooo`2ISOoo
o`00Soooo`8000000oooool0VOooo`2<oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0
003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=oooo002?oooo00@0003ooooooooo09V=
oooo001koooo1@0000;oool200001?ooo`800005oooo00@0003ooooooooo09V=oooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`040000ooooooooo`2ISOooo`00OOooo`030000
oooooooo00[oool00`000?ooooooo`02oooo0`000003o`2Ioooooooo08_oool007goool00`000?oo
ooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?oo
o`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004
oooo0P0000?oool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002_oo
o`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0003oooooool00_ooo`030000
oooooooo01?oool010000?ooooooo`0000Woool300001?ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500004_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool200002_oo
o`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.48147 .24721 L
.49955 .24721 L
.50431 .24721 L
.5095 .24721 L
.51188 .24721 L
.51441 .24721 L
.51564 .24721 L
.5168 .24721 L
.51784 .24721 L
s
.51784 .24721 m
.518 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.24141 .24721 L
.26171 .24721 L
.26709 .24721 L
.27279 .24721 L
.27513 .24721 L
.27765 .24721 L
.2784 .24721 L
.2791 .24721 L
.28042 .12361 L
.28166 .12361 L
.28302 .12361 L
.30316 .12361 L
.3438 .12361 L
.38293 .12361 L
.42451 .12361 L
.44538 .12361 L
.45453 .12361 L
.46458 .12361 L
.46926 .12361 L
.47427 .12361 L
.47671 .12361 L
.47901 .12361 L
.48001 .12361 L
.48108 .12361 L
.48224 .24721 L
.48333 .24721 L
.50313 .24721 L
.54088 .24721 L
.58108 .24721 L
.61977 .24721 L
.66091 .24721 L
.70054 .24721 L
.73864 .24721 L
.7792 .24721 L
.81825 .24721 L
.85975 .24721 L
.89973 .24721 L
.9382 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Eoooob@0I_l01000001Vo`1Vo`0000/0I_l0
0`000?ooooooo`02oooo0`0008koool005Ooool00`1Vooooooooo`0Koooo100000;oool010000?oo
ooooo`0000Woool2000000<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Voooo
ooooo`0Qoooo00@0003oooooool00009oooo00<0003oool0I_l01?ooo`030000oooooooo08koool0
05Ooool00`1Vooooooooo`0Roooo0P0000[oool300001?ooo`030000oooooooo08koool005Ooool0
0`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Voooo
ooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Vooooooooo`0`
oooo00<0I_ooooooool00_ooo`030000oooooooo08koool005Ooool00`1Vooooooooo`0`oooo00<0
I_ooooooool00_ooo`80002?oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool0
0`000?ooooooo`2>oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?oo
ooooo`2>oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>
oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo001G
oooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo001Goooo00<0
I_ooooooool0<?ooo`0306Kooooooooo00;oool20000Soooo`00Eoooo`0306Kooooooooo033oool0
0`1Vooooooooo`02oooo00<0003oooooool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Voooo
ooooo`02oooo00<0003oooooool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02
oooo00<0003oooooool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00<0
003oooooool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00<0003ooooo
ool0S_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo0P0008ooool005Ooool0
0`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo08koool001Woool30000>?oo
o`@0000boooo00<0I_ooooooool00_ooo`030000oooooooo03Ooool40000>oooo`<0000Eoooo000J
oooo00<0003oooooool0=oooo`040000oooooooo06Ko<_ooo`0306Kooooooooo00;oool00`000?oo
ooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000>Oooo`030000
oooo06Ko03;oool00`1Vooooooooo`02oooo00<0003oooooool0>?ooo`030000oooooooo03Woool5
00005Oooo`004Oooo`@00002oooo00@0003oooooool0000coooo100000Coool00`00001Vooooo`0a
oooo00<0I_ooooooool00_ooo`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003ooooo
ool0000Foooo000Hoooo00<0003oool00000>Oooo`040000oooooooo0000<_ooo`0306Kooooooooo
00;oool20000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool20000>_oo
o`8000000`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo03Soool20000??oo
o`80000Foooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>
oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo001G
oooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo001Goooo00<0
I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo001Goooo00<0I_oooooo
ool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`2>oooo000@ooooo`00017oool001Koool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`050000ooooooooooooo`2I00[oool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`00Soooo`050000ooooooooooooo`2I
08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?oo
o`00Soooo`050000ooooooooooooo`2I08coool008ooool200000_ooo`03o`2Ioooooooo08[oool0
08ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Sooo
o`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`800002oooo00?o09Woooooool0R_ooo`00Soooo`050000
ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0003ooooo
oooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oooooooooo
ool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`800002oooo00?o09Wooooo
ool0R_ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?ooooooooooool0V@2<
oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool0
08ooool01@000?ooooooooooool0V@2<oooo002?oooo0P0000;oool00ol0VOooooooo`2:oooo002?
oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool0
1@000?ooooooooooool0V@2<oooo001loooo0P0000Coool200001?ooo`800005oooo00D0003ooooo
oooooooo09T0S?ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`050000
ooooooooooooo`2I08coool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00
0003ooooo`2Ioooo08_oool007_oool010000?ooooooo`0000Woool200001Oooo`050000oooooooo
ooooo`2I08coool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00D0003ooooo
oooooooo09T0S?ooo`00O?ooo`80000:oooo0`0000Coool01@000?ooooooooooool0V@2<oooo002?
oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool2
00000_ooo`03o`2Ioooooooo08[oool008ooool01@000?ooooooooooool0V@2<oooo002?oooo00D0
003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I08coool008ooool01@000?oo
ooooooooool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000oooooooo
ooooo`2I08coool008ooool200000_ooo`03o`2Ioooooooo08[oool008ooool01@000?oooooooooo
ool0V@2<oooo002?oooo00D0003ooooooooooooo09T0S?ooo`00Soooo`050000ooooooooooooo`2I
08coool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo002?oooo0P0000?oool00ol0VOooooooo`29oooo002?oooo00<0
003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Wooooo
ool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROoo
o`00Soooo`800003oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOoo
ooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?oo
ooooo`02oooo00?o09Woooooool0ROooo`00Qoooo`D00003oooo00<0003oooooool00_ooo`03o`2I
oooooooo08Woool008Woool00`000?ooooooo`03oooo00<0003oooooool00_ooo`03o`2Ioooooooo
08Woool008Woool00`000?ooooooo`03oooo0`0000;oool00ol0VOooooooo`29oooo0029oooo00<0
003oooooool00oooo`030000oooooooo00;oool00ol0VOooooooo`29oooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo00;oool00ol0VOooooooo`29oooo0028oooo0P0000Goool00`000?oo
ooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29
oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02
oooo00?o09Woooooool0ROooo`00Soooo`800003oooo00?o09Woooooool0ROooo`00Soooo`030000
oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo
08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool0
08ooool200000oooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Wooooo
ool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROoo
o`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29oooo002?oooo0P0000?oool00ol0VOoo
ooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?oo
ooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo00;oool00ol0VOooooooo`29
oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool008ooool00`000?ooooooo`02
oooo00?o09Woooooool0ROooo`00Soooo`800003oooo00?o09Woooooool0ROooo`00Soooo`030000
oooooooo00;oool00ol0VOooooooo`29oooo002?oooo00<0003oooooool00_ooo`03o`2Ioooooooo
08Woool008ooool00`000?ooooooo`02oooo00?o09Woooooool0ROooo`00Soooo`030000oooooooo
00;oool00ol0VOooooooo`29oooo001koooo1@0000;oool200001?ooo`800005oooo00<0003ooooo
ool00_ooo`03o`2Ioooooooo08Woool007goool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool00_ooo`03o`2Ioooooooo08Woool007goool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<00002oooo00?o09Woooooool0ROooo`00OOooo`030000oooooooo00Soool2
0000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000oooooooo
07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo07Goool0
07Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool200001?oo
o`800004oooo0P0000Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`04oooo100000?oool010000?ooooooo`0000Soool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1eoooo001doooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?ooooooo`00
00Goool00`000?ooooooo`02oooo00<0003oooooool0M?ooo`00MOooo`030000oooooooo00D0000B
oooo00@0003oooooool00009oooo0P0000Coool200001?ooo`030000oooooooo07Goool007Goool0
1@000?ooooooooooo`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool00oooo`030000oooooooo07Goool007Koool00`000?ooooooo`0Goooo0P0000[oool2
00001?ooo`<00002oooo00<0003oooooool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.5095 .24721 L
.51441 .24721 L
.51896 .24721 L
.52148 .24721 L
.52221 .24721 L
.52289 .24721 L
s
.52289 .24721 m
.52309 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.27193 .24721 L
.27731 .24721 L
.28025 .24721 L
.28302 .24721 L
.28425 .24721 L
.28542 .24721 L
.28606 .12361 L
.28676 .12361 L
.288 .12361 L
.29349 .12361 L
.30316 .12361 L
.3438 .12361 L
.38293 .12361 L
.42451 .12361 L
.44538 .12361 L
.45453 .12361 L
.46458 .12361 L
.46926 .12361 L
.47183 .12361 L
.4731 .12361 L
.47427 .12361 L
.47537 .12361 L
.47654 .24721 L
.47771 .24721 L
.47901 .24721 L
.48333 .24721 L
.50313 .24721 L
.54333 .24721 L
.58202 .24721 L
.62316 .24721 L
.66278 .24721 L
.70089 .24721 L
.74145 .24721 L
.7805 .24721 L
.822 .24721 L
.86198 .24721 L
.90044 .24721 L
.94136 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00FOooob80I_l01000001Vo`1Vo`0000/0I_l0
0`000?ooooooo`02oooo0`0008koool005Woool00`1Vooooooooo`0Ioooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0Ooooo00@0
003oooooool00009oooo00<00000I_ooool01?ooo`030000oooooooo08koool005Woool00`1Voooo
ooooo`0Poooo0P0000[oool300001?ooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]
oooo00<0I_ooooooool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0
I_ooooooool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0I_oooooo
ool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00ooo
o`80002?oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>
oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001I
oooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001Ioooo00<0
I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001Ioooo00<0I_oooooo
ool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`2>oooo001Ioooo00<0I_ooooooool0;Ooo
o`0306Kooooooooo00?oool20000Soooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03
oooo00<0003oooooool0S_ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0
003oooooool0S_ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003ooooo
ool0S_ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool0S_oo
o`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool0S_ooo`00FOoo
o`0306Kooooooooo02goool00`1Vooooooooo`03oooo0P0008ooool005Woool00`1Vooooooooo`0]
oooo00<0I_ooooooool00oooo`030000oooooooo08koool001Woool30000>?ooo`@000000oooo`1V
ooooo`0^oooo00<0I_ooooooool00oooo`030000oooooooo03Ooool40000>oooo`<0000Eoooo000J
oooo00<0003oooooool0=oooo`030000oooooooo00;oool00`1Vooooooooo`0]oooo00<0I_oooooo
ool00oooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005ooo
o`D0000ioooo00D0003oooooooooool0I_l0;oooo`0306Kooooooooo00?oool00`000?ooooooo`0h
oooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool4
00001?ooo`040000oooooooo06Ko;oooo`0306Kooooooooo00?oool00`000?ooooooo`0ioooo00<0
003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000003Woool01P000?oo
ooooo`000?ooo`1Vobooool00`1Vooooooooo`03oooo0P0003Soool010000?ooooooo`0003[oool0
0`000?ooo`00000Foooo000Ioooo0P0003[oool200000_ooo`0306Kooooooooo02goool00`1Voooo
ooooo`03oooo00<0003oooooool0>?ooo`80000loooo0P0001Koool005Woool00`1Vooooooooo`0]
oooo00<0I_ooooooool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0
I_ooooooool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0I_oooooo
ool00oooo`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00ooo
o`030000oooooooo08koool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000
oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool00oooo`03o`2I
oooooooo00Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o
09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo0P00
00Coool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool0
0`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Sooo
o`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2I
oooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o
09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0
003oooooool00oooo`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo00?oool00ol0VOoo
ooooo`28oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<00003oooo00?o
09Woooooool0R?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool00oooo`03o`2Ioooooooo08Soool007coool200002_ooo`<00004oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo0P0000Coool00ol0VOoo
ooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28
oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo0P0000Coool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo
08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`800004oooo00?o09Wooooo
ool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo08Soool008ooool00`000?oo
ooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28
oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008Ooool500000oooo`030000
oooooooo00?oool00ol0VOooooooo`28oooo0029oooo00<0003oooooool00oooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo0029oooo00<0003oooooool00oooo`<00003oooo00?o09Wooooo
ool0R?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00R?oo
o`800005oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo
08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool0
0ol0VOooooooo`28oooo002?oooo0P0000Coool00ol0VOooooooo`28oooo002?oooo00<0003ooooo
ool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?oo
o`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00ooo
o`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Sooo
o`800004oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28
oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool00`000?ooooooo`03
oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo00?oool00ol0VOooooooo`28oooo002?
oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool008ooool200001?ooo`03o`2Ioooooooo
08Soool008ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Soooo`030000oooooooo
00?oool00ol0VOooooooo`28oooo002?oooo00<0003oooooool00oooo`03o`2Ioooooooo08Soool0
08ooool00`000?ooooooo`03oooo00?o09Woooooool0R?ooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001moooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo00?oool00ol0VOooooooo`28oooo001moooo00<0
003oooooool02_ooo`030000oooooooo00;oool300000oooo`03o`2Ioooooooo08Soool007goool0
0`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo
00002?ooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002Oooo`800004
oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool05ooo
o`80000:oooo0P0000?oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.5095 .24721 L
.51896 .24721 L
.52417 .24721 L
.5256 .24721 L
.52712 .24721 L
.52786 .24721 L
.52856 .24721 L
s
.52856 .24721 m
.52876 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.27193 .24721 L
.27731 .24721 L
.28302 .24721 L
.288 .24721 L
.28936 .24721 L
.29012 .24721 L
.29083 .24721 L
.2915 .24721 L
.29222 .12361 L
.29349 .12361 L
.30316 .12361 L
.3438 .12361 L
.38293 .12361 L
.42451 .12361 L
.44538 .12361 L
.45453 .12361 L
.45938 .12361 L
.46458 .12361 L
.46718 .12361 L
.46846 .12361 L
.46965 .12361 L
.47072 .24721 L
.47186 .24721 L
.47427 .24721 L
.48333 .24721 L
.50313 .24721 L
.54088 .24721 L
.58108 .24721 L
.61977 .24721 L
.66091 .24721 L
.70054 .24721 L
.73864 .24721 L
.7792 .24721 L
.81825 .24721 L
.85975 .24721 L
.89973 .24721 L
.9382 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00F_ooob40I_l01000001Vo`1Vo`0000T0I_l2
oooo00<0003oooooool00_ooo`<0002>oooo001Joooo00<0I_ooooooool06?ooo`@00002oooo00@0
003oooooool00008oooo00<0I_l0000000001Oooo`030000oooooooo08koool005[oool00`1Voooo
ooooo`0Noooo00@0003oooooool00008oooo00<0I_l0003oool01Oooo`030000oooooooo08koool0
05[oool00`1Vooooooooo`0Ooooo0P0000Woool0101Vo`000000000000Coool00`000?ooooooo`2>
oooo001Joooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001J
oooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001Joooo00<0
I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`2>oooo001Joooo00<0I_oooooo
ool0:_ooo`0306Kooooooooo00Goool20000Soooo`00F_ooo`0306Kooooooooo02[oool00`1Voooo
ooooo`05oooo00<0003oooooool0S_ooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05
oooo00<0003oooooool0S_ooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0
003oooooool0S_ooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0003ooooo
ool0S_ooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0003oooooool0S_oo
o`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo0P0008ooool005[oool00`1Voooo
ooooo`0Zoooo00<0I_ooooooool01Oooo`030000oooooooo08koool005[oool00`1Vooooooooo`0Z
oooo00<0I_ooooooool01Oooo`030000oooooooo08koool005[oool00`1Vooooooooo`0Zoooo00<0
I_ooooooool01Oooo`030000oooooooo08koool005[oool00`1Vooooooooo`0[oooo00<0I_oooooo
ool01?ooo`030000oooooooo08koool005[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?oo
o`030000oooooooo08koool005[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?ooo`80002?
oooo001Joooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool00`000?ooooooo`2>oooo000I
oooo0`0003Soool400000_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003ooooo
ool0=oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0goooo00<0003oooooool00ooo
o`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003oooooool0=oooo`030000oooooooo
03goool00`000?ooooooo`0Doooo000Goooo1@0003Woool00`000?ooooooo`02oooo00<0I_oooooo
ool0:oooo`0306Kooooooooo00Coool00`000?ooooooo`0hoooo00<0003oooooool0>Oooo`D0000E
oooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`050000oooooooooooo06Ko
02goool00`1Vooooooooo`04oooo00<0003oooooool0>Oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool00`000?ooo`00000ioooo00@0003oooooool00002oooo00<0I_oooooo
ool0:oooo`0306Kooooooooo00Coool20000>?ooo`040000oooooooo0000>_ooo`030000oooo0000
01Koool001Woool20000>_ooo`800003oooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool0
0`000?ooooooo`0hoooo0P0003coool200005_ooo`00F_ooo`0306Kooooooooo02_oool00`1Voooo
ooooo`04oooo00<0003oooooool0S_ooo`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04
oooo00<0003oooooool0S_ooo`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0
003oooooool0S_ooo`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003ooooo
ool0S_ooo`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`04oooo00?o09Woooooool01Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0Eoooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?oo
ooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27
oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool200001Oooo`03o`2I
oooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo
08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo
00Coool00ol0VOooooooo`27oooo002?oooo0P0000Goool00ol0VOooooooo`27oooo002?oooo00<0
003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Wooooo
ool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003ooooo
ool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qooo
o`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P0000Goool00ol0VOoo
ooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?oo
ooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27
oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04
oooo00?o09Woooooool0Qoooo`00Soooo`800005oooo00?o09Woooooool0Qoooo`00Soooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo
08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00O?ooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo00Coool00ol0VOooooooo`27oooo001koooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool0
07_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0000Coool00ol0VOooooooo`27
oooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`04oooo00?o09Wooooo
ool0Qoooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`04
oooo00?o09Woooooool0Qoooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`04oooo00?o
09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0
003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool200001Oooo`03o`2Ioooooooo08Ooool0
08ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool0
0ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool0
0`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOoo
ooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool200001Ooo
o`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Sooo
o`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2I
oooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P0000Goool00ol0VOooooooo`27oooo002?
oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o
09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0
003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Wooooo
ool0Qoooo`00Soooo`800005oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool0
0ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool0
0`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Qoooo`D00003oooo00<0003oooooool01?oo
o`03o`2Ioooooooo08Ooool008Woool00`000?ooooooo`03oooo00<0003oooooool01?ooo`03o`2I
oooooooo08Ooool008Woool00`000?ooooooo`03oooo0`0000Coool00ol0VOooooooo`27oooo0029
oooo00<0003oooooool00oooo`030000oooooooo00Coool00ol0VOooooooo`27oooo0029oooo00<0
003oooooool00oooo`030000oooooooo00Coool00ol0VOooooooo`27oooo0028oooo0P0000Goool0
0`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOoo
ooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?oo
ooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`800005oooo00?o09Woooooool0Qoooo`00Sooo
o`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2I
oooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo
08Ooool008ooool200001Oooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o
09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0
003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Wooooo
ool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo0P0000Goool0
0ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool0
0`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000oooooooo00Coool00ol0VOoo
ooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool008ooool00`000?oo
ooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`800005oooo00?o09Woooooool0Qoooo`00Sooo
o`030000oooooooo00Coool00ol0VOooooooo`27oooo002?oooo00<0003oooooool01?ooo`03o`2I
oooooooo08Ooool008ooool00`000?ooooooo`04oooo00?o09Woooooool0Qoooo`00Soooo`030000
oooooooo00Coool00ol0VOooooooo`27oooo001koooo1@0000;oool200001?ooo`800005oooo00<0
003oooooool01?ooo`03o`2Ioooooooo08Ooool007goool00`000?ooooooo`07oooo00@0003ooooo
ool00004oooo00<0003oooooool01?ooo`03o`2Ioooooooo08Ooool007goool00`000?ooooooo`0:
oooo00<0003oooooool00_ooo`<00004oooo00?o09Woooooool0Qoooo`00OOooo`030000oooooooo
00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P00
00[oool30000UOooo`00ooooob7oool00?oooolQoooo001foooo00<0003oooooool0;_ooo`030000
oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0003oooooool09Oooo`030000oooooooo
07Goool007Goool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=oooo0P0000Coool2
00001Oooo`030000oooooooo00;oool200001?ooo`030000oooooooo07Goool007Goool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000
oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001goooo001d
oooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?ooooooo`05
00004_ooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1e
oooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003oooooool05ooo
o`800009oooo100000?oool300000_ooo`030000oooooooo07Koool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.51896 .24721 L
.52455 .24721 L
.52986 .24721 L
.53217 .24721 L
.53344 .24721 L
.53463 .24721 L
.53531 .24721 L
s
.53531 .24721 m
.53542 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.27193 .24721 L
.28302 .24721 L
.2881 .24721 L
.29088 .24721 L
.29349 .24721 L
.2957 .24721 L
.29695 .24721 L
.29809 .12361 L
.29933 .12361 L
.30069 .12361 L
.30316 .12361 L
.3438 .12361 L
.38293 .12361 L
.40291 .12361 L
.42451 .12361 L
.43466 .12361 L
.44538 .12361 L
.45453 .12361 L
.45704 .12361 L
.45973 .12361 L
.46103 .12361 L
.46227 .12361 L
.46337 .12361 L
.46458 .24721 L
.4658 .24721 L
.46691 .24721 L
.46943 .24721 L
.47398 .24721 L
.48435 .24721 L
.50536 .24721 L
.54499 .24721 L
.58309 .24721 L
.62365 .24721 L
.6627 .24721 L
.7042 .24721 L
.74418 .24721 L
.78265 .24721 L
.82356 .24721 L
.86297 .24721 L
.90085 .24721 L
.94119 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00G?oooal0I_l01000001Vo`1Vo`0000P0I_l3
oooo00<0003oooooool00_ooo`<0002>oooo001Loooo00<0I_ooooooool05_ooo`@00002oooo00@0
003oooooool00007oooo00@0I_ooool000000005oooo00<0003oooooool0S_ooo`00G?ooo`0306Ko
oooooooo01coool010000?ooooooo`0000Ooool00`1Vooooo`000006oooo00<0003oooooool0S_oo
o`00G?ooo`0306Kooooooooo01goool200002?ooo`0306Kooooo000000800004oooo00<0003ooooo
ool0S_ooo`00G?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool0S_oo
o`00G?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00G?oo
o`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool0S_ooo`00G?ooo`0306Ko
oooooooo02Ooool00`1Vooooooooo`06oooo0P0008ooool005coool00`1Vooooooooo`0Woooo00<0
I_ooooooool01_ooo`030000oooooooo08koool005coool00`1Vooooooooo`0Woooo00<0I_oooooo
ool01_ooo`030000oooooooo08koool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_oo
o`030000oooooooo08koool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`030000
oooooooo08koool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`030000oooooooo
08koool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`80002?oooo001Loooo00<0
I_ooooooool09oooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001Loooo00<0I_oooooo
ool09oooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001Koooo00<0I_ooooooool0:?oo
o`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001Koooo00<0I_ooooooool0:?ooo`0306Ko
oooooooo00Koool00`000?ooooooo`2>oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo
00Koool00`000?ooooooo`2>oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool2
0000Soooo`00Foooo`0306Kooooooooo02Soool00`1Vooooooooo`06oooo00<0003oooooool0S_oo
o`006Oooo`<0000hoooo100000?oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000
oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000oooooooo
00Coool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000oooooooo03Ooool00`000?oo
ooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000ioooo00<0003oooooool00oooo`0306Ko
oooooooo02Soool00`1Vooooooooo`06oooo00<0003oooooool0>?ooo`030000oooooooo03Woool5
00005Oooo`004Oooo`@00002oooo00@0003oooooool0000coooo100000Coool00`000?ooooooo`02
oooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool00`000?ooooooo`0ioooo00<0003ooooo
ool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000003Woool010000?ooooooo`00
00?oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`80000hoooo00@0003oooooool0000j
oooo00<0003oool000005_ooo`006Oooo`80000joooo0P0000Coool00`1Vooooooooo`0Xoooo00<0
I_ooooooool01_ooo`030000oooooooo03Soool20000??ooo`80000Foooo001Koooo00<0I_oooooo
ool0:?ooo`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001Koooo00<0I_ooooooool0:?oo
o`0306Kooooooooo00Koool00`000?ooooooo`2>oooo001Koooo00<0I_ooooooool0:?ooo`0306Ko
oooooooo00Koool00`000?ooooooo`2>oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo
00Koool00`000?ooooooo`2>oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool0
0`000?ooooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00Koool0
0ol0VOooooooo`03oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo01Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_oo
o`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Sooo
o`800007oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25
oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06
oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?
oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool200001oooo`03o`2Ioooooooo
08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo
00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool0
08ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool0
0ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool2
00001oooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_oo
o`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Sooo
o`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo0P0000Ooool00ol0VOooooooo`25
oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06
oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo001l
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool0
07_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`06oooo00?o
09Woooooool0QOooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool300001_oo
o`03o`2Ioooooooo08Goool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
00Koool00ol0VOooooooo`25oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo00Koool00ol0VOooooooo`25oooo001loooo0P0000[oool300001?ooo`030000
oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`800007oooo00?o
09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0
003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Wooooo
ool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00Soooo`800007oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOoo
ooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?oo
ooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25
oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool200001oooo`03o`2I
oooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000
oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo
00Koool00ol0VOooooooo`25oooo002?oooo0P0000Ooool00ol0VOooooooo`25oooo002?oooo00<0
003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Wooooo
ool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo0027oooo1@0000?oool0
0`000?ooooooo`06oooo00?o09Woooooool0QOooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`06oooo00?o09Woooooool0QOooo`00ROooo`030000oooooooo00?oool300001_ooo`03o`2I
oooooooo08Goool008Woool00`000?ooooooo`03oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool008Woool00`000?ooooooo`03oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool0
08Soool200001Oooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo0P0000Ooool00ol0VOoo
ooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?oo
ooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25
oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06
oooo00?o09Woooooool0QOooo`00Soooo`800007oooo00?o09Woooooool0QOooo`00Soooo`030000
oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo
08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo
00Koool00ol0VOooooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool0
08ooool200001oooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Wooooo
ool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo00<0003ooooo
ool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?ooooooo`06oooo00?o09Woooooool0QOoo
o`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25oooo002?oooo0P0000Ooool00ol0VOoo
ooooo`25oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool008ooool00`000?oo
ooooo`06oooo00?o09Woooooool0QOooo`00Soooo`030000oooooooo00Koool00ol0VOooooooo`25
oooo002?oooo00<0003oooooool01_ooo`03o`2Ioooooooo08Goool007_oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00OOooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`06oooo00?o09Woooooool0QOooo`00OOoo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`0000Koool00ol0VOooooooo`25oooo001m
oooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo
09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00goool200001?ooo`800005oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000ooo
o`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`03
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000;
oooo00D0003oooooooooool00000N_ooo`00N?ooo`050000oooooooooooo000001Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool05oooo`800009oooo100000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.52059 .24721 L
.53057 .24721 L
.53543 .24721 L
.53755 .24721 L
.53984 .24721 L
.54107 .24721 L
s
.54107 .24721 m
.54124 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.29205 .24721 L
.29779 .24721 L
.30059 .24721 L
.30182 .24721 L
.30246 .24721 L
.30316 .24721 L
.30442 .12361 L
.3056 .12361 L
.30791 .12361 L
.31304 .12361 L
.32392 .12361 L
.34309 .12361 L
.38467 .12361 L
.40553 .12361 L
.42473 .12361 L
.44348 .12361 L
.45292 .12361 L
.45551 .12361 L
.45693 .12361 L
.45763 .12361 L
.45828 .12361 L
.45953 .24721 L
.4602 .24721 L
.4609 .24721 L
.46328 .24721 L
.50104 .24721 L
.54124 .24721 L
.57993 .24721 L
.62107 .24721 L
.66069 .24721 L
.6988 .24721 L
.73936 .24721 L
.7784 .24721 L
.8199 .24721 L
.85988 .24721 L
.89835 .24721 L
.93927 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00GOoooah0I_l01000001Vo`1Vo`0000H0I_l5
oooo00<0003oooooool00_ooo`<0002>oooo001Moooo00<0I_ooooooool05Oooo`@00002oooo00@0
003oooooool00005oooo00@0I_ooooooooooool200001Oooo`030000oooooooo08koool005goool0
0`1Vooooooooo`0Koooo00@0003oooooool00005oooo00D0I_ooooooooooool000001_ooo`030000
oooooooo08koool005goool00`1Vooooooooo`0Loooo0P0000Koool0101Vooooooooooooo`<00004
oooo00<0003oooooool0S_ooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0
003oooooool0S_ooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0003ooooo
ool0S_ooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0003oooooool0S_oo
o`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo0P0008ooool005goool00`1Voooo
ooooo`0Toooo00<0I_ooooooool02?ooo`030000oooooooo08koool005goool00`1Vooooooooo`0T
oooo00<0I_ooooooool02?ooo`030000oooooooo08koool005goool00`1Vooooooooo`0Toooo00<0
I_ooooooool02?ooo`030000oooooooo08koool005goool00`1Vooooooooo`0Toooo00<0I_oooooo
ool02?ooo`030000oooooooo08koool005goool00`1Vooooooooo`0Toooo00<0I_ooooooool02?oo
o`030000oooooooo08koool005goool00`1Vooooooooo`0Toooo00<0I_ooooooool02?ooo`80002?
oooo001Moooo00<0I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo001M
oooo00<0I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo001Moooo00<0
I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`2>oooo001Moooo00<0I_oooooo
ool09Oooo`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo001Moooo00<0I_ooooooool09Ooo
o`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo001Moooo00<0I_ooooooool09Oooo`0306Ko
oooooooo00Ooool20000Soooo`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0
003oooooool0S_ooo`006Oooo`<0000hoooo100000Goool00`1Vooooooooo`0Uoooo00<0I_oooooo
ool01oooo`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=ooo
o`030000oooooooo00Koool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo
03Ooool00`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000ioooo00<0003ooooo
ool01Oooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0003oooooool0>?ooo`030000
oooooooo03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool0000coooo100000Coool0
0`000?ooooooo`04oooo00<0I_ooooooool09Oooo`0306Kooooooooo00Ooool00`000?ooooooo`0i
oooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000003Woool0
10000?ooooooo`0000Goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`80000hoooo00@0
003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0000Koool00`1Voooo
ooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo03Soool20000??ooo`80000Foooo001M
oooo00<0I_ooooooool09Oooo`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo001Moooo00<0
I_ooooooool09Oooo`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo001Moooo00<0I_oooooo
ool09Oooo`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo001Moooo00<0I_ooooooool09Ooo
o`0306Kooooooooo00Ooool00`000?ooooooo`2>oooo001Moooo00<0I_ooooooool09Oooo`0306Ko
oooooooo00Ooool00`000?ooooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00Ooool00ol0VOooooooo`02oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo01Goool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0
003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Wooooo
ool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool200002?oo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000
oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo
08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0
003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Wooooo
ool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOoo
ooooo`24oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`07oooo00?o09Woooooool0Q?ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool300001oooo`03o`2Ioooooooo08Coool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo001loooo0P0000[oool3
00001?ooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24
oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo
00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool2
00002?ooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?oo
o`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P0000Soool00ol0VOooooooo`24
oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo0027
oooo1@0000?oool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00ROooo`030000oooooooo00?oool3
00001oooo`03o`2Ioooooooo08Coool008Woool00`000?ooooooo`03oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008Woool00`000?ooooooo`03oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008Soool200001Oooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P00
00Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool0
0`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`800008oooo00?o09Woooooool0Q?oo
o`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01ooo
o`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Sooo
o`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2I
oooooooo08Coool008ooool200002?ooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07
oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?
oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool008ooool00`000?ooooooo`07oooo00?o
09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool00ol0VOooooooo`24oooo002?oooo0P00
00Soool00ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool0
08ooool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00Soooo`030000oooooooo00Ooool0
0ol0VOooooooo`24oooo002?oooo00<0003oooooool01oooo`03o`2Ioooooooo08Coool007_oool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`07oooo00?o09Woooooool0Q?ooo`00OOoo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`07oooo00?o09Wooooo
ool0Q?ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0000Ooool00ol0VOoo
ooooo`24oooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?oo
o`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool0
07Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool0
0`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00goool200001?ooo`800003oooo0`0000Coool200001?ooo`030000oooooooo
07Goool007Goool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400000oooo`040000oooooooo00002?ooo`040000oooooooo00000_ooo`040000oooooooo
00000oooo`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04ooo
o`040000oooooooo00002?ooo`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?oo
ooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Soool300001?oo
o`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?oo
ooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Goool0
07Koool00`000?ooooooo`0Goooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0M_oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.52059 .24721 L
.53057 .24721 L
.53984 .24721 L
.54444 .24721 L
.54576 .24721 L
.54701 .24721 L
s
.54701 .24721 m
.54718 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.29205 .24721 L
.29779 .24721 L
.30316 .24721 L
.3056 .24721 L
.30791 .24721 L
.30919 .24721 L
.30992 .12361 L
.31059 .12361 L
.31304 .12361 L
.32392 .12361 L
.34309 .12361 L
.38221 .12361 L
.40219 .12361 L
.4238 .12361 L
.43394 .12361 L
.43949 .12361 L
.44466 .12361 L
.44908 .12361 L
.45035 .12361 L
.45156 .12361 L
.45264 .24721 L
.45382 .24721 L
.46386 .24721 L
.50465 .24721 L
.54391 .24721 L
.58166 .24721 L
.62187 .24721 L
.66055 .24721 L
.70169 .24721 L
.74132 .24721 L
.77943 .24721 L
.81999 .24721 L
.85903 .24721 L
.90053 .24721 L
.94051 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Gooooa`0I_l01000001Vo`1Vo`0000D0I_l6
oooo00<0003oooooool00_ooo`<0002>oooo001Ooooo00<0I_ooooooool04oooo`@00002oooo00@0
003oooooool00004oooo00<0I_ooooooool00_ooo`800005oooo00<0003oooooool0S_ooo`00Gooo
o`0306Kooooooooo01Woool010000?ooooooo`0000Coool00`1Vooooooooo`02oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool005ooool00`1Vooooooooo`0Joooo0P0000Goool00`1Voooo
ooooo`02oooo0`0000Coool00`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool08Oooo`0306Ko
oooooooo00Woool00`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo
00Woool00`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool0
0`000?ooooooo`2>oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool20000Sooo
o`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Gooo
o`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Goooo`0306Ko
oooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Goooo`0306Kooooooooo
027oool00`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Goooo`0306Kooooooooo027oool0
0`1Vooooooooo`09oooo00<0003oooooool0S_ooo`00Goooo`0306Kooooooooo027oool00`1Voooo
ooooo`09oooo0P0008ooool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000
oooooooo08koool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo
08koool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool0
05ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool005ooool0
0`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool005ooool00`1Voooo
ooooo`0Qoooo00<0I_ooooooool02Oooo`80002?oooo001Ooooo00<0I_ooooooool08Oooo`0306Ko
oooooooo00Woool00`000?ooooooo`2>oooo000Ioooo0`0003Soool400001oooo`0306Kooooooooo
027oool00`1Vooooooooo`09oooo00<0003oooooool0=oooo`@0000koooo0`0001Goool001[oool0
0`000?ooooooo`0goooo00<0003oooooool02?ooo`0306Kooooooooo027oool00`1Vooooooooo`09
oooo00<0003oooooool0=oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00
03Woool00`000?ooooooo`07oooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?oo
ooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`00
03?oool400001?ooo`030000oooooooo00Koool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Ooo
o`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0
003oool00000>Oooo`040000oooooooo00001oooo`0306Kooooooooo027oool00`1Vooooooooo`09
oooo0P0003Soool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0003[oool2
00002?ooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo
08koool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool0
05ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool005ooool0
0`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool005ooool00`1Voooo
ooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo08koool0013ooooo00004Oooo`005_oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool02Oooo`04o`2Ioooooooo00003_ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo01Goool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool200002_oo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000
oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo
08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0
003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOoo
ooooo`22oooo001loooo0P0000Coool200001?ooo`800005oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool007_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?oo
ooooo`09oooo00?o09Woooooool0P_ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo
00;oool300002Oooo`03o`2Ioooooooo08;oool007_oool010000?ooooooo`0000Woool200001Ooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo001koooo00@0003oooooool00009oooo00<0
003oooooool01?ooo`030000oooooooo00Woool00ol0VOooooooo`22oooo001loooo0P0000[oool3
00001?ooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22
oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo
00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool2
00002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_oo
o`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P0000[oool00ol0VOooooooo`22
oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo0027
oooo1@0000?oool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00ROooo`030000oooooooo00?oool3
00002Oooo`03o`2Ioooooooo08;oool008Woool00`000?ooooooo`03oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008Woool00`000?ooooooo`03oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008Soool200001Oooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P00
00[oool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool0
0`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`80000:oooo00?o09Woooooool0P_oo
o`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Ooo
o`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Sooo
o`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2I
oooooooo08;oool008ooool200002_ooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09
oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?
oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool008ooool00`000?ooooooo`09oooo00?o
09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool00ol0VOooooooo`22oooo002?oooo0P00
00[oool00ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool0
08ooool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00Soooo`030000oooooooo00Woool0
0ol0VOooooooo`22oooo002?oooo00<0003oooooool02Oooo`03o`2Ioooooooo08;oool007_oool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`09oooo00?o09Woooooool0P_ooo`00OOoo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`09oooo00?o09Wooooo
ool0P_ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0000Woool00ol0VOoo
ooooo`22oooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?oo
o`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool0
07Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00goool200001?ooo`800003oooo0`0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04oooo1000
00?oool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000Soool300001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000E
oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Goooo0P0000[oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.52059 .24721 L
.53984 .24721 L
.54444 .24721 L
.54934 .24721 L
.5508 .24721 L
.55216 .24721 L
.55339 .24721 L
s
.55339 .24721 m
.5535 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.29205 .24721 L
.30316 .24721 L
.30791 .24721 L
.31054 .24721 L
.31304 .24721 L
.31444 .24721 L
.31523 .24721 L
.31597 .12361 L
.31727 .12361 L
.31865 .12361 L
.32392 .12361 L
.34309 .12361 L
.38467 .12361 L
.40553 .12361 L
.42473 .12361 L
.43443 .12361 L
.43916 .12361 L
.44348 .12361 L
.4446 .12361 L
.44582 .12361 L
.44697 .24721 L
.44804 .24721 L
.45292 .24721 L
.46328 .24721 L
.50255 .24721 L
.5403 .24721 L
.5805 .24721 L
.61919 .24721 L
.66033 .24721 L
.69996 .24721 L
.73806 .24721 L
.77863 .24721 L
.81767 .24721 L
.85917 .24721 L
.89915 .24721 L
.93762 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00H?oooa/0I_l01000001Vo`1Vo`0000<0I_l8
oooo00<0003oooooool00_ooo`<0002>oooo001Poooo00<0I_ooooooool04_ooo`@00002oooo00@0
003oooooool00002oooo00<0I_ooooooool01?ooo`800005oooo00<0003oooooool0S_ooo`00H?oo
o`0306Kooooooooo01Soool010000?ooooooo`0000;oool00`1Vooooooooo`04oooo00<0003ooooo
ool01?ooo`030000oooooooo08koool0063oool00`1Vooooooooo`0Ioooo0P0000?oool00`1Voooo
ooooo`04oooo0`0000Coool00`000?ooooooo`2>oooo001Poooo00<0I_ooooooool07_ooo`0306Ko
oooooooo00_oool00`000?ooooooo`2>oooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo
00_oool00`000?ooooooo`2>oooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool0
0`000?ooooooo`2>oooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool20000Sooo
o`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00H?oo
o`0306Kooooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00H?ooo`0306Ko
oooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00H?ooo`0306Kooooooooo
01koool00`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00H?ooo`0306Kooooooooo01koool0
0`1Vooooooooo`0;oooo00<0003oooooool0S_ooo`00H?ooo`0306Kooooooooo01koool00`1Voooo
ooooo`0;oooo0P0008ooool0063oool00`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000
oooooooo08koool0063oool00`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000oooooooo
08koool0063oool00`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000oooooooo08koool0
063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo08koool0063oool0
0`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo08koool0063oool00`1Voooo
ooooo`0Ooooo00<0I_ooooooool02_ooo`80002?oooo001Poooo00<0I_ooooooool07oooo`0306Ko
oooooooo00[oool00`000?ooooooo`2>oooo000Ioooo0`0003Soool400002?ooo`0306Kooooooooo
01ooool00`1Vooooooooo`0:oooo00<0003oooooool0=oooo`@0000koooo0`0001Goool001[oool0
0`000?ooooooo`0goooo00<0003oooooool02Oooo`0306Kooooooooo01ooool00`1Vooooooooo`0:
oooo00<0003oooooool0=oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@00
03Woool00`000?ooooooo`08oooo00<0I_ooooooool07oooo`0306Kooooooooo00[oool00`000?oo
ooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`00
03?oool400001?ooo`030000oooooooo00Ooool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_oo
o`030000oooooooo03Woool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0
003oool00000>Oooo`040000oooooooo00002?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:
oooo0P0003Soool010000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0003[oool2
00002Oooo`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool0063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo
08koool0063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo08koool0
063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo08koool0063oool0
0`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo08koool0063oool00`1Voooo
ooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo08koool0013ooooo00004Oooo`005_oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool02oooo`03o`2I0000oooo00goool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000
oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo
083oool008ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo0P0000coool0
0ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool0
0`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?oo
ooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20
oooo002?oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000
oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo
083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o
09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Wooooo
ool0P?ooo`00O?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo001koooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool02oooo`03o`2Ioooooooo083oool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0`0000_oool00ol0VOooooooo`20oooo001koooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool2
00003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool200003?ooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo0P00
00coool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool0
0`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<oooo00?o09Woooooool0P?oo
o`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Qooo
o`D00003oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008Woool00`000?ooooooo`03
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008Woool00`000?ooooooo`03oooo0`00
00_oool00ol0VOooooooo`20oooo0029oooo00<0003oooooool00oooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo0029oooo00<0003oooooool00oooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo0028oooo0P0000Goool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0
003oooooool02oooo`03o`2Ioooooooo083oool008ooool200003?ooo`03o`2Ioooooooo083oool0
08ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool0
0ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool0
0`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOoo
ooooo`20oooo002?oooo0P0000coool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02ooo
o`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Sooo
o`030000oooooooo00_oool00ol0VOooooooo`20oooo002?oooo00<0003oooooool02oooo`03o`2I
oooooooo083oool008ooool00`000?ooooooo`0;oooo00?o09Woooooool0P?ooo`00Soooo`80000<
oooo00?o09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo002?
oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool008ooool00`000?ooooooo`0;oooo00?o
09Woooooool0P?ooo`00Soooo`030000oooooooo00_oool00ol0VOooooooo`20oooo001koooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool02oooo`03o`2Ioooooooo083oool007goool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool02oooo`03o`2Ioooooooo
083oool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000;oooo00?o09Wooooo
ool0P?ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool0
0`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001f
oooo00<0003oooooool0;_ooo`030000oooooooo07Koool007Goool00`000?ooooooo`08oooo00<0
003oooooool09Oooo`030000oooooooo07Goool007Goool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`0=oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1e
oooo001eoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`04
oooo100000?oool010000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`00
00?oool00`000?ooooooo`1eoooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool0
10000?ooooooo`0000_oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo
07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002Oooo`800004oooo0P00
00Coool00`000?ooooooo`1eoooo001eoooo00D0003oooooooooool000005Oooo`040000oooooooo
00002Oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool0MOooo`00M_oo
o`030000oooooooo01Ooool200002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1foooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.52059 .24721 L
.53984 .24721 L
.54934 .24721 L
.55195 .24721 L
.55472 .24721 L
.55607 .24721 L
.55734 .24721 L
.55848 .24721 L
s
.55848 .24721 m
.55867 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.29205 .24721 L
.30316 .24721 L
.31304 .24721 L
.31574 .24721 L
.31865 .24721 L
.32006 .24721 L
.32076 .24721 L
.3214 .24721 L
.3226 .12361 L
.32392 .12361 L
.34309 .12361 L
.38221 .12361 L
.40219 .12361 L
.4127 .12361 L
.4238 .12361 L
.43374 .12361 L
.43647 .12361 L
.43797 .12361 L
.43871 .12361 L
.43939 .12361 L
.44071 .24721 L
.44141 .24721 L
.44215 .24721 L
.44466 .24721 L
.46386 .24721 L
.50161 .24721 L
.54182 .24721 L
.5805 .24721 L
.62164 .24721 L
.66127 .24721 L
.69938 .24721 L
.73994 .24721 L
.77898 .24721 L
.82048 .24721 L
.86046 .24721 L
.89893 .24721 L
.93985 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00H_oooaT0I_l01000001Vo`1Vo`000080I_l9
oooo00<0003oooooool00_ooo`<0002>oooo001Roooo00<0I_ooooooool04?ooo`@00002oooo00H0
003oooooool0003oool0I_l7oooo0P0000Goool00`000?ooooooo`2>oooo001Roooo00<0I_oooooo
ool05_ooo`060000oooooooo0000oooo06Ko1oooo`030000oooooooo00Coool00`000?ooooooo`2>
oooo001Roooo00<0I_ooooooool05oooo`800002oooo00<0I_ooooooool01Oooo`<00004oooo00<0
003oooooool0S_ooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003ooooo
ool0S_ooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0S_oo
o`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0S_ooo`00H_oo
o`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo0P0008ooool006;oool00`1Vooooooooo`0K
oooo00<0I_ooooooool03?ooo`030000oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0
I_ooooooool03?ooo`030000oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0I_oooooo
ool03?ooo`030000oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?oo
o`030000oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000
oooooooo08koool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`80002?oooo001R
oooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0
I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_oooooo
ool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06ooo
o`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06oooo`0306Ko
oooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo
00coool20000Soooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003ooooo
ool0S_ooo`006Oooo`<0000hoooo100000[oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?oo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo00_oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo03Ooool0
0`000?ooooooo`0moooo00<0003oooooool05?ooo`005oooo`D0000ioooo00<0003oooooool02_oo
o`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0>?ooo`030000oooooooo
03Woool500005Oooo`004Oooo`@00002oooo00@0003oooooool0000coooo100000Coool00`000?oo
ooooo`09oooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`0ioooo00<0
003oooooool0>?ooo`040000oooooooo00005_ooo`006?ooo`030000oooo000003Woool010000?oo
ooooo`0000[oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`80000hoooo00@0003ooooo
ool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0000_oool00`1Vooooooooo`0K
oooo00<0I_ooooooool03?ooo`030000oooooooo03Soool20000??ooo`80000Foooo001Roooo00<0
I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_oooooo
ool06oooo`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06ooo
o`0306Kooooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06oooo`0306Ko
oooooooo00coool00`000?ooooooo`2>oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo
00coool00`000?ooooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool05Oooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0
003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Wooooo
ool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo0P0000goool0
0ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool0
0`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOoo
ooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?oo
ooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`80000=oooo00?o09Woooooool0Ooooo`00Sooo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2I
oooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`030000
oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo
07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`80000=oooo00?o
09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0
003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Wooooo
ool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003ooooo
ool03?ooo`03o`2Ioooooooo07ooool008ooool200003Oooo`03o`2Ioooooooo07ooool008ooool0
0`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOoo
ooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Noooo`040000
oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo00coool00ol0VOooooooo`1o
oooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000<oooo00?o09Wooooo
ool0Ooooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool03?ooo`03o`2I
oooooooo07ooool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool03?ooo`03o`2Ioooooooo07ooool007coool200002_ooo`<00004oooo00<0003oooooool03?oo
o`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Sooo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo0P0000goool00ol0VOooooooo`1o
oooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<
oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?
oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o
09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo0P00
00goool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool0
08ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool0
0ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool0
0`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`80000=oooo00?o09Woooooool0Oooo
o`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?oo
o`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Sooo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2I
oooooooo07ooool008ooool200003Oooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<
oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?
oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008Ooool500000oooo`030000oooooooo
00coool00ol0VOooooooo`1ooooo0029oooo00<0003oooooool00oooo`030000oooooooo00coool0
0ol0VOooooooo`1ooooo0029oooo00<0003oooooool00oooo`<0000<oooo00?o09Woooooool0Oooo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00R?ooo`800005
oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o
09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0
003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool200003Oooo`03o`2Ioooooooo07ooool0
08ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool0
0ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool0
0`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOoo
ooooo`1ooooo002?oooo0P0000goool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?oo
o`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Sooo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2I
oooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`80000=
oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?
oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool00`000?ooooooo`0<oooo00?o
09Woooooool0Ooooo`00Soooo`030000oooooooo00coool00ol0VOooooooo`1ooooo002?oooo00<0
003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool200003Oooo`03o`2Ioooooooo07ooool0
08ooool00`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Soooo`030000oooooooo00coool0
0ol0VOooooooo`1ooooo002?oooo00<0003oooooool03?ooo`03o`2Ioooooooo07ooool008ooool0
0`000?ooooooo`0<oooo00?o09Woooooool0Ooooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo00coool00ol0VOooooooo`1ooooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo00coool00ol0VOooooooo`1ooooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool300003?ooo`03o`2Ioooooooo07ooool007goool00`000?oo
ooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?oo
o`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0
003oooooool04oooo`040000oooooooo00002oooo`030000oooooooo00;oool00`000?ooooooo`1g
oooo001hoooo00<0003oooooool01@0001;oool010000?ooooooo`0000Woool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00009oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Goooo0P0000[oool3
00000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.52059 .24721 L
.53984 .24721 L
.54934 .24721 L
.55436 .24721 L
.55972 .24721 L
.56236 .24721 L
.56366 .24721 L
.56486 .24721 L
s
.56486 .24721 m
.56502 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.30316 .24721 L
.31323 .24721 L
.31875 .24721 L
.32145 .24721 L
.32392 .24721 L
.32499 .24721 L
.32617 .24721 L
.32728 .24721 L
.32831 .12361 L
.32951 .12361 L
.3306 .12361 L
.33304 .12361 L
.34309 .12361 L
.38315 .12361 L
.40153 .12361 L
.41196 .12361 L
.4217 .12361 L
.42664 .12361 L
.43133 .12361 L
.43258 .12361 L
.43326 .12361 L
.43391 .12361 L
.4346 .24721 L
.43537 .24721 L
.43672 .24721 L
.44164 .24721 L
.46271 .24721 L
.50139 .24721 L
.54253 .24721 L
.58216 .24721 L
.62027 .24721 L
.66083 .24721 L
.69987 .24721 L
.74137 .24721 L
.78135 .24721 L
.81982 .24721 L
.86074 .24721 L
.90014 .24721 L
.93803 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00HooooaP0I_l01000001Vo`1Vo`0000_oool0
0`000?ooooooo`02oooo0`0008koool006?oool00`1Vooooooooo`0?oooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool006?oool00`1Vooooooooo`0Eoooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006?oool00`1Voooo
ooooo`0Foooo0P00000306Kooooooooo00Ooool300001?ooo`030000oooooooo08koool006?oool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo08koool006?oool00`1Voooo
ooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo08koool006?oool00`1Vooooooooo`0H
oooo00<0I_ooooooool03_ooo`030000oooooooo08koool006?oool00`1Vooooooooo`0Hoooo00<0
I_ooooooool03_ooo`80002?oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool0
0`000?ooooooo`2>oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?oo
ooooo`2>oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`2>
oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`2>oooo001S
oooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`2>oooo001Soooo00<0
I_ooooooool06?ooo`0306Kooooooooo00koool20000Soooo`00Hoooo`0306Kooooooooo01Soool0
0`1Vooooooooo`0>oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Voooo
ooooo`0>oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>
oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0
003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003ooooo
ool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo0P0008ooool006?oool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo08koool001Woool30000>?oo
o`@0000;oooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0goooo1000
03_oool300005Oooo`006_ooo`030000oooooooo03Ooool00`000?ooooooo`0<oooo00<0I_oooooo
ool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000
oooooooo01Coool001Ooool50000>Oooo`030000oooooooo00_oool00`1Vooooooooo`0Hoooo00<0
I_ooooooool03_ooo`030000oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool4
00000_ooo`040000oooooooo0000<oooo`@00004oooo00<0003oooooool02_ooo`0306Kooooooooo
01Soool00`1Vooooooooo`0>oooo00<0003oooooool0>Oooo`030000oooooooo03Soool010000?oo
ooooo`0001Koool001Soool00`000?ooo`00000ioooo00@0003oooooool0000;oooo00<0I_oooooo
ool06?ooo`0306Kooooooooo00koool20000>?ooo`040000oooooooo0000>_ooo`030000oooo0000
01Koool001Woool20000>_ooo`80000<oooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool0
0`000?ooooooo`0hoooo0P0003coool200005_ooo`00Hoooo`0306Kooooooooo01Soool00`1Voooo
ooooo`0>oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>
oooo00<0003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0
003oooooool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003ooooo
ool0S_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003o09Woool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000
oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo
07koool008ooool200003_ooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Wooooo
ool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003ooooo
ool03Oooo`03o`2Ioooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1n
oooo002?oooo0P0000koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000
oooooooo00goool00ol0VOooooooo`1noooo001loooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool007_oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Noooo`040000oooooooo
00002oooo`030000oooooooo00;oool300003Oooo`03o`2Ioooooooo07koool007_oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo00goool00ol0VOooooooo`1noooo001koooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo00goool00ol0VOooooooo`1n
oooo001loooo0P0000[oool300001?ooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo
00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>oooo00?o09Woooooool0O_oo
o`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=
oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo0P00
00koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo0027oooo1@0000?oool00`000?ooooooo`0=oooo00?o09Woooooool0O_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00ROoo
o`030000oooooooo00?oool300003Oooo`03o`2Ioooooooo07koool008Woool00`000?ooooooo`03
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008Woool00`000?ooooooo`03oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool008Soool200001Oooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo0P0000koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`80000>
oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?
oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0
003oooooool03Oooo`03o`2Ioooooooo07koool008ooool200003_ooo`03o`2Ioooooooo07koool0
08ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool0
0ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2Ioooooooo07koool008ooool0
0`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Soooo`030000oooooooo00goool00ol0VOoo
ooooo`1noooo002?oooo0P0000koool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Ooo
o`03o`2Ioooooooo07koool008ooool00`000?ooooooo`0=oooo00?o09Woooooool0O_ooo`00Sooo
o`030000oooooooo00goool00ol0VOooooooo`1noooo002?oooo00<0003oooooool03Oooo`03o`2I
oooooooo07koool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0=oooo00?o
09Woooooool0O_ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`0=oooo00?o09Woooooool0O_ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`0000goool00ol0VOooooooo`1noooo001moooo00<0003oooooool02?ooo`80002Foooo001m
oooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003o
oooo8Oooo`00ooooob7oool007Koool00`000?ooooooo`0^oooo00<0003oooooool0M_ooo`00MOoo
o`030000oooooooo00Soool00`000?ooooooo`0Uoooo00<0003oooooool0MOooo`00MOooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00goool200001?ooo`800005oooo0`0000;oool2
00001?ooo`030000oooooooo07Goool007Goool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool400000oooo`040000oooooooo00002oooo`040000oooooooo
00000_ooo`050000oooooooooooo000007Ooool007Coool00`000?ooooooo`02oooo00<0003ooooo
ool04oooo`040000oooooooo00002?ooo`D00004oooo00<0003oooooool00_ooo`030000oooooooo
07Coool007Goool00`000?ooooooo`0500004_ooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool0
10000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool00oooo`030000oooooooo
07Goool007Koool00`000?ooooooo`0Goooo0P0000_oool200000oooo`<00002oooo00<0003ooooo
ool0M_ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.52059 .24721 L
.53984 .24721 L
.54934 .24721 L
.55972 .24721 L
.56446 .24721 L
.56706 .24721 L
.56834 .24721 L
.56951 .24721 L
.57063 .24721 L
s
.57063 .24721 m
.57081 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.30316 .24721 L
.31323 .24721 L
.32392 .24721 L
.32831 .24721 L
.33073 .24721 L
.33193 .24721 L
.33304 .24721 L
.33433 .12361 L
.33502 .12361 L
.33575 .12361 L
.33823 .12361 L
.34309 .12361 L
.38467 .12361 L
.40553 .12361 L
.41469 .12361 L
.41954 .12361 L
.42221 .12361 L
.42473 .12361 L
.42716 .12361 L
.42783 .12361 L
.42854 .12361 L
.4298 .24721 L
.43094 .24721 L
.432 .24721 L
.43443 .24721 L
.44348 .24721 L
.46328 .24721 L
.50197 .24721 L
.54311 .24721 L
.58274 .24721 L
.62084 .24721 L
.66141 .24721 L
.70045 .24721 L
.74195 .24721 L
.78193 .24721 L
.8204 .24721 L
.86132 .24721 L
.90072 .24721 L
.93861 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00IOoooaH0I_l01000001Vo`1Vo`0000_oool0
0`000?ooooooo`02oooo0`0008koool006Goool00`1Vooooooooo`0=oooo100000;oool010000?oo
o`1Vo`0000Woool200001Oooo`030000oooooooo08koool006Goool00`1Vooooooooo`0Coooo00@0
003oool0I_l00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006Goool00`1Voooo
ooooo`0Doooo0P0000[oool300001?ooo`030000oooooooo08koool006Goool00`1Vooooooooo`0E
oooo00<0I_ooooooool03oooo`030000oooooooo08koool006Goool00`1Vooooooooo`0Eoooo00<0
I_ooooooool03oooo`030000oooooooo08koool006Goool00`1Vooooooooo`0Eoooo00<0I_oooooo
ool03oooo`030000oooooooo08koool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03ooo
o`80002?oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>
oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo001U
oooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo001Uoooo00<0
I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo001Uoooo00<0I_oooooo
ool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`2>oooo001Uoooo00<0I_ooooooool05Ooo
o`0306Kooooooooo00ooool20000Soooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?
oooo00<0003oooooool0S_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0
003oooooool0S_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003ooooo
ool0S_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool0S_oo
o`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00IOoo
o`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo0P0008ooool006Goool00`1Vooooooooo`0E
oooo00<0I_ooooooool03oooo`030000oooooooo08koool001Woool30000>?ooo`@0000=oooo00<0
I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0goooo100003_oool300005Ooo
o`006_ooo`030000oooooooo03Ooool00`000?ooooooo`0>oooo00<0I_ooooooool05Oooo`0306Ko
oooooooo00ooool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo00goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03ooo
o`030000oooooooo03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000
oooooooo0000<oooo`@00004oooo00<0003oooooool03?ooo`0306Kooooooooo01Goool00`1Voooo
ooooo`0?oooo00<0003oooooool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool0
01Soool00`000?ooo`00000ioooo00@0003oooooool0000=oooo00<0I_ooooooool05Oooo`0306Ko
oooooooo00ooool20000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool2
0000>_ooo`80000>oooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0h
oooo0P0003coool200005_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0
003oooooool0S_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003ooooo
ool0S_ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool0S_oo
o`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`00IOoo
o`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool0S_ooo`004?ooool0000A
oooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00@0003ooooooooo09T;oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool0
08ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool0
0ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03ooo
o`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Sooo
o`80000@oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?
oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o
09Woooooool0O?ooo`00Soooo`80000@oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool0
08ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool0
0ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool2
00004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03ooo
o`03o`2Ioooooooo07coool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo00ooool00ol0VOooooooo`1loooo001koooo00@0003oooooool0000;oooo00<0
003oooooool00_ooo`<0000?oooo00?o09Woooooool0O?ooo`00Noooo`040000oooooooo00002Ooo
o`800005oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool007_oool010000?ooooooo`00
00Woool00`000?ooooooo`04oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool007coool2
00002_ooo`<00004oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOooooooo`1loooo002?oooo00<0
003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00Soooo`80000@oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOoo
ooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool200004?ooo`03o`2I
oooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008Ooool500000oooo`030000oooooooo00ooool00ol0VOooooooo`1loooo0029oooo00<0
003oooooool00oooo`030000oooooooo00ooool00ol0VOooooooo`1loooo0029oooo00<0003ooooo
ool00oooo`<0000?oooo00?o09Woooooool0O?ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00R?ooo`800005oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool0
08ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo0P00013oool00ol0VOoo
ooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?oo
ooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?
oooo00?o09Woooooool0O?ooo`00Soooo`80000@oooo00?o09Woooooool0O?ooo`00Soooo`030000
oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo
07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?ooo`00Soooo`030000oooooooo
00ooool00ol0VOooooooo`1loooo002?oooo00<0003oooooool03oooo`03o`2Ioooooooo07coool0
08ooool200004?ooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Wooooo
ool0O?ooo`00Soooo`030000oooooooo00ooool00ol0VOooooooo`1loooo002?oooo00<0003ooooo
ool03oooo`03o`2Ioooooooo07coool008ooool00`000?ooooooo`0?oooo00?o09Woooooool0O?oo
o`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo00ooool00ol0VOooooooo`1l
oooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo00ooool0
0ol0VOooooooo`1loooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool300003ooo
o`03o`2Ioooooooo07coool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?oo
ooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003o
oooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003ooooo
ool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Goool300000_ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Coool400000oooo`040000oooooooo00002oooo`050000oooooooooooo000007[oool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool04oooo`040000oooooooo00002?ooo`D00003oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool00008oooo00@0
003oooooool00003oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000001Goool0
10000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo01Ooool200002oooo`800002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.52059 .24721 L
.53984 .24721 L
.54934 .24721 L
.55972 .24721 L
.56446 .24721 L
.56951 .24721 L
.57197 .24721 L
.57429 .24721 L
.5753 .24721 L
.57636 .24721 L
s
.57636 .24721 m
.57654 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.30316 .24721 L
.31323 .24721 L
.32392 .24721 L
.33304 .24721 L
.33554 .24721 L
.33692 .24721 L
.33823 .24721 L
.33944 .12361 L
.34013 .12361 L
.34076 .12361 L
.34309 .12361 L
.38221 .12361 L
.3925 .12361 L
.40363 .12361 L
.40873 .12361 L
.41413 .12361 L
.41874 .12361 L
.42 .12361 L
.4207 .12361 L
.42135 .12361 L
.42263 .24721 L
.4238 .24721 L
.46213 .24721 L
.50291 .24721 L
.54217 .24721 L
.57993 .24721 L
.62013 .24721 L
.65882 .24721 L
.69996 .24721 L
.73958 .24721 L
.77769 .24721 L
.81825 .24721 L
.85729 .24721 L
.89879 .24721 L
.93877 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00I_oooaD0I_l010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0008koool006Koool00`1Vooooooooo`0<oooo100000;oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo08koool006Koool00`1Vooooooooo`0Boooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo08koool006Koool00`1Voooo
ooooo`0Boooo00<0I_l0000000002_ooo`<00004oooo00<0003oooooool0S_ooo`00I_ooo`0306Ko
oooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00I_ooo`0306Kooooooooo
01;oool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00I_ooo`0306Kooooooooo01;oool0
0`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`00I_ooo`0306Kooooooooo01;oool00`1Voooo
ooooo`0Aoooo0P0008ooool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000
oooooooo08koool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo
08koool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo08koool0
06Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo08koool006Koool0
0`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo08koool006Koool00`1Voooo
ooooo`0Boooo00<0I_ooooooool04Oooo`80002?oooo001Voooo00<0I_ooooooool04_ooo`0306Ko
oooooooo017oool00`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo
017oool00`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool0
0`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?oo
ooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`2>
oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool20000Soooo`00I_ooo`0306Ko
oooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool0S_ooo`006Oooo`<0000hoooo1000
00koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo03Ooool40000>ooo
o`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000oooooooo00ooool00`1Vooooooooo`0B
oooo00<0I_ooooooool04Oooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool03_ooo`0306Kooooooooo01;oool00`1Voooo
ooooo`0Aoooo00<0003oooooool0>?ooo`030000oooooooo03Woool500005Oooo`004Oooo`@00002
oooo00@0003oooooool0000coooo100000Coool00`000?ooooooo`0=oooo00<0I_ooooooool04_oo
o`0306Kooooooooo017oool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo
00005_ooo`006?ooo`030000oooo000003Woool010000?ooooooo`0000koool00`1Vooooooooo`0B
oooo00<0I_ooooooool04Oooo`80000hoooo00@0003oooooool0000joooo00<0003oool000005_oo
o`006Oooo`80000joooo0P0000ooool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000
oooooooo03Soool20000??ooo`80000Foooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo
017oool00`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool0
0`000?ooooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?oo
ooooo`2>oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`2>
oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`2>oooo000@
ooooo`00017oool001Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool01@000?ooooooooooool0V@0:
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`00Sooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2I
oooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000
oooooooo013oool00ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?
oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0
003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Wooooo
ool0Noooo`00Soooo`80000Aoooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOoo
ooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?oo
ooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`80000Aoooo00?o09Woooooool0Noooo`00Sooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2I
oooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000
oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo
07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0
003oooooool04?ooo`03o`2Ioooooooo07_oool007coool200001?ooo`800004oooo0P0000Goool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Noooo`040000oooooooo00002?ooo`040000
oooooooo00001?ooo`030000oooooooo013oool00ol0VOooooooo`1koooo001koooo00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<0000@oooo00?o09Woooooool0Noooo`00Noooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool04?ooo`03o`2Ioooooooo
07_oool007coool200002_ooo`<00004oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool0
08ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1koooo002?oooo00<0003ooooo
ool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Nooo
o`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Sooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo0P00017oool00ol0VOooooooo`1k
oooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@
oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?
oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00Soooo`80000Aoooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo
013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool0
08ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool2
00004Oooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Nooo
o`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool008Ooool500000oooo`030000oooooooo013oool00ol0VOooooooo`1k
oooo0029oooo00<0003oooooool00oooo`030000oooooooo013oool00ol0VOooooooo`1koooo0029
oooo00<0003oooooool00oooo`<0000@oooo00?o09Woooooool0Noooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00R?ooo`800005oooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Sooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2I
oooooooo07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@
oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?
oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo0P00
017oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool0
08ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool0
0`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Soooo`80000Aoooo00?o09Woooooool0Nooo
o`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?oo
o`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o09Woooooool0Noooo`00Sooo
o`030000oooooooo013oool00ol0VOooooooo`1koooo002?oooo00<0003oooooool04?ooo`03o`2I
oooooooo07_oool008ooool200004Oooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@
oooo00?o09Woooooool0Noooo`00Soooo`030000oooooooo013oool00ol0VOooooooo`1koooo002?
oooo00<0003oooooool04?ooo`03o`2Ioooooooo07_oool008ooool00`000?ooooooo`0@oooo00?o
09Woooooool0Noooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo013oool0
0ol0VOooooooo`1koooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo013oool00ol0VOooooooo`1koooo001moooo00<0003oooooool02_ooo`030000oooooooo
00;oool300004?ooo`03o`2Ioooooooo07_oool007goool00`000?ooooooo`08oooo0P0009Koool0
07goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool0
0?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo02koool00`000?ooooooo`1foooo001e
oooo00<0003oooooool02?ooo`030000oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool03Oooo`800004oooo0P0000Coool200001?oo
o`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003oooooool00008oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0MOooo`00M?ooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool01?ooo`030000
oooooooo00;oool00`000?ooooooo`1doooo001eoooo00<0003oooooool01@0001;oool010000?oo
ooooo`0000_oool010000?ooooooooooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000001Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0MOooo`00M_ooo`030000oooooooo01Ooool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1foooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.55838 .24721 L
.56817 .24721 L
.57355 .24721 L
.57861 .24721 L
.58137 .24721 L
.58213 .24721 L
.58293 .24721 L
s
.58293 .24721 m
.58303 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.33304 .24721 L
.33788 .24721 L
.34055 .24721 L
.34186 .24721 L
.34309 .24721 L
.34425 .24721 L
.34549 .12361 L
.3462 .12361 L
.34686 .12361 L
.34811 .12361 L
.35271 .12361 L
.36173 .12361 L
.3815 .12361 L
.39126 .12361 L
.40158 .12361 L
.41038 .12361 L
.4128 .12361 L
.41412 .12361 L
.41538 .12361 L
.41655 .12361 L
.41782 .24721 L
.41898 .24721 L
.42005 .24721 L
.45932 .24721 L
.49707 .24721 L
.53727 .24721 L
.57596 .24721 L
.6171 .24721 L
.65672 .24721 L
.69483 .24721 L
.73539 .24721 L
.77444 .24721 L
.81593 .24721 L
.85592 .24721 L
.89438 .24721 L
.9353 .24721 L
.9747 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00J?oooa<0I_l010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0008koool006Soool00`1Vooooooooo`0:oooo10000003oooo06Ko0000
00;oool00`000?ooooooo`07oooo0P0000Goool00`000?ooooooo`2>oooo001Xoooo00<0I_oooooo
ool03oooo`0506Ko0000oooooooo000000Woool00`000?ooooooo`04oooo00<0003oooooool0S_oo
o`00J?ooo`0306Kooooooooo00ooool0101Vooooo`00000000[oool300001?ooo`030000oooooooo
08koool006Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo08koool0
06Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo08koool006Soool0
0`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo08koool006Soool00`1Voooo
ooooo`0?oooo00<0I_ooooooool04_ooo`80002?oooo001Xoooo00<0I_ooooooool03oooo`0306Ko
oooooooo01;oool00`000?ooooooo`2>oooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo
01;oool00`000?ooooooo`2>oooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool0
0`000?ooooooo`2>oooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool00`000?oo
ooooo`2>oooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool00`000?ooooooo`2>
oooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool20000Soooo`00J?ooo`0306Ko
oooooooo00ooool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00J?ooo`0306Kooooooooo
00ooool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool0
0`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool00`1Voooo
ooooo`0Boooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0B
oooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0Boooo0P00
08ooool006Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`030000oooooooo08koool0
01Woool30000>?ooo`@0000?oooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool00`000?oo
ooooo`0goooo100003_oool300005Oooo`006_ooo`030000oooooooo03Ooool00`000?ooooooo`0@
oooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool00`000?ooooooo`0goooo00<0003ooooo
ool0?Oooo`030000oooooooo01Coool001Ooool50000>Oooo`030000oooooooo00ooool00`1Voooo
ooooo`0@oooo00<0I_ooooooool04_ooo`030000oooooooo03Soool00`000?ooooooo`0ioooo1@00
01Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0003oooooool03_oo
o`0306Kooooooooo013oool00`1Vooooooooo`0Boooo00<0003oooooool0>Oooo`030000oooooooo
03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000ioooo00@0003oooooool0000?
oooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000@oooo00<0I_ooooooool04?ooo`0306Ko
oooooooo01;oool00`000?ooooooo`0hoooo0P0003coool200005_ooo`00Ioooo`0306Kooooooooo
013oool00`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool0
0`1Vooooooooo`0Boooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool00`1Voooo
ooooo`0Boooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0B
oooo00<0003oooooool0S_ooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0Boooo00<0
003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool00oooo`03o`2Ioooooooo00Koool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0Eoooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool2
00004oooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOoo
o`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_oo
o`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Sooo
o`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P0001?oool00ol0VOooooooo`1i
oooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0B
oooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?
oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o
09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P00
01?oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool0
0ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`80000Coooo00?o09Woooooool0NOoo
o`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_oo
o`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00O?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo001k
oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool04_ooo`03o`2I
oooooooo07Woool007_oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0001;oool0
0ol0VOooooooo`1ioooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0B
oooo00?o09Woooooool0NOooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00O?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1i
oooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool200004oooo`03o`2I
oooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo
07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo
01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
08ooool200004oooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Wooooo
ool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003ooooo
ool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOoo
o`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo0P0001?oool00ol0VOoo
ooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?oo
ooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1i
oooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0B
oooo00?o09Woooooool0NOooo`00Soooo`80000Coooo00?o09Woooooool0NOooo`00Soooo`030000
oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo
07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Qoooo`D00003oooo00<0
003oooooool04_ooo`03o`2Ioooooooo07Woool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool04_ooo`03o`2Ioooooooo07Woool008Woool00`000?ooooooo`03oooo0`0001;oool00ol0VOoo
ooooo`1ioooo0029oooo00<0003oooooool00oooo`030000oooooooo01;oool00ol0VOooooooo`1i
oooo0029oooo00<0003oooooool00oooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo0028
oooo0P0000Goool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo
01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`80000Coooo00?o09Wooooo
ool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003ooooo
ool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOoo
o`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_oo
o`03o`2Ioooooooo07Woool008ooool200004oooo`03o`2Ioooooooo07Woool008ooool00`000?oo
ooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1i
oooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0B
oooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?
oooo0P0001?oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo
07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`030000oooooooo
01;oool00ol0VOooooooo`1ioooo002?oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool0
08ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOooo`00Soooo`80000Coooo00?o09Wooooo
ool0NOooo`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo002?oooo00<0003ooooo
ool04_ooo`03o`2Ioooooooo07Woool008ooool00`000?ooooooo`0Boooo00?o09Woooooool0NOoo
o`00Soooo`030000oooooooo01;oool00ol0VOooooooo`1ioooo001koooo1@0000;oool200001?oo
o`800005oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool007goool00`000?ooooooo`07
oooo00@0003oooooool00004oooo00<0003oooooool04_ooo`03o`2Ioooooooo07Woool007goool0
0`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000Boooo00?o09Woooooool0NOooo`00OOoo
o`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2E
oooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`0=
oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0Coooo00@0003oooooool0000:oooo00<0003oooooool00oooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500004_ooo`040000oooooooo00002oooo`050000
oooooooooooo000007[oool007Soool01@000?ooooooooooo`00000Eoooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo01Ooool2
00002_ooo`800003oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.55838 .24721 L
.56817 .24721 L
.57861 .24721 L
.58157 .24721 L
.58436 .24721 L
.58686 .24721 L
.58755 .24721 L
.58827 .24721 L
s
.58827 .24721 m
.58847 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.33304 .24721 L
.33788 .24721 L
.34309 .24721 L
.34566 .24721 L
.34811 .24721 L
.34918 .24721 L
.35031 .24721 L
.35156 .12361 L
.35271 .12361 L
.36173 .12361 L
.3815 .12361 L
.39178 .12361 L
.39719 .12361 L
.40291 .12361 L
.40533 .12361 L
.40792 .12361 L
.40868 .12361 L
.40941 .12361 L
.41006 .12361 L
.41076 .24721 L
.41143 .24721 L
.41214 .24721 L
.41342 .24721 L
.42308 .24721 L
.46083 .24721 L
.50104 .24721 L
.53972 .24721 L
.58086 .24721 L
.62049 .24721 L
.65859 .24721 L
.69916 .24721 L
.7382 .24721 L
.7797 .24721 L
.81968 .24721 L
.85815 .24721 L
.89907 .24721 L
.93847 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00JOoooa00I_l2oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo001Yoooo00<0I_ooooooool02Oooo`@00002oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo001Yoooo00<0I_ooooooool03?oo
o`0406Kooooooooo00000_ooo`030000oooooooo00Ooool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00JOooo`0306Kooooooooo00coool0101Vooooooooooooo`80000:oooo0`0000Coool0
0`000?ooooooo`2>oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?oo
ooooo`2>oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`2>
oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`2>oooo001Y
oooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool20000Soooo`00JOooo`0306Kooooooooo
00coool00`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool0
0`1Vooooooooo`0Doooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool00`1Voooo
ooooo`0Doooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0D
oooo00<0003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0
003oooooool0S_ooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo0P0008ooool0
06Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool0
0`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Voooo
ooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<
oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<oooo00<0
I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<oooo00<0I_oooooo
ool05?ooo`80002?oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?oo
ooooo`2>oooo000Ioooo0`0003Soool400004Oooo`0306Kooooooooo00coool00`1Vooooooooo`0D
oooo00<0003oooooool0=oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0goooo00<0
003oooooool04_ooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool0=ooo
o`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@0003Woool00`000?ooooooo`0A
oooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0hoooo00<0003ooooo
ool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000
oooooooo013oool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo03Woool0
0`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool00000>Oooo`040000
oooooooo00004Oooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo0P0003Soool010000?oo
ooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0003[oool200004_ooo`0306Kooooooooo
00coool00`1Vooooooooo`0Doooo00<0003oooooool0>?ooo`80000loooo0P0001Koool006Woool0
0`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Voooo
ooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<
oooo00<0I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<oooo00<0
I_ooooooool05?ooo`030000oooooooo08koool006Woool00`1Vooooooooo`0<oooo00<0I_oooooo
ool05?ooo`030000oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00Coool00ol0VOooooooo`05oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo01?oool00ol0VOoo
ooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?oo
ooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo002?oooo0P0001Coool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2I
oooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000Doooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003ooooo
ool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?oo
o`00Soooo`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOoo
ooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?oo
ooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool200005?ooo`03o`2I
oooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo
07Soool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
01?oool00ol0VOooooooo`1hoooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000Coooo00?o09Woooooool0N?ooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool007_oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool007coool200002_ooo`<00004
oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo0P00
01Coool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool0
08ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOoo
ooooo`1hoooo002?oooo0P0001Coool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04ooo
o`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2I
oooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`80000D
oooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?
oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool200005?ooo`03o`2Ioooooooo07Soool0
08ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008Ooool5
00000oooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo0029oooo00<0003oooooool00ooo
o`030000oooooooo01?oool00ol0VOooooooo`1hoooo0029oooo00<0003oooooool00oooo`<0000C
oooo00?o09Woooooool0N?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Coooo00?o
09Woooooool0N?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00R?ooo`800005oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOoo
ooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool200005?oo
o`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2I
oooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000
oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo0P0001Coool00ol0VOooooooo`1hoooo002?
oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o
09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0
003oooooool04oooo`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Wooooo
ool0N?ooo`00Soooo`80000Doooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool0
0ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool0
0`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Soooo`030000oooooooo01?oool00ol0VOoo
ooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2Ioooooooo07Soool008ooool200005?oo
o`03o`2Ioooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Sooo
o`030000oooooooo01?oool00ol0VOooooooo`1hoooo002?oooo00<0003oooooool04oooo`03o`2I
oooooooo07Soool008ooool00`000?ooooooo`0Coooo00?o09Woooooool0N?ooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo01?oool00ol0VOooooooo`1hoooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo01?oool00ol0VOooooooo`1h
oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool300004oooo`03o`2Ioooooooo
07Soool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0
003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00M_oo
o`030000oooooooo02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000
oooooooo02Goool00`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000?oool400000oooo`800004oooo00<0003oooooool0MOoo
o`00MOooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`@00003oooo00@0003oooooool00008oooo00<0003oooooool00oooo`040000oooooooo00000ooo
o`030000oooooooo07Goool007Coool00`000?ooooooo`02oooo00<0003oooooool04oooo`040000
oooooooo00002Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo00<0003oooooool0M?oo
o`00MOooo`030000oooooooo00D0000Boooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`800004oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0MOoo
o`00M_ooo`030000oooooooo01Ooool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1f
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.55838 .24721 L
.57861 .24721 L
.58392 .24721 L
.58957 .24721 L
.59232 .24721 L
.59367 .24721 L
.59491 .24721 L
s
.59491 .24721 m
.59508 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.33304 .24721 L
.34309 .24721 L
.34772 .24721 L
.35028 .24721 L
.35271 .24721 L
.35496 .24721 L
.35624 .24721 L
.35742 .12361 L
.35852 .12361 L
.35951 .12361 L
.36173 .12361 L
.3815 .12361 L
.39086 .12361 L
.39597 .12361 L
.40075 .12361 L
.40324 .12361 L
.40396 .12361 L
.40464 .12361 L
.40592 .24721 L
.4066 .24721 L
.40733 .24721 L
.40863 .24721 L
.41159 .24721 L
.42157 .24721 L
.45932 .24721 L
.49952 .24721 L
.53821 .24721 L
.57935 .24721 L
.61897 .24721 L
.65708 .24721 L
.69764 .24721 L
.73669 .24721 L
.77818 .24721 L
.81817 .24721 L
.85663 .24721 L
.89755 .24721 L
.93695 .24721 L
.97484 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Joooo`d0I_l3oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo001[oooo00<0I_ooooooool01oooo`@00002oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo001[oooo00<0I_ooooooool02Ooo
o`0506Kooooooooooooo000000;oool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000
oooooooo08koool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool00_ooo`80000:oooo0`00
00Coool00`000?ooooooo`2>oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool0
0`000?ooooooo`2>oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?oo
ooooo`2>oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`2>
oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool20000Soooo`00Joooo`0306Ko
oooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo
00Woool00`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo00Woool0
0`1Vooooooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo00Woool00`1Voooo
ooooo`0Eoooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0E
oooo00<0003oooooool0S_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo0P00
08ooool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool0
06_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool0
0`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Voooo
ooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Vooooooooo`09
oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Vooooooooo`09oooo00<0
I_ooooooool05Oooo`80002?oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool0
0`000?ooooooo`2>oooo000Ioooo0`0003Soool400004oooo`0306Kooooooooo00Woool00`1Voooo
ooooo`0Eoooo00<0003oooooool0=oooo`@0000koooo0`0001Goool001[oool00`000?ooooooo`0g
oooo00<0003oooooool05?ooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003ooooo
ool0=oooo`030000oooooooo03goool00`000?ooooooo`0Doooo000Goooo1@0003Woool00`000?oo
ooooo`0Coooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`0hoooo00<0
003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?oo
o`030000oooooooo01;oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo
03Woool00`000?ooooooo`0hoooo00@0003oooooool0000Foooo000Hoooo00<0003oool00000>Ooo
o`040000oooooooo00004oooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo0P0003Soool0
10000?ooooooo`0003[oool00`000?ooo`00000Foooo000Ioooo0P0003[oool200005?ooo`0306Ko
oooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool0>?ooo`80000loooo0P0001Koool0
06_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool0
0`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Voooo
ooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Vooooooooo`09
oooo00<0I_ooooooool05Oooo`030000oooooooo08koool006_oool00`1Vooooooooo`09oooo00<0
I_ooooooool05Oooo`030000oooooooo08koool0013ooooo00004Oooo`005_ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00Koool00ol0VOooooooo`03oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo002?oooo0P0001Koool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2I
oooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`80000F
oooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0
003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Wooooo
ool0M_ooo`00Soooo`80000Foooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool0
0`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_oo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2I
oooooooo07Koool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo01Goool00ol0VOooooooo`1foooo001koooo00@0003oooooool0000;oooo00<0003ooooo
ool00_ooo`<0000Eoooo00?o09Woooooool0M_ooo`00Noooo`040000oooooooo00002Oooo`800005
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool007_oool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool007coool200002_oo
o`<00004oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?
oooo0P0001Koool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo
07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo002?oooo0P0001Koool00ol0VOooooooo`1foooo002?oooo00<0003ooooo
ool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_oo
o`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`80000Foooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1f
oooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool200005_ooo`03o`2Ioooooooo
07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08Ooool500000oooo`030000oooooooo01Goool00ol0VOooooooo`1foooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo01Goool00ol0VOooooooo`1foooo0029oooo00<0003oooooool00ooo
o`<0000Eoooo00?o09Woooooool0M_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00R?ooo`800005oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool2
00005_ooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_oo
o`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Sooo
o`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo0P0001Koool00ol0VOooooooo`1f
oooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0E
oooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?
oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o
09Woooooool0M_ooo`00Soooo`80000Foooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo
01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool0
08ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Soooo`030000oooooooo01Goool0
0ol0VOooooooo`1foooo002?oooo00<0003oooooool05Oooo`03o`2Ioooooooo07Koool008ooool2
00005_ooo`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_oo
o`00Soooo`030000oooooooo01Goool00ol0VOooooooo`1foooo002?oooo00<0003oooooool05Ooo
o`03o`2Ioooooooo07Koool008ooool00`000?ooooooo`0Eoooo00?o09Woooooool0M_ooo`00Nooo
o`D00002oooo0P0000Coool200001Oooo`030000oooooooo01Goool00ol0VOooooooo`1foooo001m
oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo01Goool00ol0VOoo
ooooo`1foooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool300005Oooo`03o`2I
oooooooo07Koool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08
oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Ooo
o`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?oo
o`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004
oooo00<0003oooooool03Oooo`800004oooo0P0000?oool400000oooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool4
00000oooo`040000oooooooo00002?ooo`030000oooooooo00Coool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003ooooo
ool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`00000Eoooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo01Ooool200002_ooo`800003oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.58872 .24721 L
.59405 .24721 L
.59698 .24721 L
.59842 .24721 L
.59975 .24721 L
.60102 .24721 L
s
.60102 .24721 m
.60112 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.34309 .24721 L
.35271 .24721 L
.35742 .24721 L
.35948 .24721 L
.36173 .24721 L
.36294 .24721 L
.36405 .12361 L
.36512 .12361 L
.36626 .12361 L
.37114 .12361 L
.3815 .12361 L
.39178 .12361 L
.3946 .12361 L
.39614 .12361 L
.39758 .12361 L
.39881 .12361 L
.40012 .24721 L
.40087 .24721 L
.40158 .24721 L
.40291 .24721 L
.42308 .24721 L
.46141 .24721 L
.50219 .24721 L
.54146 .24721 L
.57921 .24721 L
.61941 .24721 L
.6581 .24721 L
.69924 .24721 L
.73886 .24721 L
.77697 .24721 L
.81753 .24721 L
.85658 .24721 L
.89808 .24721 L
.93806 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00KOooo`T0I_l5oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo001]oooo00<0I_ooooooool01Oooo`@00002oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Ooo
o`0306Kooooooooo00?oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0S_ooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`04oooo0P0000[oool300001?oo
o`030000oooooooo08koool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000
oooooooo08koool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo
08koool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo08koool0
06goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`80002?oooo001]oooo00<0I_oooooo
ool01Oooo`0306Kooooooooo01Ooool00`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Ooo
o`0306Kooooooooo01Ooool00`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Oooo`0306Ko
oooooooo01Ooool00`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo
01Ooool00`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool0
0`000?ooooooo`2>oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool20000Sooo
o`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00KOoo
o`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00K?ooo`0306Ko
oooooooo00Koool00`1Vooooooooo`0Goooo00<0003oooooool0S_ooo`00K?ooo`0306Kooooooooo
00Ooool00`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`00K?ooo`0306Kooooooooo00Ooool0
0`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`00K?ooo`0306Kooooooooo00Ooool00`1Voooo
ooooo`0Foooo0P0008ooool006coool00`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`030000
oooooooo08koool001Woool30000>?ooo`@0000Doooo00<0I_ooooooool01oooo`0306Kooooooooo
01Koool00`000?ooooooo`0goooo100003_oool300005Oooo`006_ooo`030000oooooooo03Ooool0
0`000?ooooooo`0Eoooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool00`000?ooooooo`0g
oooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000>Oooo`030000oooooooo
01Coool00`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`030000oooooooo03Soool00`000?oo
ooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<oooo`@00004oooo00<0
003oooooool04oooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool0>Ooo
o`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?ooo`00000ioooo00@0
003oooooool0000Doooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool20000>?ooo`040000
oooooooo0000>_ooo`030000oooo000001Koool001Woool20000>_ooo`80000Eoooo00<0I_oooooo
ool01oooo`0306Kooooooooo01Koool00`000?ooooooo`0hoooo0P0003coool200005_ooo`00K?oo
o`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`00K?ooo`0306Ko
oooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`00K?ooo`0306Kooooooooo
00Ooool00`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`00K?ooo`0306Kooooooooo00Ooool0
0`1Vooooooooo`0Foooo00<0003oooooool0S_ooo`00K?ooo`0306Kooooooooo00Ooool00`1Voooo
ooooo`0Foooo00<0003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool02?ooo`05o`2Ioooooooooooo000000koool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo01Goool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?oo
o`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Sooo
o`80000Hoooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0G
oooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?
oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool200006?ooo`03o`2Ioooooooo
07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
08ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool0
0ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool2
00006?ooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?oo
o`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05ooo
o`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Sooo
o`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0G
oooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo001l
oooo0P0000Coool200001?ooo`800005oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
07_oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0Goooo00?o
09Woooooool0M?ooo`00Noooo`040000oooooooo00002oooo`030000oooooooo00;oool300005ooo
o`03o`2Ioooooooo07Coool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo001koooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo01Ooool00ol0VOooooooo`1doooo001loooo0P0000[oool300001?ooo`030000
oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo
07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`80000Hoooo00?o
09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0
003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?oo
o`00Soooo`80000Hoooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOoo
ooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?oo
ooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool200006?ooo`03o`2I
oooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000
oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo
07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOooooooo`1doooo002?oooo00<0
003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo0027oooo1@0000?oool0
0`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0Goooo00?o09Woooooool0M?ooo`00ROooo`030000oooooooo00?oool300005oooo`03o`2I
oooooooo07Coool008Woool00`000?ooooooo`03oooo00<0003oooooool05oooo`03o`2Ioooooooo
07Coool008Woool00`000?ooooooo`03oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
08Soool200001Oooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?oo
o`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOoo
ooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?oo
ooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0G
oooo00?o09Woooooool0M?ooo`00Soooo`80000Hoooo00?o09Woooooool0M?ooo`00Soooo`030000
oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo
07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo
01Ooool00ol0VOooooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool0
08ooool200006?ooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Wooooo
ool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo00<0003ooooo
ool05oooo`03o`2Ioooooooo07Coool008ooool00`000?ooooooo`0Goooo00?o09Woooooool0M?oo
o`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1doooo002?oooo0P0001Soool00ol0VOoo
ooooo`1doooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool008ooool00`000?oo
ooooo`0Goooo00?o09Woooooool0M?ooo`00Soooo`030000oooooooo01Ooool00ol0VOooooooo`1d
oooo002?oooo00<0003oooooool05oooo`03o`2Ioooooooo07Coool007_oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00OOooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0Goooo00?o09Woooooool0M?ooo`00OOoo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`0001Ooool00ol0VOooooooo`1doooo001m
oooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo
09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Koool00`000?oo
ooooo`0^oooo00<0003oooooool0M_ooo`00MOooo`030000oooooooo00Soool00`000?ooooooo`0U
oooo00<0003oooooool0MOooo`00MOooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00goool200001?ooo`800003oooo1@0000;oool200001?ooo`030000oooooooo07Goool007Goool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000ooo
o`040000oooooooo00002_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001g
oooo001doooo00<0003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool0
0`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool00`000?oo
ooooo`0500004_ooo`040000oooooooo00002_ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo07Goool007Goool01@000?ooooooooooo`00000Eoooo00@0003oooooool0000:oooo00<0
003oooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`1eoooo001foooo00<0003ooooo
ool05oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Koool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.58872 .24721 L
.59405 .24721 L
.59975 .24721 L
.60256 .24721 L
.60394 .24721 L
.60521 .24721 L
.60637 .24721 L
s
.60637 .24721 m
.60655 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.34309 .24721 L
.35271 .24721 L
.36173 .24721 L
.36626 .24721 L
.36757 .24721 L
.36881 .24721 L
.36992 .12361 L
.37114 .12361 L
.3815 .12361 L
.38681 .12361 L
.38942 .12361 L
.39056 .12361 L
.39182 .12361 L
.39295 .24721 L
.394 .24721 L
.39631 .24721 L
.40117 .24721 L
.42214 .24721 L
.46105 .24721 L
.50241 .24721 L
.54226 .24721 L
.58059 .24721 L
.62137 .24721 L
.66064 .24721 L
.69839 .24721 L
.73859 .24721 L
.77728 .24721 L
.81842 .24721 L
.85804 .24721 L
.89615 .24721 L
.93671 .24721 L
.97576 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -28.0938 0 ]
[.5 .63053 28.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -89.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00K_ooo`L0I_l6oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo001^oooo00<0I_ooooooool00oooo`0306Ko00000000
00800002oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`2>oooo001^oooo00<0
I_ooooooool00oooo`0306Kooooooooo00Coool010000?ooooooo`0000Woool00`000?ooooooo`04
oooo00<0003oooooool0S_ooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`05oooo0P00
00[oool300001?ooo`030000oooooooo08koool006koool00`1Vooooooooo`03oooo00<0I_oooooo
ool06?ooo`030000oooooooo08koool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?oo
o`030000oooooooo08koool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000
oooooooo08koool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`80002?oooo001^
oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo001^oooo00<0
I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo001^oooo00<0I_oooooo
ool00oooo`0306Kooooooooo01Soool00`000?ooooooo`2>oooo001^oooo00<0I_ooooooool00ooo
o`0306Kooooooooo01Soool00`000?ooooooo`2>oooo001^oooo00<0I_ooooooool00oooo`0306Ko
oooooooo01Soool00`000?ooooooo`2>oooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo
01Soool20000Soooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003ooooo
ool0S_ooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_oo
o`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_oo
o`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_ooo`0306Ko
oooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_ooo`0306Kooooooooo
00?oool00`1Vooooooooo`0Hoooo0P0008ooool006koool00`1Vooooooooo`03oooo00<0I_oooooo
ool06?ooo`030000oooooooo08koool001Woool30000>?ooo`@0000Foooo00<0I_ooooooool00ooo
o`0306Kooooooooo01Soool00`000?ooooooo`0goooo100003_oool300005Oooo`006_ooo`030000
oooooooo03Ooool00`000?ooooooo`0Goooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool0
0`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool001Ooool50000>Ooo
o`030000oooooooo01Koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000oooooooo
03Soool00`000?ooooooo`0ioooo1@0001Goool0017oool400000_ooo`040000oooooooo0000<ooo
o`@00004oooo00<0003oooooool05Oooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0
003oooooool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?oo
o`00000ioooo00@0003oooooool0000Foooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool2
0000>?ooo`040000oooooooo0000>_ooo`030000oooo000001Koool001Woool20000>_ooo`80000G
oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0hoooo0P0003coool2
00005_ooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_oo
o`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_oo
o`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_ooo`0306Ko
oooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`00K_ooo`0306Kooooooooo
00?oool00`1Vooooooooo`0Hoooo00<0003oooooool0S_ooo`004?ooool0000Aoooo000Foooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool02Oooo`04o`2Ioooooooo00003_ooo`030000
oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?oo
ooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo002?oooo0P0001Woool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2I
oooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000
oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo
07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`80000Ioooo00?o
09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0
003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003ooooo
ool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Looo
o`00Soooo`80000Ioooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?oo
ooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool200006Oooo`03o`2I
oooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000
oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo
07?oool007coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Noooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo
01Soool00ol0VOooooooo`1coooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_oo
o`<0000Hoooo00?o09Woooooool0Loooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool06?ooo`03o`2Ioooooooo07?oool007_oool010000?ooooooo`0000Woool00`000?oo
ooooo`04oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool007coool200002_ooo`<00004
oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o
09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo0P00
01Woool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool0
08ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool0
0ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool0
0`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo002?oooo0P0001Woool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?oo
o`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Sooo
o`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2I
oooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`80000I
oooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?
oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o
09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0
003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool200006Oooo`03o`2Ioooooooo07?oool0
08ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool0
0ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008Ooool5
00000oooo`030000oooooooo01Soool00ol0VOooooooo`1coooo0029oooo00<0003oooooool00ooo
o`030000oooooooo01Soool00ol0VOooooooo`1coooo0029oooo00<0003oooooool00oooo`<0000H
oooo00?o09Woooooool0Loooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Hoooo00?o
09Woooooool0Loooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00R?ooo`800005oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool0
0`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool200006Ooo
o`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Sooo
o`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2I
oooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000
oooooooo01Soool00ol0VOooooooo`1coooo002?oooo0P0001Woool00ol0VOooooooo`1coooo002?
oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o
09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0
003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Wooooo
ool0Loooo`00Soooo`80000Ioooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool0
0ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool0
0`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Soooo`030000oooooooo01Soool00ol0VOoo
ooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2Ioooooooo07?oool008ooool200006Ooo
o`03o`2Ioooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Sooo
o`030000oooooooo01Soool00ol0VOooooooo`1coooo002?oooo00<0003oooooool06?ooo`03o`2I
oooooooo07?oool008ooool00`000?ooooooo`0Hoooo00?o09Woooooool0Loooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo01Soool00ol0VOooooooo`1coooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo01Soool00ol0VOooooooo`1c
oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool300006?ooo`03o`2Ioooooooo
07?oool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0
003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool03Oooo`800004oooo0P0000?oool500000_ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Coool400000ooo
o`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo01?oool010000?ooooooo`0000[oool00`000?ooooooo`03
oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000Boooo00@0003oooooool0000:
oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000E
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Goooo0P0000[oool200000oooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.58872 .24721 L
.59975 .24721 L
.60479 .24721 L
.60756 .24721 L
.61016 .24721 L
.61135 .24721 L
.6126 .24721 L
s
.6126 .24721 m
.6127 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.34309 .24721 L
.36173 .24721 L
.36626 .24721 L
.37114 .24721 L
.37257 .24721 L
.37328 .24721 L
.37393 .24721 L
.37515 .12361 L
.3758 .12361 L
.37649 .12361 L
.3815 .12361 L
.3841 .12361 L
.38553 .12361 L
.38622 .12361 L
.38686 .12361 L
.38799 .24721 L
.38921 .24721 L
.39178 .24721 L
.40291 .24721 L
.42308 .24721 L
.46293 .24721 L
.50126 .24721 L
.54204 .24721 L
.5813 .24721 L
.61906 .24721 L
.65926 .24721 L
.69795 .24721 L
.73909 .24721 L
.77871 .24721 L
.81682 .24721 L
.85738 .24721 L
.89642 .24721 L
.93792 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -31.0938 0 ]
[.5 .63053 31.0938 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -92.0938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
91.188 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.188 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Koooo`@0I_l8oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0002>oooo001_oooo00@0I_ooooooool0I_l2oooo100000;oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo08koool006ooool0101Vooooooooo`1V
o`Soool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0S_ooo`00Kooo
o`0406Kooooooooo06Ko2Oooo`80000:oooo0`0000Coool00`000?ooooooo`2>oooo001_oooo00@0
I_ooooooool0I_lLoooo00<0003oooooool0S_ooo`00Koooo`0406Kooooooooo06Ko7?ooo`030000
oooooooo08koool006ooool0101Vooooooooo`1Voacoool00`000?ooooooo`2>oooo001_oooo00@0
I_ooooooool0I_lLoooo0P0008ooool006ooool0101Vooooooooo`1Voacoool00`000?ooooooo`2>
oooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool0S_ooo`00Koooo`0406Kooooooooo
06Ko7?ooo`030000oooooooo08koool006ooool0101Vooooooooo`1Voacoool00`000?ooooooo`2>
oooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool0S_ooo`00Koooo`0406Kooooooooo
06Ko7?ooo`80002?oooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool0S_ooo`00Kooo
o`0406Kooooooooo06Ko7?ooo`030000oooooooo08koool006ooool0101Vooooooooo`1Voacoool0
0`000?ooooooo`2>oooo001_oooo00D0I_ooooooooooool0I_l06oooo`030000oooooooo08koool0
06ooool01@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool0S_ooo`00Koooo`0506Kooooooooo
oooo06Ko01_oool20000Soooo`00Koooo`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`2>
oooo000Ioooo0`0003Soool400005oooo`0506Kooooooooooooo06Ko01_oool00`000?ooooooo`0g
oooo100003_oool300005Oooo`006_ooo`030000oooooooo03Ooool00`000?ooooooo`0Hoooo00D0
I_ooooooooooool0I_l06oooo`030000oooooooo03Ooool00`000?ooooooo`0moooo00<0003ooooo
ool05?ooo`005oooo`D0000ioooo00<0003oooooool05oooo`0506Kooooooooooooo06Ko01_oool0
0`000?ooooooo`0hoooo00<0003oooooool0>Oooo`D0000Eoooo000Aoooo100000;oool010000?oo
ooooo`0003?oool400001?ooo`030000oooooooo01Koool01@1Vooooooooooooo`1Vo`0Koooo00<0
003oooooool0>Oooo`030000oooooooo03Soool010000?ooooooo`0001Koool001Soool00`000?oo
o`00000ioooo00@0003oooooool0000Goooo00D0I_ooooooooooool0I_l06oooo`80000hoooo00@0
003oooooool0000joooo00<0003oool000005_ooo`006Oooo`80000joooo0P0001Soool01@1Voooo
ooooooooo`1Vo`0Koooo00<0003oooooool0>?ooo`80000loooo0P0001Koool006ooool01@1Voooo
ooooooooo`1Vo`0Koooo00<0003oooooool0S_ooo`00Koooo`0506Kooooooooooooo06Ko01_oool0
0`000?ooooooo`2>oooo001_oooo00D0I_ooooooooooool0I_l06oooo`030000oooooooo08koool0
06ooool01@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool0S_ooo`00Koooo`0506Kooooooooo
oooo06Ko01_oool00`000?ooooooo`2>oooo000@ooooo`00017oool001Koool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0;oooo00?o09T0003oool03Oooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool05Oooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o
09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo0P00
01_oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool0
0`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`80000Koooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Sooo
o`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2I
oooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`80000K
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o
09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0
003oooooool06_ooo`03o`2Ioooooooo077oool008ooool200006oooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool007coool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Nooo
o`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo01[oool00ol0VOoo
ooooo`1aoooo001koooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Joooo00?o
09Woooooool0LOooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool06_ooo`03o`2Ioooooooo077oool007coool200002_ooo`<00004oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo0P0001_oool00ol0VOoo
ooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?oo
ooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`80000Koooo00?o09Wooooo
ool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool200006oooo`03o`2Ioooooooo077oool008ooool00`000?oo
ooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008Ooool500000oooo`030000
oooooooo01[oool00ol0VOooooooo`1aoooo0029oooo00<0003oooooool00oooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo0029oooo00<0003oooooool00oooo`<0000Joooo00?o09Wooooo
ool0LOooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00R?oo
o`800005oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool200006oooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool0
0ol0VOooooooo`1aoooo002?oooo0P0001_oool00ol0VOooooooo`1aoooo002?oooo00<0003ooooo
ool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOoo
o`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_oo
o`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Sooo
o`80000Koooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1a
oooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool00`000?ooooooo`0J
oooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo002?
oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool008ooool200006oooo`03o`2Ioooooooo
077oool008ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Soooo`030000oooooooo
01[oool00ol0VOooooooo`1aoooo002?oooo00<0003oooooool06_ooo`03o`2Ioooooooo077oool0
08ooool00`000?ooooooo`0Joooo00?o09Woooooool0LOooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001moooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo01[oool00ol0VOooooooo`1aoooo001moooo00<0
003oooooool02_ooo`030000oooooooo00;oool300006_ooo`03o`2Ioooooooo077oool007goool0
0`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00M_ooo`030000oooooooo
02koool00`000?ooooooo`1foooo001eoooo00<0003oooooool02?ooo`030000oooooooo02Goool0
0`000?ooooooo`1eoooo001eoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool03Ooo
o`800004oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0MOooo`00MOooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01?ooo`@00003oooo00@0
003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0MOooo`00M?ooo`030000oooooooo00;oool00`000?ooooooo`0Coooo00@0003oooooool00008
oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000oooooooo07Coool007Goool0
0`000?ooooooo`0500004_ooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`800004
oooo00<0003oooooool0MOooo`00MOooo`050000oooooooooooo000001Goool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0MOooo`00M_oo
o`030000oooooooo01Ooool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1foooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.58872 .24721 L
.59975 .24721 L
.60479 .24721 L
.61016 .24721 L
.61278 .24721 L
.61524 .24721 L
.61745 .24721 L
.61869 .24721 L
s
.61869 .24721 m
.61886 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool008ooool0
0`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000
oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo
073oool008ooool200007?ooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0
003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Wooooo
ool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003ooooo
ool06oooo`03o`2Ioooooooo073oool008ooool200007?ooo`03o`2Ioooooooo073oool008ooool0
0`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`
oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000
oooooooo01_oool00ol0VOooooooo`1`oooo001loooo0P0000Coool200001?ooo`800005oooo00<0
003oooooool06oooo`03o`2Ioooooooo073oool007_oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Noooo`040000oooooooo
00002oooo`030000oooooooo00;oool300006oooo`03o`2Ioooooooo073oool007_oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo001koooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo01_oool00ol0VOooooooo`1`
oooo001loooo0P0000[oool300001?ooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo
01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool0
0`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000Loooo00?o09Woooooool0L?oo
o`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06ooo
o`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool200007?ooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0K
oooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo0P00
01coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool0
08ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo0027oooo1@0000?oool00`000?ooooooo`0Koooo00?o09Woooooool0L?oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00ROoo
o`030000oooooooo00?oool300006oooo`03o`2Ioooooooo073oool008Woool00`000?ooooooo`03
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008Woool00`000?ooooooo`03oooo00<0
003oooooool06oooo`03o`2Ioooooooo073oool008Soool200001Oooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool0
0`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06ooo
o`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`80000L
oooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?
oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0
003oooooool06oooo`03o`2Ioooooooo073oool008ooool200007?ooo`03o`2Ioooooooo073oool0
08ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool0
0ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2Ioooooooo073oool008ooool0
0`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Soooo`030000oooooooo01_oool00ol0VOoo
ooooo`1`oooo002?oooo0P0001coool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06ooo
o`03o`2Ioooooooo073oool008ooool00`000?ooooooo`0Koooo00?o09Woooooool0L?ooo`00Sooo
o`030000oooooooo01_oool00ol0VOooooooo`1`oooo002?oooo00<0003oooooool06oooo`03o`2I
oooooooo073oool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0Koooo00?o
09Woooooool0L?ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`0Koooo00?o09Woooooool0L?ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`0001_oool00ol0VOooooooo`1`oooo001moooo00<0003oooooool02?ooo`80002Foooo001m
oooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003o
oooo8Oooo`00ooooob7oool007ooool00`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_oo
o`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo00<0003ooooo
ool0O_ooo`00O_ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`040000oooooooo00002Oooo`030000oooooooo07koool007goool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`040000oooooooo00002_ooo`030000oooooooo07goool007koool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`030000oooooooo07koool007koool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool0O_ooo`00Oooo
o`030000oooooooo017oool200002Oooo`030000oooooooo07ooool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.59832 .24721 L
.60873 .24721 L
.61445 .24721 L
.61726 .24721 L
.61984 .24721 L
.62236 .24721 L
.62363 .24721 L
.62435 .24721 L
s
.62435 .24721 m
.62445 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.34309 .24721 L
.36173 .24721 L
.36626 .24721 L
.37114 .24721 L
.37257 .24721 L
.37328 .24721 L
.37393 .24721 L
.37515 .37082 L
.3758 .37082 L
.37649 .37082 L
.3815 .37082 L
.3841 .37082 L
.38553 .37082 L
.38622 .37082 L
.38686 .37082 L
.38799 .24721 L
.38921 .24721 L
.39178 .24721 L
.40291 .24721 L
.42308 .24721 L
.46293 .24721 L
.50126 .24721 L
.54204 .24721 L
.5813 .24721 L
.61906 .24721 L
.65926 .24721 L
.69795 .24721 L
.73909 .24721 L
.77871 .24721 L
.81682 .24721 L
.85738 .24721 L
.89642 .24721 L
.93792 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0:oooo00D0
I_ooool0003oool0I_l03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000ooooo`2I00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0
06ooool01@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
06ooool01@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
06ooool01@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
06ooool01@1Vooooooooooooo`1Vo`0Koooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
06ooool01@1Vooooooooooooo`1Vo`0Koooo0P0001koool00ol0VOooooooo`1^oooo001_oooo00D0
I_ooooooooooool0I_l06oooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001_oooo00D0
I_ooooooooooool0I_l06oooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001_oooo00D0
I_ooooooooooool0I_l06oooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001_oooo00D0
I_ooooooooooool0I_l06oooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001_oooo00D0
I_ooooooooooool0I_l06oooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001_oooo00D0
I_ooooooooooool0I_l06oooo`80000Noooo00?o09Woooooool0K_ooo`00Koooo`0506Kooooooooo
oooo06Ko01_oool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Koooo`0506Kooooooooo
oooo06Ko01_oool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Koooo`0506Kooooooooo
oooo06Ko01_oool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Koooo`0406Kooooooooo
06Ko7?ooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001_oooo00@0I_ooooooool0I_lL
oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool006ooool0101Vooooooooo`1Voacoool0
0`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Koooo`0406Kooooooooo06Ko7?ooo`80000N
oooo00?o09Woooooool0K_ooo`00Koooo`0406Kooooooooo06Ko7?ooo`030000oooooooo01goool0
0ol0VOooooooo`1^oooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool07Oooo`03o`2I
oooooooo06koool006ooool0101Vooooooooo`1Voacoool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00Koooo`0406Kooooooooo06Ko7?ooo`030000oooooooo01goool00ol0VOooooooo`1^
oooo001_oooo00@0I_ooooooool0I_lLoooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool0
06ooool0101Vooooooooo`1Voacoool200007_ooo`03o`2Ioooooooo06koool006ooool0101Voooo
ooooo`1Voacoool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Koooo`0406Kooooooooo
06Ko7?ooo`030000oooooooo01goool00ol0VOooooooo`1^oooo001_oooo00@0I_ooooooool0I_lL
oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool006ooool0101Vooooooooo`1Vo`Woool2
00001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Kooo
o`0406Kooooooooo06Ko2?ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo001_oooo101Vo`Soool010000?ooooooo`0000_oool0
0`000?ooooooo`02oooo0`0001goool00ol0VOooooooo`1^oooo001koooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00O?oo
o`80000:oooo0`0000Coool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo
06koool008ooool200007_ooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o
09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0
003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0003ooooo
ool07Oooo`03o`2Ioooooooo06koool008ooool200007_ooo`03o`2Ioooooooo06koool008ooool0
0`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOoo
ooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?oo
ooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^
oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2I
oooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo
06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`80000Noooo00?o
09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0
003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00Qoooo`D00003oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008Woool0
0`000?ooooooo`03oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008Woool00`000?oo
ooooo`03oooo0`0001goool00ol0VOooooooo`1^oooo0029oooo00<0003oooooool00oooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo0029oooo00<0003oooooool00oooo`030000oooooooo
01goool00ol0VOooooooo`1^oooo0028oooo0P0000Goool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0003ooooo
ool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_oo
o`00Soooo`80000Noooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOoo
ooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?oo
ooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^
oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool200007_ooo`03o`2I
oooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000
oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo
06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo
01goool00ol0VOooooooo`1^oooo002?oooo0P0001koool00ol0VOooooooo`1^oooo002?oooo00<0
003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Wooooo
ool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^oooo002?oooo00<0003ooooo
ool07Oooo`03o`2Ioooooooo06koool008ooool00`000?ooooooo`0Moooo00?o09Woooooool0K_oo
o`00Soooo`80000Noooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOoo
ooooo`1^oooo002?oooo00<0003oooooool07Oooo`03o`2Ioooooooo06koool008ooool00`000?oo
ooooo`0Moooo00?o09Woooooool0K_ooo`00Soooo`030000oooooooo01goool00ol0VOooooooo`1^
oooo001koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool07Oooo`03o`2Ioooooooo
06koool007goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool07Ooo
o`03o`2Ioooooooo06koool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000M
oooo00?o09Woooooool0K_ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`05oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=
oooo00@0003oooooool00008oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000
oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.59832 .24721 L
.60873 .24721 L
.61984 .24721 L
.6254 .24721 L
.62812 .24721 L
.62932 .24721 L
.63064 .24721 L
s
.63064 .24721 m
.63081 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.34309 .24721 L
.35271 .24721 L
.36173 .24721 L
.36626 .24721 L
.36757 .24721 L
.36881 .24721 L
.36992 .37082 L
.37114 .37082 L
.3815 .37082 L
.38681 .37082 L
.38942 .37082 L
.39056 .37082 L
.39182 .37082 L
.39295 .24721 L
.394 .24721 L
.39631 .24721 L
.40117 .24721 L
.42214 .24721 L
.46105 .24721 L
.50241 .24721 L
.54226 .24721 L
.58059 .24721 L
.62137 .24721 L
.66064 .24721 L
.69839 .24721 L
.73859 .24721 L
.77728 .24721 L
.81842 .24721 L
.85804 .24721 L
.89615 .24721 L
.93671 .24721 L
.97576 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`09oooo00@0
I_ooooooool00002oooo00<0I_ooooooool02Oooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`040000ooooooooo`2I2oooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool05Oooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003ooooo
ool07_ooo`03o`2Ioooooooo06goool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?oo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo001^oooo00<0I_ooooooool00oooo`0306Ko
oooooooo01Soool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00K_ooo`0306Kooooooooo
00?oool00`1Vooooooooo`0Hoooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool006koool0
0`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`80000Ooooo00?o09Woooooool0KOooo`00K_oo
o`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool07_ooo`03o`2Ioooooooo
06goool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000oooooooo01koool0
0ol0VOooooooo`1]oooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?oo
ooooo`0Noooo00?o09Woooooool0KOooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0H
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool006koool00`1Vooooooooo`03oooo00<0
I_ooooooool06?ooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001^oooo00<0I_oooooo
ool00oooo`0306Kooooooooo01Soool200007oooo`03o`2Ioooooooo06goool006koool00`1Voooo
ooooo`03oooo00<0I_ooooooool06?ooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001^
oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0Noooo00?o09Wooooo
ool0KOooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool07_oo
o`03o`2Ioooooooo06goool006koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000
oooooooo01koool00ol0VOooooooo`1]oooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo
01Soool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00K_ooo`0306Kooooooooo00?oool0
0`1Vooooooooo`0Hoooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool006koool00`1Voooo
ooooo`03oooo00<0I_ooooooool06?ooo`80000Ooooo00?o09Woooooool0KOooo`00K_ooo`0306Ko
oooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool0
06koool00`1Vooooooooo`03oooo00<0I_ooooooool06?ooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo001^oooo00<0I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0N
oooo00?o09Woooooool0KOooo`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0
003oooooool07_ooo`03o`2Ioooooooo06goool006koool00`1Vooooooooo`03oooo00<0I_oooooo
ool06?ooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001^oooo00<0I_ooooooool00ooo
o`0306Kooooooooo01Soool200007oooo`03o`2Ioooooooo06goool006koool00`1Vooooooooo`03
oooo00<0I_ooooooool06?ooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001^oooo00<0
I_ooooooool00oooo`0306Kooooooooo01Soool00`000?ooooooo`0Noooo00?o09Woooooool0KOoo
o`00K_ooo`0306Kooooooooo00?oool00`1Vooooooooo`0Hoooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool006koool00`1Vooooooooo`03oooo00<0I_ooooooool01Oooo`800004oooo0P00
00Coool200001Oooo`030000oooooooo01koool00ol0VOooooooo`1]oooo001^oooo00<0I_oooooo
ool00oooo`0306Kooooooooo00Coool010000?ooooooo`0000Soool010000?ooooooo`0000Coool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00K_ooo`L0I_l6oooo00@0003oooooool0000;
oooo00<0003oooooool00_ooo`<0000Noooo00?o09Woooooool0KOooo`00Noooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool007_oool010000?oo
ooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool0
07coool200002_ooo`<00004oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo002?oooo0P0001ooool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_oo
o`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000
oooooooo01koool00ol0VOooooooo`1]oooo002?oooo0P0001ooool00ol0VOooooooo`1]oooo002?
oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0
003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Wooooo
ool0KOooo`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool0
0ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool200007ooo
o`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008Ooool500000oooo`030000oooooooo01koool00ol0VOooooooo`1]oooo0029
oooo00<0003oooooool00oooo`030000oooooooo01koool00ol0VOooooooo`1]oooo0029oooo00<0
003oooooool00oooo`<0000Noooo00?o09Woooooool0KOooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0Noooo00?o09Woooooool0KOooo`00R?ooo`800005oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000
oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo
06goool008ooool200007oooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0
003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Wooooo
ool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo0P0001ooool0
0ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool0
0`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?oo
ooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`80000Ooooo00?o09Woooooool0KOooo`00Sooo
o`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2I
oooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Woooooool0KOooo`00Soooo`030000
oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0003oooooool07_ooo`03o`2Ioooooooo
06goool008ooool200007oooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o
09Woooooool0KOooo`00Soooo`030000oooooooo01koool00ol0VOooooooo`1]oooo002?oooo00<0
003oooooool07_ooo`03o`2Ioooooooo06goool008ooool00`000?ooooooo`0Noooo00?o09Wooooo
ool0KOooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo01koool00ol0VOoo
ooooo`1]oooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
01koool00ol0VOooooooo`1]oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool3
00007_ooo`03o`2Ioooooooo06goool007goool00`000?ooooooo`08oooo0P0009Koool007goool0
0`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQ
oooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000?oool500000_ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003oooooool0Nooo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0
003oooooool00oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003?ooo`040000
oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000003oooo`040000oooooooo00002_ooo`030000oooooooo00;oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.59832 .24721 L
.60873 .24721 L
.61984 .24721 L
.6254 .24721 L
.63064 .24721 L
.63292 .24721 L
.63534 .24721 L
.6366 .24721 L
s
.6366 .24721 m
.63671 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.34309 .24721 L
.35271 .24721 L
.35742 .24721 L
.35948 .24721 L
.36173 .24721 L
.36294 .24721 L
.36405 .37082 L
.36512 .37082 L
.36626 .37082 L
.37114 .37082 L
.3815 .37082 L
.39178 .37082 L
.3946 .37082 L
.39614 .37082 L
.39758 .37082 L
.39881 .37082 L
.40012 .24721 L
.40087 .24721 L
.40158 .24721 L
.40291 .24721 L
.42308 .24721 L
.46141 .24721 L
.50219 .24721 L
.54146 .24721 L
.57921 .24721 L
.61941 .24721 L
.6581 .24721 L
.69924 .24721 L
.73886 .24721 L
.77697 .24721 L
.81753 .24721 L
.85658 .24721 L
.89808 .24721 L
.93806 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`07oooo00<0
I_ooooooool00_ooo`030000oooooooo00;oool00`1Vooooooooo`07oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool00_ooo`03o`2Ioooooooo
00Ooool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool006coool00`1Vooooooooo`07
oooo00<0I_ooooooool05_ooo`030000oooooooo023oool00ol0VOooooooo`1[oooo001/oooo00<0
I_ooooooool01oooo`0306Kooooooooo01Koool00`000?ooooooo`0Poooo00?o09Woooooool0Jooo
o`00K?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo00<0003oooooool08?ooo`03o`2I
oooooooo06_oool006coool00`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`030000oooooooo
023oool00ol0VOooooooo`1[oooo001/oooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool2
00008Oooo`03o`2Ioooooooo06_oool006coool00`1Vooooooooo`07oooo00<0I_ooooooool05_oo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo001/oooo00<0I_ooooooool01oooo`0306Ko
oooooooo01Koool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00K?ooo`0306Kooooooooo
00Ooool00`1Vooooooooo`0Foooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool006coool0
0`1Vooooooooo`07oooo00<0I_ooooooool05_ooo`030000oooooooo023oool00ol0VOooooooo`1[
oooo001/oooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00K?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0Foooo0P00027oool0
0ol0VOooooooo`1[oooo001/oooo00<0I_ooooooool01oooo`0306Kooooooooo01Koool00`000?oo
ooooo`0Poooo00?o09Woooooool0Joooo`00K?ooo`0306Kooooooooo00Ooool00`1Vooooooooo`0F
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool006coool00`1Vooooooooo`07oooo00<0
I_ooooooool05_ooo`030000oooooooo023oool00ol0VOooooooo`1[oooo001]oooo00<0I_oooooo
ool01Oooo`0306Kooooooooo01Ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00KOoo
o`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo00<0003oooooool08?ooo`03o`2Ioooooooo
06_oool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool200008Ooo
o`03o`2Ioooooooo06_oool006goool00`1Vooooooooo`05oooo00<0I_ooooooool05oooo`030000
oooooooo023oool00ol0VOooooooo`1[oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo
01Ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00KOooo`0306Kooooooooo00Goool0
0`1Vooooooooo`0Goooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool006goool00`1Voooo
ooooo`05oooo00<0I_ooooooool05oooo`030000oooooooo023oool00ol0VOooooooo`1[oooo001]
oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool00`000?ooooooo`0Poooo00?o09Wooooo
ool0Joooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo0P00027oool00ol0VOoo
ooooo`1[oooo001]oooo00<0I_ooooooool01Oooo`0306Kooooooooo01Ooool00`000?ooooooo`0P
oooo00?o09Woooooool0Joooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`0Goooo00<0
003oooooool08?ooo`03o`2Ioooooooo06_oool006goool00`1Vooooooooo`05oooo00<0I_oooooo
ool05oooo`030000oooooooo023oool00ol0VOooooooo`1[oooo001]oooo00<0I_ooooooool01Ooo
o`0306Kooooooooo00Coool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00KOooo`0306Kooooooooo00Goool00`1Vooooooooo`03oooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
06goool906Ko1Oooo`040000oooooooo00002oooo`030000oooooooo00;oool300008?ooo`03o`2I
oooooooo06_oool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo023oool00ol0VOooooooo`1[oooo001loooo0P0000[oool300001?ooo`030000oooooooo
023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`80000Qoooo00?o09Wooooo
ool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003ooooo
ool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Jooo
o`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Sooo
o`80000Qoooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[
oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0P
oooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool200008Oooo`03o`2Ioooooooo
06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo
023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo0P00027oool00ol0VOooooooo`1[oooo002?oooo00<0003ooooo
ool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Jooo
o`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo0027oooo1@0000?oool00`000?oo
ooooo`0Poooo00?o09Woooooool0Joooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0P
oooo00?o09Woooooool0Joooo`00ROooo`030000oooooooo00?oool300008?ooo`03o`2Ioooooooo
06_oool008Woool00`000?ooooooo`03oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
08Woool00`000?ooooooo`03oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008Soool2
00001Oooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Sooo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo0P00027oool00ol0VOooooooo`1[
oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0P
oooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o
09Woooooool0Joooo`00Soooo`80000Qoooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo
023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool0
08ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool0
0ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool2
00008Oooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Jooo
o`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo00<0003oooooool08?oo
o`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00Sooo
o`030000oooooooo023oool00ol0VOooooooo`1[oooo002?oooo0P00027oool00ol0VOooooooo`1[
oooo002?oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool008ooool00`000?ooooooo`0P
oooo00?o09Woooooool0Joooo`00Soooo`030000oooooooo023oool00ol0VOooooooo`1[oooo002?
oooo00<0003oooooool08?ooo`03o`2Ioooooooo06_oool007_oool500000_ooo`800004oooo0P00
00Goool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00OOooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`0Poooo00?o09Woooooool0Joooo`00OOooo`030000
oooooooo00[oool00`000?ooooooo`02oooo0`00023oool00ol0VOooooooo`1[oooo001moooo00<0
003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool0
07coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool2
00001?ooo`800003oooo1@0000;oool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`00
00[oool01@000?ooooooooooo`000002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000
oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000:oooo00<0003oooooool01?oo
o`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool0
10000?ooooooo`0000[oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000003oooo`040000oooooooo00002_ooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_oo
o`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.59832 .24721 L
.61984 .24721 L
.6298 .24721 L
.63527 .24721 L
.63796 .24721 L
.64043 .24721 L
.64164 .24721 L
.64277 .24721 L
s
.64277 .24721 m
.64295 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.33304 .24721 L
.34309 .24721 L
.34772 .24721 L
.35028 .24721 L
.35271 .24721 L
.35496 .24721 L
.35624 .24721 L
.35742 .37082 L
.35852 .37082 L
.35951 .37082 L
.36173 .37082 L
.3815 .37082 L
.39086 .37082 L
.39597 .37082 L
.40075 .37082 L
.40324 .37082 L
.40396 .37082 L
.40464 .37082 L
.40592 .24721 L
.4066 .24721 L
.40733 .24721 L
.40863 .24721 L
.41159 .24721 L
.42157 .24721 L
.45932 .24721 L
.49952 .24721 L
.53821 .24721 L
.57935 .24721 L
.61897 .24721 L
.65708 .24721 L
.69764 .24721 L
.73669 .24721 L
.77818 .24721 L
.81817 .24721 L
.85663 .24721 L
.89755 .24721 L
.93695 .24721 L
.97484 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`06oooo00<0
I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`06oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool00oooo`03o`2Ioooooooo
00Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool006_oool00`1Vooooooooo`09
oooo00<0I_ooooooool05Oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo001[oooo00<0
I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool08Oooo`03o`2I
oooooooo06[oool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo
027oool00ol0VOooooooo`1Zoooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool2
00008_ooo`03o`2Ioooooooo06[oool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Ooo
o`030000oooooooo027oool00ol0VOooooooo`1Zoooo001[oooo00<0I_ooooooool02Oooo`0306Ko
oooooooo01Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Joooo`0306Kooooooooo
00Woool00`1Vooooooooo`0Eoooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool006_oool0
0`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo0P0002;oool0
0ol0VOooooooo`1Zoooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0E
oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool006_oool00`1Vooooooooo`09oooo00<0
I_ooooooool05Oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo001[oooo00<0I_oooooo
ool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Jooo
o`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo027oool0
0ol0VOooooooo`1Zoooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool200008_oo
o`03o`2Ioooooooo06[oool006_oool00`1Vooooooooo`09oooo00<0I_ooooooool05Oooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo
01Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Joooo`0306Kooooooooo00Woool0
0`1Vooooooooo`0Eoooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool006_oool00`1Voooo
ooooo`09oooo00<0I_ooooooool05Oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo001[
oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`0Qoooo00?o09Wooooo
ool0J_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo0P0002;oool00ol0VOoo
ooooo`1Zoooo001[oooo00<0I_ooooooool02Oooo`0306Kooooooooo01Goool00`000?ooooooo`0Q
oooo00?o09Woooooool0J_ooo`00Joooo`0306Kooooooooo00Woool00`1Vooooooooo`0Eoooo00<0
003oooooool08Oooo`03o`2Ioooooooo06[oool006_oool00`1Vooooooooo`09oooo00<0I_oooooo
ool05Oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo001[oooo00<0I_ooooooool02Ooo
o`0306Kooooooooo00;oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Qoooo00?o
09Woooooool0J_ooo`00Joooo`0306Kooooooooo00Woool01@1Vooooooooooooo`000002oooo00<0
003oooooool01_ooo`040000oooooooo00001?ooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo001[oooo3@1Vo`?oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`00027oool0
0ol0VOooooooo`1Zoooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Q
oooo00?o09Woooooool0J_ooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00O?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool200008_ooo`03o`2I
oooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo
027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Wooooo
ool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo0P0002;oool00ol0VOoo
ooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Q
oooo00?o09Woooooool0J_ooo`00Soooo`80000Roooo00?o09Woooooool0J_ooo`00Soooo`030000
oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Qoooo`D00003oooo00<0
003oooooool08Oooo`03o`2Ioooooooo06[oool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool008Woool00`000?ooooooo`03oooo0`00027oool00ol0VOoo
ooooo`1Zoooo0029oooo00<0003oooooool00oooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo0029oooo00<0003oooooool00oooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo0028
oooo0P0000Goool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo
027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`80000Roooo00?o09Wooooo
ool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Ooo
o`03o`2Ioooooooo06[oool008ooool200008_ooo`03o`2Ioooooooo06[oool008ooool00`000?oo
ooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Z
oooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Q
oooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?
oooo0P0002;oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo
06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`030000oooooooo
027oool00ol0VOooooooo`1Zoooo002?oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool0
08ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_ooo`00Soooo`80000Roooo00?o09Wooooo
ool0J_ooo`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo002?oooo00<0003ooooo
ool08Oooo`03o`2Ioooooooo06[oool008ooool00`000?ooooooo`0Qoooo00?o09Woooooool0J_oo
o`00Soooo`030000oooooooo027oool00ol0VOooooooo`1Zoooo001koooo1@0000;oool200001?oo
o`800005oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool007goool00`000?ooooooo`07
oooo00@0003oooooool00004oooo00<0003oooooool08Oooo`03o`2Ioooooooo06[oool007goool0
0`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000Qoooo00?o09Woooooool0J_ooo`00OOoo
o`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2E
oooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003ooooo
ool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Ooo
o`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200000oooo`@00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002?oo
o`030000oooooooo00Coool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000
oooooooo00goool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool0N_oo
o`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool0000:oooo00<0003oooooool00_oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.59832 .24721 L
.61984 .24721 L
.6298 .24721 L
.63527 .24721 L
.64043 .24721 L
.64524 .24721 L
.64656 .24721 L
.64728 .24721 L
.64796 .24721 L
s
.64796 .24721 m
.64814 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.33304 .24721 L
.33788 .24721 L
.34309 .24721 L
.34566 .24721 L
.34811 .24721 L
.34918 .24721 L
.35031 .24721 L
.35156 .37082 L
.35271 .37082 L
.36173 .37082 L
.3815 .37082 L
.39178 .37082 L
.39719 .37082 L
.40291 .37082 L
.40533 .37082 L
.40792 .37082 L
.40868 .37082 L
.40941 .37082 L
.41006 .37082 L
.41076 .24721 L
.41143 .24721 L
.41214 .24721 L
.41342 .24721 L
.42308 .24721 L
.46083 .24721 L
.50104 .24721 L
.53972 .24721 L
.58086 .24721 L
.62049 .24721 L
.65859 .24721 L
.69916 .24721 L
.7382 .24721 L
.7797 .24721 L
.81968 .24721 L
.85815 .24721 L
.89907 .24721 L
.93847 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`04oooo00<0
I_ooooooool01Oooo`030000oooooooo00Coool00`1Vooooooooo`05oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool01?ooo`03o`2Ioooooooo
00Goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool006Woool00`1Vooooooooo`0<
oooo00<0I_ooooooool05?ooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo001Yoooo00<0
I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Roooo00?o09Woooooool0JOoo
o`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool08_ooo`03o`2I
oooooooo06Woool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo
02;oool00ol0VOooooooo`1Yoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool2
00008oooo`03o`2Ioooooooo06Woool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?oo
o`030000oooooooo02;oool00ol0VOooooooo`1Yoooo001Yoooo00<0I_ooooooool03?ooo`0306Ko
oooooooo01Coool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00JOooo`0306Kooooooooo
00coool00`1Vooooooooo`0Doooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool006Woool0
0`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo02;oool00ol0VOooooooo`1Y
oooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Roooo00?o
09Woooooool0JOooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo0P0002?oool0
0ol0VOooooooo`1Yoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?oo
ooooo`0Roooo00?o09Woooooool0JOooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0D
oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool006Woool00`1Vooooooooo`0<oooo00<0
I_ooooooool05?ooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo001Yoooo00<0I_oooooo
ool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00JOoo
o`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0003oooooool08_ooo`03o`2Ioooooooo
06Woool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo02;oool0
0ol0VOooooooo`1Yoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool200008ooo
o`03o`2Ioooooooo06Woool006Woool00`1Vooooooooo`0<oooo00<0I_ooooooool05?ooo`030000
oooooooo02;oool00ol0VOooooooo`1Yoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo
01Coool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00JOooo`0306Kooooooooo00coool0
0`1Vooooooooo`0Doooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool006Woool00`1Voooo
ooooo`0<oooo00<0I_ooooooool05?ooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo001Y
oooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0Roooo00?o09Wooooo
ool0JOooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo0P0002?oool00ol0VOoo
ooooo`1Yoooo001Yoooo00<0I_ooooooool03?ooo`0306Kooooooooo01Coool00`000?ooooooo`0R
oooo00?o09Woooooool0JOooo`00JOooo`0306Kooooooooo00coool00`1Vooooooooo`0Doooo00<0
003oooooool08_ooo`03o`2Ioooooooo06Woool006Woool00`1Vooooooooo`0<oooo00<0I_oooooo
ool05?ooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo001Yoooo00<0I_ooooooool03?oo
o`0406Kooooooooooooo0P0000Coool200001?ooo`800005oooo00<0003oooooool08_ooo`03o`2I
oooooooo06Woool006Woool00`1Vooooooooo`0<oooo00@0I_ooooooool00002oooo00<0003ooooo
ool01_ooo`040000oooooooo00001?ooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo001Y
oooo401Vo`;oool010000?ooooooo`0000_oool00`000?ooooooo`02oooo0`0002;oool00ol0VOoo
ooooo`1Yoooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Roooo00?o
09Woooooool0JOooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?oo
ooooo`0Roooo00?o09Woooooool0JOooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0R
oooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?
oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool200008oooo`03o`2Ioooooooo
06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo
02;oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool0
08ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOooo`00Soooo`030000oooooooo02;oool0
0ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_ooo`03o`2Ioooooooo06Woool008ooool2
00008oooo`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Roooo00?o09Woooooool0JOoo
o`00Soooo`030000oooooooo02;oool00ol0VOooooooo`1Yoooo002?oooo00<0003oooooool08_oo
o`03o`2Ioooooooo06Woool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo0P0002Coool00ol0VOooooooo`1X
oooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0S
oooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?
oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo
02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool0
08ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Qoooo`D00003oooo00<0003ooooo
ool08oooo`03o`2Ioooooooo06Soool008Woool00`000?ooooooo`03oooo00<0003oooooool08ooo
o`03o`2Ioooooooo06Soool008Woool00`000?ooooooo`03oooo0`0002?oool00ol0VOooooooo`1X
oooo0029oooo00<0003oooooool00oooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo0029
oooo00<0003oooooool00oooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo0028oooo0P00
00Goool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool0
0ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool0
0`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?oo
o`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08ooo
o`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2I
oooooooo06Soool008ooool200009?ooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0S
oooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?
oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o
09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo0P00
02Coool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool0
08ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`030000oooooooo02?oool0
0ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool008ooool0
0`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Soooo`80000Toooo00?o09Woooooool0J?oo
o`00Soooo`030000oooooooo02?oool00ol0VOooooooo`1Xoooo002?oooo00<0003oooooool08ooo
o`03o`2Ioooooooo06Soool008ooool00`000?ooooooo`0Soooo00?o09Woooooool0J?ooo`00Sooo
o`030000oooooooo02?oool00ol0VOooooooo`1Xoooo001koooo1@0000;oool200001?ooo`800005
oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool007goool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00<0003oooooool08oooo`03o`2Ioooooooo06Soool007goool00`000?oo
ooooo`0:oooo00<0003oooooool00_ooo`<0000Soooo00?o09Woooooool0J?ooo`00OOooo`030000
oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001l
oooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?oo
o`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000
oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P00
00Coool200000oooo`@00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008
oooo00<0003oooooool00oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03Oooo`040000oooooooo00002Oooo`030000oooooooo
00Goool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<
oooo00@0003oooooool0000:oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`00
00?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.59832 .24721 L
.61984 .24721 L
.6298 .24721 L
.64043 .24721 L
.64559 .24721 L
.64812 .24721 L
.65045 .24721 L
.65258 .24721 L
.65365 .24721 L
s
.65365 .24721 m
.65382 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.32392 .24721 L
.33304 .24721 L
.33788 .24721 L
.34055 .24721 L
.34186 .24721 L
.34309 .24721 L
.34425 .24721 L
.34549 .37082 L
.3462 .37082 L
.34686 .37082 L
.34811 .37082 L
.35271 .37082 L
.36173 .37082 L
.3815 .37082 L
.39126 .37082 L
.40158 .37082 L
.41038 .37082 L
.4128 .37082 L
.41412 .37082 L
.41538 .37082 L
.41655 .37082 L
.41782 .24721 L
.41898 .24721 L
.42005 .24721 L
.45932 .24721 L
.49707 .24721 L
.53727 .24721 L
.57596 .24721 L
.6171 .24721 L
.65672 .24721 L
.69483 .24721 L
.73539 .24721 L
.77444 .24721 L
.81593 .24721 L
.85592 .24721 L
.89438 .24721 L
.9353 .24721 L
.9747 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`02oooo00<0
I_ooooooool01oooo`030000oooooooo00Koool00`1Vooooooooo`03oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool01_ooo`03o`2Ioooooooo
00?oool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool006Ooool00`1Vooooooooo`0@
oooo00<0I_ooooooool04_ooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo001Woooo00<0
I_ooooooool04?ooo`0306Kooooooooo01;oool00`000?ooooooo`0Toooo00?o09Woooooool0Iooo
o`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0Boooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool006Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`030000oooooooo
02Coool00ol0VOooooooo`1Woooo001Woooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool2
00009Oooo`03o`2Ioooooooo06Ooool006Ooool00`1Vooooooooo`0@oooo00<0I_ooooooool04_oo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo001Woooo00<0I_ooooooool04?ooo`0306Ko
oooooooo01;oool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Ioooo`0306Kooooooooo
013oool00`1Vooooooooo`0Boooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool006Ooool0
0`1Vooooooooo`0@oooo00<0I_ooooooool04_ooo`030000oooooooo02Coool00ol0VOooooooo`1W
oooo001Woooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0Boooo0P0002Goool0
0ol0VOooooooo`1Woooo001Woooo00<0I_ooooooool04?ooo`0306Kooooooooo01;oool00`000?oo
ooooo`0Toooo00?o09Woooooool0Ioooo`00Ioooo`0306Kooooooooo013oool00`1Vooooooooo`0B
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool006Ooool00`1Vooooooooo`0@oooo00<0
I_ooooooool04_ooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo001Xoooo00<0I_oooooo
ool03oooo`0306Kooooooooo01;oool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00J?oo
o`0306Kooooooooo00ooool00`1Vooooooooo`0Boooo00<0003oooooool09?ooo`03o`2Ioooooooo
06Ooool006Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool200009Ooo
o`03o`2Ioooooooo06Ooool006Soool00`1Vooooooooo`0?oooo00<0I_ooooooool04_ooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo
01;oool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00J?ooo`0306Kooooooooo00ooool0
0`1Vooooooooo`0Boooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool006Soool00`1Voooo
ooooo`0?oooo00<0I_ooooooool04_ooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo001X
oooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool00`000?ooooooo`0Toooo00?o09Wooooo
ool0Ioooo`00J?ooo`0306Kooooooooo00ooool00`1Vooooooooo`0Boooo0P0002Goool00ol0VOoo
ooooo`1Woooo001Xoooo00<0I_ooooooool03oooo`0306Kooooooooo01;oool00`000?ooooooo`0T
oooo00?o09Woooooool0Ioooo`00J?ooo`0306Kooooooooo00ooool00`1Vooooooooo`0Boooo00<0
003oooooool09?ooo`03o`2Ioooooooo06Ooool006Soool00`1Vooooooooo`0?oooo00<0I_oooooo
ool04_ooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo001Xoooo00<0I_ooooooool03ooo
o`0406Kooooo000000001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Toooo00?o09Wooooo
ool0Ioooo`00J?ooo`0306Kooooooooo00ooool01@1Vo`000?ooooooo`000008oooo00@0003ooooo
ool00004oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool006SooolC06Ko00@0003ooooo
ool0000;oooo00<0003oooooool00_ooo`<0000Toooo00?o09Woooooool0Ioooo`00Noooo`040000
oooooooo00002Oooo`800005oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool007_oool0
10000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003oooooool09?ooo`03o`2Ioooooooo
06Ooool007coool200002_ooo`<00004oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool0
08ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOooooooo`1Woooo002?oooo00<0003ooooo
ool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Iooo
o`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?oo
o`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Sooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P0002Goool00ol0VOooooooo`1W
oooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0T
oooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`80000Uoooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo
02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool0
08ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool2
00009Oooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Iooo
o`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?oo
o`03o`2Ioooooooo06Ooool008Ooool500000oooo`030000oooooooo02Coool00ol0VOooooooo`1W
oooo0029oooo00<0003oooooool00oooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo0029
oooo00<0003oooooool00oooo`<0000Toooo00?o09Woooooool0Ioooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00R?ooo`800005oooo00<0003oooooool09?oo
o`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Sooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool200009Oooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0T
oooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo0P00
02Goool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool0
08ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool0
0`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Soooo`80000Uoooo00?o09Woooooool0Iooo
o`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?oo
o`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o09Woooooool0Ioooo`00Sooo
o`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?oooo00<0003oooooool09?ooo`03o`2I
oooooooo06Ooool008ooool200009Oooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0T
oooo00?o09Woooooool0Ioooo`00Soooo`030000oooooooo02Coool00ol0VOooooooo`1Woooo002?
oooo00<0003oooooool09?ooo`03o`2Ioooooooo06Ooool008ooool00`000?ooooooo`0Toooo00?o
09Woooooool0Ioooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo02Coool0
0ol0VOooooooo`1Woooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo02Coool00ol0VOooooooo`1Woooo001moooo00<0003oooooool02_ooo`030000oooooooo
00;oool300009?ooo`03o`2Ioooooooo06Ooool007goool00`000?ooooooo`08oooo0P0009Koool0
07goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool0
0?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001k
oooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00[oool00`000?ooooooo`03oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<
oooo00@0003oooooool0000;oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.64043 .24721 L
.65045 .24721 L
.65519 .24721 L
.65726 .24721 L
.65844 .24721 L
.65954 .24721 L
.66062 .24721 L
s
.66062 .24721 m
.66079 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.30316 .24721 L
.31323 .24721 L
.32392 .24721 L
.33304 .24721 L
.33554 .24721 L
.33692 .24721 L
.33823 .24721 L
.33944 .37082 L
.34013 .37082 L
.34076 .37082 L
.34309 .37082 L
.38221 .37082 L
.3925 .37082 L
.40363 .37082 L
.40873 .37082 L
.41413 .37082 L
.41874 .37082 L
.42 .37082 L
.4207 .37082 L
.42135 .37082 L
.42263 .24721 L
.4238 .24721 L
.46213 .24721 L
.50291 .24721 L
.54217 .24721 L
.57993 .24721 L
.62013 .24721 L
.65882 .24721 L
.69996 .24721 L
.73958 .24721 L
.77769 .24721 L
.81825 .24721 L
.85729 .24721 L
.89879 .24721 L
.93877 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool01@000?ooooooooooo`1Vo`0:
oooo00<0003oooooool01oooo`0306Kooooooooo00;oool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`08oooo00Go09Woooooooooool000003_oo
o`030000oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0Eoooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00I_ooo`0306Kooooooooo01;oool00`1Voooo
ooooo`0Aoooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool006Koool00`1Vooooooooo`0B
oooo00<0I_ooooooool04Oooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo001Voooo00<0
I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo0P0002Ooool00ol0VOooooooo`1U
oooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003ooooo
ool09_ooo`03o`2Ioooooooo06Goool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Ooo
o`030000oooooooo02Koool00ol0VOooooooo`1Uoooo001Voooo00<0I_ooooooool04_ooo`0306Ko
oooooooo017oool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00I_ooo`0306Kooooooooo
01;oool00`1Vooooooooo`0Aoooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool006Koool0
0`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`80000Woooo00?o09Woooooool0IOooo`00I_oo
o`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo02Koool0
0ol0VOooooooo`1Uoooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0A
oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool006Koool00`1Vooooooooo`0Boooo00<0
I_ooooooool04Oooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo001Voooo00<0I_oooooo
ool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00I_oo
o`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo0P0002Ooool00ol0VOooooooo`1Uoooo001V
oooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00I_ooo`0306Kooooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool09_oo
o`03o`2Ioooooooo06Goool006Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo
017oool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00I_ooo`0306Kooooooooo01;oool0
0`1Vooooooooo`0Aoooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool006Koool00`1Voooo
ooooo`0Boooo00<0I_ooooooool04Oooo`80000Woooo00?o09Woooooool0IOooo`00I_ooo`0306Ko
oooooooo01;oool00`1Vooooooooo`0Aoooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool0
06Koool00`1Vooooooooo`0Boooo00<0I_ooooooool04Oooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo001Voooo00<0I_ooooooool04_ooo`0306Kooooooooo017oool00`000?ooooooo`0V
oooo00?o09Woooooool0IOooo`00I_ooo`0306Kooooooooo01;oool00`1Vo`0000000004oooo0P00
00Coool200001Oooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo001Voooo00<0I_oooooo
ool04_ooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000oooooooo02Koool0
0ol0VOooooooo`1Uoooo001Voooo5@1Vo`040000oooooooo00002oooo`030000oooooooo00;oool3
00009_ooo`03o`2Ioooooooo06Goool007_oool010000?ooooooo`0000Woool200001Oooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo001koooo00@0003oooooool00009oooo00<0003ooooo
ool01?ooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo001loooo0P0000[oool300001?oo
o`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000W
oooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?
oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`80000Woooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool0
0ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool200009ooo
o`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Sooo
o`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool00ol0VOooooooo`1Uoooo002?
oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo0027oooo1@00
00?oool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00ROooo`030000oooooooo00?oool300009_oo
o`03o`2Ioooooooo06Goool008Woool00`000?ooooooo`03oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008Woool00`000?ooooooo`03oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008Soool200001Oooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool0
0ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?oo
ooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`80000Woooo00?o09Woooooool0IOooo`00Sooo
o`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2I
oooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000
oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo
06Goool008ooool200009oooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o
09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo00<0
003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool00`000?ooooooo`0Voooo00?o09Wooooo
ool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOooooooo`1Uoooo002?oooo0P0002Ooool0
0ol0VOooooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool008ooool0
0`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00Soooo`030000oooooooo02Koool00ol0VOoo
ooooo`1Uoooo002?oooo00<0003oooooool09_ooo`03o`2Ioooooooo06Goool007_oool500000_oo
o`800004oooo0P0000Goool00`000?ooooooo`0Voooo00?o09Woooooool0IOooo`00OOooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0Voooo00?o09Woooooool0IOoo
o`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0002Koool00ol0VOooooooo`1U
oooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000
oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Ooool200001?ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
10000?ooooooo`0000Soool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`00
00[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003?ooo`040000oooooooo00002oooo`040000oooooooooooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.64043 .24721 L
.65045 .24721 L
.65954 .24721 L
.66177 .24721 L
.66412 .24721 L
.66534 .24721 L
.66604 .24721 L
s
.66604 .24721 m
.66614 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.30316 .24721 L
.31323 .24721 L
.32392 .24721 L
.32831 .24721 L
.33073 .24721 L
.33193 .24721 L
.33304 .24721 L
.33433 .37082 L
.33502 .37082 L
.33575 .37082 L
.33823 .37082 L
.34309 .37082 L
.38467 .37082 L
.40553 .37082 L
.41469 .37082 L
.41954 .37082 L
.42221 .37082 L
.42473 .37082 L
.42716 .37082 L
.42783 .37082 L
.42854 .37082 L
.4298 .24721 L
.43094 .24721 L
.432 .24721 L
.43443 .24721 L
.44348 .24721 L
.46328 .24721 L
.50197 .24721 L
.54311 .24721 L
.58274 .24721 L
.62084 .24721 L
.66141 .24721 L
.70045 .24721 L
.74195 .24721 L
.78193 .24721 L
.8204 .24721 L
.86132 .24721 L
.90072 .24721 L
.93861 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool010000?ooooooo`1Vo`_oool0
0`000?ooooooo`09oooo00@0I_ooooooool0000>oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`09oooo00Co09Woooooool0000>oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0
06Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000oooooooo02Ooool00ol0VOoo
ooooo`1Toooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0W
oooo00?o09Woooooool0I?ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0
003oooooool09oooo`03o`2Ioooooooo06Coool006Goool00`1Vooooooooo`0Eoooo00<0I_oooooo
ool03oooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001Uoooo00<0I_ooooooool05Ooo
o`0306Kooooooooo00ooool20000:?ooo`03o`2Ioooooooo06Coool006Goool00`1Vooooooooo`0E
oooo00<0I_ooooooool03oooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001Uoooo00<0
I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool09oooo`03o`2I
oooooooo06Coool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool0
0`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00IOooo`0306Kooooooooo01Goool00`1Voooo
ooooo`0?oooo0P0002Soool00ol0VOooooooo`1Toooo001Uoooo00<0I_ooooooool05Oooo`0306Ko
oooooooo00ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00IOooo`0306Kooooooooo
01Goool00`1Vooooooooo`0?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool006Goool0
0`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000oooooooo02Ooool00ol0VOooooooo`1T
oooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0Woooo00?o
09Woooooool0I?ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03ooo
o`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001Uoooo00<0I_ooooooool05Oooo`0306Ko
oooooooo00ooool20000:?ooo`03o`2Ioooooooo06Coool006Goool00`1Vooooooooo`0Eoooo00<0
I_ooooooool03oooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001Uoooo00<0I_oooooo
ool05Oooo`0306Kooooooooo00ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00IOoo
o`0306Kooooooooo01Goool00`1Vooooooooo`0?oooo00<0003oooooool09oooo`03o`2Ioooooooo
06Coool006Goool00`1Vooooooooo`0Eoooo00<0I_ooooooool03oooo`030000oooooooo02Ooool0
0ol0VOooooooo`1Toooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo00ooool00`000?oo
ooooo`0Woooo00?o09Woooooool0I?ooo`00IOooo`0306Kooooooooo01Goool00`1Vooooooooo`0?
oooo0P0002Soool00ol0VOooooooo`1Toooo001Uoooo00<0I_ooooooool05Oooo`0306Kooooooooo
00ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00IOooo`0306Kooooooooo01Goool0
0`1Vooooooooo`0?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool006Goool00`1Voooo
ooooo`0Eoooo00<0I_ooooooool03oooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001U
oooo00<0I_ooooooool05?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo02Ooool0
0ol0VOooooooo`1Toooo001Uoooo00<0I_ooooooool04oooo`040000oooo06Ko00002?ooo`040000
oooooooo00001?ooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001Uoooo5P1Vo`040000
06Ko06Ko00002oooo`030000oooooooo00;oool300009oooo`03o`2Ioooooooo06Coool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo02Ooool00ol0VOoo
ooooo`1Toooo001loooo0P0000[oool300001?ooo`030000oooooooo02Ooool00ol0VOooooooo`1T
oooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0W
oooo00?o09Woooooool0I?ooo`00Soooo`80000Xoooo00?o09Woooooool0I?ooo`00Soooo`030000
oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo
06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool0
08ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`80000Xoooo00?o09Wooooo
ool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool008ooool20000:?ooo`03o`2Ioooooooo06Coool008ooool00`000?oo
ooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1T
oooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0W
oooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?
oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo
06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo0027oooo1@0000?oool00`000?ooooooo`0Woooo00?o09Wooooo
ool0I?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00ROooo`030000oooooooo00?oool300009oooo`03o`2Ioooooooo06Coool008Woool00`000?oo
ooooo`03oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008Woool00`000?ooooooo`03
oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008Soool200001Oooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool0
08ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool0
0ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Sooo
o`80000Xoooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1T
oooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0W
oooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?
oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool008ooool20000:?ooo`03o`2Ioooooooo
06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo
02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09oooo`03o`2Ioooooooo06Coool0
08ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00Soooo`030000oooooooo02Ooool0
0ol0VOooooooo`1Toooo002?oooo0P0002Soool00ol0VOooooooo`1Toooo002?oooo00<0003ooooo
ool09oooo`03o`2Ioooooooo06Coool008ooool00`000?ooooooo`0Woooo00?o09Woooooool0I?oo
o`00Soooo`030000oooooooo02Ooool00ol0VOooooooo`1Toooo002?oooo00<0003oooooool09ooo
o`03o`2Ioooooooo06Coool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0W
oooo00?o09Woooooool0I?ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`0Woooo00?o09Woooooool0I?ooo`00OOooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`0002Ooool00ol0VOooooooo`1Toooo001moooo00<0003oooooool02?ooo`80002F
oooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo0`00
00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00@0003oooooool0000;oooo00D0003oooooooooool00000OOoo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo1@00
00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000coool010000?ooooooo`00
00Soool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool0
00003oooo`040000oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`1koooo001l
oooo00<0003oooooool04Oooo`80000;oooo0P0000;oool00`000?ooooooo`1loooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.64043 .24721 L
.65045 .24721 L
.65954 .24721 L
.66412 .24721 L
.66652 .24721 L
.66906 .24721 L
.67129 .24721 L
.67255 .24721 L
s
.67255 .24721 m
.67273 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.30316 .24721 L
.31323 .24721 L
.31875 .24721 L
.32145 .24721 L
.32392 .24721 L
.32499 .24721 L
.32617 .24721 L
.32728 .24721 L
.32831 .37082 L
.32951 .37082 L
.3306 .37082 L
.33304 .37082 L
.34309 .37082 L
.38315 .37082 L
.40153 .37082 L
.41196 .37082 L
.4217 .37082 L
.42664 .37082 L
.43133 .37082 L
.43258 .37082 L
.43326 .37082 L
.43391 .37082 L
.4346 .24721 L
.43537 .24721 L
.43672 .24721 L
.44164 .24721 L
.46271 .24721 L
.50139 .24721 L
.54253 .24721 L
.58216 .24721 L
.62027 .24721 L
.66083 .24721 L
.69987 .24721 L
.74137 .24721 L
.78135 .24721 L
.81982 .24721 L
.86074 .24721 L
.90014 .24721 L
.93803 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`00001Vooooo`0<oooo00<0
003oooooool02_ooo`0306Kooooo000000koool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00_oool00ol0V@000?ooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool006?oool0
0`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo02Woool00ol0VOooooooo`1R
oooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0Yoooo00?o
09Woooooool0H_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool006?oool00`1Vooooooooo`0Hoooo00<0I_ooooooool03_oo
o`030000oooooooo02Woool00ol0VOooooooo`1Roooo001Soooo00<0I_ooooooool06?ooo`0306Ko
oooooooo00koool20000:_ooo`03o`2Ioooooooo06;oool006?oool00`1Vooooooooo`0Hoooo00<0
I_ooooooool03_ooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001Soooo00<0I_oooooo
ool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Hooo
o`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool006?oool00`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo02Woool0
0ol0VOooooooo`1Roooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>
oooo0P0002[oool00ol0VOooooooo`1Roooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo
00koool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Hoooo`0306Kooooooooo01Soool0
0`1Vooooooooo`0>oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool006?oool00`1Voooo
ooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001S
oooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0H_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool0:Ooo
o`03o`2Ioooooooo06;oool006?oool00`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000
oooooooo02Woool00ol0VOooooooo`1Roooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo
00koool20000:_ooo`03o`2Ioooooooo06;oool006?oool00`1Vooooooooo`0Hoooo00<0I_oooooo
ool03_ooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001Soooo00<0I_ooooooool06?oo
o`0306Kooooooooo00koool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Hoooo`0306Ko
oooooooo01Soool00`1Vooooooooo`0>oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool0
06?oool00`1Vooooooooo`0Hoooo00<0I_ooooooool03_ooo`030000oooooooo02Woool00ol0VOoo
ooooo`1Roooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool00`000?ooooooo`0Y
oooo00?o09Woooooool0H_ooo`00Hoooo`0306Kooooooooo01Soool00`1Vooooooooo`0>oooo0P00
02[oool00ol0VOooooooo`1Roooo001Soooo00<0I_ooooooool06?ooo`0306Kooooooooo00koool0
0`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Hoooo`0306Kooooooooo01Soool00`1Voooo
ooooo`0>oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool006?oool00`1Vooooooooo`0H
oooo00<0I_ooooooool03_ooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo001Soooo00<0
I_ooooooool05_ooo`800000101Vooooooooooooo`800004oooo0P0000Goool00`000?ooooooo`0Y
oooo00?o09Woooooool0H_ooo`00Hoooo`0306Kooooooooo01Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000Coool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00HooooaP0I_l0
1000001Vo`1Vo`0000_oool00`000?ooooooo`02oooo0`0002Woool00ol0VOooooooo`1Roooo001k
oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Yoooo00?o
09Woooooool0H_ooo`00O?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool0
0`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOoo
ooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1R
oooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool20000:_ooo`03o`2I
oooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000
oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo
02Woool00ol0VOooooooo`1Roooo002?oooo0P0002[oool00ol0VOooooooo`1Roooo002?oooo00<0
003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOoo
ooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Qoooo`D00003oooo00<0003oooooool0:Oooo`03o`2I
oooooooo06;oool008Woool00`000?ooooooo`03oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool008Woool00`000?ooooooo`03oooo0`0002Woool00ol0VOooooooo`1Roooo0029oooo00<0
003oooooool00oooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo0028oooo0P0000Goool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1R
oooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Y
oooo00?o09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Soooo`030000
oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo
02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool0
08ooool20000:_ooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Wooooo
ool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_oo
o`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo0P0002[oool00ol0VOoo
ooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?oo
ooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo02Woool00ol0VOooooooo`1R
oooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool008ooool00`000?ooooooo`0Y
oooo00?o09Woooooool0H_ooo`00Soooo`80000Zoooo00?o09Woooooool0H_ooo`00Soooo`030000
oooooooo02Woool00ol0VOooooooo`1Roooo002?oooo00<0003oooooool0:Oooo`03o`2Ioooooooo
06;oool008ooool00`000?ooooooo`0Yoooo00?o09Woooooool0H_ooo`00Soooo`030000oooooooo
02Woool00ol0VOooooooo`1Roooo001koooo1@0000;oool200001?ooo`800005oooo00<0003ooooo
ool0:Oooo`03o`2Ioooooooo06;oool007goool00`000?ooooooo`07oooo00@0003oooooool00004
oooo00<0003oooooool0:Oooo`03o`2Ioooooooo06;oool007goool00`000?ooooooo`0:oooo00<0
003oooooool00_ooo`<0000Yoooo00?o09Woooooool0H_ooo`00OOooo`030000oooooooo00Soool2
0000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool3
0000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo
07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool0
07Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07oooo0P0000Coool200001Ooo
o`<00002oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_oo
o`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool0000;oooo00@0003ooooo
ool00002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0=oooo00@0003oooooool00008oooo1@0000Coool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo00@0003ooooo
ool00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003ooo
o`040000oooooooo00002Oooo`030000oooo000000?oool00`000?ooooooo`03oooo00<0003ooooo
ool0N?ooo`00NOooo`030000oooooooo017oool200002oooo`800003oooo0`0000;oool00`000?oo
ooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.64043 .24721 L
.65954 .24721 L
.66906 .24721 L
.67373 .24721 L
.67578 .24721 L
.67687 .24721 L
.67803 .24721 L
s
.67803 .24721 m
.67822 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.29205 .24721 L
.30316 .24721 L
.31304 .24721 L
.31574 .24721 L
.31865 .24721 L
.32006 .24721 L
.32076 .24721 L
.3214 .24721 L
.3226 .37082 L
.32392 .37082 L
.34309 .37082 L
.38221 .37082 L
.40219 .37082 L
.4127 .37082 L
.4238 .37082 L
.43374 .37082 L
.43647 .37082 L
.43797 .37082 L
.43871 .37082 L
.43939 .37082 L
.44071 .24721 L
.44141 .24721 L
.44215 .24721 L
.44466 .24721 L
.46386 .24721 L
.50161 .24721 L
.54182 .24721 L
.5805 .24721 L
.62164 .24721 L
.66127 .24721 L
.69938 .24721 L
.73994 .24721 L
.77898 .24721 L
.82048 .24721 L
.86046 .24721 L
.89893 .24721 L
.93985 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool006;oool0
0`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo02[oool00ol0VOooooooo`1Q
oooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`0Zoooo00?o
09Woooooool0HOooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003ooooo
ool0:_ooo`03o`2Ioooooooo067oool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?oo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001Roooo00<0I_ooooooool06oooo`0306Ko
oooooooo00coool20000:oooo`03o`2Ioooooooo067oool006;oool00`1Vooooooooo`0Koooo00<0
I_ooooooool03?ooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001Roooo00<0I_oooooo
ool06oooo`0306Kooooooooo00coool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00H_oo
o`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0:_ooo`03o`2Ioooooooo
067oool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo02[oool0
0ol0VOooooooo`1Qoooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?oo
ooooo`0Zoooo00?o09Woooooool0HOooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<
oooo0P0002_oool00ol0VOooooooo`1Qoooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo
00coool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00H_ooo`0306Kooooooooo01_oool0
0`1Vooooooooo`0<oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool006;oool00`1Voooo
ooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001R
oooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`0Zoooo00?o09Wooooo
ool0HOooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0:_oo
o`03o`2Ioooooooo067oool006;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000
oooooooo02[oool00ol0VOooooooo`1Qoooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo
00coool20000:oooo`03o`2Ioooooooo067oool006;oool00`1Vooooooooo`0Koooo00<0I_oooooo
ool03?ooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001Roooo00<0I_ooooooool06ooo
o`0306Kooooooooo00coool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00H_ooo`0306Ko
oooooooo01_oool00`1Vooooooooo`0<oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool0
06;oool00`1Vooooooooo`0Koooo00<0I_ooooooool03?ooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool00`000?ooooooo`0Z
oooo00?o09Woooooool0HOooo`00H_ooo`0306Kooooooooo01_oool00`1Vooooooooo`0<oooo0P00
02_oool00ol0VOooooooo`1Qoooo001Roooo00<0I_ooooooool06oooo`0306Kooooooooo00coool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00H_ooo`0306Kooooooooo01_oool00`1Voooo
ooooo`0<oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool006;oool00`1Vooooooooo`0K
oooo00<0I_ooooooool03?ooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001Roooo00<0
I_ooooooool05oooo`800002oooo00@0I_ooool000000004oooo0P0000Goool00`000?ooooooo`0Z
oooo00?o09Woooooool0HOooo`00H_ooo`0306Kooooooooo01Koool01P000?ooooooo`000?ooo`1V
o`Koool010000?ooooooo`0000Coool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00H_oo
oaT0I_l01000001Vo`1Vo`000080I_l9oooo00<0003oooooool00_ooo`<0000Zoooo00?o09Wooooo
ool0HOooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0003ooooo
ool0:_ooo`03o`2Ioooooooo067oool007coool200002_ooo`<00004oooo00<0003oooooool0:_oo
o`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Sooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Q
oooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Z
oooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?
oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o
09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo0P00
02_oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool0
08ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool0
0ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`80000[oooo00?o09Woooooool0HOoo
o`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_oo
o`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Sooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool008ooool20000:oooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Z
oooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?
oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008Ooool500000oooo`030000oooooooo
02[oool00ol0VOooooooo`1Qoooo0029oooo00<0003oooooool00oooo`030000oooooooo02[oool0
0ol0VOooooooo`1Qoooo0029oooo00<0003oooooool00oooo`<0000Zoooo00?o09Woooooool0HOoo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00R?ooo`800005
oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o
09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool20000:oooo`03o`2Ioooooooo067oool0
08ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool0
0ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOoo
ooooo`1Qoooo002?oooo0P0002_oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_oo
o`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Sooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2I
oooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`80000[
oooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?
oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool00`000?ooooooo`0Zoooo00?o
09Woooooool0HOooo`00Soooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo002?oooo00<0
003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool20000:oooo`03o`2Ioooooooo067oool0
08ooool00`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Soooo`030000oooooooo02[oool0
0ol0VOooooooo`1Qoooo002?oooo00<0003oooooool0:_ooo`03o`2Ioooooooo067oool008ooool0
0`000?ooooooo`0Zoooo00?o09Woooooool0HOooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo02[oool00ol0VOooooooo`1Qoooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool30000:_ooo`03o`2Ioooooooo067oool007goool00`000?oo
ooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?oo
o`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool0
0`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?oo
ooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01oooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo
00goool010000?ooooooo`0000_oool00`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Nooo
o`030000oooooooo00D0000<oooo00@0003oooooool00009oooo0P0000Coool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002Oooo`030000oooooooo
00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0`0000;oool0
0`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.64043 .24721 L
.65954 .24721 L
.66906 .24721 L
.67803 .24721 L
.68044 .24721 L
.683 .24721 L
.68364 .24721 L
.68433 .24721 L
s
.68433 .24721 m
.68444 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.29205 .24721 L
.30316 .24721 L
.30791 .24721 L
.31054 .24721 L
.31304 .24721 L
.31444 .24721 L
.31523 .24721 L
.31597 .37082 L
.31727 .37082 L
.31865 .37082 L
.32392 .37082 L
.34309 .37082 L
.38467 .37082 L
.40553 .37082 L
.42473 .37082 L
.43443 .37082 L
.43916 .37082 L
.44348 .37082 L
.4446 .37082 L
.44582 .37082 L
.44697 .24721 L
.44804 .24721 L
.45292 .24721 L
.46328 .24721 L
.50255 .24721 L
.5403 .24721 L
.5805 .24721 L
.61919 .24721 L
.66033 .24721 L
.69996 .24721 L
.73806 .24721 L
.77863 .24721 L
.81767 .24721 L
.85917 .24721 L
.89915 .24721 L
.93762 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00[oool00`1Vooooo`00000>oooo00<0
003oooooool03?ooo`030000oooo06Ko00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooool0V@0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0063oool0
0`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo001Poooo00<0I_ooooooool07oooo`0306Kooooooooo00[oool00`000?ooooooo`0/oooo00?o
09Woooooool0Goooo`00H?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool0063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_oo
o`030000oooooooo02coool00ol0VOooooooo`1Ooooo001Poooo00<0I_ooooooool07oooo`0306Ko
oooooooo00[oool20000;Oooo`03o`2Ioooooooo05ooool0063oool00`1Vooooooooo`0Ooooo00<0
I_ooooooool02_ooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001Poooo00<0I_oooooo
ool07oooo`0306Kooooooooo00[oool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00H?oo
o`0306Kooooooooo01ooool00`1Vooooooooo`0:oooo00<0003oooooool0;?ooo`03o`2Ioooooooo
05ooool0063oool00`1Vooooooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo02coool0
0ol0VOooooooo`1Ooooo001Poooo00<0I_ooooooool07oooo`0306Kooooooooo00[oool00`000?oo
ooooo`0/oooo00?o09Woooooool0Goooo`00H?ooo`0306Kooooooooo01ooool00`1Vooooooooo`0:
oooo0P0002goool00ol0VOooooooo`1Ooooo001Poooo00<0I_ooooooool07oooo`0306Kooooooooo
00[oool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00H?ooo`0306Kooooooooo01ooool0
0`1Vooooooooo`0:oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0063oool00`1Voooo
ooooo`0Ooooo00<0I_ooooooool02_ooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001P
oooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool00`000?ooooooo`0/oooo00?o09Wooooo
ool0Goooo`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool0;?oo
o`03o`2Ioooooooo05ooool0063oool00`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000
oooooooo02coool00ol0VOooooooo`1Ooooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo
00_oool20000;Oooo`03o`2Ioooooooo05ooool0063oool00`1Vooooooooo`0Noooo00<0I_oooooo
ool02oooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001Poooo00<0I_ooooooool07_oo
o`0306Kooooooooo00_oool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00H?ooo`0306Ko
oooooooo01koool00`1Vooooooooo`0;oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
063oool00`1Vooooooooo`0Noooo00<0I_ooooooool02oooo`030000oooooooo02coool00ol0VOoo
ooooo`1Ooooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00H?ooo`0306Kooooooooo01koool00`1Vooooooooo`0;oooo0P00
02goool00ol0VOooooooo`1Ooooo001Poooo00<0I_ooooooool07_ooo`0306Kooooooooo00_oool0
0`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00H?ooo`0306Kooooooooo01koool00`1Voooo
ooooo`0;oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0063oool00`1Vooooooooo`0N
oooo00<0I_ooooooool02oooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001Poooo00<0
I_ooooooool06Oooo`800003oooo00<0I_l0000000001?ooo`800005oooo00<0003oooooool0;?oo
o`03o`2Ioooooooo05ooool0063oool00`1Vooooooooo`0Hoooo00@0003oooooool00002oooo00<0
I_ooooooool00oooo`040000oooooooo00001?ooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo001Poooo6`1Vo`04000006Ko06Ko00000`1Vo`Soool00`000?ooooooo`02oooo0`0002coool0
0ol0VOooooooo`1Ooooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00O?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool20000;Oooo`03o`2I
oooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000
oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool20000;Oooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Wooooo
ool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo0P0002goool00ol0VOoo
ooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?oo
ooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Woooooool0Goooo`00Soooo`030000
oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Qoooo`D00003oooo00<0
003oooooool0;?ooo`03o`2Ioooooooo05ooool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008Woool00`000?ooooooo`03oooo0`0002coool00ol0VOoo
ooooo`1Ooooo0029oooo00<0003oooooool00oooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo0029oooo00<0003oooooool00oooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo0028
oooo0P0000Goool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Wooooo
ool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?oo
o`03o`2Ioooooooo05ooool008ooool20000;Oooo`03o`2Ioooooooo05ooool008ooool00`000?oo
ooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1O
oooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/
oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?
oooo0P0002goool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo
05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`030000oooooooo
02coool00ol0VOooooooo`1Ooooo002?oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool0
08ooool00`000?ooooooo`0/oooo00?o09Woooooool0Goooo`00Soooo`80000]oooo00?o09Wooooo
ool0Goooo`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo002?oooo00<0003ooooo
ool0;?ooo`03o`2Ioooooooo05ooool008ooool00`000?ooooooo`0/oooo00?o09Woooooool0Gooo
o`00Soooo`030000oooooooo02coool00ol0VOooooooo`1Ooooo001koooo1@0000;oool200001?oo
o`800005oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool007goool00`000?ooooooo`07
oooo00@0003oooooool00004oooo00<0003oooooool0;?ooo`03o`2Ioooooooo05ooool007goool0
0`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000/oooo00?o09Woooooool0Goooo`00OOoo
o`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2E
oooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001ioooo00<0003ooooo
ool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0003oooooool07ooo
o`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`07
oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003ooooo
ool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?oo
o`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool0000;oooo00<0
003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003ooooo
ool01@0000coool010000?ooooooo`0000Woool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`03
oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P00
00[oool300000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.64043 .24721 L
.65954 .24721 L
.67803 .24721 L
.68335 .24721 L
.68596 .24721 L
.68711 .24721 L
.68837 .24721 L
.6895 .24721 L
s
.6895 .24721 m
.68966 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.29205 .24721 L
.29779 .24721 L
.30316 .24721 L
.3056 .24721 L
.30791 .24721 L
.30919 .24721 L
.30992 .37082 L
.31059 .37082 L
.31304 .37082 L
.32392 .37082 L
.34309 .37082 L
.38221 .37082 L
.40219 .37082 L
.4238 .37082 L
.43394 .37082 L
.43949 .37082 L
.44466 .37082 L
.44908 .37082 L
.45035 .37082 L
.45156 .37082 L
.45264 .24721 L
.45382 .24721 L
.46386 .24721 L
.50465 .24721 L
.54391 .24721 L
.58166 .24721 L
.62187 .24721 L
.66055 .24721 L
.70169 .24721 L
.74132 .24721 L
.77943 .24721 L
.81999 .24721 L
.85903 .24721 L
.90053 .24721 L
.94051 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Woool0101Vooooooooo`0000koool0
0`000?ooooooo`0<oooo00@0003oooooool0I_l;oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00@0003ooooooooo09T;oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0
05ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo02goool00ol0VOoo
ooooo`1Noooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`0]
oooo00?o09Woooooool0G_ooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0
003oooooool0;Oooo`03o`2Ioooooooo05koool005ooool00`1Vooooooooo`0Qoooo00<0I_oooooo
ool02Oooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001Ooooo00<0I_ooooooool08Ooo
o`0306Kooooooooo00Woool20000;_ooo`03o`2Ioooooooo05koool005ooool00`1Vooooooooo`0Q
oooo00<0I_ooooooool02Oooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001Ooooo00<0
I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0;Oooo`03o`2I
oooooooo05koool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool0
0`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Goooo`0306Kooooooooo027oool00`1Voooo
ooooo`09oooo0P0002koool00ol0VOooooooo`1Noooo001Ooooo00<0I_ooooooool08Oooo`0306Ko
oooooooo00Woool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Goooo`0306Kooooooooo
027oool00`1Vooooooooo`09oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool005ooool0
0`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`0]oooo00?o
09Woooooool0G_ooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Ooo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo001Ooooo00<0I_ooooooool08Oooo`0306Ko
oooooooo00Woool20000;_ooo`03o`2Ioooooooo05koool005ooool00`1Vooooooooo`0Qoooo00<0
I_ooooooool02Oooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001Ooooo00<0I_oooooo
ool08Oooo`0306Kooooooooo00Woool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Gooo
o`0306Kooooooooo027oool00`1Vooooooooo`09oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool005ooool00`1Vooooooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo02goool0
0ol0VOooooooo`1Noooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo00Woool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Goooo`0306Kooooooooo027oool00`1Vooooooooo`09
oooo0P0002koool00ol0VOooooooo`1Noooo001Ooooo00<0I_ooooooool08Oooo`0306Kooooooooo
00Woool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Goooo`0306Kooooooooo027oool0
0`1Vooooooooo`09oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool005ooool00`1Voooo
ooooo`0Qoooo00<0I_ooooooool02Oooo`030000oooooooo02goool00ol0VOooooooo`1Noooo001O
oooo00<0I_ooooooool06_ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo02goool0
0ol0VOooooooo`1Noooo001Ooooo00<0I_ooooooool06Oooo`040000oooooooo00001?ooo`0506Ko
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool005oooolL06Ko00@00000I_l0I_l0000506Ko1_ooo`030000oooooooo00;oool30000;Ooo
o`03o`2Ioooooooo05koool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo001koooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo02goool00ol0VOooooooo`1Noooo001loooo0P0000[oool300001?ooo`030000
oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o
09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0
003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool20000;_ooo`03o`2I
oooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000
oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOooooooo`1Noooo002?oooo00<0
003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo0027oooo1@0000?oool0
0`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00ROooo`030000oooooooo00?oool30000;Oooo`03o`2I
oooooooo05koool008Woool00`000?ooooooo`03oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool008Woool00`000?ooooooo`03oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08Soool200001Oooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]
oooo00?o09Woooooool0G_ooo`00Soooo`80000^oooo00?o09Woooooool0G_ooo`00Soooo`030000
oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo
05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo
02goool00ol0VOooooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool0
08ooool20000;_ooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Wooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo00<0003ooooo
ool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?ooooooo`0]oooo00?o09Woooooool0G_oo
o`00Soooo`030000oooooooo02goool00ol0VOooooooo`1Noooo002?oooo0P0002koool00ol0VOoo
ooooo`1Noooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool008ooool00`000?oo
ooooo`0]oooo00?o09Woooooool0G_ooo`00Soooo`030000oooooooo02goool00ol0VOooooooo`1N
oooo002?oooo00<0003oooooool0;Oooo`03o`2Ioooooooo05koool007_oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00OOooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0]oooo00?o09Woooooool0G_ooo`00OOoo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`0002goool00ol0VOooooooo`1Noooo001m
oooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo
09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007coool00`000?oo
ooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0I
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Ooool200001?ooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003oooooool00008oooo0`0000Coool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000003oooo`040000oooooooo00002Ooo
o`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:
oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.64043 .24721 L
.65954 .24721 L
.67803 .24721 L
.68335 .24721 L
.68837 .24721 L
.69287 .24721 L
.6941 .24721 L
.6954 .24721 L
s
.6954 .24721 m
.69557 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.28158 .24721 L
.29205 .24721 L
.29779 .24721 L
.30059 .24721 L
.30182 .24721 L
.30246 .24721 L
.30316 .24721 L
.30442 .37082 L
.3056 .37082 L
.30791 .37082 L
.31304 .37082 L
.32392 .37082 L
.34309 .37082 L
.38467 .37082 L
.40553 .37082 L
.42473 .37082 L
.44348 .37082 L
.45292 .37082 L
.45551 .37082 L
.45693 .37082 L
.45763 .37082 L
.45828 .37082 L
.45953 .24721 L
.4602 .24721 L
.4609 .24721 L
.46328 .24721 L
.50104 .24721 L
.54124 .24721 L
.57993 .24721 L
.62107 .24721 L
.66069 .24721 L
.6988 .24721 L
.73936 .24721 L
.7784 .24721 L
.8199 .24721 L
.85988 .24721 L
.89835 .24721 L
.93927 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Ooool00`1Vooooooooo`02oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`02oooo00<0I_ooooooool01ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00;oool00ol0VOooooooo`07oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool005goool00`1Vooooooooo`0U
oooo00<0I_ooooooool01oooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo001Moooo00<0
I_ooooooool09Oooo`0306Kooooooooo00Ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?oo
o`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo00<0003oooooool0;oooo`03o`2I
oooooooo05coool005goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo
02ooool00ol0VOooooooo`1Loooo001Moooo00<0I_ooooooool09Oooo`0306Kooooooooo00Ooool2
0000<?ooo`03o`2Ioooooooo05coool005goool00`1Vooooooooo`0Uoooo00<0I_ooooooool01ooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo001Moooo00<0I_ooooooool09Oooo`0306Ko
oooooooo00Ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00GOooo`0306Kooooooooo
02Goool00`1Vooooooooo`07oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool005goool0
0`1Vooooooooo`0Uoooo00<0I_ooooooool01oooo`030000oooooooo02ooool00ol0VOooooooo`1L
oooo001Moooo00<0I_ooooooool09Oooo`0306Kooooooooo00Ooool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07oooo0P00033oool0
0ol0VOooooooo`1Loooo001Moooo00<0I_ooooooool09Oooo`0306Kooooooooo00Ooool00`000?oo
ooooo`0_oooo00?o09Woooooool0G?ooo`00GOooo`0306Kooooooooo02Goool00`1Vooooooooo`07
oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool005goool00`1Vooooooooo`0Uoooo00<0
I_ooooooool01oooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo001Moooo00<0I_oooooo
ool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00GOoo
o`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0003oooooool0;oooo`03o`2Ioooooooo
05coool005goool00`1Vooooooooo`0Toooo00<0I_ooooooool02?ooo`030000oooooooo02ooool0
0ol0VOooooooo`1Loooo001Moooo00<0I_ooooooool09?ooo`0306Kooooooooo00Soool20000<?oo
o`03o`2Ioooooooo05coool005goool00`1Vooooooooo`0Toooo00<0I_ooooooool02?ooo`030000
oooooooo02ooool00ol0VOooooooo`1Loooo001Moooo00<0I_ooooooool09?ooo`0306Kooooooooo
00Soool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00GOooo`0306Kooooooooo02Coool0
0`1Vooooooooo`08oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool005goool00`1Voooo
ooooo`0Toooo00<0I_ooooooool02?ooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo001M
oooo00<0I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo0P00033oool00ol0VOoo
ooooo`1Loooo001Moooo00<0I_ooooooool09?ooo`0306Kooooooooo00Soool00`000?ooooooo`0_
oooo00?o09Woooooool0G?ooo`00GOooo`0306Kooooooooo02Coool00`1Vooooooooo`08oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool005goool00`1Vooooooooo`0Toooo00<0I_oooooo
ool02?ooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo001Moooo00<0I_ooooooool07?oo
o`800004oooo0P00000406Kooooooooooooo0P0000Goool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00GOooo`0306Kooooooooo01_oool010000?ooooooo`0000Goool0101Vooooooooo`00
00;oool00`000?ooooooo`02oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool005gooolN
06Ko00@00000I_l0I_l0000606Ko1Oooo`030000oooooooo00;oool30000;oooo`03o`2Ioooooooo
05coool007_oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo
02ooool00ol0VOooooooo`1Loooo001loooo0P0000[oool300001?ooo`030000oooooooo02ooool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`80000`oooo00?o09Woooooool0G?oo
o`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2I
oooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`80000`
oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?
oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool008ooool20000<?ooo`03o`2Ioooooooo05coool0
08ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo0027oooo1@0000?oool00`000?ooooooo`0_
oooo00?o09Woooooool0G?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00ROooo`030000oooooooo00?oool30000;oooo`03o`2Ioooooooo05coool0
08Woool00`000?ooooooo`03oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008Soool200001Ooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2I
oooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000
oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?
oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Wooooo
ool0G?ooo`00Soooo`80000`oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool0
0ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOoo
ooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool20000<?oo
o`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Sooo
o`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0003oooooool0;oooo`03o`2I
oooooooo05coool008ooool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00Soooo`030000
oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo0P00033oool00ol0VOooooooo`1Loooo002?
oooo00<0003oooooool0;oooo`03o`2Ioooooooo05coool008ooool00`000?ooooooo`0_oooo00?o
09Woooooool0G?ooo`00Soooo`030000oooooooo02ooool00ol0VOooooooo`1Loooo002?oooo00<0
003oooooool0;oooo`03o`2Ioooooooo05coool007_oool500000_ooo`800004oooo0P0000Goool0
0`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00OOooo`030000oooooooo00Ooool010000?oo
ooooo`0000Coool00`000?ooooooo`0_oooo00?o09Woooooool0G?ooo`00OOooo`030000oooooooo
00[oool00`000?ooooooo`02oooo0`0002ooool00ol0VOooooooo`1Loooo001moooo00<0003ooooo
ool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool2
00002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0
003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003ooooo
ool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?oo
o`800003oooo0`0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oooooooooo
o`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000Soool0
10000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001goooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Soool010000?ooooooo`00
00Goool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000<
oooo00@0003oooooool00008oooo0`0000Coool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`80000:oooo0`00
00?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.67958 .24721 L
.6883 .24721 L
.69289 .24721 L
.69774 .24721 L
.70025 .24721 L
.70094 .24721 L
.70168 .24721 L
.70238 .24721 L
s
.70238 .24721 m
.70247 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.27193 .24721 L
.28302 .24721 L
.2881 .24721 L
.29088 .24721 L
.29349 .24721 L
.2957 .24721 L
.29695 .24721 L
.29809 .37082 L
.29933 .37082 L
.30069 .37082 L
.30316 .37082 L
.3438 .37082 L
.38293 .37082 L
.40291 .37082 L
.42451 .37082 L
.43466 .37082 L
.44538 .37082 L
.45453 .37082 L
.45704 .37082 L
.45973 .37082 L
.46103 .37082 L
.46227 .37082 L
.46337 .37082 L
.46458 .24721 L
.4658 .24721 L
.46691 .24721 L
.46943 .24721 L
.47398 .24721 L
.48435 .24721 L
.50536 .24721 L
.54499 .24721 L
.58309 .24721 L
.62365 .24721 L
.6627 .24721 L
.7042 .24721 L
.74418 .24721 L
.78265 .24721 L
.82356 .24721 L
.86297 .24721 L
.90085 .24721 L
.94119 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Goool00`1Vooooooooo`04oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`03oooo00<0I_ooooooool01_oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00?oool00ol0VOooooooo`06oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool005_oool00`1Vooooooooo`0X
oooo00<0I_ooooooool01_ooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001Koooo00<0
I_ooooooool0:?ooo`0306Kooooooooo00Koool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Foooo`0306Kooooooooo02Soool00`1Vooooooooo`06oooo00<0003oooooool0<?ooo`03o`2I
oooooooo05_oool005_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool2
0000<Oooo`03o`2Ioooooooo05_oool005_oool00`1Vooooooooo`0Xoooo00<0I_ooooooool01_oo
o`030000oooooooo033oool00ol0VOooooooo`1Koooo001Koooo00<0I_ooooooool0:?ooo`0306Ko
oooooooo00Koool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Foooo`0306Kooooooooo
02Soool00`1Vooooooooo`06oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool005_oool0
0`1Vooooooooo`0Xoooo00<0I_ooooooool01_ooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool00`000?ooooooo`0`oooo00?o
09Woooooool0Foooo`00Foooo`0306Kooooooooo02Soool00`1Vooooooooo`06oooo0P00037oool0
0ol0VOooooooo`1Koooo001Koooo00<0I_ooooooool0:?ooo`0306Kooooooooo00Koool00`000?oo
ooooo`0`oooo00?o09Woooooool0Foooo`00Foooo`0306Kooooooooo02Soool00`1Vooooooooo`06
oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool005_oool00`1Vooooooooo`0Xoooo00<0
I_ooooooool01_ooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001Loooo00<0I_oooooo
ool09oooo`0306Kooooooooo00Koool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00G?oo
o`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo00Koool20000<Ooo
o`03o`2Ioooooooo05_oool005coool00`1Vooooooooo`0Woooo00<0I_ooooooool01_ooo`030000
oooooooo033oool00ol0VOooooooo`1Koooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo
00Koool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00G?ooo`0306Kooooooooo02Ooool0
0`1Vooooooooo`06oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool005coool00`1Voooo
ooooo`0Woooo00<0I_ooooooool01_ooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001L
oooo00<0I_ooooooool09oooo`0306Kooooooooo00Koool00`000?ooooooo`0`oooo00?o09Wooooo
ool0Foooo`00G?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo0P00037oool00ol0VOoo
ooooo`1Koooo001Loooo00<0I_ooooooool09oooo`0306Kooooooooo00Koool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00G?ooo`0306Kooooooooo02Ooool00`1Vooooooooo`06oooo00<0
003oooooool0<?ooo`03o`2Ioooooooo05_oool005coool00`1Vooooooooo`0Woooo00<0I_oooooo
ool01_ooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001Loooo00<0I_ooooooool07Ooo
o`800004oooo0P0000;oool0101Vooooo`00000000Goool00`000?ooooooo`0`oooo00?o09Wooooo
ool0Foooo`00G?ooo`0306Kooooooooo01coool010000?ooooooo`0000Ooool01@1Vo`000?oooooo
o`000004oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool005cooolO06Ko00@00000I_l0
I_l0000806Ko0oooo`030000oooooooo00;oool30000<?ooo`03o`2Ioooooooo05_oool007_oool0
10000?ooooooo`0000Woool200001Oooo`030000oooooooo033oool00ol0VOooooooo`1Koooo001k
oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo033oool00ol0VOoo
ooooo`1Koooo001loooo0P0000[oool300001?ooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000
oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool0
08ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`80000aoooo00?o09Wooooo
ool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003ooooo
ool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool20000<Oooo`03o`2Ioooooooo05_oool008ooool00`000?oo
ooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?
oooo0P00037oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo
05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo0027oooo1@0000?oool00`000?ooooooo`0`oooo00?o09Wooooo
ool0Foooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00ROooo`030000oooooooo00?oool30000<?ooo`03o`2Ioooooooo05_oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008Woool00`000?ooooooo`03
oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008Soool200001Oooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool0
08ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo0P00037oool00ol0VOooooooo`1Koooo002?oooo00<0003ooooo
ool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Sooo
o`80000aoooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1K
oooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?
oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool008ooool20000<Oooo`03o`2Ioooooooo
05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo
033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?ooo`03o`2Ioooooooo05_oool0
08ooool00`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00Soooo`030000oooooooo033oool0
0ol0VOooooooo`1Koooo002?oooo0P00037oool00ol0VOooooooo`1Koooo002?oooo00<0003ooooo
ool0<?ooo`03o`2Ioooooooo05_oool008ooool00`000?ooooooo`0`oooo00?o09Woooooool0Fooo
o`00Soooo`030000oooooooo033oool00ol0VOooooooo`1Koooo002?oooo00<0003oooooool0<?oo
o`03o`2Ioooooooo05_oool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0`
oooo00?o09Woooooool0Foooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`0`oooo00?o09Woooooool0Foooo`00OOooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`00033oool00ol0VOooooooo`1Koooo001moooo00<0003oooooool02?ooo`80002F
oooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo00<0
003oooooool00_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0
003oooooool00_ooo`030000oooooooo00Goool010000?ooooooo`0000[oool00`000?ooooooo`02
oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0
003oooooool0000:oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool00`000?oo
ooooo`0500003?ooo`040000oooooooo00002oooo`050000oooooooooooo000007goool007_oool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00O?ooo`030000oooooooo017oool200002Oooo`@00002oooo00<0003ooooo
ool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.67958 .24721 L
.69774 .24721 L
.7026 .24721 L
.70516 .24721 L
.70656 .24721 L
.70787 .24721 L
s
.70787 .24721 m
.70804 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.27193 .24721 L
.27731 .24721 L
.28302 .24721 L
.288 .24721 L
.28936 .24721 L
.29012 .24721 L
.29083 .24721 L
.2915 .24721 L
.29222 .37082 L
.29349 .37082 L
.30316 .37082 L
.3438 .37082 L
.38293 .37082 L
.42451 .37082 L
.44538 .37082 L
.45453 .37082 L
.45938 .37082 L
.46458 .37082 L
.46718 .37082 L
.46846 .37082 L
.46965 .37082 L
.47072 .24721 L
.47186 .24721 L
.47427 .24721 L
.48333 .24721 L
.50313 .24721 L
.54088 .24721 L
.58108 .24721 L
.61977 .24721 L
.66091 .24721 L
.70054 .24721 L
.73864 .24721 L
.7792 .24721 L
.81825 .24721 L
.85975 .24721 L
.89973 .24721 L
.9382 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Coool00`1Vooooooooo`05oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`05oooo00<0I_ooooooool01?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00Goool00ol0VOooooooo`04oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool005[oool00`1Vooooooooo`0[
oooo00<0I_ooooooool01?ooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001Joooo00<0
I_ooooooool0:oooo`0306Kooooooooo00Coool00`000?ooooooo`0boooo00?o09Woooooool0FOoo
o`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool005[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?ooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo001Joooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool2
0000<oooo`03o`2Ioooooooo05Woool005[oool00`1Vooooooooo`0[oooo00<0I_ooooooool01?oo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001Joooo00<0I_ooooooool0:oooo`0306Ko
oooooooo00Coool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00F_ooo`0306Kooooooooo
02_oool00`1Vooooooooo`04oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool005[oool0
0`1Vooooooooo`0[oooo00<0I_ooooooool01?ooo`030000oooooooo03;oool00ol0VOooooooo`1I
oooo001Joooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04oooo0P0003?oool0
0ol0VOooooooo`1Ioooo001Joooo00<0I_ooooooool0:oooo`0306Kooooooooo00Coool00`000?oo
ooooo`0boooo00?o09Woooooool0FOooo`00F_ooo`0306Kooooooooo02_oool00`1Vooooooooo`04
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool005[oool00`1Vooooooooo`0[oooo00<0
I_ooooooool01?ooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001Joooo00<0I_oooooo
ool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00F_oo
o`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
05Woool005[oool00`1Vooooooooo`0Zoooo00<0I_ooooooool01Oooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo001Joooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool20000<ooo
o`03o`2Ioooooooo05Woool005[oool00`1Vooooooooo`0Zoooo00<0I_ooooooool01Oooo`030000
oooooooo03;oool00ol0VOooooooo`1Ioooo001Joooo00<0I_ooooooool0:_ooo`0306Kooooooooo
00Goool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00F_ooo`0306Kooooooooo02[oool0
0`1Vooooooooo`05oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool005[oool00`1Voooo
ooooo`0Zoooo00<0I_ooooooool01Oooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001J
oooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`0boooo00?o09Wooooo
ool0FOooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo0P0003?oool00ol0VOoo
ooooo`1Ioooo001Joooo00<0I_ooooooool0:_ooo`0306Kooooooooo00Goool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00F_ooo`0306Kooooooooo02[oool00`1Vooooooooo`05oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool005[oool00`1Vooooooooo`0Zoooo00<0I_oooooo
ool01Oooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001Joooo00<0I_ooooooool07ooo
o`800004oooo0P0000?oool00`1Vo`0000000005oooo00<0003oooooool0<_ooo`03o`2Ioooooooo
05Woool005[oool00`1Vooooooooo`0Noooo00@0003oooooool00008oooo00@0003oooooool00004
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool005[ooolQ06Ko00@00000I_l0I_l00009
06Ko0_ooo`030000oooooooo00;oool30000<_ooo`03o`2Ioooooooo05Woool007_oool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo001koooo00@0
003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo03;oool00ol0VOooooooo`1I
oooo001loooo0P0000[oool300001?ooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00Soooo`80000coooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo
03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool0
08ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`80000coooo00?o09Woooooool0FOoo
o`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool008ooool20000<oooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0b
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo0P00
03?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool0
08ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo0027oooo1@0000?oool00`000?ooooooo`0boooo00?o09Woooooool0FOoo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00ROoo
o`030000oooooooo00?oool30000<_ooo`03o`2Ioooooooo05Woool008Woool00`000?ooooooo`03
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008Woool00`000?ooooooo`03oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool008Soool200001Oooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOoo
ooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`80000c
oooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?
oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0
003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool20000<oooo`03o`2Ioooooooo05Woool0
08ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool0
0ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2Ioooooooo05Woool008ooool0
0`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Soooo`030000oooooooo03;oool00ol0VOoo
ooooo`1Ioooo002?oooo0P0003?oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_oo
o`03o`2Ioooooooo05Woool008ooool00`000?ooooooo`0boooo00?o09Woooooool0FOooo`00Sooo
o`030000oooooooo03;oool00ol0VOooooooo`1Ioooo002?oooo00<0003oooooool0<_ooo`03o`2I
oooooooo05Woool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0boooo00?o
09Woooooool0FOooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`0boooo00?o09Woooooool0FOooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`0003;oool00ol0VOooooooo`1Ioooo001moooo00<0003oooooool02?ooo`80002Foooo001m
oooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003o
oooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?oo
o`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Ooool200001?ooo`800005oooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo00002_ooo`050000oooooooo
oooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_ooo`030000
oooooooo00goool010000?ooooooo`0000[oool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002ooo
o`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo00?oool0
0`000?ooooooo`1hoooo001ioooo00<0003oooooool04Oooo`800009oooo100000?oool300000_oo
o`030000oooooooo07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.67958 .24721 L
.69774 .24721 L
.7026 .24721 L
.70787 .24721 L
.71028 .24721 L
.7116 .24721 L
.71284 .24721 L
.71389 .24721 L
s
.71389 .24721 m
.71406 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.27193 .24721 L
.27731 .24721 L
.28025 .24721 L
.28302 .24721 L
.28425 .24721 L
.28542 .24721 L
.28606 .37082 L
.28676 .37082 L
.288 .37082 L
.29349 .37082 L
.30316 .37082 L
.3438 .37082 L
.38293 .37082 L
.42451 .37082 L
.44538 .37082 L
.45453 .37082 L
.46458 .37082 L
.46926 .37082 L
.47183 .37082 L
.4731 .37082 L
.47427 .37082 L
.47537 .37082 L
.47654 .24721 L
.47771 .24721 L
.47901 .24721 L
.48333 .24721 L
.50313 .24721 L
.54333 .24721 L
.58202 .24721 L
.62316 .24721 L
.66278 .24721 L
.70089 .24721 L
.74145 .24721 L
.7805 .24721 L
.822 .24721 L
.86198 .24721 L
.90044 .24721 L
.94136 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00?oool00`1Vooooooooo`06oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`06oooo00<0I_ooooooool00ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00Koool00ol0VOooooooo`03oooo00<0003oooooool03?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool005Woool00`1Vooooooooo`0]
oooo00<0I_ooooooool00oooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001Ioooo00<0
I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`0coooo00?o09Woooooool0F?oo
o`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool0<oooo`03o`2I
oooooooo05Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool2
0000=?ooo`03o`2Ioooooooo05Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00ooo
o`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001Ioooo00<0I_ooooooool0;Oooo`0306Ko
oooooooo00?oool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00FOooo`0306Kooooooooo
02goool00`1Vooooooooo`03oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool005Woool0
0`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo03?oool00ol0VOooooooo`1H
oooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`0coooo00?o
09Woooooool0F?ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo0P0003Coool0
0ol0VOooooooo`1Hoooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?oo
ooooo`0coooo00?o09Woooooool0F?ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03
oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool005Woool00`1Vooooooooo`0]oooo00<0
I_ooooooool00oooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001Ioooo00<0I_oooooo
ool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00FOoo
o`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0003oooooool0<oooo`03o`2Ioooooooo
05Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo03?oool0
0ol0VOooooooo`1Hoooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool20000=?oo
o`03o`2Ioooooooo05Soool005Woool00`1Vooooooooo`0]oooo00<0I_ooooooool00oooo`030000
oooooooo03?oool00ol0VOooooooo`1Hoooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo
00?oool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00FOooo`0306Kooooooooo02goool0
0`1Vooooooooo`03oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool005Woool00`1Voooo
ooooo`0]oooo00<0I_ooooooool00oooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001I
oooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo0P0003Coool00ol0VOoo
ooooo`1Hoooo001Ioooo00<0I_ooooooool0;Oooo`0306Kooooooooo00?oool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00FOooo`0306Kooooooooo02goool00`1Vooooooooo`03oooo00<0
003oooooool0<oooo`03o`2Ioooooooo05Soool005Woool00`1Vooooooooo`0]oooo00<0I_oooooo
ool00oooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001Ioooo00<0I_ooooooool08?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001I
oooo00<0I_ooooooool07oooo`040000oooooooo00002?ooo`040000oooo06Ko00001?ooo`030000
oooooooo03?oool00ol0VOooooooo`1Hoooo001Ioooo8P1Vo`04000006Ko06Ko00002`1Vo`030000
oooooooo00;oool30000<oooo`03o`2Ioooooooo05Soool007_oool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001koooo00@0003oooooool00009
oooo00<0003oooooool01?ooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo001loooo0P00
00[oool300001?ooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003ooooo
ool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?oo
o`00Soooo`80000doooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOoo
ooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?oo
ooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1H
oooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00Soooo`80000doooo00?o09Woooooool0F?ooo`00Soooo`030000
oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool0
08ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Wooooo
ool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003ooooo
ool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?oo
o`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo0P0003Coool00ol0VOoo
ooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?oo
ooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1H
oooo0027oooo1@0000?oool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00ROooo`030000oooooooo
00?oool30000<oooo`03o`2Ioooooooo05Soool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0<oooo`03o`2Ioooooooo05Soool008Woool00`000?ooooooo`03oooo00<0003oooooool0<ooo
o`03o`2Ioooooooo05Soool008Soool200001Oooo`030000oooooooo03?oool00ol0VOooooooo`1H
oooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?
oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool0
08ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`80000doooo00?o09Wooooo
ool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003ooooo
ool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?oo
o`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<ooo
o`03o`2Ioooooooo05Soool008ooool20000=?ooo`03o`2Ioooooooo05Soool008ooool00`000?oo
ooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1H
oooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool008ooool00`000?ooooooo`0c
oooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo03?oool00ol0VOooooooo`1Hoooo002?
oooo0P0003Coool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo
05Soool008ooool00`000?ooooooo`0coooo00?o09Woooooool0F?ooo`00Soooo`030000oooooooo
03?oool00ol0VOooooooo`1Hoooo002?oooo00<0003oooooool0<oooo`03o`2Ioooooooo05Soool0
07_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0coooo00?o09Woooooool0F?oo
o`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0coooo00?o
09Woooooool0F?ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0003?oool0
0ol0VOooooooo`1Hoooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003ooooo
ool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Ooool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_oo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003oooooool00008oooo00@0003ooooo
ool00004oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000<oooo00@0003ooooo
ool00009oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000003ooo
o`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool0
0`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.70787 .24721 L
.71284 .24721 L
.71741 .24721 L
.71874 .24721 L
.71998 .24721 L
s
.71998 .24721 m
.72017 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.24141 .24721 L
.26171 .24721 L
.26709 .24721 L
.27279 .24721 L
.27513 .24721 L
.27765 .24721 L
.2784 .24721 L
.2791 .24721 L
.28042 .37082 L
.28166 .37082 L
.28302 .37082 L
.30316 .37082 L
.3438 .37082 L
.38293 .37082 L
.42451 .37082 L
.44538 .37082 L
.45453 .37082 L
.46458 .37082 L
.46926 .37082 L
.47427 .37082 L
.47671 .37082 L
.47901 .37082 L
.48001 .37082 L
.48108 .37082 L
.48224 .24721 L
.48333 .24721 L
.50313 .24721 L
.54088 .24721 L
.58108 .24721 L
.61977 .24721 L
.66091 .24721 L
.70054 .24721 L
.73864 .24721 L
.7792 .24721 L
.81825 .24721 L
.85975 .24721 L
.89973 .24721 L
.9382 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`050000oooooooooooo06Ko00[oool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00Ooool00`1Vooooooooo`02oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02?ooo`05o`2I
oooooooooooo000000koool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0Eoooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Eoooo`0306Kooooooooo033oool00`1Voooo
ooooo`02oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool005Ooool00`1Vooooooooo`0`
oooo00<0I_ooooooool00_ooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001Goooo00<0
I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`0eoooo00?o09Woooooool0E_oo
o`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo0P0003Koool00ol0VOooooooo`1F
oooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00<0003ooooo
ool0=Oooo`03o`2Ioooooooo05Koool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_oo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo001Goooo00<0I_ooooooool0<?ooo`0306Ko
oooooooo00;oool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Eoooo`0306Kooooooooo
033oool00`1Vooooooooo`02oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool005Ooool0
0`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`80000foooo00?o09Woooooool0E_ooo`00Eooo
o`0306Kooooooooo033oool00`1Vooooooooo`02oooo00<0003oooooool0=Oooo`03o`2Ioooooooo
05Koool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?oo
ooooo`0eoooo00?o09Woooooool0E_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool005Ooool00`1Vooooooooo`0`oooo00<0
I_ooooooool00_ooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001Goooo00<0I_oooooo
ool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Eooo
o`0306Kooooooooo033oool00`1Vooooooooo`02oooo0P0003Koool00ol0VOooooooo`1Foooo001G
oooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`0eoooo00?o09Wooooo
ool0E_ooo`00Eoooo`0306Kooooooooo033oool00`1Vooooooooo`02oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool005Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000
oooooooo03Goool00ol0VOooooooo`1Foooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo
00;oool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Eoooo`0306Kooooooooo033oool0
0`1Vooooooooo`02oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool005Ooool00`1Voooo
ooooo`0`oooo00<0I_ooooooool00_ooo`80000foooo00?o09Woooooool0E_ooo`00Eoooo`0306Ko
oooooooo033oool00`1Vooooooooo`02oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool0
05Ooool00`1Vooooooooo`0`oooo00<0I_ooooooool00_ooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo001Goooo00<0I_ooooooool0<?ooo`0306Kooooooooo00;oool00`000?ooooooo`0e
oooo00?o09Woooooool0E_ooo`00Eoooo`0306Kooooooooo02;oool200001?ooo`800004oooo0P00
000306Kooooooooo00;oool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Eoooo`0306Ko
oooooooo027oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0e
oooo00?o09Woooooool0E_ooo`00Eoooob@0I_l01000001Vo`1Vo`0000/0I_l00`000?ooooooo`02
oooo0`0003Goool00ol0VOooooooo`1Foooo001koooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Noooo`040000oooooooo00002Oooo`030000
oooooooo00Coool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00O?ooo`80000:oooo0`00
00Coool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool2
0000=_ooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_oo
o`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0e
oooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo0P00
03Koool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool0
08ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000foooo00?o09Woooooool0E_oo
o`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Qooo
o`D00003oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008Woool00`000?ooooooo`03
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008Woool00`000?ooooooo`03oooo0`00
03Goool00ol0VOooooooo`1Foooo0029oooo00<0003oooooool00oooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo0029oooo00<0003oooooool00oooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo0028oooo0P0000Goool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000f
oooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0
003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool20000=_ooo`03o`2Ioooooooo05Koool0
08ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool0
0ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool0
0`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOoo
ooooo`1Foooo002?oooo0P0003Koool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Ooo
o`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Sooo
o`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?oooo00<0003oooooool0=Oooo`03o`2I
oooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o09Woooooool0E_ooo`00Soooo`80000f
oooo00?o09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo002?
oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool008ooool00`000?ooooooo`0eoooo00?o
09Woooooool0E_ooo`00Soooo`030000oooooooo03Goool00ol0VOooooooo`1Foooo001koooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0=Oooo`03o`2Ioooooooo05Koool007goool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0=Oooo`03o`2Ioooooooo
05Koool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000eoooo00?o09Wooooo
ool0E_ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool0
0`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00@0003oooooool00008oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0=oooo00@0003ooooo
ool00008oooo00@0003oooooool00005oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003?ooo`040000oooooooo00002Oooo`800004oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?oo
o`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0
003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQ
oooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.70787 .24721 L
.71741 .24721 L
.72269 .24721 L
.72414 .24721 L
.72493 .24721 L
.72567 .24721 L
s
.72567 .24721 m
.72587 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.24141 .24721 L
.26171 .24721 L
.26709 .24721 L
.27003 .24721 L
.27147 .24721 L
.27279 .24721 L
.27399 .37082 L
.27513 .37082 L
.27765 .37082 L
.28302 .37082 L
.30316 .37082 L
.34135 .37082 L
.38199 .37082 L
.42112 .37082 L
.4411 .37082 L
.46271 .37082 L
.47285 .37082 L
.4784 .37082 L
.48357 .37082 L
.48584 .37082 L
.48696 .37082 L
.48799 .37082 L
.48918 .24721 L
.49047 .24721 L
.49273 .24721 L
.50277 .24721 L
.54204 .24721 L
.57979 .24721 L
.61999 .24721 L
.65868 .24721 L
.69982 .24721 L
.73944 .24721 L
.77755 .24721 L
.81811 .24721 L
.85716 .24721 L
.89866 .24721 L
.93864 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooo06Ko00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00Woool0101Vooooooooo`0000koool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00Woool01?l0VOooooooo`0000koool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo001E
oooo00<0I_ooooooool0=?ooo`0406Kooooooooo0000>?ooo`03o`2Ioooooooo05Goool005Goool0
0`1Vooooooooo`0doooo00@0I_ooooooool0000hoooo00?o09Woooooool0EOooo`00EOooo`0306Ko
oooooooo03Coool0101Vooooooooo`0003Soool00ol0VOooooooo`1Eoooo001Eoooo00<0I_oooooo
ool0=?ooo`0406Kooooooooo0000>?ooo`03o`2Ioooooooo05Goool005Goool00`1Vooooooooo`0d
oooo00<0I_ooooooool00P0003Ooool00ol0VOooooooo`1Eoooo001Eoooo00<0I_ooooooool0=?oo
o`0406Kooooooooo0000>?ooo`03o`2Ioooooooo05Goool005Goool00`1Vooooooooo`0doooo00@0
I_ooooooool0000hoooo00?o09Woooooool0EOooo`00EOooo`0306Kooooooooo03Coool0101Voooo
ooooo`0003Soool00ol0VOooooooo`1Eoooo001Eoooo00<0I_ooooooool0=?ooo`0406Kooooooooo
0000>?ooo`03o`2Ioooooooo05Goool005Goool00`1Vooooooooo`0doooo00@0I_ooooooool0000h
oooo00?o09Woooooool0EOooo`00EOooo`0306Kooooooooo03Coool00`1Vooooooooo`020000=ooo
o`03o`2Ioooooooo05Goool005Goool00`1Vooooooooo`0doooo00@0I_ooooooool0000hoooo00?o
09Woooooool0EOooo`00EOooo`0306Kooooooooo03Coool0101Vooooooooo`0003Soool00ol0VOoo
ooooo`1Eoooo001Eoooo00<0I_ooooooool0=?ooo`0406Kooooooooo0000>?ooo`03o`2Ioooooooo
05Goool005Koool00`1Vooooooooo`0coooo00@0I_ooooooool0000hoooo00?o09Woooooool0EOoo
o`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`0003Soool00ol0VOooooooo`1Eoooo001F
oooo00<0I_ooooooool0<oooo`0406Kooooooooo0000>?ooo`03o`2Ioooooooo05Goool005Koool0
0`1Vooooooooo`0coooo00<0I_ooooooool00P0003Ooool00ol0VOooooooo`1Eoooo001Foooo00<0
I_ooooooool0<oooo`0406Kooooooooo0000>?ooo`03o`2Ioooooooo05Goool005Koool00`1Voooo
ooooo`0coooo00@0I_ooooooool0000hoooo00?o09Woooooool0EOooo`00E_ooo`0306Kooooooooo
03?oool0101Vooooooooo`0003Soool00ol0VOooooooo`1Eoooo001Foooo00<0I_ooooooool0<ooo
o`0406Kooooooooo0000>?ooo`03o`2Ioooooooo05Goool005Koool00`1Vooooooooo`0coooo00@0
I_ooooooool0000hoooo00?o09Woooooool0EOooo`00E_ooo`0306Kooooooooo03?oool00`1Voooo
ooooo`020000=oooo`03o`2Ioooooooo05Goool005Koool00`1Vooooooooo`0coooo00@0I_oooooo
ool0000hoooo00?o09Woooooool0EOooo`00E_ooo`0306Kooooooooo03?oool0101Vooooooooo`00
03Soool00ol0VOooooooo`1Eoooo001Foooo00<0I_ooooooool0<oooo`0406Kooooooooo0000>?oo
o`03o`2Ioooooooo05Goool005Koool00`1Vooooooooo`0Soooo0P0000Coool200001?ooo`800002
oooo00@0I_ooooooool0000hoooo00?o09Woooooool0EOooo`00E_ooo`0306Kooooooooo02;oool0
10000?ooooooo`0000Soool01P000?ooooooo`000?ooo`1Vo`;oool00`000?ooooooo`0foooo00?o
09Woooooool0EOooo`00E_ooobD0I_l01000001Vo`1Vo`0000/0I_l00`00001Vo`1Vo`02oooo0`00
03Koool00ol0VOooooooo`1Eoooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?oo
ooooo`0foooo00?o09Woooooool0EOooo`00Noooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00O?ooo`80000:oooo0`0000Coool0
0`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=ooo
o`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Sooo
o`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2I
oooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000
oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo
05Goool008ooool20000=oooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o
09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0
003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Wooooo
ool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo0P0003Ooool0
0ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool0
0`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool00`000?oo
ooooo`0foooo00?o09Woooooool0EOooo`00Soooo`80000goooo00?o09Woooooool0EOooo`00Sooo
o`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2I
oooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Qoooo`D00003
oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008Woool00`000?ooooooo`03oooo00<0
003oooooool0=_ooo`03o`2Ioooooooo05Goool008Woool00`000?ooooooo`03oooo0`0003Koool0
0ol0VOooooooo`1Eoooo0029oooo00<0003oooooool00oooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Eoooo0029oooo00<0003oooooool00oooo`030000oooooooo03Koool00ol0VOooooooo`1E
oooo0028oooo0P0000Goool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000
oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo
05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`80000goooo00?o
09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0
003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Wooooo
ool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003ooooo
ool0=_ooo`03o`2Ioooooooo05Goool008ooool20000=oooo`03o`2Ioooooooo05Goool008ooool0
0`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOoo
ooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool00`000?oo
ooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1E
oooo002?oooo0P0003Ooool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2I
oooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`030000
oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0003oooooool0=_ooo`03o`2Ioooooooo
05Goool008ooool00`000?ooooooo`0foooo00?o09Woooooool0EOooo`00Soooo`80000goooo00?o
09Woooooool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo002?oooo00<0
003oooooool0=_ooo`03o`2Ioooooooo05Goool008ooool00`000?ooooooo`0foooo00?o09Wooooo
ool0EOooo`00Soooo`030000oooooooo03Koool00ol0VOooooooo`1Eoooo001koooo1@0000;oool2
00001?ooo`800005oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool007goool00`000?oo
ooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0=_ooo`03o`2Ioooooooo05Goool0
07goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000foooo00?o09Woooooool0EOoo
o`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?oo
ooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0
003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003ooooo
ool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`07oooo0P0000Coool200000oooo`<00004oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002_ooo`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_oo
o`030000oooooooo00goool010000?ooooooo`0000Woool300001?ooo`030000oooooooo07[oool0
07_oool00`000?ooooooo`0500003?ooo`040000oooooooo00002?ooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.71741 .24721 L
.72307 .24721 L
.72585 .24721 L
.72841 .24721 L
.73074 .24721 L
.73191 .24721 L
s
.73191 .24721 m
.73211 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.24141 .24721 L
.25127 .24721 L
.26171 .24721 L
.26425 .24721 L
.26565 .24721 L
.26698 .24721 L
.26773 .24721 L
.26855 .37082 L
.26929 .37082 L
.26998 .37082 L
.27279 .37082 L
.28302 .37082 L
.30316 .37082 L
.34228 .37082 L
.38387 .37082 L
.42393 .37082 L
.46248 .37082 L
.48242 .37082 L
.48727 .37082 L
.48994 .37082 L
.49246 .37082 L
.49316 .37082 L
.49389 .37082 L
.4947 .24721 L
.49545 .24721 L
.49817 .24721 L
.50349 .24721 L
.54124 .24721 L
.58144 .24721 L
.62013 .24721 L
.66127 .24721 L
.70089 .24721 L
.739 .24721 L
.77956 .24721 L
.81861 .24721 L
.86011 .24721 L
.90009 .24721 L
.93855 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`03000006Kooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00_oool00`1Vo`000?ooo`0=oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0;oooo00?o09T0003oool03Oooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool005Coool0
0`1Vooooooooo`0goooo00<0I_l0003oool0>Oooo`03o`2Ioooooooo05?oool005Coool00`1Voooo
ooooo`0goooo00<0I_l0003oool0>Oooo`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0g
oooo00<0I_l0003oool0>Oooo`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0goooo00<0
I_l0003oool0>Oooo`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0goooo00<0I_l00000
0000>Oooo`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0goooo00<0I_l0003oool0>Ooo
o`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0goooo00<0I_l0003oool0>Oooo`03o`2I
oooooooo05?oool005Coool00`1Vooooooooo`0goooo00<0I_l0003oool0>Oooo`03o`2Ioooooooo
05?oool005Coool00`1Vooooooooo`0goooo00<0I_l0003oool0>Oooo`03o`2Ioooooooo05?oool0
05Coool00`1Vooooooooo`0goooo00<0I_l0003oool0>Oooo`03o`2Ioooooooo05?oool005Coool0
0`1Vooooooooo`0goooo00<0I_l000000000>Oooo`03o`2Ioooooooo05?oool005Coool00`1Voooo
ooooo`0goooo00<0I_l0003oool0>Oooo`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0g
oooo00<0I_l0003oool0>Oooo`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0goooo00<0
I_l0003oool0>Oooo`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0foooo00<0I_ooool0
0000>_ooo`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0foooo00<0I_ooool00000>_oo
o`03o`2Ioooooooo05?oool005Coool00`1Vooooooooo`0foooo00<0I_ooool00000>_ooo`03o`2I
oooooooo05?oool005Coool00`1Vooooooooo`0foooo00@0I_ooool00000000ioooo00?o09Wooooo
ool0Doooo`00E?ooo`0306Kooooooooo03Koool00`1Vooooo`00000joooo00?o09Woooooool0Dooo
o`00E?ooo`0306Kooooooooo03Koool00`1Vooooo`00000joooo00?o09Woooooool0Doooo`00E?oo
o`0306Kooooooooo03Koool00`1Vooooo`00000joooo00?o09Woooooool0Doooo`00E?ooo`0306Ko
oooooooo03Koool00`1Vooooo`00000joooo00?o09Woooooool0Doooo`00E?ooo`0306Kooooooooo
03Koool00`1Vooooo`00000joooo00?o09Woooooool0Doooo`00E?ooo`0306Kooooooooo03Koool0
101Vooooo`00000003Woool00ol0VOooooooo`1Coooo001Doooo00<0I_ooooooool0=_ooo`0306Ko
oooo000003[oool00ol0VOooooooo`1Coooo001Doooo00<0I_ooooooool0=_ooo`0306Kooooo0000
03[oool00ol0VOooooooo`1Coooo001Doooo00<0I_ooooooool0=_ooo`0306Kooooo000003[oool0
0ol0VOooooooo`1Coooo001Doooo00<0I_ooooooool09Oooo`800004oooo0P0000Coool200000ooo
o`0306Kooooo000003[oool00ol0VOooooooo`1Coooo001Doooo00<0I_ooooooool09?ooo`040000
oooooooo00002?ooo`040000oooooooo00000_ooo`0306Kooooo000003[oool00ol0VOooooooo`1C
oooo001Doooo9`1Vo`04000006Ko06Ko00002`1Vo`05000006Ko06Ko06Kooooo00<0000hoooo00?o
09Woooooool0Doooo`00Noooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0>?oo
o`03o`2Ioooooooo05?oool007_oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool0>?ooo`03o`2Ioooooooo05?oool007coool200002_ooo`<00004oooo00<0003ooooo
ool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Dooo
o`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo0P0003Woool00ol0VOoo
ooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?oo
ooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1C
oooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0h
oooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?
oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo
05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo
03Soool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool0
08ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`80000ioooo00?o09Wooooo
ool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo00<0003ooooo
ool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Dooo
o`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?oo
o`03o`2Ioooooooo05?oool008ooool20000>Oooo`03o`2Ioooooooo05?oool008ooool00`000?oo
ooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1C
oooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008Ooool500000oooo`030000
oooooooo03Soool00ol0VOooooooo`1Coooo0029oooo00<0003oooooool00oooo`030000oooooooo
03Soool00ol0VOooooooo`1Coooo0029oooo00<0003oooooool00oooo`<0000hoooo00?o09Wooooo
ool0Doooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0hoooo00?o09Woooooool0Dooo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00R?oo
o`800005oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0h
oooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?
oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool20000>Oooo`03o`2Ioooooooo
05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo
03Soool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool0
08ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool0
0ol0VOooooooo`1Coooo002?oooo0P0003Woool00ol0VOooooooo`1Coooo002?oooo00<0003ooooo
ool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Dooo
o`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?oo
o`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Sooo
o`80000ioooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1C
oooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool00`000?ooooooo`0h
oooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo002?
oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool008ooool20000>Oooo`03o`2Ioooooooo
05?oool008ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Soooo`030000oooooooo
03Soool00ol0VOooooooo`1Coooo002?oooo00<0003oooooool0>?ooo`03o`2Ioooooooo05?oool0
08ooool00`000?ooooooo`0hoooo00?o09Woooooool0Doooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo001moooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo03Soool00ol0VOooooooo`1Coooo001moooo00<0
003oooooool02_ooo`030000oooooooo00;oool30000>?ooo`03o`2Ioooooooo05?oool007goool0
0`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01ooo
o`800004oooo0P0000?oool300001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`040000oooooooo
00002_ooo`050000oooooooooooo000000;oool01@000?ooooooooooo`00001joooo001goooo00<0
003oooooool00_ooo`030000oooooooo00goool010000?ooooooo`0000Woool300001Oooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000coool010000?oo
ooooo`0000Soool010000?ooooooo`0000?oool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`00000?oooo00@0003oooooool00008oooo00@0003oooooool00003oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool3
00000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.71741 .24721 L
.72307 .24721 L
.72841 .24721 L
.7332 .24721 L
.73451 .24721 L
.7359 .24721 L
.73708 .24721 L
s
.73708 .24721 m
.73728 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.24141 .24721 L
.25127 .24721 L
.25666 .24721 L
.2593 .24721 L
.26045 .24721 L
.26171 .24721 L
.26301 .37082 L
.26425 .37082 L
.26698 .37082 L
.27279 .37082 L
.28302 .37082 L
.30316 .37082 L
.3438 .37082 L
.38293 .37082 L
.42451 .37082 L
.44538 .37082 L
.46458 .37082 L
.48333 .37082 L
.49277 .37082 L
.49535 .37082 L
.49678 .37082 L
.49813 .37082 L
.49938 .37082 L
.50009 .24721 L
.50074 .24721 L
.50313 .24721 L
.5424 .24721 L
.58015 .24721 L
.62035 .24721 L
.65904 .24721 L
.70018 .24721 L
.7398 .24721 L
.77791 .24721 L
.81847 .24721 L
.85752 .24721 L
.89901 .24721 L
.939 .24721 L
.97619 .24721 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool005?oool0
0`1Vooooooooo`0ioooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool005?oool00`1Voooo
ooooo`0ioooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool005?oool00`1Vooooooooo`0i
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool005?oool00`1Vooooooooo`0ioooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool005?oool00`1Vooooooooo`0ioooo0P0003[oool0
0ol0VOooooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo001Coooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001C
oooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001Coooo00<0
I_ooooooool0>Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001Coooo00<0I_oooooo
ool0>Oooo`80000joooo00?o09Woooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0ioooo00?o09Wooooo
ool0D_ooo`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Doooo`0306Kooooooooo03Woool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Dooo
o`0306Kooooooooo03Woool20000>_ooo`03o`2Ioooooooo05;oool005?oool00`1Vooooooooo`0i
oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool005?oool00`1Vooooooooo`0ioooo00<0
003oooooool0>Oooo`03o`2Ioooooooo05;oool005?oool00`1Vooooooooo`0ioooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool005?oool00`1Vooooooooo`0ioooo00<0003oooooool0>Oooo`03o`2I
oooooooo05;oool005?oool00`1Vooooooooo`0ioooo0P0003[oool00ol0VOooooooo`1Boooo001C
oooo00<0I_ooooooool0>Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001Coooo00<0
I_ooooooool0>Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001Coooo00<0I_oooooo
ool0>Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001Coooo00<0I_ooooooool09_oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001C
oooo00<0I_ooooooool09Oooo`040000oooooooo00002?ooo`040000oooooooo00001?ooo`030000
oooooooo03Woool00ol0VOooooooo`1Boooo001Coooo:01Vo`04000006Ko06Ko00002`1Vo`030000
06Ko06Ko0080I_l30000>Oooo`03o`2Ioooooooo05;oool007_oool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001koooo00@0003oooooool00009
oooo00<0003oooooool01?ooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo001loooo0P00
00[oool300001?ooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOoo
ooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Woooooool0D_ooo`00Soooo`030000
oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo
05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Wooooo
ool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo0P0003[oool00ol0VOoo
ooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo0027oooo1@0000?oool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00ROooo`030000oooooooo
00?oool30000>Oooo`03o`2Ioooooooo05;oool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool008Woool00`000?ooooooo`03oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool008Soool200001Oooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo0P0003[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo
05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
08ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`80000joooo00?o09Wooooo
ool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003ooooo
ool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Ooo
o`03o`2Ioooooooo05;oool008ooool20000>_ooo`03o`2Ioooooooo05;oool008ooool00`000?oo
ooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1B
oooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool008ooool00`000?ooooooo`0i
oooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo03Woool00ol0VOooooooo`1Boooo002?
oooo0P0003[oool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo
05;oool008ooool00`000?ooooooo`0ioooo00?o09Woooooool0D_ooo`00Soooo`030000oooooooo
03Woool00ol0VOooooooo`1Boooo002?oooo00<0003oooooool0>Oooo`03o`2Ioooooooo05;oool0
07_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0ioooo00?o09Woooooool0D_oo
o`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0ioooo00?o
09Woooooool0D_ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0003Woool0
0ol0VOooooooo`1Boooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003ooooo
ool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00oooo
ob7oool007ooool00`000?ooooooo`0Loooo00<0003oooooool0Ooooo`00O_ooo`030000oooooooo
00Soool00`000?ooooooo`0Coooo00<0003oooooool0O_ooo`00O_ooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool500000_ooo`800004oooo00<0003oooooool0O_ooo`00O_oo
o`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000
oooooooo00Soool00`000?ooooooo`1noooo001moooo00<0003oooooool00_ooo`030000oooooooo
00ooool00`000?ooooooo`09oooo00<0003oooooool0OOooo`00O_ooo`030000oooooooo00D0000>
oooo00<0003oooooool02?ooo`030000oooooooo07koool007koool01@000?ooooooooooo`00000A
oooo00<0003oooooool02?ooo`030000oooooooo07koool007ooool00`000?ooooooo`0Aoooo0P00
00Woool00`000?ooooooo`1ooooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.71905 .24721 L
.72912 .24721 L
.73838 .24721 L
.74082 .24721 L
.74201 .24721 L
.74309 .24721 L
s
.74309 .24721 m
.74326 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.22272 .24721 L
.23233 .24721 L
.24276 .24721 L
.24754 .24721 L
.25016 .24721 L
.25261 .24721 L
.2547 .24721 L
.25587 .24721 L
.25694 .37082 L
.25811 .37082 L
.25939 .37082 L
.26171 .37082 L
.30236 .37082 L
.34148 .37082 L
.38307 .37082 L
.42313 .37082 L
.46168 .37082 L
.48162 .37082 L
.48647 .37082 L
.48914 .37082 L
.49166 .37082 L
.49309 .37082 L
.4939 .37082 L
.49465 .37113 L
.49737 .37255 L
.4987 .37326 L
.49995 .37392 L
.50125 .37329 L
.50269 .37253 L
.50386 .37191 L
.50512 .37125 L
.50631 .24721 L
.50738 .24721 L
.51252 .24721 L
.52287 .24721 L
.54137 .24721 L
.58136 .24721 L
.61982 .24721 L
.66074 .24721 L
.70014 .24721 L
.73803 .24721 L
.77837 .24721 L
.8172 .24721 L
.85847 .24721 L
Mistroke
.89823 .24721 L
.93648 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool02_ooo`0306Kooooo000000koool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooo`1Vo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo09T03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool0057oool0
0`1Vooooooooo`0koooo00<0003oool0I_l0>oooo`03o`2Ioooooooo053oool0057oool00`1Voooo
ooooo`0koooo00<0003oool0I_l0>oooo`03o`2Ioooooooo053oool0057oool00`1Vooooooooo`0k
oooo00<0003oool0I_l0>oooo`03o`2Ioooooooo053oool0057oool00`1Vooooooooo`0koooo00<0
003oool0I_l0>oooo`03o`2Ioooooooo053oool0057oool00`1Vooooooooo`0koooo0P00000306Ko
oooooooo03Woool00ol0VOooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooo06Ko
03_oool00ol0VOooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooo06Ko03_oool0
0ol0VOooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooo06Ko03_oool00ol0VOoo
ooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`030000oooo06Ko03_oool00ol0VOooooooo`1@
oooo001Aoooo00<0I_ooooooool0>oooo`030000oooo06Ko03_oool00ol0VOooooooo`1@oooo001A
oooo00<0I_ooooooool0>oooo`8000000`1Vooooooooo`0ioooo00?o09Woooooool0D?ooo`00DOoo
o`0306Kooooooooo03_oool00`000?ooo`1Vo`0koooo00?o09Woooooool0D?ooo`00DOooo`0306Ko
oooooooo03_oool00`000?ooo`1Vo`0koooo00?o09Woooooool0D?ooo`00DOooo`0306Kooooooooo
03_oool00`000?ooo`1Vo`0koooo00?o09Woooooool0D?ooo`00DOooo`0306Kooooooooo03_oool0
0`00001Vooooo`0koooo00?o09Woooooool0D?ooo`00DOooo`0306Kooooooooo03_oool00`00001V
ooooo`0koooo00?o09Woooooool0D?ooo`00DOooo`0306Kooooooooo03_oool00`00001Vooooo`0k
oooo00?o09Woooooool0D?ooo`00DOooo`0306Kooooooooo03_oool20000??ooo`03o`2Ioooooooo
053oool0057oool00`1Vooooooooo`0koooo00<00000I_ooool0>oooo`03o`2Ioooooooo053oool0
057oool00`1Vooooooooo`0koooo00<00000I_ooool0>oooo`03o`2Ioooooooo053oool0057oool0
0`1Vooooooooo`0koooo00<00000I_ooool0>oooo`03o`2Ioooooooo053oool0057oool00`1Voooo
ooooo`0koooo00<00000I_ooool0>oooo`03o`2Ioooooooo053oool0057oool00`1Vooooooooo`0k
oooo00<00000I_ooool0>oooo`03o`2Ioooooooo053oool0057oool00`1Vooooooooo`0koooo0P00
03coool00ol0VOooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`03000006Kooooo03_oool0
0ol0VOooooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`03000006Kooooo03_oool00ol0VOoo
ooooo`1@oooo001Aoooo00<0I_ooooooool0>oooo`03000006Kooooo03_oool00ol0VOooooooo`1@
oooo001Aoooo00<0I_ooooooool0:?ooo`800004oooo0P0000Coool200001Oooo`03000006Kooooo
03_oool00ol0VOooooooo`1@oooo001Aoooo00<0I_ooooooool09oooo`040000oooooooo00002?oo
o`040000oooooooo00001?ooo`03000006Kooooo03_oool00ol0VOooooooo`1@oooo001Aoooo:P1V
o`04000006Ko06Ko00002`1Vo`03000006Ko06Ko0080I_l30000>oooo`03o`2Ioooooooo053oool0
07_oool010000?ooooooo`0000Woool200001?ooo`0306Ko000006Ko03coool00ol0VOooooooo`1@
oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo03_oool0
0ol0VOooooooo`1@oooo001loooo0P0000[oool300001?ooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`80000loooo00?o09Woooooool0D?ooo`00Sooo
o`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo
053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`80000loooo00?o
09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2Ioooooooo053oool008ooool0
0`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@
oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo0027oooo1@0000?oool00`000?ooooooo`0koooo00?o
09Woooooool0D?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00ROooo`030000oooooooo00?oool30000>oooo`03o`2Ioooooooo053oool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008Soool200001Oooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo
053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo
03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?oo
o`00Soooo`80000loooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOoo
ooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@
oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo053oool008ooool20000??ooo`03o`2I
oooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000
oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003oooooool0>oooo`03o`2Ioooooooo
053oool008ooool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00Soooo`030000oooooooo
03_oool00ol0VOooooooo`1@oooo002?oooo0P0003coool00ol0VOooooooo`1@oooo002?oooo00<0
003oooooool0>oooo`03o`2Ioooooooo053oool008ooool00`000?ooooooo`0koooo00?o09Wooooo
ool0D?ooo`00Soooo`030000oooooooo03_oool00ol0VOooooooo`1@oooo002?oooo00<0003ooooo
ool0>oooo`03o`2Ioooooooo053oool007_oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`0koooo00?o09Woooooool0D?ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`0koooo00?o09Woooooool0D?ooo`00OOooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`0003_oool00ol0VOooooooo`1@oooo001moooo00<0003oooooool02?oo
o`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001Oooo`030000
oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0
003oooooooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?oo
ooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004
oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.71905 .24721 L
.73838 .24721 L
.74309 .24721 L
.74566 .24721 L
.74806 .24721 L
.74932 .24721 L
s
.74932 .24721 m
.74942 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.22272 .24721 L
.23233 .24721 L
.23739 .24721 L
.24276 .24721 L
.24502 .24721 L
.24745 .24721 L
.24816 .24721 L
.24884 .24721 L
.25012 .37082 L
.25131 .37082 L
.25261 .37082 L
.26171 .37082 L
.30236 .37082 L
.34148 .37082 L
.38307 .37082 L
.42313 .37082 L
.46168 .37082 L
.472 .37082 L
.48162 .37082 L
.48411 .37082 L
.48647 .37082 L
.48777 .37082 L
.48851 .37103 L
.48919 .37139 L
.49166 .37269 L
.49701 .37554 L
.49831 .37624 L
.49899 .37661 L
.49971 .377 L
.50051 .37688 L
.50124 .37648 L
.50269 .3757 L
.50526 .37432 L
.50769 .37303 L
.50987 .37188 L
.5111 .37124 L
.51223 .24721 L
.51345 .24721 L
.51459 .24721 L
.51719 .24721 L
.52243 .24721 L
.5408 .24721 L
.57962 .24721 L
.6209 .24721 L
Mistroke
.66066 .24721 L
.6989 .24721 L
.7396 .24721 L
.77878 .24721 L
.82042 .24721 L
.86054 .24721 L
.89914 .24721 L
.94019 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool02?ooo`0506Kooooooooooooo000000koool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool010000?ooooooo`1Vo`_oool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool010000?ooooooool0V@_oool0
0`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0E
oooo001?oooo00<0I_ooooooool0?Oooo`040000oooooooo06Ko>oooo`03o`2Ioooooooo04ooool0
04ooool00`1Vooooooooo`0moooo00@0003oooooool0I_lkoooo00?o09Woooooool0Coooo`00Cooo
o`0306Kooooooooo03goool010000?ooooooo`1Voc_oool00ol0VOooooooo`1?oooo001?oooo00<0
I_ooooooool0?Oooo`040000oooooooo06Ko>oooo`03o`2Ioooooooo04ooool004ooool00`1Voooo
ooooo`0moooo0P000003oooo06Kooooo03[oool00ol0VOooooooo`1?oooo001?oooo00<0I_oooooo
ool0?Oooo`040000oooooooo06Ko>oooo`03o`2Ioooooooo04ooool004ooool00`1Vooooooooo`0m
oooo00@0003oooooool0I_lkoooo00?o09Woooooool0Coooo`00Coooo`0306Kooooooooo03goool0
10000?ooooooo`1Voc_oool00ol0VOooooooo`1?oooo001?oooo00<0I_ooooooool0?Oooo`040000
oooooooo06Ko>oooo`03o`2Ioooooooo04ooool004ooool00`1Vooooooooo`0moooo00@0003ooooo
ool0I_lkoooo00?o09Woooooool0Coooo`00Coooo`0306Kooooooooo03goool2000000?oool0I_oo
ool0>_ooo`03o`2Ioooooooo04ooool004ooool00`1Vooooooooo`0moooo00@0003oooooool0I_lk
oooo00?o09Woooooool0Coooo`00Coooo`0306Kooooooooo03goool010000?ooooooo`1Voc_oool0
0ol0VOooooooo`1?oooo001?oooo00<0I_ooooooool0?Oooo`040000oooooooo06Ko>oooo`03o`2I
oooooooo04ooool0053oool00`1Vooooooooo`0loooo00@0003oooooool0I_lkoooo00?o09Wooooo
ool0Coooo`00D?ooo`0306Kooooooooo03coool010000?ooooooo`1Voc_oool00ol0VOooooooo`1?
oooo001@oooo00<0I_ooooooool0??ooo`040000oooooooo06Ko>oooo`03o`2Ioooooooo04ooool0
053oool00`1Vooooooooo`0loooo0P000003oooo06Kooooo03[oool00ol0VOooooooo`1?oooo001@
oooo00<0I_ooooooool0??ooo`040000oooooooo06Ko>oooo`03o`2Ioooooooo04ooool0053oool0
0`1Vooooooooo`0loooo00@0003oooooool0I_lkoooo00?o09Woooooool0Coooo`00D?ooo`0306Ko
oooooooo03coool010000?ooooooo`1Voc_oool00ol0VOooooooo`1?oooo001@oooo00<0I_oooooo
ool0??ooo`040000oooooooo06Ko>oooo`03o`2Ioooooooo04ooool0053oool00`1Vooooooooo`0l
oooo00@0003oooooool0I_lkoooo00?o09Woooooool0Coooo`00D?ooo`0306Kooooooooo03coool2
000000?oool0I_ooool0>_ooo`03o`2Ioooooooo04ooool0053oool00`1Vooooooooo`0loooo00@0
003oooooool0I_lkoooo00?o09Woooooool0Coooo`00D?ooo`0306Kooooooooo03coool010000?oo
ooooo`1Voc_oool00ol0VOooooooo`1?oooo001@oooo00<0I_ooooooool0??ooo`040000oooooooo
06Ko>oooo`03o`2Ioooooooo04ooool0053oool00`1Vooooooooo`0Yoooo0P0000Coool200001?oo
o`800005oooo00@0003oooooool0I_lkoooo00?o09Woooooool0Coooo`00D?ooo`0306Kooooooooo
02Soool010000?ooooooo`0000Soool010000?ooooooo`0000Coool010000?ooooooo`1Voc_oool0
0ol0VOooooooo`1?oooo001@oooo:`1Vo`04000006Ko06Ko00002`1Vo`03000006Ko06Ko00;oool3
000000<0I_ooooooool0>Oooo`03o`2Ioooooooo04ooool007_oool010000?ooooooo`0000Woool2
00000oooo`80I_l00`00001Vo`1Vo`0loooo00?o09Woooooool0Coooo`00Noooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00O?oo
o`80000:oooo0`0000Coool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000
oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo
04ooool008ooool20000?Oooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o
09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0
003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Wooooo
ool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003ooooo
ool0??ooo`03o`2Ioooooooo04ooool008ooool20000?Oooo`03o`2Ioooooooo04ooool008ooool0
0`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOoo
ooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?oo
ooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?
oooo002?oooo0P0003goool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2I
oooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000
oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo
04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`80000moooo00?o
09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0
003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Wooooo
ool0Coooo`00Qoooo`D00003oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008Woool00`000?oo
ooooo`03oooo0`0003coool00ol0VOooooooo`1?oooo0029oooo00<0003oooooool00oooo`030000
oooooooo03coool00ol0VOooooooo`1?oooo0029oooo00<0003oooooool00oooo`030000oooooooo
03coool00ol0VOooooooo`1?oooo0028oooo0P0000Goool00`000?ooooooo`0loooo00?o09Wooooo
ool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003ooooo
ool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Cooo
o`00Soooo`80000moooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOoo
ooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?oo
ooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?
oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool20000?Oooo`03o`2I
oooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000
oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo
04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo
03coool00ol0VOooooooo`1?oooo002?oooo0P0003goool00ol0VOooooooo`1?oooo002?oooo00<0
003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Wooooo
ool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?oooo002?oooo00<0003ooooo
ool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?ooooooo`0loooo00?o09Woooooool0Cooo
o`00Soooo`80000moooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOoo
ooooo`1?oooo002?oooo00<0003oooooool0??ooo`03o`2Ioooooooo04ooool008ooool00`000?oo
ooooo`0loooo00?o09Woooooool0Coooo`00Soooo`030000oooooooo03coool00ol0VOooooooo`1?
oooo001koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0??ooo`03o`2Ioooooooo
04ooool007goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0??oo
o`03o`2Ioooooooo04ooool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0000l
oooo00?o09Woooooool0Coooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool0
0?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?oo
ooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`D00002oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003ooooo
ool01oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_oo
o`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo
00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`09
oooo00<0003oooooool00_ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000A
oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1koooo001loooo00<0
003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1loooo003ooooo8Oooo`00oooo
ob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.71905 .24721 L
.73838 .24721 L
.74806 .24721 L
.75071 .24721 L
.75351 .24721 L
.75467 .24721 L
.75591 .24721 L
s
.75591 .24721 m
.75601 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.22272 .24721 L
.23233 .24721 L
.23739 .24721 L
.24016 .24721 L
.24152 .24721 L
.24276 .24721 L
.24392 .24721 L
.24502 .37082 L
.24618 .37082 L
.24745 .37082 L
.25261 .37082 L
.26171 .37082 L
.30236 .37082 L
.34148 .37082 L
.38307 .37082 L
.42313 .37082 L
.46168 .37082 L
.472 .37082 L
.47703 .37082 L
.47923 .37082 L
.48039 .37082 L
.48162 .37082 L
.48292 .37122 L
.48411 .37185 L
.48647 .37309 L
.49166 .37586 L
.4969 .37873 L
.49834 .37952 L
.49909 .37994 L
.49989 .38038 L
.50058 .38012 L
.50135 .3797 L
.50269 .37895 L
.50797 .37606 L
.51296 .37339 L
.51514 .37224 L
.51633 .37162 L
.51744 .37104 L
.51865 .24721 L
.51928 .24721 L
.51997 .24721 L
.5223 .24721 L
.54325 .24721 L
.58453 .24721 L
Mistroke
.62429 .24721 L
.66253 .24721 L
.70323 .24721 L
.74241 .24721 L
.78404 .24721 L
.82416 .24721 L
.86277 .24721 L
.90382 .24721 L
.94336 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool01oooo`0306Kooooooooo00;oool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool00_oo
o`0306Kooooooooo00Ooool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`02oooo00?o09Woooooool01oooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool004koool00`1Vooooooooo`0n
oooo00<0003oooooool00_ooo`0306Kooooooooo03Woool00ol0VOooooooo`1=oooo001>oooo00<0
I_ooooooool0?_ooo`030000oooooooo00;oool00`1Vooooooooo`0ioooo00?o09Woooooool0COoo
o`00C_ooo`0306Kooooooooo03koool00`000?ooooooo`02oooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo04goool004koool00`1Vooooooooo`0noooo00<0003oooooool00_ooo`0306Kooooooooo
03Woool00ol0VOooooooo`1=oooo001>oooo00<0I_ooooooool0?_ooo`800003oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo04goool004koool00`1Vooooooooo`0noooo00<0003oooooool00_oo
o`0306Kooooooooo03Woool00ol0VOooooooo`1=oooo001>oooo00<0I_ooooooool0?_ooo`030000
oooooooo00;oool00`1Vooooooooo`0ioooo00?o09Woooooool0COooo`00C_ooo`0306Kooooooooo
03koool00`000?ooooooo`02oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04goool004koool0
0`1Vooooooooo`0noooo00<0003oooooool00_ooo`0306Kooooooooo03Woool00ol0VOooooooo`1=
oooo001>oooo00<0I_ooooooool0?_ooo`030000oooooooo00;oool00`1Vooooooooo`0ioooo00?o
09Woooooool0COooo`00C_ooo`0306Kooooooooo03koool200000oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`1=oooo001>oooo00<0I_ooooooool0?_ooo`030000oooooooo00;oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0COooo`00C_ooo`0306Kooooooooo03koool00`000?ooooooo`02
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04goool004koool00`1Vooooooooo`0noooo00<0
003oooooool00_ooo`0306Kooooooooo03Woool00ol0VOooooooo`1=oooo001>oooo00<0I_oooooo
ool0?_ooo`050000oooooooooooo06Ko03coool00ol0VOooooooo`1=oooo001>oooo00<0I_oooooo
ool0?_ooo`050000oooooooooooo06Ko03coool00ol0VOooooooo`1=oooo001>oooo00<0I_oooooo
ool0?_ooo`050000oooooooooooo06Ko03coool00ol0VOooooooo`1=oooo001>oooo00<0I_oooooo
ool0?_ooo`800002oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04goool004koool00`1Voooo
ooooo`0noooo00D0003oooooooooool0I_l0??ooo`03o`2Ioooooooo04goool004koool00`1Voooo
ooooo`0noooo00D0003oooooooooool0I_l0??ooo`03o`2Ioooooooo04goool004koool00`1Voooo
ooooo`0noooo00D0003oooooooooool0I_l0??ooo`03o`2Ioooooooo04goool004koool00`1Voooo
ooooo`0noooo00D0003oooooooooool0I_l0??ooo`03o`2Ioooooooo04goool004koool00`1Voooo
ooooo`0noooo00D0003oooooooooool0I_l0??ooo`03o`2Ioooooooo04goool004koool00`1Voooo
ooooo`0noooo0P0000;oool00`1Vooooooooo`0joooo00?o09Woooooool0COooo`00C_ooo`0306Ko
oooooooo03koool01@000?ooooooooooo`1Vo`0loooo00?o09Woooooool0COooo`00C_ooo`0306Ko
oooooooo03koool01@000?ooooooooooo`1Vo`0loooo00?o09Woooooool0COooo`00C_ooo`0306Ko
oooooooo03koool01@000?ooooooooooo`1Vo`0loooo00?o09Woooooool0COooo`00C_ooo`0306Ko
oooooooo02_oool200001?ooo`800004oooo0P0000Goool01@000?ooooooooooo`1Vo`0loooo00?o
09Woooooool0COooo`00C_ooo`0306Kooooooooo02[oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool01@000?ooooooooooo`1Vo`0loooo00?o09Woooooool0COooo`00C_ooobd0I_l0
1000001Vo`1Vo`0000/0I_l00`00001Vooooo`02oooo0`000003oooo06Kooooo03_oool00ol0VOoo
ooooo`1=oooo001koooo00@0003oooooool00009oooo0P0000;oool206Ko00?oool0003oool00P1V
ocgoool00ol0VOooooooo`1=oooo001koooo00@0003oooooool00009oooo00<0003oooooool00ooo
o`0306Ko000006Ko03ooool00ol0VOooooooo`1=oooo001loooo0P0000[oool300001?ooo`030000
oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo
04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`80000ooooo00?o
09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0
003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Wooooo
ool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003ooooo
ool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COoo
o`00Soooo`80000ooooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOoo
ooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?oo
ooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=
oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool20000?oooo`03o`2I
oooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000
oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo
04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo
03koool00ol0VOooooooo`1=oooo002?oooo0P0003ooool00ol0VOooooooo`1=oooo002?oooo00<0
003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Wooooo
ool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo0027oooo1@0000?oool0
0`000?ooooooo`0noooo00?o09Woooooool0COooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`0noooo00?o09Woooooool0COooo`00ROooo`030000oooooooo00?oool30000?_ooo`03o`2I
oooooooo04goool008Woool00`000?ooooooo`03oooo00<0003oooooool0?_ooo`03o`2Ioooooooo
04goool008Woool00`000?ooooooo`03oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool0
08Soool200001Oooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003ooooo
ool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COoo
o`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo0P0003ooool00ol0VOoo
ooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?oo
ooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=
oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0n
oooo00?o09Woooooool0COooo`00Soooo`80000ooooo00?o09Woooooool0COooo`00Soooo`030000
oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo
04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo
03koool00ol0VOooooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool0
08ooool20000?oooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Wooooo
ool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo00<0003ooooo
ool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?ooooooo`0noooo00?o09Woooooool0COoo
o`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=oooo002?oooo0P0003ooool00ol0VOoo
ooooo`1=oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool008ooool00`000?oo
ooooo`0noooo00?o09Woooooool0COooo`00Soooo`030000oooooooo03koool00ol0VOooooooo`1=
oooo002?oooo00<0003oooooool0?_ooo`03o`2Ioooooooo04goool007_oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00OOooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0noooo00?o09Woooooool0COooo`00OOoo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`0003koool00ol0VOooooooo`1=oooo001m
oooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo
09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?oo
ooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0O
oooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool500000_ooo`800003oooo1@0000;oool200001?ooo`030000oooooooo07Soool007Soool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`09oooo00D0003oooooooooool000000_ooo`050000oooooooooooo000007[oool007Ooool0
0`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00Woool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_oo
o`030000oooooooo00Woool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001h
oooo00D0003oooooooooool000004Oooo`030000oooooooo00Woool00`000?ooooooo`02oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool2
00001?ooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.71905 .24721 L
.73838 .24721 L
.74806 .24721 L
.75315 .24721 L
.75593 .24721 L
.75853 .24721 L
.7597 .24721 L
.76081 .24721 L
s
.76081 .24721 m
.761 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.22272 .24721 L
.23233 .24721 L
.23496 .24721 L
.2364 .24721 L
.23711 .24721 L
.23775 .24721 L
.2389 .37082 L
.24014 .37082 L
.24276 .37082 L
.26171 .37082 L
.30142 .37082 L
.33961 .37082 L
.38026 .37082 L
.41939 .37082 L
.43936 .37082 L
.44987 .37082 L
.46097 .37082 L
.46577 .37082 L
.47092 .37082 L
.47243 .37082 L
.47387 .37082 L
.47516 .37082 L
.47589 .37082 L
.47656 .37101 L
.47778 .37165 L
.47912 .37235 L
.48184 .37379 L
.49119 .37886 L
.49365 .38023 L
.49629 .38171 L
.49757 .38243 L
.49878 .38312 L
.49986 .38374 L
.50104 .38323 L
.50586 .3805 L
.51113 .37758 L
.51553 .37519 L
.52038 .37261 L
.52169 .37192 L
.52242 .37154 L
.52311 .37119 L
.52374 .37086 L
.52444 .24721 L
.52565 .24721 L
Mistroke
.53123 .24721 L
.54124 .24721 L
.58194 .24721 L
.62112 .24721 L
.66275 .24721 L
.70287 .24721 L
.74147 .24721 L
.78253 .24721 L
.82207 .24721 L
.86009 .24721 L
.90057 .24721 L
.93953 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool01Oooo`0306Kooooooooo00Coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool00ooo
o`0306Kooooooooo00Koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`03oooo00?o09Woooooool01_ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool004coool00`1Vooooooooo`10
oooo00<0003oooooool00oooo`0306Kooooooooo03Woool00ol0VOooooooo`1<oooo001<oooo00<0
I_ooooooool0@?ooo`030000oooooooo00?oool00`1Vooooooooo`0ioooo00?o09Woooooool0C?oo
o`00C?ooo`0306Kooooooooo043oool00`000?ooooooo`03oooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo04coool004coool00`1Vooooooooo`10oooo00<0003oooooool00oooo`0306Kooooooooo
03Woool00ol0VOooooooo`1<oooo001<oooo00<0I_ooooooool0@?ooo`800004oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo04coool004coool00`1Vooooooooo`10oooo00<0003oooooool00ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`1<oooo001<oooo00<0I_ooooooool0@?ooo`030000
oooooooo00?oool00`1Vooooooooo`0ioooo00?o09Woooooool0C?ooo`00C?ooo`0306Kooooooooo
043oool00`000?ooooooo`03oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04coool004coool0
0`1Vooooooooo`10oooo00<0003oooooool00oooo`0306Kooooooooo03Woool00ol0VOooooooo`1<
oooo001<oooo00<0I_ooooooool0@?ooo`030000oooooooo00?oool00`1Vooooooooo`0ioooo00?o
09Woooooool0C?ooo`00C?ooo`0306Kooooooooo043oool200001?ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`1<oooo001<oooo00<0I_ooooooool0@?ooo`030000oooooooo00?oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0C?ooo`00C?ooo`0306Kooooooooo043oool00`000?ooooooo`03
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04coool004coool00`1Vooooooooo`10oooo00<0
003oooooool00oooo`0306Kooooooooo03Woool00ol0VOooooooo`1<oooo001=oooo00<0I_oooooo
ool0?oooo`030000oooooooo00?oool00`1Vooooooooo`0ioooo00?o09Woooooool0C?ooo`00COoo
o`0306Kooooooooo03ooool00`000?ooooooo`03oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
04coool004goool00`1Vooooooooo`0ooooo00<0003oooooool00oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`1<oooo001=oooo00<0I_ooooooool0?oooo`800004oooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo04coool004goool00`1Vooooooooo`0ooooo00<0003oooooool00oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`1<oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo
00?oool00`1Vooooooooo`0ioooo00?o09Woooooool0C?ooo`00COooo`0306Kooooooooo03ooool0
0`000?ooooooo`03oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04coool004goool00`1Voooo
ooooo`0ooooo00<0003oooooool00oooo`0306Kooooooooo03Woool00ol0VOooooooo`1<oooo001=
oooo00<0I_ooooooool0?oooo`030000oooooooo00?oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0C?ooo`00COooo`0306Kooooooooo03ooool200001?ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`1<oooo001=oooo00<0I_ooooooool0?oooo`030000oooooooo00?oool00`1Vooooooooo`0i
oooo00?o09Woooooool0C?ooo`00COooo`0306Kooooooooo03ooool00`000?ooooooo`03oooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo04coool004goool00`1Vooooooooo`0ooooo00<0003ooooo
ool00oooo`0306Kooooooooo03Woool00ol0VOooooooo`1<oooo001=oooo00<0I_ooooooool0;?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo00?oool00`1Vooooooooo`0ioooo00?o
09Woooooool0C?ooo`00COooo`0306Kooooooooo02_oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`03oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04coool0
04goool^06Ko00@00000I_l0I_l0000;06Ko00<0003oooooool00_ooo`<00002oooo0P1Voc_oool0
0ol0VOooooooo`1<oooo001koooo00@0003oooooool00009oooo0P000080I_l3oooo00@0003ooooo
ooooool206Ko??ooo`03o`2Ioooooooo04coool007_oool010000?ooooooo`0000Woool010000?oo
ooooooooo`80I_l01Oooo`000?ooooooo`1Vo`0noooo00?o09Woooooool0C?ooo`00O?ooo`80000:
oooo0`0000?oool0101Vo`00001Vo`1Vocooool00ol0VOooooooo`1<oooo002?oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?oo
o`00Soooo`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOoo
ooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?oo
ooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`800010oooo00?o09Woooooool0C?ooo`00Soooo`030000
oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool0
08ooool20000@?ooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Wooooo
ool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?oo
o`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo0P00043oool00ol0VOoo
ooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?oo
ooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<
oooo0027oooo1@0000?oool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00ROooo`030000oooooooo
00?oool30000?oooo`03o`2Ioooooooo04coool008Woool00`000?ooooooo`03oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo04coool008Woool00`000?ooooooo`03oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008Soool200001Oooo`030000oooooooo03ooool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool0
08ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`800010oooo00?o09Wooooo
ool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003ooooo
ool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?oo
o`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?ooo
o`03o`2Ioooooooo04coool008ooool20000@?ooo`03o`2Ioooooooo04coool008ooool00`000?oo
ooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<
oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool008ooool00`000?ooooooo`0o
oooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo03ooool00ol0VOooooooo`1<oooo002?
oooo0P00043oool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo
04coool008ooool00`000?ooooooo`0ooooo00?o09Woooooool0C?ooo`00Soooo`030000oooooooo
03ooool00ol0VOooooooo`1<oooo002?oooo00<0003oooooool0?oooo`03o`2Ioooooooo04coool0
07_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`0ooooo00?o09Woooooool0C?oo
o`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`0ooooo00?o
09Woooooool0C?ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0003ooool0
0ol0VOooooooo`1<oooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003ooooo
ool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00oooo
ob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo
00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool2
00001?ooo`030000oooooooo00Koool500000_ooo`800003oooo100000?oool00`000?ooooooo`1k
oooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`07
oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08oooo00<0003oooooool01?oo
o`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Woool0
0`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000017oool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000
oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQ
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.71905 .24721 L
.73838 .24721 L
.74806 .24721 L
.75315 .24721 L
.75853 .24721 L
.76324 .24721 L
.76453 .24721 L
.76592 .24721 L
.76723 .24721 L
s
.76723 .24721 m
.7674 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.21345 .24721 L
.22272 .24721 L
.22738 .24721 L
.22974 .24721 L
.23038 .24721 L
.23107 .24721 L
.23233 .37082 L
.23302 .37082 L
.23366 .37082 L
.23512 .37082 L
.23778 .37082 L
.24276 .37082 L
.26171 .37082 L
.30084 .37082 L
.34242 .37082 L
.38249 .37082 L
.42104 .37082 L
.44059 .37082 L
.45094 .37082 L
.45664 .37082 L
.46204 .37082 L
.46716 .37082 L
.46856 .37082 L
.46933 .37082 L
.47005 .37082 L
.47132 .37138 L
.47272 .37212 L
.48246 .37733 L
.49157 .38241 L
.49406 .38383 L
.49673 .38537 L
.49802 .38612 L
.49924 .38683 L
.50034 .38708 L
.50153 .38638 L
.51136 .38075 L
.51639 .37796 L
.52171 .37507 L
.5263 .37263 L
.52755 .37197 L
.52825 .37161 L
.5289 .37127 L
.53018 .24721 L
.53134 .24721 L
Mistroke
.54022 .24721 L
.57846 .24721 L
.61916 .24721 L
.65834 .24721 L
.69998 .24721 L
.74009 .24721 L
.7787 .24721 L
.81975 .24721 L
.85929 .24721 L
.89732 .24721 L
.93779 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool01?ooo`0306Kooooooooo00Goool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool01Ooo
o`0306Kooooooooo00Coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`05oooo00?o09Woooooool01?ooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool004_oool00`1Vooooooooo`11
oooo00<0003oooooool01Oooo`0306Kooooooooo03Woool00ol0VOooooooo`1:oooo001;oooo00<0
I_ooooooool0@Oooo`030000oooooooo00Goool00`1Vooooooooo`0ioooo00?o09Woooooool0B_oo
o`00Boooo`0306Kooooooooo047oool00`000?ooooooo`05oooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo04[oool004_oool00`1Vooooooooo`11oooo00<0003oooooool01Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`800006oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo04[oool004_oool00`1Vooooooooo`11oooo00<0003oooooool01Ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`030000
oooooooo00Goool00`1Vooooooooo`0ioooo00?o09Woooooool0B_ooo`00Boooo`0306Kooooooooo
047oool00`000?ooooooo`05oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04[oool004_oool0
0`1Vooooooooo`11oooo00<0003oooooool01Oooo`0306Kooooooooo03Woool00ol0VOooooooo`1:
oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo00Goool00`1Vooooooooo`0ioooo00?o
09Woooooool0B_ooo`00Boooo`0306Kooooooooo047oool200001_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo00Goool00`1Voooo
ooooo`0ioooo00?o09Woooooool0B_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`05
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04[oool004_oool00`1Vooooooooo`11oooo00<0
003oooooool01Oooo`0306Kooooooooo03Woool00ol0VOooooooo`1:oooo001;oooo00<0I_oooooo
ool0@Oooo`030000oooooooo00Coool00`1Vooooooooo`0joooo00?o09Woooooool0B_ooo`00Booo
o`0306Kooooooooo047oool00`000?ooooooo`04oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
04[oool004_oool00`1Vooooooooo`11oooo00<0003oooooool01?ooo`0306Kooooooooo03[oool0
0ol0VOooooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`800005oooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo04[oool004_oool00`1Vooooooooo`11oooo00<0003oooooool01?ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo
00Coool00`1Vooooooooo`0joooo00?o09Woooooool0B_ooo`00Boooo`0306Kooooooooo047oool0
0`000?ooooooo`04oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04[oool004_oool00`1Voooo
ooooo`11oooo00<0003oooooool01?ooo`0306Kooooooooo03[oool00ol0VOooooooo`1:oooo001;
oooo00<0I_ooooooool0@Oooo`030000oooooooo00Coool00`1Vooooooooo`0joooo00?o09Wooooo
ool0B_ooo`00Boooo`0306Kooooooooo047oool200001Oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`1:oooo001;oooo00<0I_ooooooool0@Oooo`030000oooooooo00Coool00`1Vooooooooo`0j
oooo00?o09Woooooool0B_ooo`00Boooo`0306Kooooooooo047oool00`000?ooooooo`04oooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo04[oool004_oool00`1Vooooooooo`11oooo00<0003ooooo
ool01?ooo`0306Kooooooooo03[oool00ol0VOooooooo`1:oooo001;oooo00<0I_ooooooool0;_oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo00Coool00`1Vooooooooo`0joooo00?o
09Woooooool0B_ooo`00Boooo`0306Kooooooooo02goool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`04oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04[oool0
04_oool`06Ko00@00000I_l0I_l0000:06Ko00?oool0003oool00oooo`<00004oooo00<0I_oooooo
ool0>_ooo`03o`2Ioooooooo04[oool007_oool010000?ooooooo`0000Woool2000000<0I_oooooo
ool00_ooo`030000oooooooo00;oool306Ko??ooo`03o`2Ioooooooo04[oool007_oool010000?oo
ooooo`0000Woool010000?ooooooo`1Vo`?oool01@000?ooooooooooo`1Vo`0ooooo00?o09Wooooo
ool0B_ooo`00O?ooo`80000:oooo0`000006oooo06Ko06Kooooo0000oooo0P1Vod3oool00ol0VOoo
ooooo`1:oooo002>oooo00<0I_l00000I_l0@_ooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Sooo
o`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`800012oooo00?o
09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2Ioooooooo04[oool008ooool0
0`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo0027oooo1@0000?oool00`000?ooooooo`11oooo00?o
09Woooooool0B_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00ROooo`030000oooooooo00?oool30000@Oooo`03o`2Ioooooooo04[oool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008Soool200001Oooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo
047oool00ol0VOooooooo`1:oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_oo
o`00Soooo`800012oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOoo
ooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:
oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool20000@_ooo`03o`2I
oooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000
oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003oooooool0@Oooo`03o`2Ioooooooo
04[oool008ooool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00Soooo`030000oooooooo
047oool00ol0VOooooooo`1:oooo002?oooo0P0004;oool00ol0VOooooooo`1:oooo002?oooo00<0
003oooooool0@Oooo`03o`2Ioooooooo04[oool008ooool00`000?ooooooo`11oooo00?o09Wooooo
ool0B_ooo`00Soooo`030000oooooooo047oool00ol0VOooooooo`1:oooo002?oooo00<0003ooooo
ool0@Oooo`03o`2Ioooooooo04[oool007_oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`11oooo00?o09Woooooool0B_ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`11oooo00?o09Woooooool0B_ooo`00OOooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`00047oool00ol0VOooooooo`1:oooo001moooo00<0003oooooool02?oo
o`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800003
oooo100000?oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00<0003ooooo
ool00oooo`040000oooooooo00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02
oooo00<0003oooooool03oooo`030000oooooooo00Soool00`000?ooooooo`05oooo00<0003ooooo
ool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo
00Woool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.71905 .24721 L
.73838 .24721 L
.74806 .24721 L
.75853 .24721 L
.76334 .24721 L
.76842 .24721 L
.77051 .24721 L
.77166 .24721 L
.77275 .24721 L
s
.77275 .24721 m
.77295 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20342 .24721 L
.21345 .24721 L
.21786 .24721 L
.22037 .24721 L
.22272 .24721 L
.22387 .24721 L
.22496 .24721 L
.22623 .37082 L
.22738 .37082 L
.23233 .37082 L
.24276 .37082 L
.26171 .37082 L
.2999 .37082 L
.34055 .37082 L
.37968 .37082 L
.42126 .37082 L
.44213 .37082 L
.45128 .37082 L
.45613 .37082 L
.4588 .37082 L
.46133 .37082 L
.4625 .37082 L
.46376 .37082 L
.46441 .37088 L
.46513 .37126 L
.4664 .37192 L
.47102 .37437 L
.48007 .37929 L
.4904 .38515 L
.49493 .3878 L
.49732 .38922 L
.49855 .38995 L
.49924 .39037 L
.49988 .39075 L
.50119 .39011 L
.50244 .38936 L
.50476 .38798 L
.5093 .38532 L
.51922 .37968 L
.52935 .37417 L
.53182 .37286 L
.53317 .37215 L
.53446 .37147 L
.53519 .37109 L
.53598 .24721 L
Mistroke
.5367 .24721 L
.53736 .24721 L
.54008 .24721 L
.57926 .24721 L
.6209 .24721 L
.66102 .24721 L
.69962 .24721 L
.74067 .24721 L
.78021 .24721 L
.81824 .24721 L
.85871 .24721 L
.89767 .24721 L
.93909 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool00_ooo`0306Kooooooooo00Ooool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool01_oo
o`0306Kooooooooo00?oool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`06oooo00?o09Woooooool00oooo`030000oooooooo00goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool004Woool00`1Vooooooooo`13
oooo00<0003oooooool01_ooo`0306Kooooooooo03Woool00ol0VOooooooo`19oooo0019oooo00<0
I_ooooooool0@oooo`030000oooooooo00Koool00`1Vooooooooo`0ioooo00?o09Woooooool0BOoo
o`00BOooo`0306Kooooooooo04?oool00`000?ooooooo`06oooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo04Woool004Woool00`1Vooooooooo`13oooo00<0003oooooool01_ooo`0306Kooooooooo
03Woool00ol0VOooooooo`19oooo0019oooo00<0I_ooooooool0@oooo`800007oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo04Woool004Woool00`1Vooooooooo`13oooo00<0003oooooool01_oo
o`0306Kooooooooo03Woool00ol0VOooooooo`19oooo0019oooo00<0I_ooooooool0@oooo`030000
oooooooo00Koool00`1Vooooooooo`0ioooo00?o09Woooooool0BOooo`00BOooo`0306Kooooooooo
04?oool00`000?ooooooo`06oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Woool004Woool0
0`1Vooooooooo`13oooo00<0003oooooool01_ooo`0306Kooooooooo03Woool00ol0VOooooooo`19
oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo00Koool00`1Vooooooooo`0ioooo00?o
09Woooooool0BOooo`00BOooo`0306Kooooooooo04?oool200001oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`19oooo0019oooo00<0I_ooooooool0@oooo`030000oooooooo00Koool00`1Voooo
ooooo`0ioooo00?o09Woooooool0BOooo`00BOooo`0306Kooooooooo04?oool00`000?ooooooo`06
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Woool004Woool00`1Vooooooooo`13oooo00<0
003oooooool01_ooo`0306Kooooooooo03Woool00ol0VOooooooo`19oooo001:oooo00<0I_oooooo
ool0@_ooo`030000oooooooo00Koool00`1Vooooooooo`0ioooo00?o09Woooooool0BOooo`00B_oo
o`0306Kooooooooo04;oool00`000?ooooooo`06oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
04Woool004[oool00`1Vooooooooo`12oooo00<0003oooooool01_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`19oooo001:oooo00<0I_ooooooool0@_ooo`800007oooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo04Woool004[oool00`1Vooooooooo`12oooo00<0003oooooool01_ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`19oooo001:oooo00<0I_ooooooool0@_ooo`030000oooooooo
00Koool00`1Vooooooooo`0ioooo00?o09Woooooool0BOooo`00B_ooo`0306Kooooooooo04;oool0
0`000?ooooooo`06oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Woool004[oool00`1Voooo
ooooo`12oooo00<0003oooooool01_ooo`0306Kooooooooo03Woool00ol0VOooooooo`19oooo001:
oooo00<0I_ooooooool0@_ooo`030000oooooooo00Koool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0BOooo`00B_ooo`0306Kooooooooo04;oool200001oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`19oooo001:oooo00<0I_ooooooool0@_ooo`030000oooooooo00Koool00`1Vooooooooo`0i
oooo00?o09Woooooool0BOooo`00B_ooo`0306Kooooooooo04;oool00`000?ooooooo`06oooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo04Woool004[oool00`1Vooooooooo`12oooo00<0003ooooo
ool01_ooo`0306Kooooooooo03Woool00ol0VOooooooo`19oooo001:oooo00<0I_ooooooool0;ooo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo00Koool00`1Vooooooooo`0ioooo00?o
09Woooooool0BOooo`00B_ooo`0306Kooooooooo02koool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`06oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Woool0
04[ooola06Ko00@00000I_l0I_l0000806Ko0oooo`030000oooooooo00;oool300001Oooo`80I_lk
oooo00?o09Woooooool0BOooo`00Noooo`040000oooooooo00002?ooo`0306Ko0000000000Goool0
0`000?ooooooo`04oooo0P1Voccoool00ol0VOooooooo`19oooo001koooo00@0003oooooool00009
oooo00<00000I_l0I_l01?ooo`030000oooooooo00;oool206Ko?_ooo`03o`2Ioooooooo04Woool0
07coool200002_ooo`<0000206Ko0_ooo`030000oooooooo0080I_m0oooo00?o09Woooooool0BOoo
o`00SOooo`80I_l00`00001Vo`1Vo`12oooo00?o09Woooooool0BOooo`00S_ooo`0306Ko000006Ko
04?oool00ol0VOooooooo`19oooo002?oooo0P0004?oool00ol0VOooooooo`19oooo002?oooo00<0
003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Wooooo
ool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo00<0003ooooo
ool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOoo
o`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo0P0004?oool00ol0VOoo
ooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?oo
ooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19
oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12
oooo00?o09Woooooool0BOooo`00Soooo`800013oooo00?o09Woooooool0BOooo`00Soooo`030000
oooooooo04;oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo
04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo
04;oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool0
08ooool20000@oooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Wooooo
ool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo00<0003ooooo
ool0@_ooo`03o`2Ioooooooo04Woool008Ooool500000oooo`030000oooooooo04;oool00ol0VOoo
ooooo`19oooo0029oooo00<0003oooooool00oooo`030000oooooooo04;oool00ol0VOooooooo`19
oooo0029oooo00<0003oooooool00oooo`<00012oooo00?o09Woooooool0BOooo`00ROooo`030000
oooooooo00?oool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00R?ooo`800005oooo00<0003ooooo
ool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOoo
o`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_oo
o`03o`2Ioooooooo04Woool008ooool20000@oooo`03o`2Ioooooooo04Woool008ooool00`000?oo
ooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19
oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12
oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?
oooo0P0004?oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo
04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo
04;oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool0
08ooool00`000?ooooooo`12oooo00?o09Woooooool0BOooo`00Soooo`800013oooo00?o09Wooooo
ool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo00<0003ooooo
ool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12oooo00?o09Woooooool0BOoo
o`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19oooo002?oooo00<0003oooooool0@_oo
o`03o`2Ioooooooo04Woool008ooool20000@oooo`03o`2Ioooooooo04Woool008ooool00`000?oo
ooooo`12oooo00?o09Woooooool0BOooo`00Soooo`030000oooooooo04;oool00ol0VOooooooo`19
oooo002?oooo00<0003oooooool0@_ooo`03o`2Ioooooooo04Woool008ooool00`000?ooooooo`12
oooo00?o09Woooooool0BOooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo
04;oool00ol0VOooooooo`19oooo001moooo00<0003oooooool01oooo`040000oooooooo00001?oo
o`030000oooooooo04;oool00ol0VOooooooo`19oooo001moooo00<0003oooooool02_ooo`030000
oooooooo00;oool30000@_ooo`03o`2Ioooooooo04Woool007goool00`000?ooooooo`08oooo0P00
09Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`00
09Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1l
oooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001k
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool2
00001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0
003oooooool0Noooo`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool02Oooo`030000oooooooo00?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@00
00koool00`000?ooooooo`0:oooo00D0003oooooooooool00000OOooo`00Noooo`050000oooooooo
oooo0000017oool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?ooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.75718 .24721 L
.76707 .24721 L
.77247 .24721 L
.77511 .24721 L
.77751 .24721 L
.77883 .24721 L
s
.77883 .24721 m
.77902 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20178 .24721 L
.20742 .24721 L
.21274 .24721 L
.21753 .24721 L
.21884 .24721 L
.21955 .24721 L
.22022 .24721 L
.22141 .37082 L
.22272 .37082 L
.26149 .37082 L
.30271 .37082 L
.34242 .37082 L
.38061 .37082 L
.40193 .37082 L
.42126 .37082 L
.43094 .37082 L
.44141 .37082 L
.44622 .37082 L
.45129 .37082 L
.45563 .37082 L
.45682 .37082 L
.45809 .37082 L
.45929 .37132 L
.46039 .37189 L
.48109 .38322 L
.49019 .38852 L
.49502 .39141 L
.49756 .39296 L
.49823 .39337 L
.49895 .39381 L
.50023 .39431 L
.50149 .39354 L
.50262 .39285 L
.50524 .39126 L
.50982 .38851 L
.51882 .38327 L
.52909 .37752 L
.5336 .37508 L
.536 .3738 L
.53856 .37244 L
.53986 .37176 L
.54108 .37113 L
.54218 .24721 L
.54338 .24721 L
.54788 .24721 L
Mistroke
.55775 .24721 L
.57855 .24721 L
.61924 .24721 L
.65843 .24721 L
.70006 .24721 L
.74018 .24721 L
.77878 .24721 L
.81984 .24721 L
.85938 .24721 L
.8974 .24721 L
.93788 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00D0003oooooooooool0I_l02_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`08oooo00D0I_oooooo
ooooool000003_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02?oo
o`05o`2Ioooooooooooo000000ooool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000
oooooooo01Goool004Soool00`1Vooooooooo`14oooo00<0003oooooool02?ooo`0306Kooooooooo
03Woool00ol0VOooooooo`17oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo00Soool0
0`1Vooooooooo`0ioooo00?o09Woooooool0Aoooo`00B?ooo`0306Kooooooooo04Coool00`000?oo
ooooo`08oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Ooool004Soool00`1Vooooooooo`14
oooo00<0003oooooool02?ooo`0306Kooooooooo03Woool00ol0VOooooooo`17oooo0018oooo00<0
I_ooooooool0A?ooo`800009oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Ooool004Soool0
0`1Vooooooooo`14oooo00<0003oooooool02?ooo`0306Kooooooooo03Woool00ol0VOooooooo`17
oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo00Soool00`1Vooooooooo`0ioooo00?o
09Woooooool0Aoooo`00B?ooo`0306Kooooooooo04Coool00`000?ooooooo`08oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo04Ooool004Soool00`1Vooooooooo`14oooo00<0003oooooool02?oo
o`0306Kooooooooo03Woool00ol0VOooooooo`17oooo0018oooo00<0I_ooooooool0A?ooo`030000
oooooooo00Soool00`1Vooooooooo`0ioooo00?o09Woooooool0Aoooo`00B?ooo`0306Kooooooooo
04Coool200002Oooo`0306Kooooooooo03Woool00ol0VOooooooo`17oooo0018oooo00<0I_oooooo
ool0A?ooo`030000oooooooo00Soool00`1Vooooooooo`0ioooo00?o09Woooooool0Aoooo`00B?oo
o`0306Kooooooooo04Coool00`000?ooooooo`08oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
04Ooool004Soool00`1Vooooooooo`14oooo00<0003oooooool02?ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`17oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo00Ooool00`1Voooo
ooooo`0joooo00?o09Woooooool0Aoooo`00B?ooo`0306Kooooooooo04Coool00`000?ooooooo`07
oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04Ooool004Soool00`1Vooooooooo`14oooo00<0
003oooooool01oooo`0306Kooooooooo03[oool00ol0VOooooooo`17oooo0018oooo00<0I_oooooo
ool0A?ooo`800008oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04Ooool004Soool00`1Voooo
ooooo`14oooo00<0003oooooool01oooo`0306Kooooooooo03[oool00ol0VOooooooo`17oooo0018
oooo00<0I_ooooooool0A?ooo`030000oooooooo00Ooool00`1Vooooooooo`0joooo00?o09Wooooo
ool0Aoooo`00B?ooo`0306Kooooooooo04Coool00`000?ooooooo`07oooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo04Ooool004Soool00`1Vooooooooo`14oooo00<0003oooooool01oooo`0306Ko
oooooooo03[oool00ol0VOooooooo`17oooo0018oooo00<0I_ooooooool0A?ooo`030000oooooooo
00Ooool00`1Vooooooooo`0joooo00?o09Woooooool0Aoooo`00B?ooo`0306Kooooooooo04Coool2
00002?ooo`0306Kooooooooo03[oool00ol0VOooooooo`17oooo0018oooo00<0I_ooooooool0A?oo
o`030000oooooooo00Ooool00`1Vooooooooo`0joooo00?o09Woooooool0Aoooo`00B?ooo`0306Ko
oooooooo04Coool00`000?ooooooo`07oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04Ooool0
04Soool00`1Vooooooooo`14oooo00<0003oooooool01oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`17oooo0018oooo00<0I_ooooooool0<Oooo`800004oooo0P0000Coool200001Oooo`030000
oooooooo00Ooool00`1Vooooooooo`0joooo00?o09Woooooool0Aoooo`00B?ooo`0306Kooooooooo
033oool010000?ooooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`07oooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo04Ooool004Sooolc06Ko00@00000I_l0I_l0000706Ko1?oo
o`030000oooooooo00;oool300001oooo`0306Kooooooooo03[oool00ol0VOooooooo`17oooo001k
oooo00@0003oooooool00007oooo0P1Vo`800005oooo00<0003oooooool01Oooo`80I_lmoooo00?o
09Woooooool0Aoooo`00Noooo`040000oooooooo00002Oooo`03000006Kooooo00Coool00`000?oo
ooooo`04oooo00<0I_ooooooool0?Oooo`03o`2Ioooooooo04Ooool007coool200002_ooo`<00004
oooo00<0003oooooool00_ooo`80I_m0oooo00?o09Woooooool0Aoooo`00Roooo`0506Kooooooooo
oooo000000;oool206Ko@_ooo`03o`2Ioooooooo04Ooool008coool306Ko00<00000I_l0I_l0A?oo
o`03o`2Ioooooooo04Ooool008koool00`1Vo`0000000015oooo00?o09Woooooool0Aoooo`00Sooo
o`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2I
oooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000
oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo
04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`800015oooo00?o
09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0
003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Wooooo
ool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003ooooo
ool0A?ooo`03o`2Ioooooooo04Ooool008ooool20000AOooo`03o`2Ioooooooo04Ooool008ooool0
0`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOoo
ooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?oo
ooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17
oooo002?oooo0P0004Goool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2I
oooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000
oooooooo04Coool00ol0VOooooooo`17oooo0027oooo1@0000?oool00`000?ooooooo`14oooo00?o
09Woooooool0Aoooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`14oooo00?o09Wooooo
ool0Aoooo`00ROooo`030000oooooooo00?oool30000A?ooo`03o`2Ioooooooo04Ooool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008Soool200001Oooo`030000
oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo
04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo
04Coool00ol0VOooooooo`17oooo002?oooo0P0004Goool00ol0VOooooooo`17oooo002?oooo00<0
003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Wooooo
ool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003ooooo
ool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aooo
o`00Soooo`800015oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOoo
ooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?oo
ooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17
oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool20000AOooo`03o`2I
oooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000
oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003oooooool0A?ooo`03o`2Ioooooooo
04Ooool008ooool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00Soooo`030000oooooooo
04Coool00ol0VOooooooo`17oooo002?oooo0P0004Goool00ol0VOooooooo`17oooo002?oooo00<0
003oooooool0A?ooo`03o`2Ioooooooo04Ooool008ooool00`000?ooooooo`14oooo00?o09Wooooo
ool0Aoooo`00Soooo`030000oooooooo04Coool00ol0VOooooooo`17oooo002?oooo00<0003ooooo
ool0A?ooo`03o`2Ioooooooo04Ooool007_oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`14oooo00?o09Woooooool0Aoooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`14oooo00?o09Woooooool0Aoooo`00OOooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`0004Coool00ol0VOooooooo`17oooo001moooo00<0003oooooool02?oo
o`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`07oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02_ooo`040000oooooooooooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`03
oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`800004oooo0`00
00;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.75718 .24721 L
.76707 .24721 L
.77751 .24721 L
.78008 .24721 L
.78283 .24721 L
.78364 .24721 L
.78441 .24721 L
.7851 .24721 L
s
.7851 .24721 m
.78521 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.20178 .24721 L
.20742 .24721 L
.21019 .24721 L
.2114 .24721 L
.21274 .24721 L
.21394 .24721 L
.21506 .37082 L
.21625 .37082 L
.21753 .37082 L
.22272 .37082 L
.26394 .37082 L
.30365 .37082 L
.34184 .37082 L
.38249 .37082 L
.42162 .37082 L
.4319 .37082 L
.43731 .37082 L
.44303 .37082 L
.44804 .37082 L
.44941 .37082 L
.45088 .37082 L
.45159 .37082 L
.45227 .37082 L
.45353 .37142 L
.4632 .37657 L
.48142 .38685 L
.49179 .39307 L
.49427 .3946 L
.49687 .39622 L
.49795 .39689 L
.4991 .39762 L
.50036 .39796 L
.50153 .39722 L
.51105 .39134 L
.5213 .38527 L
.53223 .37907 L
.54231 .37361 L
.54488 .37225 L
.54614 .37159 L
.54729 .37099 L
.5485 .24721 L
.5498 .24721 L
.55255 .24721 L
.56366 .24721 L
.58381 .24721 L
Mistroke
.62357 .24721 L
.66182 .24721 L
.70251 .24721 L
.74169 .24721 L
.78333 .24721 L
.82345 .24721 L
.86205 .24721 L
.90311 .24721 L
.94265 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oool0I_l03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`09oooo00@0I_ooooooool0000>
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`09oooo00Co09Wooooo
ool0000?oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo0016
oooo00<0I_ooooooool0A_ooo`030000oooooooo00Woool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0A_ooo`00A_ooo`0306Kooooooooo04Koool00`000?ooooooo`09oooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo04Koool004Koool00`1Vooooooooo`16oooo00<0003oooooool02Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`16oooo0016oooo00<0I_ooooooool0A_ooo`030000oooooooo
00Woool00`1Vooooooooo`0ioooo00?o09Woooooool0A_ooo`00A_ooo`0306Kooooooooo04Koool2
00002_ooo`0306Kooooooooo03Woool00ol0VOooooooo`16oooo0016oooo00<0I_ooooooool0A_oo
o`030000oooooooo00Woool00`1Vooooooooo`0ioooo00?o09Woooooool0A_ooo`00A_ooo`0306Ko
oooooooo04Koool00`000?ooooooo`09oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Koool0
04Koool00`1Vooooooooo`16oooo00<0003oooooool02Oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`16oooo0016oooo00<0I_ooooooool0A_ooo`030000oooooooo00Woool00`1Vooooooooo`0i
oooo00?o09Woooooool0A_ooo`00A_ooo`0306Kooooooooo04Koool00`000?ooooooo`09oooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo04Koool004Koool00`1Vooooooooo`16oooo0P0000[oool0
0`1Vooooooooo`0ioooo00?o09Woooooool0A_ooo`00A_ooo`0306Kooooooooo04Koool00`000?oo
ooooo`09oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Koool004Koool00`1Vooooooooo`16
oooo00<0003oooooool02Oooo`0306Kooooooooo03Woool00ol0VOooooooo`16oooo0016oooo00<0
I_ooooooool0A_ooo`030000oooooooo00Woool00`1Vooooooooo`0ioooo00?o09Woooooool0A_oo
o`00Aoooo`0306Kooooooooo04Goool00`000?ooooooo`09oooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo04Koool004Ooool00`1Vooooooooo`15oooo00<0003oooooool02Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`16oooo0017oooo00<0I_ooooooool0AOooo`030000oooooooo00Woool0
0`1Vooooooooo`0ioooo00?o09Woooooool0A_ooo`00Aoooo`0306Kooooooooo04Goool200002_oo
o`0306Kooooooooo03Woool00ol0VOooooooo`16oooo0017oooo00<0I_ooooooool0AOooo`030000
oooooooo00Woool00`1Vooooooooo`0ioooo00?o09Woooooool0A_ooo`00Aoooo`0306Kooooooooo
04Goool00`000?ooooooo`09oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Koool004Ooool0
0`1Vooooooooo`15oooo00<0003oooooool02Oooo`0306Kooooooooo03Woool00ol0VOooooooo`16
oooo0017oooo00<0I_ooooooool0AOooo`030000oooooooo00Woool00`1Vooooooooo`0ioooo00?o
09Woooooool0A_ooo`00Aoooo`0306Kooooooooo04Goool00`000?ooooooo`09oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo04Koool004Ooool00`1Vooooooooo`15oooo0P0000[oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0A_ooo`00Aoooo`0306Kooooooooo04Goool00`000?ooooooo`09
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Koool004Ooool00`1Vooooooooo`15oooo00<0
003oooooool02Oooo`0306Kooooooooo03Woool00ol0VOooooooo`16oooo0017oooo00<0I_oooooo
ool0AOooo`030000oooooooo00Woool00`1Vooooooooo`0ioooo00?o09Woooooool0A_ooo`00Aooo
o`0306Kooooooooo03;oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`09oooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo04Koool004Ooool00`1Vooooooooo`0aoooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool02Oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`16oooo0017oooo=01Vo`04000006Ko06Ko00001@1Vo`Koool00`000?ooooooo`02
oooo0`0000Soool206Ko>oooo`03o`2Ioooooooo04Koool007_oool010000?ooooooo`0000Goool2
06Ko0_ooo`800005oooo00<0003oooooool01oooo`80I_lloooo00?o09Woooooool0A_ooo`00Nooo
o`040000oooooooo00001oooo`0306Kooooo000000Koool00`000?ooooooo`05oooo0P1Vockoool0
0ol0VOooooooo`16oooo001loooo0P0000Woool0101Vo`000000000000Coool00`000?ooooooo`03
oooo0P1Vod3oool00ol0VOooooooo`16oooo0029oooo0P1Vo`Coool00`000?ooooooo`02oooo00<0
I_ooooooool0@?ooo`03o`2Ioooooooo04Koool008_oool206Ko0_ooo`030000oooooooo0080I_m3
oooo00?o09Woooooool0A_ooo`00SOooo`80I_l2000000<0I_ooooooool0@oooo`03o`2Ioooooooo
04Koool008koool00`1Vo`000?ooo`16oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool0
08ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool0
0ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool2
0000A_ooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_oo
o`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P0004Koool00ol0VOooooooo`16
oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15
oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?
oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o
09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo
04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool0
08ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Qoooo`D00003oooo00<0003ooooo
ool0AOooo`03o`2Ioooooooo04Koool008Woool00`000?ooooooo`03oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool008Woool00`000?ooooooo`03oooo0`0004Goool00ol0VOooooooo`16
oooo0029oooo00<0003oooooool00oooo`030000oooooooo04Goool00ol0VOooooooo`16oooo0029
oooo00<0003oooooool00oooo`030000oooooooo04Goool00ol0VOooooooo`16oooo0028oooo0P00
00Goool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool0
0ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_oo
o`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2I
oooooooo04Koool008ooool20000A_ooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15
oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?
oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o
09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo0P00
04Koool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool0
08ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`030000oooooooo04Goool0
0ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool008ooool0
0`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Soooo`800016oooo00?o09Woooooool0A_oo
o`00Soooo`030000oooooooo04Goool00ol0VOooooooo`16oooo002?oooo00<0003oooooool0AOoo
o`03o`2Ioooooooo04Koool008ooool00`000?ooooooo`15oooo00?o09Woooooool0A_ooo`00Sooo
o`030000oooooooo04Goool00ol0VOooooooo`16oooo001koooo1@0000;oool200001?ooo`800005
oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool007goool00`000?ooooooo`07oooo00@0
003oooooool00004oooo00<0003oooooool0AOooo`03o`2Ioooooooo04Koool007goool00`000?oo
ooooo`0:oooo00<0003oooooool00_ooo`<00015oooo00?o09Woooooool0A_ooo`00OOooo`030000
oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001l
oooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_oo
o`030000oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000
oooooooo07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@00
00;oool200001Oooo`<00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool01oooo`030000oooooooo00[oool01@000?oo
ooooooooo`00001moooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`07oooo1@0000?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool0
0`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo0000017oool00`000?ooooooo`08oooo00<0003oool000000oooo`030000oooooooo
07_oool007coool00`000?ooooooo`0Aoooo0P0000_oool200000_ooo`030000oooooooo07coool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.75718 .24721 L
.77751 .24721 L
.78293 .24721 L
.7859 .24721 L
.78866 .24721 L
.78988 .24721 L
.79102 .24721 L
.79166 .24721 L
s
.79166 .24721 m
.79176 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.19227 .24721 L
.20178 .24721 L
.20433 .24721 L
.20573 .24721 L
.20704 .24721 L
.20772 .24721 L
.20845 .37082 L
.20926 .37082 L
.21 .37082 L
.21274 .37082 L
.22272 .37082 L
.26243 .37082 L
.30062 .37082 L
.34126 .37082 L
.38039 .37082 L
.40037 .37082 L
.42198 .37082 L
.43212 .37082 L
.43767 .37082 L
.44037 .37082 L
.44284 .37082 L
.44393 .37082 L
.44511 .37082 L
.44623 .37082 L
.44726 .37125 L
.452 .37374 L
.46204 .3792 L
.48229 .39092 L
.49221 .39703 L
.49656 .39979 L
.49775 .40055 L
.49902 .40137 L
.50022 .40187 L
.50131 .40116 L
.51016 .39554 L
.51948 .38985 L
.52966 .38388 L
.53906 .37859 L
.54838 .37355 L
.55064 .37235 L
.55189 .3717 L
.55308 .37108 L
.55374 .24721 L
.55447 .24721 L
.55575 .24721 L
Mistroke
.55824 .24721 L
.57904 .24721 L
.61974 .24721 L
.65892 .24721 L
.70055 .24721 L
.74067 .24721 L
.77928 .24721 L
.82033 .24721 L
.85987 .24721 L
.8979 .24721 L
.93837 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<00000I_ooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0;oooo00<0I_l0003oool03Ooo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02oooo`03o`2I0000oooo
00koool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool004Goool0
0`1Vooooooooo`17oooo00<0003oooooool02oooo`0306Kooooooooo03Woool00ol0VOooooooo`14
oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo00_oool00`1Vooooooooo`0ioooo00?o
09Woooooool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`0;oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo04Coool004Goool00`1Vooooooooo`17oooo00<0003oooooool02ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`80000<
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Coool004Goool00`1Vooooooooo`17oooo00<0
003oooooool02oooo`0306Kooooooooo03Woool00ol0VOooooooo`14oooo0015oooo00<0I_oooooo
ool0Aoooo`030000oooooooo00_oool00`1Vooooooooo`0ioooo00?o09Woooooool0A?ooo`00AOoo
o`0306Kooooooooo04Ooool00`000?ooooooo`0;oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
04Coool004Goool00`1Vooooooooo`17oooo00<0003oooooool02oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo00_oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0A?ooo`00AOooo`0306Kooooooooo04Ooool200003?ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo
00_oool00`1Vooooooooo`0ioooo00?o09Woooooool0A?ooo`00AOooo`0306Kooooooooo04Ooool0
0`000?ooooooo`0;oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04Coool004Goool00`1Voooo
ooooo`17oooo00<0003oooooool02oooo`0306Kooooooooo03Woool00ol0VOooooooo`14oooo0015
oooo00<0I_ooooooool0Aoooo`030000oooooooo00[oool00`1Vooooooooo`0joooo00?o09Wooooo
ool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?ooooooo`0:oooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo04Coool004Goool00`1Vooooooooo`17oooo00<0003oooooool02_ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`80000;oooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo04Coool004Goool00`1Vooooooooo`17oooo00<0003ooooo
ool02_ooo`0306Kooooooooo03[oool00ol0VOooooooo`14oooo0015oooo00<0I_ooooooool0Aooo
o`030000oooooooo00[oool00`1Vooooooooo`0joooo00?o09Woooooool0A?ooo`00AOooo`0306Ko
oooooooo04Ooool00`000?ooooooo`0:oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04Coool0
04Goool00`1Vooooooooo`17oooo00<0003oooooool02_ooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo00[oool00`1Vooooooooo`0j
oooo00?o09Woooooool0A?ooo`00AOooo`0306Kooooooooo04Ooool200002oooo`0306Kooooooooo
03[oool00ol0VOooooooo`14oooo0015oooo00<0I_ooooooool0Aoooo`030000oooooooo00[oool0
0`1Vooooooooo`0joooo00?o09Woooooool0A?ooo`00AOooo`0306Kooooooooo04Ooool00`000?oo
ooooo`0:oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04Coool004Goool00`1Vooooooooo`17
oooo00<0003oooooool02_ooo`0306Kooooooooo03[oool00ol0VOooooooo`14oooo0015oooo00<0
I_ooooooool0=?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo00[oool00`1Voooo
ooooo`0joooo00?o09Woooooool0A?ooo`00AOooo`0306Kooooooooo03?oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0:oooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo04Coool004Gooolf06Ko00@00000I_l0I_l0000406Ko1oooo`030000oooooooo00;oool3
00002_ooo`0306Kooooooooo03[oool00ol0VOooooooo`14oooo001koooo00@0003oooooool00004
oooo00<0I_ooooooool00_ooo`800005oooo00<0003oooooool02Oooo`0306Kooooooooo03_oool0
0ol0VOooooooo`14oooo001koooo00@0003oooooool00005oooo0P1Vo`;oool00`000?ooooooo`04
oooo00<0003oooooool01_ooo`<0I_lnoooo00?o09Woooooool0A?ooo`00O?ooo`800008oooo0P1V
o`<00004oooo00<0003oooooool01?ooo`80I_m1oooo00?o09Woooooool0A?ooo`00R?ooo`80I_l5
oooo00<0003oooooool00oooo`0306Kooooooooo047oool00ol0VOooooooo`14oooo002:oooo00<0
I_ooooooool00_ooo`030000oooooooo00;oool00`1Vooooooooo`12oooo00?o09Woooooool0A?oo
o`00Roooo`80I_l2oooo0P000003oooo06Ko06Ko04Goool00ol0VOooooooo`14oooo002=oooo0P1V
o`03000006Ko06Ko04Ooool00ol0VOooooooo`14oooo002>oooo00<0I_l0003oool0B?ooo`03o`2I
oooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000
oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo
04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`800018oooo00?o
09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0
003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Wooooo
ool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?ooo`03o`2Ioooooooo04Coool008ooool0
0`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14
oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2I
oooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000
oooooooo04Ooool00ol0VOooooooo`14oooo0027oooo1@0000?oool00`000?ooooooo`17oooo00?o
09Woooooool0A?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`17oooo00?o09Wooooo
ool0A?ooo`00ROooo`030000oooooooo00?oool30000Aoooo`03o`2Ioooooooo04Coool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008Soool200001Oooo`030000
oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo
04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo
04Ooool00ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0
003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Wooooo
ool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?oo
o`00Soooo`800018oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOoo
ooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14
oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool20000B?ooo`03o`2I
oooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000
oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003oooooool0Aoooo`03o`2Ioooooooo
04Coool008ooool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00Soooo`030000oooooooo
04Ooool00ol0VOooooooo`14oooo002?oooo0P0004Soool00ol0VOooooooo`14oooo002?oooo00<0
003oooooool0Aoooo`03o`2Ioooooooo04Coool008ooool00`000?ooooooo`17oooo00?o09Wooooo
ool0A?ooo`00Soooo`030000oooooooo04Ooool00ol0VOooooooo`14oooo002?oooo00<0003ooooo
ool0Aoooo`03o`2Ioooooooo04Coool007_oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`17oooo00?o09Woooooool0A?ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`17oooo00?o09Woooooool0A?ooo`00OOooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`0004Ooool00ol0VOooooooo`14oooo001moooo00<0003oooooool02?oo
o`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800005
oooo0`0000;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?ooooooo`0:oooo00@0003ooooo
ool00002oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?oo
ooooo`0?oooo00<0003oooooool01oooo`D00004oooo00<0003oooooool00_ooo`030000oooooooo
07Ooool007Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`00
00?oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0
003oooooool02?ooo`030000oooo000000?oool00`000?ooooooo`03oooo00<0003oooooool0N?oo
o`00NOooo`030000oooooooo017oool200002oooo`800003oooo0`0000;oool00`000?ooooooo`1i
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.75718 .24721 L
.77751 .24721 L
.78293 .24721 L
.78866 .24721 L
.79355 .24721 L
.79489 .24721 L
.79563 .24721 L
.79633 .24721 L
.79698 .24721 L
s
.79698 .24721 m
.79709 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.19227 .24721 L
.19721 .24721 L
.19939 .24721 L
.20054 .24721 L
.20178 .24721 L
.2031 .37082 L
.20433 .37082 L
.20704 .37082 L
.21274 .37082 L
.22272 .37082 L
.26394 .37082 L
.30365 .37082 L
.34184 .37082 L
.38249 .37082 L
.40128 .37082 L
.42162 .37082 L
.42704 .37082 L
.43277 .37082 L
.43766 .37082 L
.439 .37082 L
.43974 .37082 L
.44044 .37082 L
.44109 .37114 L
.44179 .37151 L
.44303 .37215 L
.4632 .3832 L
.48258 .39473 L
.4879 .39806 L
.49362 .40173 L
.49625 .40345 L
.49769 .4044 L
.49903 .40528 L
.50017 .40581 L
.50139 .405 L
.50398 .4033 L
.52282 .39142 L
.54325 .37957 L
.54864 .3766 L
.55435 .37353 L
.55671 .37229 L
.558 .37161 L
.55923 .37097 L
.55992 .24721 L
.56068 .24721 L
.562 .24721 L
Mistroke
.56459 .24721 L
.58475 .24721 L
.62544 .24721 L
.66463 .24721 L
.70626 .24721 L
.74638 .24721 L
.78498 .24721 L
.82604 .24721 L
.86558 .24721 L
.9036 .24721 L
.94408 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0<oooo00<0I_l0003oool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool004?oool0
0`1Vooooooooo`19oooo00<0003oooooool03?ooo`0306Kooooooooo03Woool00ol0VOooooooo`13
oooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo00coool00`1Vooooooooo`0ioooo00?o
09Woooooool0@oooo`00@oooo`0306Kooooooooo04Woool00`000?ooooooo`0<oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo04?oool004?oool00`1Vooooooooo`19oooo00<0003oooooool03?oo
o`0306Kooooooooo03Woool00ol0VOooooooo`13oooo0013oooo00<0I_ooooooool0BOooo`80000=
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04?oool004?oool00`1Vooooooooo`19oooo00<0
003oooooool03?ooo`0306Kooooooooo03Woool00ol0VOooooooo`13oooo0013oooo00<0I_oooooo
ool0BOooo`030000oooooooo00coool00`1Vooooooooo`0ioooo00?o09Woooooool0@oooo`00@ooo
o`0306Kooooooooo04Woool00`000?ooooooo`0<oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
04?oool004?oool00`1Vooooooooo`19oooo00<0003oooooool03?ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`13oooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo00coool00`1Voooo
ooooo`0ioooo00?o09Woooooool0@oooo`00@oooo`0306Kooooooooo04Woool200003Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`13oooo0013oooo00<0I_ooooooool0BOooo`030000oooooooo
00coool00`1Vooooooooo`0ioooo00?o09Woooooool0@oooo`00@oooo`0306Kooooooooo04Woool0
0`000?ooooooo`0<oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04?oool004?oool00`1Voooo
ooooo`19oooo00<0003oooooool03?ooo`0306Kooooooooo03Woool00ol0VOooooooo`13oooo0014
oooo00<0I_ooooooool0B?ooo`030000oooooooo00coool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0@oooo`00A?ooo`0306Kooooooooo04Soool00`000?ooooooo`0<oooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo04?oool004Coool00`1Vooooooooo`18oooo00<0003oooooool03?ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`13oooo0014oooo00<0I_ooooooool0B?ooo`80000=oooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo04?oool004Coool00`1Vooooooooo`18oooo00<0003ooooo
ool03?ooo`0306Kooooooooo03Woool00ol0VOooooooo`13oooo0014oooo00<0I_ooooooool0B?oo
o`030000oooooooo00coool00`1Vooooooooo`0ioooo00?o09Woooooool0@oooo`00A?ooo`0306Ko
oooooooo04Soool00`000?ooooooo`0<oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04?oool0
04Coool00`1Vooooooooo`18oooo00<0003oooooool03?ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`13oooo0014oooo00<0I_ooooooool0B?ooo`030000oooooooo00coool00`1Vooooooooo`0i
oooo00?o09Woooooool0@oooo`00A?ooo`0306Kooooooooo04Soool200003Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`13oooo0014oooo00<0I_ooooooool0B?ooo`030000oooooooo00coool0
0`1Vooooooooo`0ioooo00?o09Woooooool0@oooo`00A?ooo`0306Kooooooooo04Soool00`000?oo
ooooo`0<oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo04?oool004Coool00`1Vooooooooo`18
oooo00<0003oooooool03?ooo`0306Kooooooooo03Woool00ol0VOooooooo`13oooo0014oooo00<0
I_ooooooool0=Oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo00coool00`1Voooo
ooooo`0ioooo00?o09Woooooool0@oooo`00A?ooo`0306Kooooooooo03Coool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0<oooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo04?oool004Cooolg06Ko00@00000I_l0I_l0000306Ko2?ooo`030000oooooooo00;oool3
00002oooo`80I_lkoooo00?o09Woooooool0@oooo`00Noooo`040000oooooooo00000oooo`80I_l4
oooo0P0000Goool00`000?ooooooo`0;oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo04?oool0
07_oool010000?ooooooo`0000Goool206Ko0_ooo`030000oooooooo00Coool00`000?ooooooo`08
oooo0`1Vocgoool00ol0VOooooooo`13oooo001loooo0P0000Soool00`1Vooooo`00000200001?oo
o`030000oooooooo00Koool206Ko@?ooo`03o`2Ioooooooo04?oool008Ooool206Ko1_ooo`030000
oooooooo00Coool206Ko@_ooo`03o`2Ioooooooo04?oool008Woool206Ko1?ooo`030000oooooooo
00?oool00`1Vooooooooo`12oooo00?o09Woooooool0@oooo`00Roooo`0406Kooooooooooooo0P00
00;oool206KoAOooo`03o`2Ioooooooo04?oool008coool01@1Vooooooooo`000?ooo`0206KoAooo
o`03o`2Ioooooooo04?oool008goool206Ko00<00000I_ooool0B?ooo`03o`2Ioooooooo04?oool0
08koool00`1Vo`000?ooo`19oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool0
0ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool0
0`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019oooo00?o09Woooooool0@ooo
o`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?oo
o`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Sooo
o`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2I
oooooooo04?oool008ooool20000BOooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18
oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o
09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo0P00
04Woool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool0
08ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool0
0ol0VOooooooo`13oooo0027oooo1@0000?oool00`000?ooooooo`18oooo00?o09Woooooool0@ooo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00ROoo
o`030000oooooooo00?oool30000B?ooo`03o`2Ioooooooo04?oool008Woool00`000?ooooooo`03
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008Woool00`000?ooooooo`03oooo00<0
003oooooool0B?ooo`03o`2Ioooooooo04?oool008Soool200001Oooo`030000oooooooo04Soool0
0ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool0
0`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOoo
ooooo`13oooo002?oooo0P0004Woool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?oo
o`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Sooo
o`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2I
oooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`800019
oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?
oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o
09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0
003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool20000BOooo`03o`2Ioooooooo04?oool0
08ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool0
0ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2Ioooooooo04?oool008ooool0
0`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Soooo`030000oooooooo04Soool00ol0VOoo
ooooo`13oooo002?oooo0P0004Woool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?oo
o`03o`2Ioooooooo04?oool008ooool00`000?ooooooo`18oooo00?o09Woooooool0@oooo`00Sooo
o`030000oooooooo04Soool00ol0VOooooooo`13oooo002?oooo00<0003oooooool0B?ooo`03o`2I
oooooooo04?oool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`18oooo00?o
09Woooooool0@oooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`18oooo00?o09Woooooool0@oooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`0004Soool00ol0VOooooooo`13oooo001moooo00<0003oooooool02?ooo`80002Foooo001m
oooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003o
oooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800004oooo0P0000Coool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo
07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03oooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0
003oooooool02?ooo`800004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
017oool00`000?ooooooo`08oooo00<0003oooooool00oooo`030000oooooooo07_oool007coool0
0`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.7878 .24721 L
.79321 .24721 L
.79616 .24721 L
.79892 .24721 L
.80134 .24721 L
.80204 .24721 L
.8027 .24721 L
s
.8027 .24721 m
.80288 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.16408 .24721 L
.18221 .24721 L
.18703 .24721 L
.18957 .24721 L
.19227 .24721 L
.19462 .24721 L
.19527 .24721 L
.19596 .24721 L
.19721 .37082 L
.19844 .37082 L
.1996 .37082 L
.20178 .37082 L
.22272 .37082 L
.26091 .37082 L
.30156 .37082 L
.34068 .37082 L
.38227 .37082 L
.40313 .37082 L
.41229 .37082 L
.42233 .37082 L
.42701 .37082 L
.42959 .37082 L
.43203 .37082 L
.43313 .37082 L
.4343 .37082 L
.43558 .37137 L
.43676 .37199 L
.44108 .37427 L
.46088 .38529 L
.48058 .3972 L
.4892 .40273 L
.49409 .40595 L
.49643 .40752 L
.49863 .40902 L
.49978 .4098 L
.50102 .40925 L
.50215 .40848 L
.50319 .40778 L
.50806 .40453 L
.51798 .39811 L
.53884 .38545 L
.54788 .3803 L
.5576 .37498 L
.56046 .37345 L
.56187 .37271 L
.56317 .37202 L
Mistroke
.56435 .3714 L
.56561 .24721 L
.56633 .24721 L
.567 .24721 L
.56826 .24721 L
.57824 .24721 L
.61684 .24721 L
.6579 .24721 L
.69744 .24721 L
.73546 .24721 L
.77594 .24721 L
.8149 .24721 L
.85631 .24721 L
.89621 .24721 L
.93459 .24721 L
.97543 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0;oooo00<0I_ooool000003_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oool0I_l03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000ooooo`2I
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool004;oool0
0`1Vooooooooo`1:oooo00<0003oooooool03_ooo`0306Kooooooooo03Woool00ol0VOooooooo`11
oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo00koool00`1Vooooooooo`0ioooo00?o
09Woooooool0@Oooo`00@_ooo`0306Kooooooooo04[oool00`000?ooooooo`0>oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo047oool004;oool00`1Vooooooooo`1:oooo00<0003oooooool03_oo
o`0306Kooooooooo03Woool00ol0VOooooooo`11oooo0012oooo00<0I_ooooooool0B_ooo`80000?
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo047oool004;oool00`1Vooooooooo`1:oooo00<0
003oooooool03_ooo`0306Kooooooooo03Woool00ol0VOooooooo`11oooo0012oooo00<0I_oooooo
ool0B_ooo`030000oooooooo00koool00`1Vooooooooo`0ioooo00?o09Woooooool0@Oooo`00@_oo
o`0306Kooooooooo04[oool00`000?ooooooo`0>oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
047oool004;oool00`1Vooooooooo`1:oooo00<0003oooooool03_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`11oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo00koool00`1Voooo
ooooo`0ioooo00?o09Woooooool0@Oooo`00@_ooo`0306Kooooooooo04[oool200003oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`11oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo
00koool00`1Vooooooooo`0ioooo00?o09Woooooool0@Oooo`00@_ooo`0306Kooooooooo04[oool0
0`000?ooooooo`0>oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo047oool004;oool00`1Voooo
ooooo`1:oooo00<0003oooooool03_ooo`0306Kooooooooo03Woool00ol0VOooooooo`11oooo0012
oooo00<0I_ooooooool0B_ooo`030000oooooooo00goool00`1Vooooooooo`0joooo00?o09Wooooo
ool0@Oooo`00@_ooo`0306Kooooooooo04[oool00`000?ooooooo`0=oooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo047oool004;oool00`1Vooooooooo`1:oooo00<0003oooooool03Oooo`0306Ko
oooooooo03[oool00ol0VOooooooo`11oooo0012oooo00<0I_ooooooool0B_ooo`80000>oooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo047oool004;oool00`1Vooooooooo`1:oooo00<0003ooooo
ool03Oooo`0306Kooooooooo03[oool00ol0VOooooooo`11oooo0012oooo00<0I_ooooooool0B_oo
o`030000oooooooo00goool00`1Vooooooooo`0joooo00?o09Woooooool0@Oooo`00@_ooo`0306Ko
oooooooo04[oool00`000?ooooooo`0=oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo047oool0
04;oool00`1Vooooooooo`1:oooo00<0003oooooool03Oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`11oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo00goool00`1Vooooooooo`0j
oooo00?o09Woooooool0@Oooo`00@_ooo`0306Kooooooooo04[oool200003_ooo`0306Kooooooooo
03[oool00ol0VOooooooo`11oooo0012oooo00<0I_ooooooool0B_ooo`030000oooooooo00goool0
0`1Vooooooooo`0joooo00?o09Woooooool0@Oooo`00@_ooo`0306Kooooooooo04[oool00`000?oo
ooooo`0=oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo047oool004;oool00`1Vooooooooo`1:
oooo00<0003oooooool03Oooo`0306Kooooooooo03[oool00ol0VOooooooo`11oooo0012oooo00<0
I_ooooooool0=oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo00goool00`1Voooo
ooooo`0joooo00?o09Woooooool0@Oooo`00@_ooo`0306Kooooooooo03Koool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0=oooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo047oool004;oooli06Ko00D00000I_l0I_l00000I_l02_ooo`030000oooooooo00;oool3
00003Oooo`0306Kooooooooo03[oool00ol0VOooooooo`11oooo001koooo00H0003oooooool0003o
ool0I_l7oooo0P0000Goool00`000?ooooooo`0;oooo0`1Voccoool00ol0VOooooooo`11oooo001k
oooo00@0003oooooool00002oooo0P1Vo`Goool00`000?ooooooo`04oooo00<0003oooooool02Ooo
o`80I_looooo00?o09Woooooool0@Oooo`00O?ooo`800005oooo0P1Vo`?oool300001?ooo`030000
oooooooo00Soool00`1Vooooooooo`0ooooo00?o09Woooooool0@Oooo`00QOooo`0306Kooooooooo
00Ooool00`000?ooooooo`07oooo00<0I_ooooooool0@?ooo`03o`2Ioooooooo047oool008Koool2
06Ko1oooo`030000oooooooo00Goool206Ko@oooo`03o`2Ioooooooo047oool008Soool206Ko1Ooo
o`800004oooo0P1VodGoool00ol0VOooooooo`11oooo002:oooo00<0I_ooooooool00_ooo`030000
oooooooo00;oool00`1Vooooooooo`15oooo00?o09Woooooool0@Oooo`00Roooo`80I_l2oooo00<0
003oooooool00P1VodSoool00ol0VOooooooo`11oooo002=oooo0P1Vo`03000006Ko06Ko04[oool0
0ol0VOooooooo`11oooo002?oooo00<00000I_ooool0B_ooo`03o`2Ioooooooo047oool008ooool0
0`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOoo
ooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_oo
o`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Sooo
o`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2I
oooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`80001;
oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?
oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o
09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0
003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool20000Boooo`03o`2Ioooooooo047oool0
08ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool0
0ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008Ooool5
00000oooo`030000oooooooo04[oool00ol0VOooooooo`11oooo0029oooo00<0003oooooool00ooo
o`030000oooooooo04[oool00ol0VOooooooo`11oooo0029oooo00<0003oooooool00oooo`<0001:
oooo00?o09Woooooool0@Oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1:oooo00?o
09Woooooool0@Oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1:oooo00?o09Wooooo
ool0@Oooo`00R?ooo`800005oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool0
0`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOoo
ooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool20000Booo
o`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Sooo
o`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2I
oooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000
oooooooo04[oool00ol0VOooooooo`11oooo002?oooo0P0004_oool00ol0VOooooooo`11oooo002?
oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o
09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0
003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Wooooo
ool0@Oooo`00Soooo`80001;oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool0
0ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool0
0`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Soooo`030000oooooooo04[oool00ol0VOoo
ooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2Ioooooooo047oool008ooool20000Booo
o`03o`2Ioooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Sooo
o`030000oooooooo04[oool00ol0VOooooooo`11oooo002?oooo00<0003oooooool0B_ooo`03o`2I
oooooooo047oool008ooool00`000?ooooooo`1:oooo00?o09Woooooool0@Oooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo04[oool00ol0VOooooooo`11oooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo04[oool00ol0VOooooooo`11
oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool30000B_ooo`03o`2Ioooooooo
047oool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0
003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`800004oooo00<0003oooooool0N?oo
o`00N?ooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01ooo
o`030000oooooooo00Ooool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`0:
oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000koool00`000?ooooooo`08oooo0P0000Coool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0003oooooool02?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000oooooooo017oool2
00002_ooo`<00003oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.7878 .24721 L
.79892 .24721 L
.80403 .24721 L
.80682 .24721 L
.80819 .24721 L
.80943 .24721 L
s
.80943 .24721 m
.8096 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.16408 .24721 L
.17277 .24721 L
.18221 .24721 L
.18475 .24721 L
.18744 .24721 L
.18855 .24721 L
.18974 .24721 L
.19104 .37082 L
.19227 .37082 L
.20178 .37082 L
.22272 .37082 L
.26394 .37082 L
.30365 .37082 L
.34184 .37082 L
.38249 .37082 L
.40128 .37082 L
.41117 .37082 L
.42162 .37082 L
.42418 .37082 L
.42693 .37082 L
.42774 .37082 L
.42851 .37082 L
.4292 .37115 L
.42995 .37154 L
.43277 .37302 L
.44303 .37856 L
.4632 .39017 L
.48258 .4023 L
.4879 .4058 L
.49362 .40965 L
.49625 .41146 L
.49769 .41245 L
.49903 .41338 L
.50017 .41395 L
.50139 .41309 L
.50398 .4113 L
.54325 .38635 L
.55349 .38049 L
.55888 .37751 L
.56459 .37442 L
.567 .37314 L
.56959 .37178 L
.57035 .37138 L
.57107 .37101 L
.57172 .24721 L
.57242 .24721 L
Mistroke
.57508 .24721 L
.58475 .24721 L
.62544 .24721 L
.66463 .24721 L
.70626 .24721 L
.74638 .24721 L
.78498 .24721 L
.82604 .24721 L
.86558 .24721 L
.9036 .24721 L
.94408 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`09oooo00D0I_ooooooooooool000003_ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00@0003ooooo
ool0I_l;oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00@0
003ooooooooo09T<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0E
oooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo00ooool00`1Vooooooooo`0ioooo00?o
09Woooooool0@?ooo`00@?ooo`0306Kooooooooo04coool00`000?ooooooo`0?oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo043oool0043oool00`1Vooooooooo`1<oooo00<0003oooooool03ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`10oooo0010oooo00<0I_ooooooool0C?ooo`030000
oooooooo00ooool00`1Vooooooooo`0ioooo00?o09Woooooool0@?ooo`00@?ooo`0306Kooooooooo
04coool200004?ooo`0306Kooooooooo03Woool00ol0VOooooooo`10oooo0010oooo00<0I_oooooo
ool0C?ooo`030000oooooooo00ooool00`1Vooooooooo`0ioooo00?o09Woooooool0@?ooo`00@?oo
o`0306Kooooooooo04coool00`000?ooooooo`0?oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
043oool0043oool00`1Vooooooooo`1<oooo00<0003oooooool03oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`10oooo0010oooo00<0I_ooooooool0C?ooo`030000oooooooo00ooool00`1Voooo
ooooo`0ioooo00?o09Woooooool0@?ooo`00@?ooo`0306Kooooooooo04coool00`000?ooooooo`0?
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo043oool0043oool00`1Vooooooooo`1<oooo0P00
013oool00`1Vooooooooo`0ioooo00?o09Woooooool0@?ooo`00@?ooo`0306Kooooooooo04coool0
0`000?ooooooo`0?oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo043oool0043oool00`1Voooo
ooooo`1<oooo00<0003oooooool03oooo`0306Kooooooooo03Woool00ol0VOooooooo`10oooo0010
oooo00<0I_ooooooool0C?ooo`030000oooooooo00ooool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0@?ooo`00@Oooo`0306Kooooooooo04_oool00`000?ooooooo`0?oooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo043oool0047oool00`1Vooooooooo`1;oooo00<0003oooooool03oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`10oooo0011oooo00<0I_ooooooool0Boooo`030000oooooooo
00ooool00`1Vooooooooo`0ioooo00?o09Woooooool0@?ooo`00@Oooo`0306Kooooooooo04_oool2
00004?ooo`0306Kooooooooo03Woool00ol0VOooooooo`10oooo0011oooo00<0I_ooooooool0Booo
o`030000oooooooo00ooool00`1Vooooooooo`0ioooo00?o09Woooooool0@?ooo`00@Oooo`0306Ko
oooooooo04_oool00`000?ooooooo`0?oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo043oool0
047oool00`1Vooooooooo`1;oooo00<0003oooooool03oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`10oooo0011oooo00<0I_ooooooool0Boooo`030000oooooooo00ooool00`1Vooooooooo`0i
oooo00?o09Woooooool0@?ooo`00@Oooo`0306Kooooooooo04_oool00`000?ooooooo`0?oooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo043oool0047oool00`1Vooooooooo`1;oooo0P00013oool0
0`1Vooooooooo`0ioooo00?o09Woooooool0@?ooo`00@Oooo`0306Kooooooooo04_oool00`000?oo
ooooo`0?oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo043oool0047oool00`1Vooooooooo`1;
oooo00<0003oooooool03oooo`0306Kooooooooo03Woool00ol0VOooooooo`10oooo0011oooo00<0
I_ooooooool0Boooo`030000oooooooo00ooool00`1Vooooooooo`0ioooo00?o09Woooooool0@?oo
o`00@Oooo`0306Kooooooooo03Soool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0?
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo043oool0047oool00`1Vooooooooo`0goooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool03oooo`0306Kooooooooo
03Woool00ol0VOooooooo`10oooo0011oooo>P1Vo`04000006Ko06Ko00002oooo`030000oooooooo
00;oool300003oooo`0306Kooooooooo03Woool00ol0VOooooooo`10oooo001koooo00D0003ooooo
ool00000I_l02?ooo`800005oooo00<0003oooooool03Oooo`80I_lloooo00?o09Woooooool0@?oo
o`00Noooo`050000oooooooo0000oooo0080I_l6oooo00<0003oooooool01?ooo`030000oooooooo
00coool00`1Vooooooooo`0loooo00?o09Woooooool0@?ooo`00O?ooo`800004oooo0P1Vo`Coool3
00001?ooo`030000oooooooo00[oool206Ko?oooo`03o`2Ioooooooo043oool008Coool206Ko2Ooo
o`030000oooooooo00Soool206Ko@Oooo`03o`2Ioooooooo043oool008Koool00`1Vooooooooo`06
oooo00<0003oooooool01_ooo`80I_m3oooo00?o09Woooooool0@?ooo`00Qoooo`80I_l6oooo0P00
00Goool206KoAOooo`03o`2Ioooooooo043oool008Woool206Ko1?ooo`030000oooooooo00?oool0
0`1Vooooooooo`15oooo00?o09Woooooool0@?ooo`00Roooo`0506Kooooooooooooo000000?oool2
06KoB?ooo`03o`2Ioooooooo043oool008coool01@1Vooooooooo`000?ooo`0206KoB_ooo`03o`2I
oooooooo043oool008goool206Ko00<00000I_ooool0Boooo`03o`2Ioooooooo043oool008koool0
0`1Vo`000?ooo`1<oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOoo
ooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Booo
o`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Sooo
o`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`80001<
oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?
oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0
003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?ooo`03o`2Ioooooooo043oool0
08ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008Ooool5
00000oooo`030000oooooooo04_oool00ol0VOooooooo`10oooo0029oooo00<0003oooooool00ooo
o`030000oooooooo04_oool00ol0VOooooooo`10oooo0029oooo00<0003oooooool00oooo`<0001;
oooo00?o09Woooooool0@?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00R?ooo`800005oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool0
0`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?oo
o`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Sooo
o`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000
oooooooo04_oool00ol0VOooooooo`10oooo002?oooo0P0004coool00ol0VOooooooo`10oooo002?
oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o
09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0
003oooooool0Boooo`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Wooooo
ool0@?ooo`00Soooo`80001<oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool0
0ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool0
0`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Soooo`030000oooooooo04_oool00ol0VOoo
ooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2Ioooooooo043oool008ooool20000C?oo
o`03o`2Ioooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Sooo
o`030000oooooooo04_oool00ol0VOooooooo`10oooo002?oooo00<0003oooooool0Boooo`03o`2I
oooooooo043oool008ooool00`000?ooooooo`1;oooo00?o09Woooooool0@?ooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo04_oool00ol0VOooooooo`10oooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo04_oool00ol0VOooooooo`10
oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool30000Boooo`03o`2Ioooooooo
043oool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0
003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00O?oo
o`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000
oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000?oool300001?ooo`030000oooooooo07_oool007_oool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Ooool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo
00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool300001?oo
o`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000Aoooo00<0003oooooool02?oo
o`030000oooooooo00?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:
oooo0`0000;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.7878 .24721 L
.79892 .24721 L
.80403 .24721 L
.80943 .24721 L
.81165 .24721 L
.81404 .24721 L
.81474 .24721 L
.8154 .24721 L
s
.8154 .24721 m
.81559 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.16408 .24721 L
.17277 .24721 L
.17735 .24721 L
.17986 .24721 L
.18221 .24721 L
.18341 .24721 L
.1847 .37082 L
.18543 .37082 L
.18613 .37082 L
.18744 .37082 L
.19227 .37082 L
.20178 .37082 L
.22272 .37082 L
.26091 .37082 L
.30156 .37082 L
.34068 .37082 L
.38227 .37082 L
.40313 .37082 L
.41229 .37082 L
.41714 .37082 L
.4198 .37082 L
.42112 .37082 L
.42233 .37082 L
.42351 .37128 L
.42476 .37194 L
.4274 .37333 L
.43203 .3758 L
.44108 .38079 L
.46088 .39237 L
.48058 .40489 L
.4892 .4107 L
.49409 .41409 L
.49643 .41574 L
.49863 .41731 L
.49978 .41813 L
.50102 .41756 L
.50215 .41675 L
.50319 .41601 L
.50806 .4126 L
.51798 .40584 L
.53884 .39254 L
.5576 .38153 L
.56274 .37866 L
.56826 .37564 L
.57094 .37421 L
.57348 .37286 L
Mistroke
.57576 .37167 L
.57705 .37099 L
.57824 .24721 L
.57953 .24721 L
.5809 .24721 L
.58333 .24721 L
.58884 .24721 L
.5988 .24721 L
.61742 .24721 L
.65545 .24721 L
.69592 .24721 L
.73488 .24721 L
.7763 .24721 L
.81619 .24721 L
.85458 .24721 L
.89541 .24721 L
.93473 .24721 L
.97253 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`08oooo00<0I_ooooooool00_ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00;oool00`1Vooooooooo`07oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool00_ooo`03o`2Ioooooooo00Soool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool003ooool00`1Vooooooooo`1=
oooo00<0003oooooool04Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0noooo000ooooo00<0
I_ooooooool0COooo`030000oooooooo017oool00`1Vooooooooo`0ioooo00?o09Woooooool0?_oo
o`00?oooo`0306Kooooooooo04goool00`000?ooooooo`0Aoooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo03koool003ooool00`1Vooooooooo`1=oooo00<0003oooooool04Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0noooo000ooooo00<0I_ooooooool0COooo`80000Boooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03koool003ooool00`1Vooooooooo`1=oooo00<0003oooooool04Ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0noooo000ooooo00<0I_ooooooool0COooo`030000
oooooooo017oool00`1Vooooooooo`0ioooo00?o09Woooooool0?_ooo`00?oooo`0306Kooooooooo
04goool00`000?ooooooo`0Aoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03koool003ooool0
0`1Vooooooooo`1=oooo00<0003oooooool04Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0n
oooo000ooooo00<0I_ooooooool0COooo`030000oooooooo017oool00`1Vooooooooo`0ioooo00?o
09Woooooool0?_ooo`00?oooo`0306Kooooooooo04goool200004_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0noooo000ooooo00<0I_ooooooool0COooo`030000oooooooo017oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0?_ooo`00?oooo`0306Kooooooooo04goool00`000?ooooooo`0A
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03koool003ooool00`1Vooooooooo`1=oooo00<0
003oooooool04Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0noooo000ooooo00<0I_oooooo
ool0COooo`030000oooooooo017oool00`1Vooooooooo`0ioooo00?o09Woooooool0?_ooo`00?ooo
o`0306Kooooooooo04goool00`000?ooooooo`0Aoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03koool003ooool00`1Vooooooooo`1=oooo00<0003oooooool04Oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0noooo000ooooo00<0I_ooooooool0COooo`80000Boooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo03koool003ooool00`1Vooooooooo`1=oooo00<0003oooooool04Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0noooo000ooooo00<0I_ooooooool0COooo`030000oooooooo
017oool00`1Vooooooooo`0ioooo00?o09Woooooool0?_ooo`00?oooo`0306Kooooooooo04goool0
0`000?ooooooo`0Aoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03koool003ooool00`1Voooo
ooooo`1=oooo00<0003oooooool04Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0noooo000o
oooo00<0I_ooooooool0COooo`030000oooooooo017oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0?_ooo`00?oooo`0306Kooooooooo04goool200004_ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0noooo000ooooo00<0I_ooooooool0COooo`030000oooooooo017oool00`1Vooooooooo`0i
oooo00?o09Woooooool0?_ooo`00?oooo`0306Kooooooooo04goool00`000?ooooooo`0Aoooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo03koool003ooool00`1Vooooooooo`1=oooo00<0003ooooo
ool04Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0noooo000ooooo00<0I_ooooooool0>_oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo017oool00`1Vooooooooo`0ioooo00?o
09Woooooool0?_ooo`00?oooo`0306Kooooooooo03Woool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0Aoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03koool0
03ooooll06Ko00@00000I_ooool0000;oooo00<0003oooooool00_ooo`<0000@oooo0P1Voc_oool0
0ol0VOooooooo`0noooo001koooo00@0003oool0I_l00009oooo0P0000Goool00`000?ooooooo`0>
oooo0`1Voccoool00ol0VOooooooo`0noooo001koooo00D0003oooooool00000I_l02?ooo`030000
oooooooo00Coool00`000?ooooooo`0=oooo00<0I_ooooooool0?Oooo`03o`2Ioooooooo03koool0
07coool200000_ooo`0306Kooooooooo00Goool300001?ooo`030000oooooooo00coool00`1Voooo
ooooo`0noooo00?o09Woooooool0?_ooo`00POooo`80I_l<oooo00<0003oooooool02_ooo`80I_m1
oooo00?o09Woooooool0?_ooo`00Poooo`80I_l:oooo00<0003oooooool02?ooo`80I_m3oooo00?o
09Woooooool0?_ooo`00QOooo`0306Kooooooooo00Ooool200002?ooo`0306Kooooooooo04?oool0
0ol0VOooooooo`0noooo0026oooo0P1Vo`Ooool00`000?ooooooo`05oooo0P1VodKoool00ol0VOoo
ooooo`0noooo0028oooo0P1Vo`Goool00`000?ooooooo`03oooo0P1VodSoool00ol0VOooooooo`0n
oooo002:oooo00<0I_ooooooool00_ooo`030000oooooooo00;oool00`1Vooooooooo`18oooo00?o
09Woooooool0?_ooo`00Roooo`80I_l2oooo00<0003oooooool00P1Vod_oool00ol0VOooooooo`0n
oooo002=oooo0P1Vo`030000oooo06Ko04goool00ol0VOooooooo`0noooo002?oooo00<00000I_oo
ool0COooo`03o`2Ioooooooo03koool008ooool20000C_ooo`03o`2Ioooooooo03koool008ooool0
0`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOoo
ooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0n
oooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2I
oooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000
oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo
03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`80001>oooo00?o
09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0
003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Wooooo
ool0?_ooo`00Qoooo`D00003oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008Woool0
0`000?ooooooo`03oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008Woool00`000?oo
ooooo`03oooo0`0004goool00ol0VOooooooo`0noooo0029oooo00<0003oooooool00oooo`030000
oooooooo04goool00ol0VOooooooo`0noooo0029oooo00<0003oooooool00oooo`030000oooooooo
04goool00ol0VOooooooo`0noooo0028oooo0P0000Goool00`000?ooooooo`1=oooo00?o09Wooooo
ool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOoo
ooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0n
oooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool20000C_ooo`03o`2I
oooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000
oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo
03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo
04goool00ol0VOooooooo`0noooo002?oooo0P0004koool00ol0VOooooooo`0noooo002?oooo00<0
003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Wooooo
ool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0noooo002?oooo00<0003ooooo
ool0COooo`03o`2Ioooooooo03koool008ooool00`000?ooooooo`1=oooo00?o09Woooooool0?_oo
o`00Soooo`80001>oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOoo
ooooo`0noooo002?oooo00<0003oooooool0COooo`03o`2Ioooooooo03koool008ooool00`000?oo
ooooo`1=oooo00?o09Woooooool0?_ooo`00Soooo`030000oooooooo04goool00ol0VOooooooo`0n
oooo001koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0COooo`03o`2Ioooooooo
03koool007goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0COoo
o`03o`2Ioooooooo03koool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0001=
oooo00?o09Woooooool0?_ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000
oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool0
0?oooolQoooo001ioooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02
oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200000oooo`<00004oooo0P0000Coool0
0`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`07oooo00<0003oooooool01oooo`040000oooooooo00000_ooo`040000oooooooo
00000oooo`030000oooooooo07Soool007Ooool00`000?ooooooo`02oooo00<0003oooooool03ooo
o`030000oooooooo00Ooool010000?ooooooo`0000Goool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`<00004oooo0P00
00Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool000004Oooo`030000oooooooo
00Soool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo07Soool007Woool0
0`000?ooooooo`0Aoooo0P0000[oool300000oooo`<00002oooo00<0003oooooool0NOooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.79749 .24721 L
.80799 .24721 L
.81373 .24721 L
.81654 .24721 L
.81776 .24721 L
.81909 .24721 L
.82037 .24721 L
s
.82037 .24721 m
.82055 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.14415 .24721 L
.16254 .24721 L
.16783 .24721 L
.17284 .24721 L
.17502 .24721 L
.17733 .24721 L
.17854 .24721 L
.17922 .37082 L
.17987 .37082 L
.18221 .37082 L
.22098 .37082 L
.2622 .37082 L
.30191 .37082 L
.34011 .37082 L
.36142 .37082 L
.38075 .37082 L
.39043 .37082 L
.4009 .37082 L
.40571 .37082 L
.41079 .37082 L
.41288 .37082 L
.41512 .37082 L
.41641 .37082 L
.41758 .3713 L
.41988 .3725 L
.45973 .39532 L
.47795 .4071 L
.48832 .41422 L
.4934 .41782 L
.49562 .41942 L
.4968 .42028 L
.49806 .42119 L
.49931 .42212 L
.50046 .42228 L
.50161 .42144 L
.50269 .42065 L
.50757 .41713 L
.51783 .40996 L
.53884 .39622 L
.55716 .38519 L
.56756 .37928 L
.57265 .37649 L
.5773 .37399 L
.57966 .37274 L
.5809 .37209 L
.58222 .3714 L
Mistroke
.58349 .24721 L
.58464 .24721 L
.58689 .24721 L
.59718 .24721 L
.61822 .24721 L
.65834 .24721 L
.69694 .24721 L
.738 .24721 L
.77754 .24721 L
.81556 .24721 L
.85604 .24721 L
.895 .24721 L
.93641 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`06oooo00<0I_ooooooool01?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00?oool00`1Vooooooooo`06oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool00oooo`03o`2Ioooooooo00Ooool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool003goool00`1Vooooooooo`1?
oooo00<0003oooooool04_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0moooo000moooo00<0
I_ooooooool0Coooo`030000oooooooo01;oool00`1Vooooooooo`0ioooo00?o09Woooooool0?Ooo
o`00?Oooo`0306Kooooooooo04ooool00`000?ooooooo`0Boooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo03goool003goool00`1Vooooooooo`1?oooo00<0003oooooool04_ooo`0306Kooooooooo
03Woool00ol0VOooooooo`0moooo000moooo00<0I_ooooooool0Coooo`80000Coooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03goool003goool00`1Vooooooooo`1?oooo00<0003oooooool04_oo
o`0306Kooooooooo03Woool00ol0VOooooooo`0moooo000moooo00<0I_ooooooool0Coooo`030000
oooooooo01;oool00`1Vooooooooo`0ioooo00?o09Woooooool0?Oooo`00?Oooo`0306Kooooooooo
04ooool00`000?ooooooo`0Boooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03goool003goool0
0`1Vooooooooo`1?oooo00<0003oooooool04_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0m
oooo000moooo00<0I_ooooooool0Coooo`030000oooooooo01;oool00`1Vooooooooo`0ioooo00?o
09Woooooool0?Oooo`00?Oooo`0306Kooooooooo04ooool200004oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0moooo000moooo00<0I_ooooooool0Coooo`030000oooooooo01;oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0?Oooo`00?Oooo`0306Kooooooooo04ooool00`000?ooooooo`0B
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03goool003goool00`1Vooooooooo`1?oooo00<0
003oooooool04_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0moooo000noooo00<0I_oooooo
ool0C_ooo`030000oooooooo01;oool00`1Vooooooooo`0ioooo00?o09Woooooool0?Oooo`00?_oo
o`0306Kooooooooo04koool00`000?ooooooo`0Boooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03goool003koool00`1Vooooooooo`1>oooo00<0003oooooool04_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0moooo000noooo00<0I_ooooooool0C_ooo`80000Coooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo03goool003koool00`1Vooooooooo`1>oooo00<0003oooooool04_ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0moooo000noooo00<0I_ooooooool0C_ooo`030000oooooooo
01;oool00`1Vooooooooo`0ioooo00?o09Woooooool0?Oooo`00?_ooo`0306Kooooooooo04koool0
0`000?ooooooo`0Boooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03goool003koool00`1Voooo
ooooo`1>oooo00<0003oooooool04_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0moooo000n
oooo00<0I_ooooooool0C_ooo`030000oooooooo01;oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0?Oooo`00?_ooo`0306Kooooooooo04koool200004oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0moooo000noooo00<0I_ooooooool0C_ooo`030000oooooooo01;oool00`1Vooooooooo`0i
oooo00?o09Woooooool0?Oooo`00?_ooo`0306Kooooooooo04koool00`000?ooooooo`0Boooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo03goool003koool00`1Vooooooooo`1>oooo00<0003ooooo
ool04_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0moooo000noooo00<0I_ooooooool0>ooo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo01;oool00`1Vooooooooo`0ioooo00?o
09Woooooool0?Oooo`00?_ooo`0306Kooooooooo03[oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0Boooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03goool0
03kooolm06Ko00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Aoooo0P1Voc_oool0
0ol0VOooooooo`0moooo001koooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0A
oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo03goool007_oool01000001Vo`1Vo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool03_ooo`<0I_lmoooo00?o09Woooooool0?Oooo`00O?oo
o`80000206Ko2?ooo`<00004oooo00<0003oooooool03?ooo`80I_m0oooo00?o09Woooooool0?Ooo
o`00P?ooo`80I_l=oooo00<0003oooooool02oooo`0306Kooooooooo043oool00ol0VOooooooo`0m
oooo0022oooo0P1Vo`_oool00`000?ooooooo`0:oooo00<0I_ooooooool0@Oooo`03o`2Ioooooooo
03goool008Coool206Ko2Oooo`800009oooo0P1VodCoool00ol0VOooooooo`0moooo0026oooo00<0
I_ooooooool01_ooo`030000oooooooo00Ooool00`1Vooooooooo`14oooo00?o09Woooooool0?Ooo
o`00Qoooo`80I_l6oooo00<0003oooooool01Oooo`80I_m7oooo00?o09Woooooool0?Oooo`00ROoo
o`0306Kooooooooo00?oool00`000?ooooooo`03oooo0P1VodWoool00ol0VOooooooo`0moooo002:
oooo0P1Vo`?oool010000?ooooooooooo`80I_m;oooo00?o09Woooooool0?Oooo`00S?ooo`0406Ko
oooooooo00000_ooo`0306Kooooooooo04_oool00ol0VOooooooo`0moooo002=oooo0P1Vo`030000
oooo06Ko04koool00ol0VOooooooo`0moooo002>oooo00<0I_l000000000Coooo`03o`2Ioooooooo
03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo
04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool0
08ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool0
0ol0VOooooooo`0moooo002?oooo0P0004ooool00ol0VOooooooo`0moooo002?oooo00<0003ooooo
ool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Ooo
o`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_oo
o`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Sooo
o`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0m
oooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>
oooo00?o09Woooooool0?Oooo`00Qoooo`D00003oooo00<0003oooooool0C_ooo`03o`2Ioooooooo
03goool008Woool00`000?ooooooo`03oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool0
08Woool00`000?ooooooo`03oooo0`0004koool00ol0VOooooooo`0moooo0029oooo00<0003ooooo
ool00oooo`030000oooooooo04koool00ol0VOooooooo`0moooo0029oooo00<0003oooooool00ooo
o`030000oooooooo04koool00ol0VOooooooo`0moooo0028oooo0P0000Goool00`000?ooooooo`1>
oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o
09Woooooool0?Oooo`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo
04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool0
08ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool0
0ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool2
0000Coooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Ooo
o`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_oo
o`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Sooo
o`030000oooooooo04koool00ol0VOooooooo`0moooo002?oooo0P0004ooool00ol0VOooooooo`0m
oooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>
oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool00ol0VOooooooo`0moooo002?
oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool008ooool00`000?ooooooo`1>oooo00?o
09Woooooool0?Oooo`00Soooo`80001?oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo
04koool00ol0VOooooooo`0moooo002?oooo00<0003oooooool0C_ooo`03o`2Ioooooooo03goool0
08ooool00`000?ooooooo`1>oooo00?o09Woooooool0?Oooo`00Soooo`030000oooooooo04koool0
0ol0VOooooooo`0moooo001koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0C_oo
o`03o`2Ioooooooo03goool007goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0
003oooooool0C_ooo`03o`2Ioooooooo03goool007goool00`000?ooooooo`0:oooo00<0003ooooo
ool00_ooo`<0001>oooo00?o09Woooooool0?Oooo`00OOooo`030000oooooooo00Soool20000U_oo
o`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOoo
o`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool0
07_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool0
0`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo1@0000;oool200001Oooo`030000
oooooooo00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool02Oooo`030000oooooooo00;oool0
0`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?oo
ooooo`09oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool00`000?ooooooo`05
00003_ooo`030000oooooooo00[oool01@000?ooooooooooo`00001moooo001koooo00D0003ooooo
ooooool000004Oooo`030000oooooooo00Ooool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001loooo00<0003oooooool04Oooo`800009oooo100000;oool00`000?ooooooo`1loooo003o
oooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.79749 .24721 L
.80799 .24721 L
.81373 .24721 L
.81909 .24721 L
.8239 .24721 L
.82528 .24721 L
.82659 .24721 L
s
.82659 .24721 m
.82676 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.14415 .24721 L
.1536 .24721 L
.16254 .24721 L
.16748 .24721 L
.16883 .24721 L
.17026 .24721 L
.17149 .24721 L
.17219 .24721 L
.17284 .37082 L
.17405 .37082 L
.1752 .37082 L
.17735 .37082 L
.18221 .37082 L
.2204 .37082 L
.26105 .37082 L
.30018 .37082 L
.34176 .37082 L
.36263 .37082 L
.38182 .37082 L
.40057 .37082 L
.40513 .37082 L
.40764 .37082 L
.40887 .37082 L
.41001 .37082 L
.41066 .37082 L
.41135 .37115 L
.41282 .37192 L
.41537 .37326 L
.42038 .37594 L
.45813 .39806 L
.4791 .41195 L
.48828 .41842 L
.49314 .42195 L
.49581 .42392 L
.49712 .4249 L
.49833 .4258 L
.49952 .4267 L
.50078 .42647 L
.50205 .42552 L
.50344 .42448 L
.50809 .42105 L
.51718 .41454 L
.53702 .40116 L
.5581 .38812 L
.57736 .37717 L
.58197 .37468 L
Mistroke
.5845 .37333 L
.58689 .37207 L
.58825 .37136 L
.58901 .37096 L
.58971 .24721 L
.59096 .24721 L
.59228 .24721 L
.59727 .24721 L
.61618 .24721 L
.6542 .24721 L
.69468 .24721 L
.73364 .24721 L
.77505 .24721 L
.81495 .24721 L
.85333 .24721 L
.89417 .24721 L
.93349 .24721 L
.97129 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`05oooo00<0I_ooooooool01Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00Goool00`1Vooooooooo`04oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool01Oooo`03o`2Ioooooooo00Goool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool003coool00`1Vooooooooo`1@
oooo00<0003oooooool05?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0koooo000loooo00<0
I_ooooooool0D?ooo`030000oooooooo01Coool00`1Vooooooooo`0ioooo00?o09Woooooool0>ooo
o`00??ooo`0306Kooooooooo053oool00`000?ooooooo`0Doooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo03_oool003coool00`1Vooooooooo`1@oooo00<0003oooooool05?ooo`0306Kooooooooo
03Woool00ol0VOooooooo`0koooo000loooo00<0I_ooooooool0D?ooo`80000Eoooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03_oool003coool00`1Vooooooooo`1@oooo00<0003oooooool05?oo
o`0306Kooooooooo03Woool00ol0VOooooooo`0koooo000loooo00<0I_ooooooool0D?ooo`030000
oooooooo01Coool00`1Vooooooooo`0ioooo00?o09Woooooool0>oooo`00??ooo`0306Kooooooooo
053oool00`000?ooooooo`0Doooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03_oool003coool0
0`1Vooooooooo`1@oooo00<0003oooooool05?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0k
oooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo01Coool00`1Vooooooooo`0ioooo00?o
09Woooooool0>oooo`00??ooo`0306Kooooooooo053oool200005Oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0koooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo01Coool00`1Voooo
ooooo`0ioooo00?o09Woooooool0>oooo`00??ooo`0306Kooooooooo053oool00`000?ooooooo`0D
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03_oool003coool00`1Vooooooooo`1@oooo00<0
003oooooool05?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0koooo000loooo00<0I_oooooo
ool0D?ooo`030000oooooooo01Coool00`1Vooooooooo`0ioooo00?o09Woooooool0>oooo`00??oo
o`0306Kooooooooo053oool00`000?ooooooo`0Doooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03_oool003coool00`1Vooooooooo`1@oooo00<0003oooooool05?ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0koooo000loooo00<0I_ooooooool0D?ooo`80000Eoooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo03_oool003coool00`1Vooooooooo`1@oooo00<0003oooooool05?ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0koooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo
01Coool00`1Vooooooooo`0ioooo00?o09Woooooool0>oooo`00??ooo`0306Kooooooooo053oool0
0`000?ooooooo`0Doooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03_oool003coool00`1Voooo
ooooo`1@oooo00<0003oooooool05?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0koooo000l
oooo00<0I_ooooooool0D?ooo`030000oooooooo01Coool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0>oooo`00??ooo`0306Kooooooooo053oool200005Oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0koooo000loooo00<0I_ooooooool0D?ooo`030000oooooooo01Coool00`1Vooooooooo`0i
oooo00?o09Woooooool0>oooo`00??ooo`0306Kooooooooo053oool00`000?ooooooo`0Doooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo03_oool003coool00`1Vooooooooo`1@oooo00<0003ooooo
ool05?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0koooo000loooo00<0I_ooooooool0?Ooo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo01Coool00`1Vooooooooo`0ioooo00?o
09Woooooool0>oooo`00??ooo`0306Kooooooooo03coool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0Doooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03_oool0
03coooln06Ko00Goool0003oooooool000002oooo`030000oooooooo00;oool300004oooo`80I_lk
oooo00?o09Woooooool0>oooo`00N_ooo`0506Ko0000oooooooo000000Woool200001Oooo`030000
oooooooo01;oool00`1Vooooooooo`0koooo00?o09Woooooool0>oooo`00Noooo`04000006Ko06Ko
00002Oooo`030000oooooooo00Coool00`000?ooooooo`0@oooo0P1Vockoool00ol0VOooooooo`0k
oooo001loooo0P00000306Kooooooooo00Ooool300001?ooo`030000oooooooo00koool206Ko@?oo
o`03o`2Ioooooooo03_oool007ooool206Ko3_ooo`030000oooooooo00coool206Ko@_ooo`03o`2I
oooooooo03_oool0087oool00`1Vooooooooo`0;oooo00<0003oooooool02_ooo`80I_m4oooo00?o
09Woooooool0>oooo`00P_ooo`80I_l;oooo0P0000[oool00`1Vooooooooo`14oooo00?o09Wooooo
ool0>oooo`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`07oooo0P1VodOoool00ol0VOoo
ooooo`0koooo0025oooo0P1Vo`Soool00`000?ooooooo`06oooo00<0I_ooooooool0Aoooo`03o`2I
oooooooo03_oool008Ooool00`1Vooooooooo`05oooo00<0003oooooool01?ooo`80I_m:oooo00?o
09Woooooool0>oooo`00R?ooo`80I_l5oooo00<0003oooooool00_ooo`80I_m<oooo00?o09Wooooo
ool0>oooo`00R_ooo`0306Kooooooooo00;oool01@000?ooooooooooo`1Vo`1>oooo00?o09Wooooo
ool0>oooo`00Roooo`80I_l2oooo00@0003oooooool0I_m?oooo00?o09Woooooool0>oooo`00SOoo
o`0506Kooooo0000000006Ko053oool00ol0VOooooooo`0koooo002>oooo00<0I_l00000I_l0DOoo
o`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Sooo
o`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2I
oooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`80001A
oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOooooooo`0koooo002?
oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o
09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0
003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOooo`03o`2Ioooooooo03_oool0
08ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool0
0ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008Ooool5
00000oooo`030000oooooooo053oool00ol0VOooooooo`0koooo0029oooo00<0003oooooool00ooo
o`030000oooooooo053oool00ol0VOooooooo`0koooo0029oooo00<0003oooooool00oooo`<0001@
oooo00?o09Woooooool0>oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1@oooo00?o
09Woooooool0>oooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1@oooo00?o09Wooooo
ool0>oooo`00R?ooo`800005oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool0
0`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOoo
ooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOoo
o`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Sooo
o`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2I
oooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000
oooooooo053oool00ol0VOooooooo`0koooo002?oooo0P00057oool00ol0VOooooooo`0koooo002?
oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o
09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0
003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Wooooo
ool0>oooo`00Soooo`80001Aoooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool0
0ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool0
0`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Soooo`030000oooooooo053oool00ol0VOoo
ooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2Ioooooooo03_oool008ooool20000DOoo
o`03o`2Ioooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Sooo
o`030000oooooooo053oool00ol0VOooooooo`0koooo002?oooo00<0003oooooool0D?ooo`03o`2I
oooooooo03_oool008ooool00`000?ooooooo`1@oooo00?o09Woooooool0>oooo`00Noooo`D00002
oooo0P0000Coool200001Oooo`030000oooooooo053oool00ol0VOooooooo`0koooo001moooo00<0
003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo053oool00ol0VOooooooo`0k
oooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool30000D?ooo`03o`2Ioooooooo
03_oool007goool00`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0
003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOoo
o`030000oooooooo02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000
oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool01_ooo`D00002oooo0P0000Goool00`000?ooooooo`02oooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo00<0003oooooool02Oooo`050000oooooooooooo000000;oool01@000?oooooooooo
o`00001joooo001goooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`09
oooo00<0003oooooool01?ooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000koool00`000?ooooooo`0:oooo00@0003oooooooooool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`800009oooo100000?oool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.79749 .24721 L
.80799 .24721 L
.81909 .24721 L
.8239 .24721 L
.82904 .24721 L
.83056 .24721 L
.832 .24721 L
.83329 .24721 L
s
.83329 .24721 m
.8334 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.14415 .24721 L
.1536 .24721 L
.15825 .24721 L
.16254 .24721 L
.16494 .24721 L
.16615 .24721 L
.16683 .37082 L
.16748 .37082 L
.17284 .37082 L
.18221 .37082 L
.22098 .37082 L
.2622 .37082 L
.30191 .37082 L
.34011 .37082 L
.36142 .37082 L
.38075 .37082 L
.39043 .37082 L
.39552 .37082 L
.3983 .37082 L
.4009 .37082 L
.40317 .37082 L
.40445 .37082 L
.40561 .37126 L
.41079 .37399 L
.41988 .37892 L
.45973 .40292 L
.47795 .4153 L
.48832 .42278 L
.4934 .42657 L
.49562 .42825 L
.4968 .42915 L
.49806 .43011 L
.49931 .43108 L
.50046 .43126 L
.50161 .43037 L
.50269 .42954 L
.50757 .42584 L
.51783 .41831 L
.53884 .40386 L
.55716 .39226 L
.56756 .38606 L
.5773 .38049 L
.58689 .37523 L
.58965 .37376 L
.59227 .37237 L
.5934 .37178 L
Mistroke
.59462 .37114 L
.59531 .24721 L
.59595 .24721 L
.59718 .24721 L
.61822 .24721 L
.65834 .24721 L
.69694 .24721 L
.738 .24721 L
.77754 .24721 L
.81556 .24721 L
.85604 .24721 L
.895 .24721 L
.93641 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`03oooo00<0I_ooooooool01oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00Koool00`1Vooooooooo`03oooo00<0003oooooool03?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool01_ooo`03o`2Ioooooooo00Coool00`000?oo
ooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool003[oool00`1Vooooooooo`1B
oooo00<0003oooooool05Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0joooo000joooo00<0
I_ooooooool0D_ooo`030000oooooooo01Goool00`1Vooooooooo`0ioooo00?o09Woooooool0>_oo
o`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`0Eoooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo03[oool003[oool00`1Vooooooooo`1Boooo00<0003oooooool05Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0joooo000joooo00<0I_ooooooool0D_ooo`80000Foooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03[oool003[oool00`1Vooooooooo`1Boooo00<0003oooooool05Ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0joooo000joooo00<0I_ooooooool0D_ooo`030000
oooooooo01Goool00`1Vooooooooo`0ioooo00?o09Woooooool0>_ooo`00>_ooo`0306Kooooooooo
05;oool00`000?ooooooo`0Eoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03[oool003[oool0
0`1Vooooooooo`1Boooo00<0003oooooool05Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0j
oooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo01Goool00`1Vooooooooo`0ioooo00?o
09Woooooool0>_ooo`00>_ooo`0306Kooooooooo05;oool200005_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0joooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo01Goool00`1Voooo
ooooo`0ioooo00?o09Woooooool0>_ooo`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`0E
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03[oool003[oool00`1Vooooooooo`1Boooo00<0
003oooooool05Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0joooo000joooo00<0I_oooooo
ool0D_ooo`030000oooooooo01Goool00`1Vooooooooo`0ioooo00?o09Woooooool0>_ooo`00>_oo
o`0306Kooooooooo05;oool00`000?ooooooo`0Eoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03[oool003[oool00`1Vooooooooo`1Boooo00<0003oooooool05Oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0joooo000joooo00<0I_ooooooool0D_ooo`80000Foooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo03[oool003[oool00`1Vooooooooo`1Boooo00<0003oooooool05Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0joooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo
01Goool00`1Vooooooooo`0ioooo00?o09Woooooool0>_ooo`00>_ooo`0306Kooooooooo05;oool0
0`000?ooooooo`0Eoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03[oool003[oool00`1Voooo
ooooo`1Boooo00<0003oooooool05Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0joooo000j
oooo00<0I_ooooooool0D_ooo`030000oooooooo01Goool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0>_ooo`00>_ooo`0306Kooooooooo05;oool200005_ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0joooo000joooo00<0I_ooooooool0D_ooo`030000oooooooo01Goool00`1Vooooooooo`0i
oooo00?o09Woooooool0>_ooo`00>_ooo`0306Kooooooooo05;oool00`000?ooooooo`0Eoooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo03[oool003[oool00`1Vooooooooo`1Boooo00<0003ooooo
ool05Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0joooo000joooo00<0I_ooooooool0?ooo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo01Goool00`1Vooooooooo`0ioooo00?o
09Woooooool0>_ooo`00>_ooo`0306Kooooooooo03koool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0Eoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03[oool0
03[oooln06Ko0oooo`040000oooooooo00002oooo`030000oooooooo00;oool300005?ooo`80I_lk
oooo00?o09Woooooool0>_ooo`00N?ooo`80I_l01Oooo`000?ooooooo`000009oooo0P0000Goool0
0`000?ooooooo`0Coooo0P1Voccoool00ol0VOooooooo`0joooo001joooo00D0I_l0003oooooool0
00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Boooo00<0I_ooooooool0??ooo`03o`2I
oooooooo03[oool007coool200002_ooo`<00004oooo00<0003oooooool04?ooo`80I_looooo00?o
09Woooooool0>_ooo`00O_ooo`80I_l?oooo00<0003oooooool03_ooo`80I_m1oooo00?o09Wooooo
ool0>_ooo`00P?ooo`0306Kooooooooo00coool00`000?ooooooo`0<oooo0P1Vod?oool00ol0VOoo
ooooo`0joooo0021oooo0P1Vo`coool200003?ooo`0306Kooooooooo04?oool00ol0VOooooooo`0j
oooo0023oooo0P1Vo`[oool00`000?ooooooo`09oooo0P1VodKoool00ol0VOooooooo`0joooo0025
oooo00<0I_ooooooool01oooo`030000oooooooo00Ooool206KoB?ooo`03o`2Ioooooooo03[oool0
08Koool00`1Vooooooooo`06oooo00<0003oooooool01Oooo`80I_m:oooo00?o09Woooooool0>_oo
o`00Qoooo`80I_l6oooo00<0003oooooool01?ooo`0306Kooooooooo04[oool00ol0VOooooooo`0j
oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00;oool206KoCOooo`03o`2Ioooooooo
03[oool008[oool206Ko0oooo`050000oooooooooooo06Ko04ooool00ol0VOooooooo`0joooo002<
oooo00<0I_ooooooool00P000003oooo06Kooooo04ooool00ol0VOooooooo`0joooo002=oooo00D0
I_ooool0003oool0I_l0DOooo`03o`2Ioooooooo03[oool008koool00`1Vo`00001Vo`1Boooo00?o
09Woooooool0>_ooo`00Soooo`030000oooooooo057oool00ol0VOooooooo`0joooo002?oooo00<0
003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Wooooo
ool0>Oooo`00Soooo`80001Coooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo05;oool0
0ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool0
0`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOoo
ooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool20000Dooo
o`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Sooo
o`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2I
oooooooo03Woool008Ooool500000oooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo0029
oooo00<0003oooooool00oooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo0029oooo00<0
003oooooool00oooo`<0001Boooo00?o09Woooooool0>Oooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`1Boooo00?o09Woooooool0>Oooo`00R?ooo`800005oooo00<0003oooooool0D_ooo`03o`2I
oooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000
oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo
03Woool008ooool20000Doooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o
09Woooooool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0
003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Wooooo
ool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo0P0005?oool0
0ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool0
0`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOoo
ooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?oo
ooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`80001Coooo00?o09Woooooool0>Oooo`00Sooo
o`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2I
oooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Woooooool0>Oooo`00Soooo`030000
oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0003oooooool0D_ooo`03o`2Ioooooooo
03Woool008ooool20000Doooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o
09Woooooool0>Oooo`00Soooo`030000oooooooo05;oool00ol0VOooooooo`0ioooo002?oooo00<0
003oooooool0D_ooo`03o`2Ioooooooo03Woool008ooool00`000?ooooooo`1Boooo00?o09Wooooo
ool0>Oooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo05;oool00ol0VOoo
ooooo`0ioooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
05;oool00ol0VOooooooo`0ioooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool3
0000D_ooo`03o`2Ioooooooo03Woool007goool00`000?ooooooo`08oooo0P0009Koool007goool0
0`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQ
oooo003ooooo8Oooo`00O?ooo`030000oooooooo02;oool00`000?ooooooo`1loooo001koooo00<0
003oooooool02?ooo`030000oooooooo01Woool00`000?ooooooo`1koooo001koooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`030000
oooooooo07_oool007_oool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Ooool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Nooo
o`00N_ooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000
oooooooo00Soool200001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000A
oooo00<0003oooooool01oooo`040000oooooooo00000oooo`030000oooooooo07_oool007coool0
0`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo07coool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.79749 .24721 L
.80799 .24721 L
.81909 .24721 L
.82904 .24721 L
.83177 .24721 L
.83469 .24721 L
.83611 .24721 L
.83745 .24721 L
.83865 .24721 L
s
.83865 .24721 m
.83885 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.13506 .24721 L
.14415 .24721 L
.14868 .24721 L
.1536 .24721 L
.15586 .24721 L
.15825 .24721 L
.15923 .24721 L
.16029 .24721 L
.16145 .37082 L
.16254 .37082 L
.18221 .37082 L
.22343 .37082 L
.26314 .37082 L
.30133 .37082 L
.34198 .37082 L
.36078 .37082 L
.38111 .37082 L
.38653 .37082 L
.39226 .37082 L
.39462 .37082 L
.39715 .37082 L
.3979 .37082 L
.3986 .37082 L
.39924 .37104 L
.39993 .3714 L
.40252 .37276 L
.42269 .38386 L
.46347 .40939 L
.48373 .42379 L
.48856 .42741 L
.49365 .4313 L
.49575 .43293 L
.49799 .43469 L
.49928 .43571 L
.50045 .43592 L
.50163 .43499 L
.50274 .43412 L
.52091 .42039 L
.54049 .40671 L
.57896 .38292 L
.58923 .37719 L
.59425 .37448 L
.59644 .37331 L
.59883 .37205 L
.60012 .37138 L
.60131 .24721 L
Mistroke
.60245 .24721 L
.60366 .24721 L
.60885 .24721 L
.61988 .24721 L
.66151 .24721 L
.70163 .24721 L
.74023 .24721 L
.78129 .24721 L
.82083 .24721 L
.85885 .24721 L
.89933 .24721 L
.93829 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`02oooo00<0I_ooooooool02?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00Soool01@1Vooooooooooooo`00000>oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`08oooo00?o09Woooooool00_ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`00>Oooo`0306Kooooooooo05?oool00`000?oo
ooooo`0Goooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Soool003Woool00`1Vooooooooo`1C
oooo00<0003oooooool05oooo`0306Kooooooooo03Woool00ol0VOooooooo`0hoooo000ioooo00<0
I_ooooooool0Doooo`030000oooooooo01Ooool00`1Vooooooooo`0ioooo00?o09Woooooool0>?oo
o`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0Goooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo03Soool003Woool00`1Vooooooooo`1Coooo0P0001Soool00`1Vooooooooo`0ioooo00?o
09Woooooool0>?ooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0Goooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03Soool003Woool00`1Vooooooooo`1Coooo00<0003oooooool05ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0hoooo000ioooo00<0I_ooooooool0Doooo`030000
oooooooo01Ooool00`1Vooooooooo`0ioooo00?o09Woooooool0>?ooo`00>Oooo`0306Kooooooooo
05?oool00`000?ooooooo`0Goooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Soool003Woool0
0`1Vooooooooo`1Coooo00<0003oooooool05oooo`0306Kooooooooo03Woool00ol0VOooooooo`0h
oooo000ioooo00<0I_ooooooool0Doooo`80000Hoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03Soool003Woool00`1Vooooooooo`1Coooo00<0003oooooool05oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0hoooo000ioooo00<0I_ooooooool0Doooo`030000oooooooo01Ooool00`1Voooo
ooooo`0ioooo00?o09Woooooool0>?ooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0G
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Soool003Woool00`1Vooooooooo`1Coooo00<0
003oooooool05_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0hoooo000ioooo00<0I_oooooo
ool0Doooo`030000oooooooo01Koool00`1Vooooooooo`0joooo00?o09Woooooool0>?ooo`00>Ooo
o`0306Kooooooooo05?oool00`000?ooooooo`0Foooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
03Soool003Woool00`1Vooooooooo`1Coooo0P0001Ooool00`1Vooooooooo`0joooo00?o09Wooooo
ool0>?ooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0Foooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo03Soool003Woool00`1Vooooooooo`1Coooo00<0003oooooool05_ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0hoooo000ioooo00<0I_ooooooool0Doooo`030000oooooooo
01Koool00`1Vooooooooo`0joooo00?o09Woooooool0>?ooo`00>Oooo`0306Kooooooooo05?oool0
0`000?ooooooo`0Foooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo03Soool003Woool00`1Voooo
ooooo`1Coooo00<0003oooooool05_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0hoooo000i
oooo00<0I_ooooooool0Doooo`80000Goooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo03Soool0
03Woool00`1Vooooooooo`1Coooo00<0003oooooool05_ooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0hoooo000ioooo00<0I_ooooooool0Doooo`030000oooooooo01Koool00`1Vooooooooo`0j
oooo00?o09Woooooool0>?ooo`00>Oooo`0306Kooooooooo05?oool00`000?ooooooo`0Foooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo03Soool003Woool00`1Vooooooooo`10oooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool05_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0h
oooo000ioooo00<0I_ooooooool0?oooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo01Koool00`1Vooooooooo`0joooo00?o09Woooooool0>?ooo`00>Ooooch0I_l4
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Foooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo03Soool007Koool206Ko0oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool05Oooo`0306Kooooooooo03_oool00ol0VOooooooo`0hoooo001hoooo0P1Vo`05oooo
0000oooooooo000000Woool00`000?ooooooo`04oooo00<0003oooooool04oooo`80I_lnoooo00?o
09Woooooool0>?ooo`00N_ooo`80I_l200002_ooo`<00004oooo00<0003oooooool04Oooo`80I_m0
oooo00?o09Woooooool0>?ooo`00O?ooo`80I_lAoooo00<0003oooooool03oooo`80I_m2oooo00?o
09Woooooool0>?ooo`00O_ooo`0306Kooooooooo00koool00`000?ooooooo`0=oooo0P1VodCoool0
0ol0VOooooooo`0hoooo001ooooo0P1Vo`koool200003Oooo`0306Kooooooooo04Coool00ol0VOoo
ooooo`0hoooo0021oooo0P1Vo`coool00`000?ooooooo`0:oooo0P1VodOoool00ol0VOooooooo`0h
oooo0023oooo00<0I_ooooooool02Oooo`030000oooooooo00Soool206KoBOooo`03o`2Ioooooooo
03Soool008Coool206Ko2Oooo`030000oooooooo00Ooool00`1Vooooooooo`19oooo00?o09Wooooo
ool0>?ooo`00Q_ooo`0306Kooooooooo00Koool00`000?ooooooo`06oooo00<0I_ooooooool0B_oo
o`03o`2Ioooooooo03Soool008Ooool00`1Vooooooooo`05oooo00<0003oooooool01?ooo`80I_m=
oooo00?o09Woooooool0>?ooo`00R?ooo`80I_l5oooo00<0003oooooool00oooo`0306Kooooooooo
04goool00ol0VOooooooo`0hoooo002:oooo00<0I_ooooooool00_ooo`800003oooo00<0I_oooooo
ool0C_ooo`03o`2Ioooooooo03Soool008_oool206Ko0_ooo`050000oooooooooooo06Ko057oool0
0ol0VOooooooo`0hoooo002=oooo00@0I_ooool0003oool206KoD_ooo`03o`2Ioooooooo03Soool0
08koool00`1Vo`00001Vo`1Doooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool0
0ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool2
0000E?ooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?oo
o`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Dooo
o`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Sooo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo0P0005Coool00ol0VOooooooo`0h
oooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1C
oooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo0027
oooo1@0000?oool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00ROooo`030000oooooooo00?oool3
0000Doooo`03o`2Ioooooooo03Soool008Woool00`000?ooooooo`03oooo00<0003oooooool0Dooo
o`03o`2Ioooooooo03Soool008Woool00`000?ooooooo`03oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool008Soool200001Oooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o
09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo0P00
05Coool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
08ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool0
0ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool0
0`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`80001Doooo00?o09Woooooool0>?oo
o`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Dooo
o`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Sooo
o`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2I
oooooooo03Soool008ooool20000E?ooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1C
oooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?
oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool008ooool00`000?ooooooo`1Coooo00?o
09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool00ol0VOooooooo`0hoooo002?oooo0P00
05Coool00ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool0
08ooool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00Soooo`030000oooooooo05?oool0
0ol0VOooooooo`0hoooo002?oooo00<0003oooooool0Doooo`03o`2Ioooooooo03Soool007_oool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`1Coooo00?o09Woooooool0>?ooo`00OOoo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1Coooo00?o09Wooooo
ool0>?ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0005?oool00ol0VOoo
ooooo`0hoooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?oo
o`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool0
07Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool0
0`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool500000_ooo`800004oooo0P0000Coool200001?ooo`030000oooooooo
07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo
00Ooool00`000?ooooooo`07oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0
003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?oooo00<0003ooooo
ool01oooo`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001h
oooo00<0003oooooool01@0000koool00`000?ooooooo`08oooo0P0000Coool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0003oooooool01oooo`040000
oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.79749 .24721 L
.81909 .24721 L
.82924 .24721 L
.83479 .24721 L
.83996 .24721 L
.84223 .24721 L
.84335 .24721 L
.84438 .24721 L
s
.84438 .24721 m
.84456 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.13506 .24721 L
.14415 .24721 L
.14868 .24721 L
.15107 .24721 L
.15238 .24721 L
.1536 .24721 L
.15467 .24721 L
.15581 .37082 L
.15709 .37082 L
.15825 .37082 L
.16254 .37082 L
.18221 .37082 L
.22192 .37082 L
.26011 .37082 L
.30075 .37082 L
.33988 .37082 L
.35986 .37082 L
.37037 .37082 L
.38147 .37082 L
.38627 .37082 L
.38891 .37082 L
.39141 .37082 L
.3921 .37082 L
.39283 .37082 L
.39363 .37122 L
.39437 .37161 L
.39706 .37302 L
.40233 .37584 L
.42153 .38664 L
.45928 .4106 L
.48026 .42564 L
.48944 .43266 L
.4943 .43648 L
.49697 .43861 L
.49828 .43967 L
.49949 .44065 L
.50068 .44052 L
.50194 .43949 L
.5046 .43736 L
.50925 .43368 L
.51833 .4267 L
.53817 .41235 L
.57606 .38806 L
.59551 .37701 L
.60111 .37399 L
.60387 .37253 L
Mistroke
.60521 .37183 L
.60643 .37119 L
.60762 .24721 L
.60874 .24721 L
.6112 .24721 L
.6164 .24721 L
.655 .24721 L
.69606 .24721 L
.7356 .24721 L
.77362 .24721 L
.8141 .24721 L
.85306 .24721 L
.89447 .24721 L
.93437 .24721 L
.97275 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool010000?oo
ooooo`1Vo`coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`09
oooo00@0I_ooooooool0000>oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`09oooo00Go09Woooooooooool000003_ooo`030000oooooooo00coool00`000?ooooooo`0E
oooo000goooo00<0I_ooooooool0EOooo`030000oooooooo01Soool00`1Vooooooooo`0ioooo00?o
09Woooooool0=oooo`00=oooo`0306Kooooooooo05Goool00`000?ooooooo`0Hoooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03Ooool003Ooool00`1Vooooooooo`1Eoooo00<0003oooooool06?oo
o`0306Kooooooooo03Woool00ol0VOooooooo`0goooo000goooo00<0I_ooooooool0EOooo`030000
oooooooo01Soool00`1Vooooooooo`0ioooo00?o09Woooooool0=oooo`00=oooo`0306Kooooooooo
05Goool200006Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0goooo000goooo00<0I_oooooo
ool0EOooo`030000oooooooo01Soool00`1Vooooooooo`0ioooo00?o09Woooooool0=oooo`00=ooo
o`0306Kooooooooo05Goool00`000?ooooooo`0Hoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03Ooool003Ooool00`1Vooooooooo`1Eoooo00<0003oooooool06?ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0goooo000goooo00<0I_ooooooool0EOooo`030000oooooooo01Soool00`1Voooo
ooooo`0ioooo00?o09Woooooool0=oooo`00=oooo`0306Kooooooooo05Goool00`000?ooooooo`0H
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Ooool003Ooool00`1Vooooooooo`1Eoooo0P00
01Woool00`1Vooooooooo`0ioooo00?o09Woooooool0=oooo`00=oooo`0306Kooooooooo05Goool0
0`000?ooooooo`0Hoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Ooool003Ooool00`1Voooo
ooooo`1Eoooo00<0003oooooool06?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0goooo000g
oooo00<0I_ooooooool0EOooo`030000oooooooo01Soool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0=oooo`00>?ooo`0306Kooooooooo05Coool00`000?ooooooo`0Hoooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo03Ooool003Soool00`1Vooooooooo`1Doooo00<0003oooooool06?ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo
01Soool00`1Vooooooooo`0ioooo00?o09Woooooool0=oooo`00>?ooo`0306Kooooooooo05Coool2
00006Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0goooo000hoooo00<0I_ooooooool0E?oo
o`030000oooooooo01Soool00`1Vooooooooo`0ioooo00?o09Woooooool0=oooo`00>?ooo`0306Ko
oooooooo05Coool00`000?ooooooo`0Hoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Ooool0
03Soool00`1Vooooooooo`1Doooo00<0003oooooool06?ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0goooo000hoooo00<0I_ooooooool0E?ooo`030000oooooooo01Soool00`1Vooooooooo`0i
oooo00?o09Woooooool0=oooo`00>?ooo`0306Kooooooooo05Coool00`000?ooooooo`0Hoooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo03Ooool003Soool00`1Vooooooooo`1Doooo0P0001Woool0
0`1Vooooooooo`0ioooo00?o09Woooooool0=oooo`00>?ooo`0306Kooooooooo05Coool00`000?oo
ooooo`0Hoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Ooool003Soool00`1Vooooooooo`1D
oooo00<0003oooooool06?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0goooo000hoooo00<0
I_ooooooool0E?ooo`030000oooooooo01Soool00`1Vooooooooo`0ioooo00?o09Woooooool0=ooo
o`00>?ooo`0306Kooooooooo047oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0H
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Ooool003Soool00`1Vooooooooo`10oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool06?ooo`0306Kooooooooo
03Woool00ol0VOooooooo`0goooo000hoooo?@1Vo`Koool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`0001Soool00`1Vooooooooo`0ioooo00?o09Woooooool0=oooo`00MOooo`80I_l4
oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Goooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo03Ooool007Ooool206Ko0_ooo`040000oooooooo00002Oooo`030000oooooooo
00Coool00`000?ooooooo`0Doooo0`1Vocgoool00ol0VOooooooo`0goooo001ioooo0P1Vo`03oooo
0000000000[oool300001?ooo`030000oooooooo01;oool206Ko@?ooo`03o`2Ioooooooo03Ooool0
07_oool00`1Vooooooooo`0Aoooo00<0003oooooool04?ooo`80I_m2oooo00?o09Woooooool0=ooo
o`00O?ooo`80I_lAoooo00<0003oooooool03oooo`0306Kooooooooo04;oool00ol0VOooooooo`0g
oooo001noooo0P1Vo`ooool200003_ooo`80I_m5oooo00?o09Woooooool0=oooo`00P?ooo`0306Ko
oooooooo00coool00`000?ooooooo`0<oooo00<0I_ooooooool0AOooo`03o`2Ioooooooo03Ooool0
087oool206Ko3?ooo`030000oooooooo00_oool00`1Vooooooooo`16oooo00?o09Woooooool0=ooo
o`00Poooo`80I_l:oooo00<0003oooooool02Oooo`80I_m9oooo00?o09Woooooool0=oooo`00QOoo
o`0306Kooooooooo00Ooool00`000?ooooooo`08oooo00<0I_ooooooool0BOooo`03o`2Ioooooooo
03Ooool008Koool00`1Vooooooooo`06oooo00<0003oooooool01oooo`0306Kooooooooo04[oool0
0ol0VOooooooo`0goooo0027oooo0P1Vo`Koool00`000?ooooooo`05oooo0P1Vodgoool00ol0VOoo
ooooo`0goooo0029oooo00<0I_ooooooool00oooo`800004oooo0P1Vodooool00ol0VOooooooo`0g
oooo002:oooo00<0I_ooooooool00_ooo`030000oooooooo00;oool00`1Vooooooooo`1?oooo00?o
09Woooooool0=oooo`00Roooo`0506Kooooooooooooo000000;oool206KoD_ooo`03o`2Ioooooooo
03Ooool008coool01P1Vooooooooo`000?ooo`1VoeCoool00ol0VOooooooo`0goooo002=oooo0P1V
o`03000006Kooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2I
oooooooo03Ooool008ooool20000EOooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1D
oooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?
oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o
09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo0P00
05Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool0
08ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool0
0ol0VOooooooo`0goooo0027oooo1@0000?oool00`000?ooooooo`1Doooo00?o09Woooooool0=ooo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00ROoo
o`030000oooooooo00?oool30000E?ooo`03o`2Ioooooooo03Ooool008Woool00`000?ooooooo`03
oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008Woool00`000?ooooooo`03oooo00<0
003oooooool0E?ooo`03o`2Ioooooooo03Ooool008Soool200001Oooo`030000oooooooo05Coool0
0ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOoo
ooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Sooo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2I
oooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`80001E
oooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?
oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o
09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0
003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool20000EOooo`03o`2Ioooooooo03Ooool0
08ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool0
0ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2Ioooooooo03Ooool008ooool0
0`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Soooo`030000oooooooo05Coool00ol0VOoo
ooooo`0goooo002?oooo0P0005Goool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?oo
o`03o`2Ioooooooo03Ooool008ooool00`000?ooooooo`1Doooo00?o09Woooooool0=oooo`00Sooo
o`030000oooooooo05Coool00ol0VOooooooo`0goooo002?oooo00<0003oooooool0E?ooo`03o`2I
oooooooo03Ooool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`1Doooo00?o
09Woooooool0=oooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?oo
ooooo`1Doooo00?o09Woooooool0=oooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02
oooo0`0005Coool00ol0VOooooooo`0goooo001moooo00<0003oooooool02?ooo`80002Foooo001m
oooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003o
oooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Nooo
o`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000
oooooooo00;oool200001?ooo`030000oooooooo00Koool500000_ooo`800003oooo0`0000Coool0
0`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`07oooo00<0003oooooool02Oooo`030000oooooooo00;oool00`000?ooooooo`1k
oooo001joooo00<0003oooooool00_ooo`030000oooooooo00ooool00`000?ooooooo`08oooo0`00
00Coool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`07
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo0000
017oool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?oo
o`030000oooooooo017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool0
0?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.79749 .24721 L
.81909 .24721 L
.82924 .24721 L
.83996 .24721 L
.84438 .24721 L
.84681 .24721 L
.84911 .24721 L
.85042 .24721 L
.85115 .24721 L
s
.85115 .24721 m
.85125 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.12507 .24721 L
.13506 .24721 L
.14415 .24721 L
.14635 .24721 L
.14756 .24721 L
.14868 .24721 L
.1499 .37082 L
.15055 .37082 L
.15124 .37082 L
.1536 .37082 L
.16254 .37082 L
.18221 .37082 L
.22343 .37082 L
.26314 .37082 L
.30133 .37082 L
.34198 .37082 L
.36078 .37082 L
.37066 .37082 L
.38111 .37082 L
.38367 .37082 L
.38509 .37082 L
.38578 .37082 L
.38643 .37082 L
.38718 .37096 L
.388 .37139 L
.38944 .37215 L
.39226 .37363 L
.40252 .3792 L
.42269 .39087 L
.46196 .41662 L
.48165 .43123 L
.49028 .43802 L
.49516 .44198 L
.4975 .4439 L
.49865 .44485 L
.49971 .44573 L
.50085 .44526 L
.5021 .44423 L
.50426 .44245 L
.50913 .4385 L
.51906 .43069 L
.53991 .4153 L
.56027 .40153 L
.57931 .38966 L
.59758 .37914 L
.60284 .37626 L
.60783 .37358 L
Mistroke
.61 .37244 L
.61119 .37181 L
.61232 .37123 L
.61295 .37089 L
.61365 .24721 L
.61485 .24721 L
.6172 .24721 L
.65826 .24721 L
.6978 .24721 L
.73582 .24721 L
.7763 .24721 L
.81526 .24721 L
.85667 .24721 L
.89657 .24721 L
.93495 .24721 L
.97578 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
o`1Vo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02ooo
o`0306Ko0000oooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00_oool00ol0VOooo`00000>oooo00<0003oooooool03?ooo`030000oooooooo01Goool003Koool0
0`1Vooooooooo`1Foooo00<0003oooooool06_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0e
oooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo01[oool00`1Vooooooooo`0ioooo00?o
09Woooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`0Joooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03Goool003Koool00`1Vooooooooo`1Foooo00<0003oooooool06_oo
o`0306Kooooooooo03Woool00ol0VOooooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`80000K
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Goool003Koool00`1Vooooooooo`1Foooo00<0
003oooooool06_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0eoooo000foooo00<0I_oooooo
ool0E_ooo`030000oooooooo01[oool00`1Vooooooooo`0ioooo00?o09Woooooool0=Oooo`00=_oo
o`0306Kooooooooo05Koool00`000?ooooooo`0Joooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03Goool003Koool00`1Vooooooooo`1Foooo00<0003oooooool06_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo01[oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool200006oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo
01[oool00`1Vooooooooo`0ioooo00?o09Woooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool0
0`000?ooooooo`0Joooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Goool003Koool00`1Voooo
ooooo`1Foooo00<0003oooooool06_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0eoooo000f
oooo00<0I_ooooooool0E_ooo`030000oooooooo01[oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?ooooooo`0Joooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo03Goool003Koool00`1Vooooooooo`1Foooo00<0003oooooool06_ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`80000Koooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo03Goool003Koool00`1Vooooooooo`1Foooo00<0003ooooo
ool06_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0eoooo000foooo00<0I_ooooooool0E_oo
o`030000oooooooo01[oool00`1Vooooooooo`0ioooo00?o09Woooooool0=Oooo`00=_ooo`0306Ko
oooooooo05Koool00`000?ooooooo`0Joooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Goool0
03Koool00`1Vooooooooo`1Foooo00<0003oooooool06_ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo01[oool00`1Vooooooooo`0i
oooo00?o09Woooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool200006oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0eoooo000foooo00<0I_ooooooool0E_ooo`030000oooooooo01[oool0
0`1Vooooooooo`0ioooo00?o09Woooooool0=Oooo`00=_ooo`0306Kooooooooo05Koool00`000?oo
ooooo`0Joooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Goool003Koool00`1Vooooooooo`1F
oooo00<0003oooooool06_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0eoooo000foooo00<0
I_ooooooool0@oooo`800004oooo0P0000Coool200001Oooo`030000oooooooo01[oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0=Oooo`00=_ooo`0306Kooooooooo04;oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0Joooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo03Goool003Koooln06Ko1oooo`040000oooooooo00002oooo`030000oooooooo00;oool3
00006Oooo`80I_lkoooo00?o09Woooooool0=Oooo`00M?ooo`0306Kooooooooo00Coool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo01Ooool206Ko?Oooo`03o`2Ioooooooo03Goool0
07Goool206Ko1?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0F
oooo00<0I_ooooooool0?Oooo`03o`2Ioooooooo03Goool007Ooool206Ko0oooo`80000:oooo0`00
00Coool00`000?ooooooo`0Doooo0P1Vod3oool00ol0VOooooooo`0eoooo001ioooo0P1VoaCoool0
0`000?ooooooo`0Boooo0P1Vod;oool00ol0VOooooooo`0eoooo001koooo00<0I_ooooooool04Ooo
o`030000oooooooo017oool00`1Vooooooooo`12oooo00?o09Woooooool0=Oooo`00O?ooo`80I_lA
oooo0P00013oool206KoAOooo`03o`2Ioooooooo03Goool007koool00`1Vooooooooo`0>oooo00<0
003oooooool03Oooo`80I_m7oooo00?o09Woooooool0=Oooo`00Ooooo`0306Kooooooooo00goool0
0`000?ooooooo`0<oooo00<0I_ooooooool0Aoooo`03o`2Ioooooooo03Goool0083oool206Ko3Ooo
o`030000oooooooo00[oool206KoB_ooo`03o`2Ioooooooo03Goool008;oool00`1Vooooooooo`0:
oooo00<0003oooooool02?ooo`80I_m<oooo00?o09Woooooool0=Oooo`00Poooo`80I_l:oooo00<0
003oooooool01oooo`0306Kooooooooo04coool00ol0VOooooooo`0eoooo0025oooo00<0I_oooooo
ool01oooo`030000oooooooo00Koool00`1Vooooooooo`1=oooo00?o09Woooooool0=Oooo`00Q_oo
o`80I_l7oooo0P0000Goool206KoD?ooo`03o`2Ioooooooo03Goool008Soool206Ko1Oooo`030000
oooooooo00?oool00`1Vooooooooo`1@oooo00?o09Woooooool0=Oooo`00R_ooo`0306Kooooooooo
00;oool00`000?ooooooo`02oooo00<0I_ooooooool0DOooo`03o`2Ioooooooo03Goool008_oool2
06Ko0_ooo`030000oooooooo0080I_mDoooo00?o09Woooooool0=Oooo`00SOooo`0506Kooooo0000
oooo06Ko05Koool00ol0VOooooooo`0eoooo002>oooo00<0I_l00000I_l0Eoooo`03o`2Ioooooooo
03Goool008koool00`1Vo`000000001Goooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo
05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool0
08ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool0
0ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool2
0000Eoooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Ooo
o`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_oo
o`03o`2Ioooooooo03Goool008Ooool500000oooo`030000oooooooo05Koool00ol0VOooooooo`0e
oooo0029oooo00<0003oooooool00oooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo0029
oooo00<0003oooooool00oooo`<0001Foooo00?o09Woooooool0=Oooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00R?ooo`800005oooo00<0003oooooool0E_oo
o`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Sooo
o`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1F
oooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?
oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o
09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo0P00
05Ooool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool0
08ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool0
0ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool0
0`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Soooo`80001Goooo00?o09Woooooool0=Ooo
o`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_oo
o`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o09Woooooool0=Oooo`00Sooo
o`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?oooo00<0003oooooool0E_ooo`03o`2I
oooooooo03Goool008ooool20000Eoooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1F
oooo00?o09Woooooool0=Oooo`00Soooo`030000oooooooo05Koool00ol0VOooooooo`0eoooo002?
oooo00<0003oooooool0E_ooo`03o`2Ioooooooo03Goool008ooool00`000?ooooooo`1Foooo00?o
09Woooooool0=Oooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo05Koool0
0ol0VOooooooo`0eoooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo05Koool00ol0VOooooooo`0eoooo001moooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000E_ooo`03o`2Ioooooooo03Goool007goool00`000?ooooooo`08oooo0P0009Koool0
07goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`D00002oooo0P0000?oool300001?oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01oooo`030000oooooooo00Woool01@000?ooooooooooo`000002
oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0?
oooo00<0003oooooool02?ooo`<00005oooo00<0003oooooool00_ooo`030000oooooooo07Ooool0
07Soool00`000?ooooooo`0500003_ooo`030000oooooooo00Ooool010000?ooooooo`0000?oool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000Aoooo00<0003ooooo
ool01oooo`040000oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001i
oooo00<0003oooooool04Oooo`80000:oooo0`0000?oool300000_ooo`030000oooooooo07Woool0
0?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.79749 .24721 L
.81909 .24721 L
.82924 .24721 L
.83996 .24721 L
.84911 .24721 L
.85162 .24721 L
.85431 .24721 L
.85561 .24721 L
.85685 .24721 L
s
.85685 .24721 m
.85701 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.08255 .24721 L
.10458 .24721 L
.11448 .24721 L
.12507 .24721 L
.1302 .24721 L
.13506 .24721 L
.13942 .24721 L
.14061 .24721 L
.14188 .24721 L
.14296 .37082 L
.14415 .37082 L
.18444 .37082 L
.22321 .37082 L
.26444 .37082 L
.30414 .37082 L
.34234 .37082 L
.36201 .37082 L
.36767 .37082 L
.37301 .37082 L
.3778 .37082 L
.37911 .37082 L
.37983 .37082 L
.3805 .37082 L
.38168 .3712 L
.38298 .37188 L
.42189 .39401 L
.46325 .42186 L
.48395 .43772 L
.49305 .44514 L
.49554 .44723 L
.49685 .44833 L
.49823 .4495 L
.49944 .45053 L
.50013 .45089 L
.50077 .45035 L
.5031 .44837 L
.52168 .43327 L
.54143 .41846 L
.58047 .39256 L
.59071 .38644 L
.60182 .3801 L
.60691 .37728 L
.6123 .37437 L
.61452 .37319 L
.61691 .37194 L
.61761 .37157 L
.61827 .37122 L
.61952 .24721 L
Mistroke
.62069 .24721 L
.62197 .24721 L
.66267 .24721 L
.70185 .24721 L
.74348 .24721 L
.7836 .24721 L
.82221 .24721 L
.86326 .24721 L
.9028 .24721 L
.94082 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -21.7813 0 ]
[.5 .63053 21.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -82.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
96.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00coool00ol0V@000?ooo`0=oooo00<0003oooooool03?ooo`030000oooooooo01Goool003Coool0
0`1Vooooooooo`1Hoooo00<0003oooooool06oooo`0306Kooooooooo03Woool00ol0VOooooooo`0d
oooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo01_oool00`1Vooooooooo`0ioooo00?o
09Woooooool0=?ooo`00=?ooo`0306Kooooooooo05Soool00`000?ooooooo`0Koooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03Coool003Coool00`1Vooooooooo`1Hoooo00<0003oooooool06ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0doooo000doooo00<0I_ooooooool0F?ooo`80000L
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Coool003Coool00`1Vooooooooo`1Hoooo00<0
003oooooool06oooo`0306Kooooooooo03Woool00ol0VOooooooo`0doooo000doooo00<0I_oooooo
ool0F?ooo`030000oooooooo01_oool00`1Vooooooooo`0ioooo00?o09Woooooool0=?ooo`00=?oo
o`0306Kooooooooo05Soool00`000?ooooooo`0Koooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03Coool003Coool00`1Vooooooooo`1Hoooo00<0003oooooool06oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0doooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo01_oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0=?ooo`00=?ooo`0306Kooooooooo05Soool200007?ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0doooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo
01_oool00`1Vooooooooo`0ioooo00?o09Woooooool0=?ooo`00=?ooo`0306Kooooooooo05Soool0
0`000?ooooooo`0Koooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Coool003Coool00`1Voooo
ooooo`1Hoooo00<0003oooooool06oooo`0306Kooooooooo03Woool00ol0VOooooooo`0doooo000d
oooo00<0I_ooooooool0F?ooo`030000oooooooo01_oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0=?ooo`00=?ooo`0306Kooooooooo05Soool00`000?ooooooo`0Koooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo03Coool003Coool00`1Vooooooooo`1Hoooo00<0003oooooool06oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0doooo000doooo00<0I_ooooooool0F?ooo`80000Loooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo03Coool003Coool00`1Vooooooooo`1Hoooo00<0003ooooo
ool06oooo`0306Kooooooooo03Woool00ol0VOooooooo`0doooo000doooo00<0I_ooooooool0F?oo
o`030000oooooooo01_oool00`1Vooooooooo`0ioooo00?o09Woooooool0=?ooo`00=?ooo`0306Ko
oooooooo05Soool00`000?ooooooo`0Koooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Coool0
03Coool00`1Vooooooooo`1Hoooo00<0003oooooool06oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0doooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo01_oool00`1Vooooooooo`0i
oooo00?o09Woooooool0=?ooo`00=?ooo`0306Kooooooooo05Soool200007?ooo`0306Kooooooooo
03Woool00ol0VOooooooo`0doooo000doooo00<0I_ooooooool0F?ooo`030000oooooooo01_oool0
0`1Vooooooooo`0ioooo00?o09Woooooool0=?ooo`00=?ooo`0306Kooooooooo05Soool00`000?oo
ooooo`0Koooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03Coool003Coool00`1Vooooooooo`1H
oooo00<0003oooooool06oooo`0306Kooooooooo03Woool00ol0VOooooooo`0doooo000doooo00<0
I_ooooooool0AOooo`800004oooo0P0000Coool200001Oooo`030000oooooooo01_oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0=?ooo`00=?ooo`0306Kooooooooo04Coool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0Koooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo03Coool003Coooln06Ko2Oooo`040000oooooooo00002oooo`030000oooooooo00;oool3
00006oooo`0306Kooooooooo03Woool00ol0VOooooooo`0doooo001boooo0P1Vo`Ooool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo01Woool206Ko??ooo`03o`2Ioooooooo03Coool0
07Coool206Ko1Oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0G
oooo0P1Vockoool00ol0VOooooooo`0doooo001foooo00<0I_ooooooool00oooo`80000:oooo0`00
00Coool00`000?ooooooo`0Eoooo0P1Vod3oool00ol0VOooooooo`0doooo001goooo0P1VoaKoool0
0`000?ooooooo`0Doooo00<0I_ooooooool0@?ooo`03o`2Ioooooooo03Coool007Woool206Ko5?oo
o`030000oooooooo01;oool206Ko@oooo`03o`2Ioooooooo03Coool007_oool00`1Vooooooooo`0A
oooo0P0001;oool00`1Vooooooooo`13oooo00?o09Woooooool0=?ooo`00O?ooo`80I_lAoooo00<0
003oooooool03oooo`80I_m6oooo00?o09Woooooool0=?ooo`00O_ooo`0306Kooooooooo00koool0
0`000?ooooooo`0=oooo0P1VodSoool00ol0VOooooooo`0doooo001ooooo0P1Vo`koool00`000?oo
ooooo`0<oooo00<0I_ooooooool0B?ooo`03o`2Ioooooooo03Coool0087oool206Ko3?ooo`030000
oooooooo00[oool206KoBoooo`03o`2Ioooooooo03Coool008?oool00`1Vooooooooo`09oooo00<0
003oooooool02?ooo`80I_m=oooo00?o09Woooooool0=?ooo`00Q?ooo`80I_l9oooo00<0003ooooo
ool01oooo`0306Kooooooooo04goool00ol0VOooooooo`0doooo0026oooo00<0I_ooooooool01_oo
o`800007oooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo03Coool008Ooool00`1Vooooooooo`05
oooo00<0003oooooool01?ooo`80I_mAoooo00?o09Woooooool0=?ooo`00R?ooo`80I_l5oooo00<0
003oooooool00oooo`0306Kooooooooo057oool00ol0VOooooooo`0doooo002:oooo00<0I_oooooo
ool00_ooo`030000oooooooo00;oool00`1Vooooooooo`1Boooo00?o09Woooooool0=?ooo`00Rooo
o`0506Kooooooooooooo000000?oool00`1Vooooooooo`1Coooo00?o09Woooooool0=?ooo`00S?oo
o`0406Kooooooooo00000_ooo`0306Kooooooooo05Coool00ol0VOooooooo`0doooo002=oooo0P1V
o`8000000`1Vooooooooo`1Eoooo00?o09Woooooool0=?ooo`00S_ooo`0306Ko000006Ko05Soool0
0ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool0
0`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool20000F?oo
o`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Sooo
o`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2I
oooooooo03Coool008Ooool500000oooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo0029
oooo00<0003oooooool00oooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo0029oooo00<0
003oooooool00oooo`<0001Goooo00?o09Woooooool0=?ooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00ROooo`030000oooooooo00?oool00`000?oo
ooooo`1Goooo00?o09Woooooool0=?ooo`00R?ooo`800005oooo00<0003oooooool0Eoooo`03o`2I
oooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000
oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo
03Coool008ooool20000F?ooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o
09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0
003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Wooooo
ool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo0P0005Soool0
0ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool0
0`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOoo
ooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?oo
ooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`80001Hoooo00?o09Woooooool0=?ooo`00Sooo
o`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2I
oooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Woooooool0=?ooo`00Soooo`030000
oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0003oooooool0Eoooo`03o`2Ioooooooo
03Coool008ooool20000F?ooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o
09Woooooool0=?ooo`00Soooo`030000oooooooo05Ooool00ol0VOooooooo`0doooo002?oooo00<0
003oooooool0Eoooo`03o`2Ioooooooo03Coool008ooool00`000?ooooooo`1Goooo00?o09Wooooo
ool0=?ooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo05Ooool00ol0VOoo
ooooo`0doooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000oooooooo
05Ooool00ol0VOooooooo`0doooo001moooo00<0003oooooool02_ooo`030000oooooooo00;oool3
0000Eoooo`03o`2Ioooooooo03Coool007goool00`000?ooooooo`08oooo0P0009Koool007goool0
0`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool00?oooolQ
oooo003ooooo8Oooo`00Ooooo`030000oooooooo01coool00`000?ooooooo`1ooooo001noooo00<0
003oooooool02?ooo`030000oooooooo01?oool00`000?ooooooo`1noooo001noooo00<0003ooooo
ool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000Coool00`000?ooooooo`1n
oooo001noooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00<0003oooooool02_ooo`030000oooooooo07koool007goool00`000?ooooooo`02oooo00<0
003oooooool03_ooo`030000oooooooo00[oool00`000?ooooooo`1moooo001noooo00<0003ooooo
ool01@0000koool00`000?ooooooo`08oooo00<0003oooooool0O_ooo`00O_ooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`1noooo001ooooo00<0003ooooo
ool04Oooo`800009oooo00<0003oooooool0Ooooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.83996 .24721 L
.84911 .24721 L
.85396 .24721 L
.85663 .24721 L
.85916 .24721 L
.86159 .24721 L
.86226 .24721 L
.86296 .24721 L
s
.86296 .24721 m
.86315 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.08255 .24721 L
.10458 .24721 L
.11448 .24721 L
.12507 .24721 L
.1302 .24721 L
.13273 .24721 L
.13384 .24721 L
.13506 .24721 L
.13615 .24721 L
.13718 .37082 L
.13826 .37082 L
.13942 .37082 L
.14415 .37082 L
.18538 .37082 L
.22508 .37082 L
.26328 .37082 L
.30392 .37082 L
.34305 .37082 L
.35334 .37082 L
.36446 .37082 L
.36957 .37082 L
.37236 .37082 L
.37373 .37082 L
.37497 .37082 L
.37611 .3714 L
.37719 .37196 L
.37958 .37322 L
.38463 .37592 L
.42296 .39841 L
.46375 .42665 L
.484 .44259 L
.48883 .44659 L
.49392 .4509 L
.49602 .4527 L
.49826 .45465 L
.49955 .45577 L
.50072 .45553 L
.5019 .4545 L
.50301 .45354 L
.52118 .43838 L
.54076 .42329 L
.57923 .39702 L
.59872 .38525 L
.60905 .37939 L
.61474 .37626 L
.61755 .37475 L
.62015 .37336 L
.62261 .37207 L
Mistroke
.62332 .37169 L
.62399 .37135 L
.62524 .24721 L
.62591 .24721 L
.62663 .24721 L
.62791 .24721 L
.63079 .24721 L
.64051 .24721 L
.65955 .24721 L
.69758 .24721 L
.73805 .24721 L
.77701 .24721 L
.81843 .24721 L
.85832 .24721 L
.89671 .24721 L
.93754 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.05) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00_oool00`1Vo`00
0?ooo`0>oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooo06Ko00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?l0VOooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool003?oool0
0`1Vooooooooo`1Ioooo00<0003oooooool07Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0b
oooo000coooo00<0I_ooooooool0FOooo`030000oooooooo01goool00`1Vooooooooo`0ioooo00?o
09Woooooool0<_ooo`00<oooo`0306Kooooooooo05Woool00`000?ooooooo`0Moooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo03;oool003?oool00`1Vooooooooo`1Ioooo00<0003oooooool07Ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0boooo000coooo00<0I_ooooooool0FOooo`80000N
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03;oool003?oool00`1Vooooooooo`1Ioooo00<0
003oooooool07Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0boooo000coooo00<0I_oooooo
ool0FOooo`030000oooooooo01goool00`1Vooooooooo`0ioooo00?o09Woooooool0<_ooo`00<ooo
o`0306Kooooooooo05Woool00`000?ooooooo`0Moooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
03;oool003?oool00`1Vooooooooo`1Ioooo00<0003oooooool07Oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0boooo000coooo00<0I_ooooooool0FOooo`030000oooooooo01goool00`1Voooo
ooooo`0ioooo00?o09Woooooool0<_ooo`00<oooo`0306Kooooooooo05Woool200007_ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0boooo000coooo00<0I_ooooooool0FOooo`030000oooooooo
01goool00`1Vooooooooo`0ioooo00?o09Woooooool0<_ooo`00<oooo`0306Kooooooooo05Woool0
0`000?ooooooo`0Moooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo03;oool003?oool00`1Voooo
ooooo`1Ioooo00<0003oooooool07Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0boooo000c
oooo00<0I_ooooooool0FOooo`030000oooooooo01coool00`1Vooooooooo`0joooo00?o09Wooooo
ool0<_ooo`00<oooo`0306Kooooooooo05Woool00`000?ooooooo`0Loooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo03;oool003?oool00`1Vooooooooo`1Ioooo00<0003oooooool07?ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0boooo000coooo00<0I_ooooooool0FOooo`80000Moooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo03;oool003?oool00`1Vooooooooo`1Ioooo00<0003ooooo
ool07?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0boooo000coooo00<0I_ooooooool0FOoo
o`030000oooooooo01coool00`1Vooooooooo`0joooo00?o09Woooooool0<_ooo`00<oooo`0306Ko
oooooooo05Woool00`000?ooooooo`0Loooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo03;oool0
03?oool00`1Vooooooooo`1Ioooo00<0003oooooool07?ooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0boooo000coooo00<0I_ooooooool0FOooo`030000oooooooo01coool00`1Vooooooooo`0j
oooo00?o09Woooooool0<_ooo`00<oooo`0306Kooooooooo05Woool200007Oooo`0306Kooooooooo
03[oool00ol0VOooooooo`0boooo000coooo00<0I_ooooooool0FOooo`030000oooooooo01coool0
0`1Vooooooooo`0joooo00?o09Woooooool0<_ooo`00<oooo`0306Kooooooooo05Woool00`000?oo
ooooo`0Loooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo03;oool003?oool00`1Vooooooooo`1I
oooo00<0003oooooool07?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0boooo000coooo00<0
I_ooooooool0A_ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo01coool00`1Voooo
ooooo`0joooo00?o09Woooooool0<_ooo`00<oooo`0306Kooooooooo04Goool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0Loooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo03;oool003?oooln06Ko2_ooo`040000oooooooo00002oooo`030000oooooooo00;oool3
00007?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0boooo001`oooo0`1Vo`Soool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo01[oool206Ko?Oooo`03o`2Ioooooooo03;oool0
07?oool206Ko1_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0I
oooo00<0I_ooooooool0?Oooo`03o`2Ioooooooo03;oool007Goool00`1Vooooooooo`04oooo0P00
00[oool300001?ooo`030000oooooooo01Ooool206Ko@?ooo`03o`2Ioooooooo03;oool007Koool2
06Ko5oooo`030000oooooooo01Koool00`1Vooooooooo`10oooo00?o09Woooooool0<_ooo`00N?oo
o`0306Kooooooooo01Coool00`000?ooooooo`0Doooo0P1Vod?oool00ol0VOooooooo`0boooo001i
oooo0P1VoaCoool200004oooo`80I_m5oooo00?o09Woooooool0<_ooo`00Noooo`0306Kooooooooo
017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0AOooo`03o`2Ioooooooo03;oool007coool2
06Ko4Oooo`030000oooooooo00ooool206KoB?ooo`03o`2Ioooooooo03;oool007koool00`1Voooo
ooooo`0>oooo00<0003oooooool03Oooo`80I_m:oooo00?o09Woooooool0<_ooo`00Ooooo`80I_l>
oooo00<0003oooooool03?ooo`0306Kooooooooo04[oool00ol0VOooooooo`0boooo0021oooo0P1V
o`coool00`000?ooooooo`0:oooo0P1Vodgoool00ol0VOooooooo`0boooo0023oooo00<0I_oooooo
ool02Oooo`030000oooooooo00Soool206KoCoooo`03o`2Ioooooooo03;oool008Coool206Ko2Ooo
o`800008oooo00<0I_ooooooool0Coooo`03o`2Ioooooooo03;oool008Koool00`1Vooooooooo`06
oooo00<0003oooooool01_ooo`0306Kooooooooo053oool00ol0VOooooooo`0boooo0027oooo00<0
I_ooooooool01Oooo`030000oooooooo00Coool206KoDoooo`03o`2Ioooooooo03;oool008Soool2
06Ko1Oooo`030000oooooooo00?oool00`1Vooooooooo`1Coooo00?o09Woooooool0<_ooo`00R_oo
o`0306Kooooooooo00;oool00`000?ooooooo`02oooo00<0I_ooooooool0E?ooo`03o`2Ioooooooo
03;oool008_oool01@1Vooooooooooooo`000003oooo00<0I_ooooooool0EOooo`03o`2Ioooooooo
03;oool008coool00`1Vooooooooo`02000000?oool0I_ooool0Eoooo`03o`2Ioooooooo03;oool0
08goool01@1Vooooo`000?ooo`1Vo`1Ioooo00?o09Woooooool0<_ooo`00S_ooo`0306Ko000006Ko
05[oool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool0
08ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool0
0ol0VOooooooo`0boooo002?oooo0P0005[oool00ol0VOooooooo`0boooo002?oooo00<0003ooooo
ool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo0027oooo1@0000?oool00`000?oo
ooooo`1Ioooo00?o09Woooooool0<_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1I
oooo00?o09Woooooool0<_ooo`00ROooo`030000oooooooo00?oool30000FOooo`03o`2Ioooooooo
03;oool008Woool00`000?ooooooo`03oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool0
08Woool00`000?ooooooo`03oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008Soool2
00001Oooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOoo
o`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Sooo
o`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo0P0005[oool00ol0VOooooooo`0b
oooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1I
oooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?
oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o
09Woooooool0<_ooo`00Soooo`80001Joooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo
05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool0
08ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool0
0ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool2
0000F_ooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_oo
o`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo00<0003oooooool0FOoo
o`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00Sooo
o`030000oooooooo05Woool00ol0VOooooooo`0boooo002?oooo0P0005[oool00ol0VOooooooo`0b
oooo002?oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool008ooool00`000?ooooooo`1I
oooo00?o09Woooooool0<_ooo`00Soooo`030000oooooooo05Woool00ol0VOooooooo`0boooo002?
oooo00<0003oooooool0FOooo`03o`2Ioooooooo03;oool007_oool500000_ooo`800004oooo0P00
00Goool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00OOooo`030000oooooooo00Ooool0
10000?ooooooo`0000Coool00`000?ooooooo`1Ioooo00?o09Woooooool0<_ooo`00OOooo`030000
oooooooo00[oool00`000?ooooooo`02oooo0`0005Woool00ol0VOooooooo`0boooo001moooo00<0
003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool0
07coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0X
oooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0
003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool4
00000oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?oo
ooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09
oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Mooo
o`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02?ooo`040000oooooooo
00001Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0003oooooool01@00
00koool00`000?ooooooo`07oooo00@0003oooooool00003oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo
00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003oooooool04Ooo
o`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003ooooo8Ooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.83996 .24721 L
.84911 .24721 L
.85916 .24721 L
.86384 .24721 L
.86642 .24721 L
.86768 .24721 L
.86886 .24721 L
s
.86886 .24721 m
.86902 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.08255 .24721 L
.10458 .24721 L
.11448 .24721 L
.11992 .24721 L
.12507 .24721 L
.12739 .24721 L
.12867 .24721 L
.12986 .24721 L
.13115 .37082 L
.13183 .37082 L
.13256 .37082 L
.13506 .37082 L
.14415 .37082 L
.18538 .37082 L
.22508 .37082 L
.26328 .37082 L
.30392 .37082 L
.34305 .37082 L
.35334 .37082 L
.35875 .37082 L
.3617 .37082 L
.36446 .37082 L
.36688 .37082 L
.36758 .37082 L
.36824 .37082 L
.36947 .37104 L
.37014 .37139 L
.37084 .37175 L
.37211 .37242 L
.37497 .37393 L
.38463 .37918 L
.42239 .40186 L
.46259 .4303 L
.48107 .44508 L
.49154 .45397 L
.49416 .45626 L
.49664 .45845 L
.49886 .46044 L
.50012 .46135 L
.50128 .46031 L
.51097 .45181 L
.52132 .44311 L
.54242 .4265 L
.58182 .39915 L
.60162 .38703 L
.61971 .3768 L
.62448 .37423 L
.627 .37289 L
Mistroke
.62838 .37216 L
.62968 .37148 L
.63092 .37084 L
.63162 .24721 L
.63226 .24721 L
.6346 .24721 L
.63915 .24721 L
.66005 .24721 L
.69959 .24721 L
.73761 .24721 L
.77809 .24721 L
.81705 .24721 L
.85846 .24721 L
.89836 .24721 L
.93674 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00Woool0101Voooo
ooooo`0000ooool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00@0003oooooool0I_l;oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003ooooo09T03?ooo`030000oooooooo00coool00`000?ooooooo`0Eoooo000a
oooo00<0I_ooooooool0Foooo`030000oooooooo01koool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0<Oooo`00<Oooo`0306Kooooooooo05_oool00`000?ooooooo`0Noooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo037oool0037oool00`1Vooooooooo`1Koooo00<0003oooooool07_ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0aoooo000aoooo00<0I_ooooooool0Foooo`030000oooooooo
01koool00`1Vooooooooo`0ioooo00?o09Woooooool0<Oooo`00<Oooo`0306Kooooooooo05_oool2
00007oooo`0306Kooooooooo03Woool00ol0VOooooooo`0aoooo000aoooo00<0I_ooooooool0Fooo
o`030000oooooooo01koool00`1Vooooooooo`0ioooo00?o09Woooooool0<Oooo`00<Oooo`0306Ko
oooooooo05_oool00`000?ooooooo`0Noooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo037oool0
037oool00`1Vooooooooo`1Koooo00<0003oooooool07_ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0aoooo000aoooo00<0I_ooooooool0Foooo`030000oooooooo01koool00`1Vooooooooo`0i
oooo00?o09Woooooool0<Oooo`00<Oooo`0306Kooooooooo05_oool00`000?ooooooo`0Noooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo037oool0037oool00`1Vooooooooo`1Koooo0P0001ooool0
0`1Vooooooooo`0ioooo00?o09Woooooool0<Oooo`00<Oooo`0306Kooooooooo05_oool00`000?oo
ooooo`0Noooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo037oool0037oool00`1Vooooooooo`1K
oooo00<0003oooooool07_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0aoooo000aoooo00<0
I_ooooooool0Foooo`030000oooooooo01koool00`1Vooooooooo`0ioooo00?o09Woooooool0<Ooo
o`00<Oooo`0306Kooooooooo05_oool00`000?ooooooo`0Noooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo037oool0037oool00`1Vooooooooo`1Koooo00<0003oooooool07_ooo`0306Kooooooooo
03Woool00ol0VOooooooo`0aoooo000aoooo00<0I_ooooooool0Foooo`030000oooooooo01koool0
0`1Vooooooooo`0ioooo00?o09Woooooool0<Oooo`00<Oooo`0306Kooooooooo05_oool200007ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0aoooo000aoooo00<0I_ooooooool0Foooo`030000
oooooooo01koool00`1Vooooooooo`0ioooo00?o09Woooooool0<Oooo`00<Oooo`0306Kooooooooo
05_oool00`000?ooooooo`0Noooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo037oool0037oool0
0`1Vooooooooo`1Koooo00<0003oooooool07_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0a
oooo000aoooo00<0I_ooooooool0Foooo`030000oooooooo01koool00`1Vooooooooo`0ioooo00?o
09Woooooool0<Oooo`00<Oooo`0306Kooooooooo05_oool00`000?ooooooo`0Noooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo037oool0037oool00`1Vooooooooo`1Koooo0P0001ooool00`1Voooo
ooooo`0ioooo00?o09Woooooool0<Oooo`00<Oooo`0306Kooooooooo05_oool00`000?ooooooo`0N
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo037oool0037oool00`1Vooooooooo`1Koooo00<0
003oooooool07_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0aoooo000aoooo00<0I_oooooo
ool0Foooo`030000oooooooo01koool00`1Vooooooooo`0ioooo00?o09Woooooool0<Oooo`00<Ooo
o`0306Kooooooooo04Soool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0Noooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo037oool0037oool00`1Vooooooooo`17oooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool07_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0aoooo000aoooo?`1Vo`_oool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0`0001koool00`1Vooooooooo`0ioooo00?o09Woooooool0<Oooo`00Koooo`80I_l:oooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`0Moooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo037oool0077oool206Ko2?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`0Koooo0P1Vocgoool00ol0VOooooooo`0aoooo001coooo0P1Vo`Ooool200002_oo
o`<00004oooo00<0003oooooool06Oooo`80I_looooo00?o09Woooooool0<Oooo`00MOooo`0306Ko
oooooooo01Ooool00`000?ooooooo`0Goooo0P1Vod7oool00ol0VOooooooo`0aoooo001foooo0P1V
oaOoool00`000?ooooooo`0Eoooo0P1Vod?oool00ol0VOooooooo`0aoooo001hoooo00<0I_oooooo
ool05?ooo`80000Doooo0P1VodGoool00ol0VOooooooo`0aoooo001ioooo0P1VoaCoool00`000?oo
ooooo`0Boooo00<0I_ooooooool0AOooo`03o`2Ioooooooo037oool007_oool00`1Vooooooooo`0A
oooo00<0003oooooool04?ooo`80I_m8oooo00?o09Woooooool0<Oooo`00O?ooo`80I_lAoooo00<0
003oooooool03oooo`0306Kooooooooo04Soool00ol0VOooooooo`0aoooo001noooo00<0I_oooooo
ool03_ooo`030000oooooooo00koool00`1Vooooooooo`19oooo00?o09Woooooool0<Oooo`00Oooo
o`0306Kooooooooo00goool00`000?ooooooo`0<oooo0P1Vodcoool00ol0VOooooooo`0aoooo0020
oooo0P1Vo`goool00`000?ooooooo`0;oooo00<0I_ooooooool0C?ooo`03o`2Ioooooooo037oool0
08;oool00`1Vooooooooo`0:oooo0P0000[oool206KoCoooo`03o`2Ioooooooo037oool008?oool2
06Ko2_ooo`030000oooooooo00Soool00`1Vooooooooo`1?oooo00?o09Woooooool0<Oooo`00QOoo
o`0306Kooooooooo00Ooool00`000?ooooooo`06oooo0P1Voe;oool00ol0VOooooooo`0aoooo0026
oooo00<0I_ooooooool01_ooo`030000oooooooo00Goool00`1Vooooooooo`1Boooo00?o09Wooooo
ool0<Oooo`00Qoooo`80I_l6oooo00<0003oooooool00oooo`80I_mFoooo00?o09Woooooool0<?oo
o`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`02oooo00<0I_ooooooool0E_ooo`03o`2I
oooooooo033oool008[oool00`1Vooooooooo`02oooo0P0000;oool00`1Vooooooooo`1Goooo00?o
09Woooooool0<?ooo`00Roooo`80I_l2oooo00D0003oooooooooool0I_l0FOooo`03o`2Ioooooooo
033oool008goool00`1Vooooo`000002oooo00<0I_ooooooool0F?ooo`03o`2Ioooooooo033oool0
08goool206Ko00<00000I_l0I_l0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1K
oooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?
oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo
033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo
05_oool00ol0VOooooooo`0`oooo0027oooo1@0000?oool00`000?ooooooo`1Koooo00?o09Wooooo
ool0<?ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Koooo00?o09Woooooool0<?oo
o`00ROooo`030000oooooooo00?oool30000Foooo`03o`2Ioooooooo033oool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008Woool00`000?ooooooo`03
oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008Soool200001Oooo`030000oooooooo
05_oool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool0
08ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool0
0ol0VOooooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003ooooo
ool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?oo
o`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Fooo
o`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Sooo
o`80001Loooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`
oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1K
oooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?
oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool008ooool20000G?ooo`03o`2Ioooooooo
033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo
05_oool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Foooo`03o`2Ioooooooo033oool0
08ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00Soooo`030000oooooooo05_oool0
0ol0VOooooooo`0`oooo002?oooo0P0005coool00ol0VOooooooo`0`oooo002?oooo00<0003ooooo
ool0Foooo`03o`2Ioooooooo033oool008ooool00`000?ooooooo`1Koooo00?o09Woooooool0<?oo
o`00Soooo`030000oooooooo05_oool00ol0VOooooooo`0`oooo002?oooo00<0003oooooool0Fooo
o`03o`2Ioooooooo033oool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`1K
oooo00?o09Woooooool0<?ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`1Koooo00?o09Woooooool0<?ooo`00OOooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`0005_oool00ol0VOooooooo`0`oooo001moooo00<0003oooooool02?ooo`80002F
oooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003oooo1@00
00;oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00<0003oooooool02oooo`030000oooooooo00;oool00`000?oo
ooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`0:
oooo00<0003oooooool00oooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_oo
o`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000ooool010000?ooooooo`0000[oool00`000?ooooooo`02oooo00<0003ooooo
ool0Noooo`00O?ooo`030000oooooooo017oool200002_ooo`800003oooo00<0003oooooool0O?oo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.83996 .24721 L
.84911 .24721 L
.85916 .24721 L
.86384 .24721 L
.86886 .24721 L
.87129 .24721 L
.87248 .24721 L
.87359 .24721 L
.87459 .24721 L
s
.87459 .24721 m
.87475 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.08255 .24721 L
.0932 .24721 L
.10458 .24721 L
.11009 .24721 L
.11531 .24721 L
.11999 .24721 L
.12127 .24721 L
.12263 .24721 L
.12379 .24721 L
.12507 .37082 L
.12634 .37082 L
.12755 .37082 L
.12981 .37082 L
.13492 .37082 L
.14415 .37082 L
.18234 .37082 L
.22299 .37082 L
.26212 .37082 L
.3037 .37082 L
.32457 .37082 L
.34377 .37082 L
.35346 .37082 L
.3582 .37082 L
.36027 .37082 L
.36136 .37082 L
.36251 .37082 L
.36373 .37115 L
.36485 .37174 L
.36707 .3729 L
.37196 .37551 L
.38232 .38121 L
.42007 .40424 L
.46027 .43312 L
.47875 .44812 L
.48922 .45715 L
.49432 .4617 L
.49674 .46389 L
.49896 .46592 L
.50012 .46677 L
.50135 .46564 L
.50394 .46327 L
.50865 .45904 L
.519 .45003 L
.5401 .43283 L
.57799 .40552 L
.59907 .39211 L
.61833 .38085 L
.62786 .37561 L
Mistroke
.63047 .37421 L
.63325 .37273 L
.6346 .37202 L
.63587 .37136 L
.63701 .24721 L
.63824 .24721 L
.65715 .24721 L
.69821 .24721 L
.73775 .24721 L
.77577 .24721 L
.81625 .24721 L
.85521 .24721 L
.89662 .24721 L
.93652 .24721 L
.9749 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.15) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00Soool01@1Voooo
ooooooooo`00000?oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00;oool00`1Vooooooooo`07oooo00<0003oooooool03?ooo`030000
oooooooo00coool00`000?ooooooo`0=oooo00D0003ooooooooooooo09T02_ooo`030000oooooooo
00coool00`000?ooooooo`0Eoooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo023oool0
0`1Vooooooooo`0ioooo00?o09Woooooool0;oooo`00<?ooo`0306Kooooooooo05coool00`000?oo
ooooo`0Poooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02ooool0033oool00`1Vooooooooo`1L
oooo00<0003oooooool08?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0_oooo000`oooo00<0
I_ooooooool0G?ooo`030000oooooooo023oool00`1Vooooooooo`0ioooo00?o09Woooooool0;ooo
o`00<?ooo`0306Kooooooooo05coool200008Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0_
oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo023oool00`1Vooooooooo`0ioooo00?o
09Woooooool0;oooo`00<?ooo`0306Kooooooooo05coool00`000?ooooooo`0Poooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo02ooool0033oool00`1Vooooooooo`1Loooo00<0003oooooool08?oo
o`0306Kooooooooo03Woool00ol0VOooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000
oooooooo023oool00`1Vooooooooo`0ioooo00?o09Woooooool0;oooo`00<?ooo`0306Kooooooooo
05coool00`000?ooooooo`0Poooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02ooool0033oool0
0`1Vooooooooo`1Loooo0P00027oool00`1Vooooooooo`0ioooo00?o09Woooooool0;oooo`00<?oo
o`0306Kooooooooo05coool00`000?ooooooo`0Poooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02ooool0033oool00`1Vooooooooo`1Loooo00<0003oooooool08?ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo023oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0;oooo`00<?ooo`0306Kooooooooo05coool00`000?ooooooo`0O
oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02ooool0033oool00`1Vooooooooo`1Loooo00<0
003oooooool07oooo`0306Kooooooooo03[oool00ol0VOooooooo`0_oooo000`oooo00<0I_oooooo
ool0G?ooo`030000oooooooo01ooool00`1Vooooooooo`0joooo00?o09Woooooool0;oooo`00<?oo
o`0306Kooooooooo05coool200008?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0_oooo000`
oooo00<0I_ooooooool0G?ooo`030000oooooooo01ooool00`1Vooooooooo`0joooo00?o09Wooooo
ool0;oooo`00<?ooo`0306Kooooooooo05coool00`000?ooooooo`0Ooooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo02ooool0033oool00`1Vooooooooo`1Loooo00<0003oooooool07oooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo
01ooool00`1Vooooooooo`0joooo00?o09Woooooool0;oooo`00<?ooo`0306Kooooooooo05coool0
0`000?ooooooo`0Ooooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02ooool0033oool00`1Voooo
ooooo`1Loooo0P00023oool00`1Vooooooooo`0joooo00?o09Woooooool0;oooo`00<?ooo`0306Ko
oooooooo05coool00`000?ooooooo`0Ooooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02ooool0
033oool00`1Vooooooooo`1Loooo00<0003oooooool07oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0_oooo000`oooo00<0I_ooooooool0G?ooo`030000oooooooo01ooool00`1Vooooooooo`0j
oooo00?o09Woooooool0;oooo`00<?ooo`0306Kooooooooo04Woool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`0Ooooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02ooool0033oool0
0`1Vooooooooo`18oooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool07oooo`0306Kooooooooo03[oool00ol0VOooooooo`0_oooo000`oooo?P1Vo`goool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`0001ooool00`1Vooooooooo`0joooo00?o09Wooooo
ool0;oooo`00KOooo`<0I_l;oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0M
oooo0`1Voccoool00ol0VOooooooo`0_oooo001`oooo00<0I_ooooooool02?ooo`040000oooooooo
00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Loooo00<0I_ooooooool0?Oooo`03o`2I
oooooooo02ooool0077oool00`1Vooooooooo`08oooo0P0000[oool300001?ooo`030000oooooooo
01[oool206Ko@?ooo`03o`2Ioooooooo02ooool007;oool206Ko6oooo`030000oooooooo01Soool2
06Ko@_ooo`03o`2Ioooooooo02ooool007Coool206Ko6Oooo`030000oooooooo01Koool206KoA?oo
o`03o`2Ioooooooo02ooool007Koool00`1Vooooooooo`0Foooo0P0001Koool00`1Vooooooooo`14
oooo00?o09Woooooool0;oooo`00Moooo`80I_lFoooo00<0003oooooool04oooo`80I_m7oooo00?o
09Woooooool0;oooo`00NOooo`80I_lDoooo00<0003oooooool04_ooo`0306Kooooooooo04Ooool0
0ol0VOooooooo`0_oooo001koooo00<0I_ooooooool04Oooo`030000oooooooo017oool00`1Voooo
ooooo`18oooo00?o09Woooooool0;oooo`00O?ooo`80I_lAoooo00<0003oooooool03oooo`80I_m;
oooo00?o09Woooooool0;oooo`00O_ooo`0306Kooooooooo00koool00`000?ooooooo`0>oooo00<0
I_ooooooool0Boooo`03o`2Ioooooooo02ooool007ooool00`1Vooooooooo`0=oooo00<0003ooooo
ool03Oooo`0306Kooooooooo04coool00ol0VOooooooo`0_oooo0020oooo0P1Vo`goool200003?oo
o`80I_m?oooo00?o09Woooooool0;oooo`00P_ooo`0306Kooooooooo00[oool00`000?ooooooo`0:
oooo00<0I_ooooooool0Coooo`03o`2Ioooooooo02ooool008?oool206Ko2_ooo`030000oooooooo
00Soool206KoD_ooo`03o`2Ioooooooo02ooool008Goool00`1Vooooooooo`07oooo00<0003ooooo
ool01oooo`0306Kooooooooo05;oool00ol0VOooooooo`0_oooo0026oooo00<0I_ooooooool01_oo
o`030000oooooooo00Koool00`1Vooooooooo`1Coooo00?o09Woooooool0;oooo`00Qoooo`80I_l6
oooo00<0003oooooool01?ooo`80I_mFoooo00?o09Woooooool0;oooo`00ROooo`0306Kooooooooo
00?oool200001?ooo`0306Kooooooooo05Koool00ol0VOooooooo`0_oooo002:oooo00<0I_oooooo
ool00_ooo`030000oooooooo00;oool00`1Vooooooooo`1Goooo00?o09Woooooool0;oooo`00Rooo
o`0506Kooooooooooooo000000;oool206KoF_ooo`03o`2Ioooooooo02ooool008coool01P1Voooo
ooooo`000?ooo`1Voecoool00ol0VOooooooo`0_oooo002=oooo0P1Vo`03000006Kooooo05coool0
0ol0VOooooooo`0_oooo002>oooo00<0I_l00000I_l0GOooo`03o`2Ioooooooo02ooool008ooool2
0000GOooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;ooo
o`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?oo
o`03o`2Ioooooooo02ooool008Ooool500000oooo`030000oooooooo05coool00ol0VOooooooo`0_
oooo0029oooo00<0003oooooool00oooo`030000oooooooo05coool00ol0VOooooooo`0_oooo0029
oooo00<0003oooooool00oooo`<0001Loooo00?o09Woooooool0;oooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00ROooo`030000oooooooo00?oool0
0`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00R?ooo`800005oooo00<0003oooooool0G?oo
o`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Sooo
o`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2I
oooooooo02ooool008ooool20000GOooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1L
oooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?
oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o
09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo0P00
05goool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool0
08ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool0
0ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool0
0`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Soooo`80001Moooo00?o09Woooooool0;ooo
o`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?oo
o`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o09Woooooool0;oooo`00Sooo
o`030000oooooooo05coool00ol0VOooooooo`0_oooo002?oooo00<0003oooooool0G?ooo`03o`2I
oooooooo02ooool008ooool20000GOooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1L
oooo00?o09Woooooool0;oooo`00Soooo`030000oooooooo05coool00ol0VOooooooo`0_oooo002?
oooo00<0003oooooool0G?ooo`03o`2Ioooooooo02ooool008ooool00`000?ooooooo`1Loooo00?o
09Woooooool0;oooo`00Noooo`D00002oooo0P0000Coool200001Oooo`030000oooooooo05coool0
0ol0VOooooooo`0_oooo001moooo00<0003oooooool01oooo`040000oooooooo00001?ooo`030000
oooooooo05coool00ol0VOooooooo`0_oooo001moooo00<0003oooooool02_ooo`030000oooooooo
00;oool30000G?ooo`03o`2Ioooooooo02ooool007goool00`000?ooooooo`08oooo0P0009Koool0
07goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?ooo`80000:oooo0`0009Goool0
0?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool00`000?ooooooo`1ioooo001h
oooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?ooooooo`1hoooo001hoooo00<0
003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003oooo0P0000?oool500000_oo
o`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000;oool00`000?oo
ooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00_oool01@000?ooooooooooo`000002
oooo00D0003oooooooooool00000N_ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>
oooo00<0003oooooool02_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003ooooo
ool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool02Oooo`030000oooooooo
00;oool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0
003oooooool0000:oooo00<0003oooooool00_ooo`030000oooooooo00?oool00`000?ooooooo`1h
oooo001ioooo00<0003oooooool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo
07Woool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.83996 .24721 L
.85916 .24721 L
.86886 .24721 L
.87359 .24721 L
.87791 .24721 L
.87903 .24721 L
.88025 .24721 L
s
.88025 .24721 m
.88042 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.08255 .24721 L
.0932 .24721 L
.10458 .24721 L
.11009 .24721 L
.1128 .24721 L
.11531 .24721 L
.11758 .24721 L
.11872 .24721 L
.11999 .37082 L
.12125 .37082 L
.12261 .37082 L
.12507 .37082 L
.14415 .37082 L
.18538 .37082 L
.22508 .37082 L
.26328 .37082 L
.30392 .37082 L
.32272 .37082 L
.34305 .37082 L
.34848 .37082 L
.35144 .37082 L
.3542 .37082 L
.35542 .37082 L
.35656 .37082 L
.3572 .37085 L
.35789 .37121 L
.3591 .37184 L
.36446 .37468 L
.38463 .38595 L
.42542 .41187 L
.46468 .44139 L
.48438 .45814 L
.493 .46592 L
.49536 .4681 L
.49789 .47045 L
.49911 .4716 L
.50027 .47218 L
.50131 .47121 L
.50243 .47015 L
.51186 .4615 L
.52178 .45275 L
.54264 .43551 L
.58356 .40578 L
.60391 .39279 L
.62296 .38159 L
.63233 .37641 L
.63694 .37393 L
.63919 .37274 L
Mistroke
.64122 .37167 L
.64245 .37103 L
.6436 .24721 L
.64482 .24721 L
.64613 .24721 L
.65148 .24721 L
.66085 .24721 L
.7019 .24721 L
.74144 .24721 L
.77947 .24721 L
.81994 .24721 L
.8589 .24721 L
.90032 .24721 L
.94021 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00Koool00`1Voooo
ooooo`03oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`03oooo00<0I_ooooooool01_ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00;oool00ol0VOoo
ooooo`07oooo00<0003oooooool03?ooo`030000oooooooo01Goool002koool00`1Vooooooooo`1N
oooo00<0003oooooool08Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0^oooo000^oooo00<0
I_ooooooool0G_ooo`030000oooooooo027oool00`1Vooooooooo`0ioooo00?o09Woooooool0;_oo
o`00;_ooo`0306Kooooooooo05koool00`000?ooooooo`0Qoooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo02koool002koool00`1Vooooooooo`1Noooo00<0003oooooool08Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0^oooo000^oooo00<0I_ooooooool0G_ooo`80000Roooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo02koool002koool00`1Vooooooooo`1Noooo00<0003oooooool08Ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0^oooo000^oooo00<0I_ooooooool0G_ooo`030000
oooooooo027oool00`1Vooooooooo`0ioooo00?o09Woooooool0;_ooo`00;_ooo`0306Kooooooooo
05koool00`000?ooooooo`0Qoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02koool002koool0
0`1Vooooooooo`1Noooo00<0003oooooool08Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0^
oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo027oool00`1Vooooooooo`0ioooo00?o
09Woooooool0;_ooo`00;_ooo`0306Kooooooooo05koool200008_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0^oooo000^oooo00<0I_ooooooool0G_ooo`030000oooooooo027oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0;_ooo`00;_ooo`0306Kooooooooo05koool00`000?ooooooo`0Q
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02koool002koool00`1Vooooooooo`1Noooo00<0
003oooooool08Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0^oooo000_oooo00<0I_oooooo
ool0GOooo`030000oooooooo027oool00`1Vooooooooo`0ioooo00?o09Woooooool0;_ooo`00;ooo
o`0306Kooooooooo05goool00`000?ooooooo`0Qoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02koool002ooool00`1Vooooooooo`1Moooo00<0003oooooool08Oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0^oooo000_oooo00<0I_ooooooool0GOooo`80000Roooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo02koool002ooool00`1Vooooooooo`1Moooo00<0003oooooool08Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0^oooo000_oooo00<0I_ooooooool0GOooo`030000oooooooo
027oool00`1Vooooooooo`0ioooo00?o09Woooooool0;_ooo`00;oooo`0306Kooooooooo05goool0
0`000?ooooooo`0Qoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02koool002ooool00`1Voooo
ooooo`1Moooo00<0003oooooool08Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0^oooo000_
oooo00<0I_ooooooool0GOooo`030000oooooooo027oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0;_ooo`00;oooo`0306Kooooooooo05goool200008_ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0^oooo000_oooo00<0I_ooooooool0GOooo`030000oooooooo027oool00`1Vooooooooo`0i
oooo00?o09Woooooool0;_ooo`00;oooo`0306Kooooooooo05goool00`000?ooooooo`0Qoooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo02koool002ooool00`1Vooooooooo`1Moooo00<0003ooooo
ool08Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0^oooo000_oooo00<0I_ooooooool0B_oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo027oool00`1Vooooooooo`0ioooo00?o
09Woooooool0;_ooo`00;oooo`0306Kooooooooo04Woool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0Qoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02koool0
02oooolm06Ko3oooo`040000oooooooo00002oooo`030000oooooooo00;oool300008Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0^oooo001/oooo0P1Vo`goool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo023oool00`1Vooooooooo`0joooo00?o09Woooooool0;_ooo`00K_oo
o`80I_l;oooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo01koool2
06Ko?Oooo`03o`2Ioooooooo02koool0073oool206Ko2_ooo`80000:oooo0`0000Coool00`000?oo
ooooo`0Loooo0P1Vocooool00ol0VOooooooo`0^oooo001boooo00<0I_ooooooool06_ooo`030000
oooooooo01[oool206Ko@Oooo`03o`2Ioooooooo02koool007?oool206Ko6_ooo`030000oooooooo
01Soool206Ko@oooo`03o`2Ioooooooo02koool007Goool206Ko6?ooo`80000Hoooo00<0I_oooooo
ool0@oooo`03o`2Ioooooooo02koool007Ooool00`1Vooooooooo`0Eoooo00<0003oooooool05Ooo
o`80I_m6oooo00?o09Woooooool0;_ooo`00N?ooo`80I_lEoooo00<0003oooooool04oooo`80I_m8
oooo00?o09Woooooool0;_ooo`00N_ooo`80I_lCoooo00<0003oooooool04_ooo`0306Kooooooooo
04Soool00ol0VOooooooo`0^oooo001loooo00<0I_ooooooool04?ooo`030000oooooooo013oool2
06KoBoooo`03o`2Ioooooooo02koool007goool00`1Vooooooooo`0?oooo00<0003oooooool03ooo
o`0306Kooooooooo04_oool00ol0VOooooooo`0^oooo001noooo0P1Vo`ooool00`000?ooooooo`0>
oooo00<0I_ooooooool0C?ooo`03o`2Ioooooooo02koool0083oool00`1Vooooooooo`0<oooo0P00
00goool206KoCoooo`03o`2Ioooooooo02koool0087oool00`1Vooooooooo`0;oooo00<0003ooooo
ool02oooo`0306Kooooooooo04ooool00ol0VOooooooo`0^oooo0022oooo00<0I_ooooooool02_oo
o`030000oooooooo00Woool206KoD_ooo`03o`2Ioooooooo02koool008?oool206Ko2_ooo`030000
oooooooo00Soool00`1Vooooooooo`1Boooo00?o09Woooooool0;_ooo`00QOooo`0306Kooooooooo
00Ooool00`000?ooooooo`07oooo00<0I_ooooooool0Doooo`03o`2Ioooooooo02koool008Koool0
0`1Vooooooooo`06oooo00<0003oooooool01_ooo`0306Kooooooooo05Coool00ol0VOooooooo`0^
oooo0027oooo00<0I_ooooooool01Oooo`800005oooo0P1VoeOoool00ol0VOooooooo`0^oooo0028
oooo0P1Vo`Goool00`000?ooooooo`03oooo00<0I_ooooooool0Eoooo`03o`2Ioooooooo02koool0
08[oool00`1Vooooooooo`02oooo00<0003oooooool00_ooo`0306Kooooooooo05Soool00ol0VOoo
ooooo`0^oooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo05Woool00ol0VOoo
ooooo`0^oooo002<oooo00@0I_ooooooool00002oooo00<0I_ooooooool0F_ooo`03o`2Ioooooooo
02koool008goool01@1Vooooo`000?ooo`1Vo`1Moooo00?o09Woooooool0;_ooo`00S_ooo`0306Ko
0000000005koool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo
02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo
05goool00ol0VOooooooo`0^oooo0027oooo1@0000?oool00`000?ooooooo`1Moooo00?o09Wooooo
ool0;_ooo`00ROooo`030000oooooooo00?oool00`000?ooooooo`1Moooo00?o09Woooooool0;_oo
o`00ROooo`030000oooooooo00?oool30000GOooo`03o`2Ioooooooo02koool008Woool00`000?oo
ooooo`03oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008Woool00`000?ooooooo`03
oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008Soool200001Oooo`030000oooooooo
05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool0
08ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool0
0ol0VOooooooo`0^oooo002?oooo0P0005koool00ol0VOooooooo`0^oooo002?oooo00<0003ooooo
ool0GOooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_oo
o`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOoo
o`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Sooo
o`80001Noooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^
oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1M
oooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?
oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool008ooool20000G_ooo`03o`2Ioooooooo
02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo
05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOooo`03o`2Ioooooooo02koool0
08ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00Soooo`030000oooooooo05goool0
0ol0VOooooooo`0^oooo002?oooo0P0005koool00ol0VOooooooo`0^oooo002?oooo00<0003ooooo
ool0GOooo`03o`2Ioooooooo02koool008ooool00`000?ooooooo`1Moooo00?o09Woooooool0;_oo
o`00Soooo`030000oooooooo05goool00ol0VOooooooo`0^oooo002?oooo00<0003oooooool0GOoo
o`03o`2Ioooooooo02koool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`1M
oooo00?o09Woooooool0;_ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool0
0`000?ooooooo`1Moooo00?o09Woooooool0;_ooo`00OOooo`030000oooooooo00[oool00`000?oo
ooooo`02oooo0`0005goool00ol0VOooooooo`0^oooo001moooo00<0003oooooool02?ooo`80002F
oooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002E
oooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003oooooool0O?oo
o`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Nooo
o`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800003oooo1000
00?oool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000oooooooo
00;oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`030000oooooooo00Coool00`000?oo
ooooo`1koooo001joooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`09
oooo00<0003oooooool01?ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_oo
o`030000oooooooo00Woool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000ooool010000?ooooooo`0000Soool010000?ooooooo`0000?oool00`000?oo
ooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0P0000?oool00`000?ooooooo`1l
oooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.83996 .24721 L
.85916 .24721 L
.86886 .24721 L
.87791 .24721 L
.88246 .24721 L
.88378 .24721 L
.88502 .24721 L
.88613 .24721 L
s
.88613 .24721 m
.88632 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.08255 .24721 L
.0932 .24721 L
.09905 .24721 L
.10458 .24721 L
.10972 .24721 L
.11113 .24721 L
.1119 .24721 L
.11263 .24721 L
.1139 .37082 L
.11458 .37082 L
.11531 .37082 L
.12507 .37082 L
.14415 .37082 L
.18538 .37082 L
.22508 .37082 L
.26328 .37082 L
.30392 .37082 L
.32272 .37082 L
.33261 .37082 L
.34305 .37082 L
.34562 .37082 L
.34837 .37082 L
.34918 .37082 L
.34995 .37082 L
.35064 .37082 L
.35139 .37092 L
.3521 .37129 L
.35285 .37169 L
.3542 .37239 L
.36446 .37791 L
.38463 .38946 L
.42239 .4139 L
.46259 .44456 L
.48107 .46049 L
.49154 .47008 L
.49416 .47255 L
.49664 .4749 L
.49886 .47704 L
.50012 .47803 L
.50128 .47691 L
.51097 .46775 L
.52132 .45836 L
.54242 .44046 L
.58182 .41098 L
.61971 .38689 L
.62968 .38116 L
.63915 .37594 L
.64438 .37314 L
Mistroke
.64581 .37239 L
.64733 .37159 L
.64807 .3712 L
.64877 .37084 L
.65007 .24721 L
.65129 .24721 L
.65257 .24721 L
.65487 .24721 L
.66005 .24721 L
.69807 .24721 L
.73855 .24721 L
.77751 .24721 L
.81892 .24721 L
.85882 .24721 L
.8972 .24721 L
.93803 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00Goool00`1Voooo
ooooo`04oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`05oooo00<0I_ooooooool01?ooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00Coool00ol0VOoo
ooooo`05oooo00<0003oooooool03?ooo`030000oooooooo01Goool002goool00`1Vooooooooo`1O
oooo00<0003oooooool08oooo`0306Kooooooooo03Woool00ol0VOooooooo`0/oooo000]oooo00<0
I_ooooooool0Goooo`030000oooooooo02?oool00`1Vooooooooo`0ioooo00?o09Woooooool0;?oo
o`00;Oooo`0306Kooooooooo05ooool00`000?ooooooo`0Soooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo02coool002goool00`1Vooooooooo`1Ooooo00<0003oooooool08oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0/oooo000]oooo00<0I_ooooooool0Goooo`80000Toooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo02coool002goool00`1Vooooooooo`1Ooooo00<0003oooooool08ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0/oooo000]oooo00<0I_ooooooool0Goooo`030000
oooooooo02?oool00`1Vooooooooo`0ioooo00?o09Woooooool0;?ooo`00;Oooo`0306Kooooooooo
05ooool00`000?ooooooo`0Soooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02coool002goool0
0`1Vooooooooo`1Ooooo00<0003oooooool08oooo`0306Kooooooooo03Woool00ol0VOooooooo`0/
oooo000]oooo00<0I_ooooooool0Goooo`030000oooooooo02?oool00`1Vooooooooo`0ioooo00?o
09Woooooool0;?ooo`00;Oooo`0306Kooooooooo05ooool200009?ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0/oooo000]oooo00<0I_ooooooool0Goooo`030000oooooooo02?oool00`1Voooo
ooooo`0ioooo00?o09Woooooool0;?ooo`00;Oooo`0306Kooooooooo05ooool00`000?ooooooo`0S
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02coool002goool00`1Vooooooooo`1Ooooo00<0
003oooooool08oooo`0306Kooooooooo03Woool00ol0VOooooooo`0/oooo000]oooo00<0I_oooooo
ool0Goooo`030000oooooooo02?oool00`1Vooooooooo`0ioooo00?o09Woooooool0;?ooo`00;Ooo
o`0306Kooooooooo05ooool00`000?ooooooo`0Soooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02coool002goool00`1Vooooooooo`1Ooooo00<0003oooooool08oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0/oooo000]oooo00<0I_ooooooool0Goooo`80000Toooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo02coool002goool00`1Vooooooooo`1Ooooo00<0003oooooool08oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0/oooo000]oooo00<0I_ooooooool0Goooo`030000oooooooo
02?oool00`1Vooooooooo`0ioooo00?o09Woooooool0;?ooo`00;Oooo`0306Kooooooooo05ooool0
0`000?ooooooo`0Soooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02coool002goool00`1Voooo
ooooo`1Ooooo00<0003oooooool08oooo`0306Kooooooooo03Woool00ol0VOooooooo`0/oooo000]
oooo00<0I_ooooooool0Goooo`030000oooooooo02?oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0;?ooo`00;Oooo`0306Kooooooooo05ooool200009?ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0/oooo000]oooo00<0I_ooooooool0Goooo`030000oooooooo02?oool00`1Vooooooooo`0i
oooo00?o09Woooooool0;?ooo`00;Oooo`0306Kooooooooo05ooool00`000?ooooooo`0Soooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo02coool002goool00`1Vooooooooo`1Ooooo00<0003ooooo
ool08oooo`0306Kooooooooo03Woool00ol0VOooooooo`0/oooo000]oooo00<0I_ooooooool0C?oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo02?oool00`1Vooooooooo`0ioooo00?o
09Woooooool0;?ooo`00;Oooo`0306Kooooooooo04_oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0Soooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02coool0
02goooln06Ko4?ooo`040000oooooooo00002oooo`030000oooooooo00;oool300008_ooo`80I_lk
oooo00?o09Woooooool0;?ooo`00Joooo`80I_l>oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`0Poooo0`1Voccoool00ol0VOooooooo`0/oooo001]oooo00<0I_ooooooool02ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Ooooo00<0I_oooooo
ool0?Oooo`03o`2Ioooooooo02coool006koool206Ko3?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`0Moooo0P1Vod3oool00ol0VOooooooo`0/oooo001`oooo0P1Voagoool00`000?ooooooo`0K
oooo0P1Vod;oool00ol0VOooooooo`0/oooo001boooo00<0I_ooooooool06_ooo`030000oooooooo
01Woool206KoA?ooo`03o`2Ioooooooo02coool007?oool206Ko6_ooo`80000Ioooo00<0I_oooooo
ool0A?ooo`03o`2Ioooooooo02coool007Goool00`1Vooooooooo`0Goooo00<0003oooooool05_oo
o`80I_m7oooo00?o09Woooooool0;?ooo`00M_ooo`80I_lGoooo00<0003oooooool05Oooo`0306Ko
oooooooo04Ooool00ol0VOooooooo`0/oooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo
01?oool206KoB_ooo`03o`2Ioooooooo02coool007Woool206Ko5?ooo`030000oooooooo01;oool0
0`1Vooooooooo`1:oooo00?o09Woooooool0;?ooo`00Noooo`0306Kooooooooo017oool00`000?oo
ooooo`0Aoooo00<0I_ooooooool0Boooo`03o`2Ioooooooo02coool007coool00`1Vooooooooo`0@
oooo00<0003oooooool03oooo`80I_m>oooo00?o09Woooooool0;?ooo`00OOooo`80I_l@oooo0P00
00ooool00`1Vooooooooo`1>oooo00?o09Woooooool0;?ooo`00Ooooo`0306Kooooooooo00goool0
0`000?ooooooo`0=oooo00<0I_ooooooool0Coooo`03o`2Ioooooooo02coool0083oool00`1Voooo
ooooo`0<oooo00<0003oooooool03?ooo`0306Kooooooooo053oool00ol0VOooooooo`0/oooo0021
oooo00<0I_ooooooool02oooo`030000oooooooo00[oool206KoDoooo`03o`2Ioooooooo02coool0
08;oool206Ko2oooo`030000oooooooo00Woool00`1Vooooooooo`1Coooo00?o09Woooooool0;?oo
o`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`08oooo00<0I_ooooooool0E?ooo`03o`2I
oooooooo02coool008Goool00`1Vooooooooo`07oooo0P0000Ooool206KoEoooo`03o`2Ioooooooo
02coool008Koool00`1Vooooooooo`06oooo00<0003oooooool01Oooo`0306Kooooooooo05Ooool0
0ol0VOooooooo`0/oooo0027oooo0P1Vo`Koool00`000?ooooooo`03oooo0P1Voe[oool00ol0VOoo
ooooo`0/oooo0029oooo00<0I_ooooooool00oooo`030000oooooooo00;oool00`1Vooooooooo`1J
oooo00?o09Woooooool0;?ooo`00R_ooo`0306Kooooooooo00;oool01@000?ooooooooooo`1Vo`1M
oooo00?o09Woooooool0;?ooo`00Roooo`80I_l2oooo00D0003oooooooooool0I_l0GOooo`03o`2I
oooooooo02coool008goool01P1Vooooo`0000000?ooo`1Voekoool00ol0VOooooooo`0/oooo002=
oooo0P1Vo`03000006Ko06Ko05ooool00ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Gooo
o`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Qooo
o`D00003oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008Woool00`000?ooooooo`03
oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008Woool00`000?ooooooo`03oooo0`00
05ooool00ol0VOooooooo`0/oooo0029oooo00<0003oooooool00oooo`030000oooooooo05ooool0
0ol0VOooooooo`0/oooo0029oooo00<0003oooooool00oooo`030000oooooooo05ooool00ol0VOoo
ooooo`0/oooo0028oooo0P0000Goool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Sooo
o`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2I
oooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001P
oooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?
oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o
09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo00<0
003oooooool0Goooo`03o`2Ioooooooo02coool008ooool20000H?ooo`03o`2Ioooooooo02coool0
08ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool0
0ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool0
0`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOoo
ooooo`0/oooo002?oooo0P00063oool00ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Gooo
o`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Sooo
o`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?oooo00<0003oooooool0Goooo`03o`2I
oooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o09Woooooool0;?ooo`00Soooo`80001P
oooo00?o09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo002?
oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool008ooool00`000?ooooooo`1Ooooo00?o
09Woooooool0;?ooo`00Soooo`030000oooooooo05ooool00ol0VOooooooo`0/oooo001koooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0Goooo`03o`2Ioooooooo02coool007goool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0Goooo`03o`2Ioooooooo
02coool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0001Ooooo00?o09Wooooo
ool0;?ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool0
0`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`06oooo100000?oool200000oooo`@00003oooo0P0000Coool00`000?ooooooo`1h
oooo001hoooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05
oooo00<0003oooooool02Oooo`030000oooooooo00?oool010000?ooooooo`0000?oool00`000?oo
ooooo`1hoooo001goooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`09
oooo00<0003oooooool01Oooo`030000oooooooo00;oool00`000?ooooooo`1goooo001hoooo00<0
003oooooool01@0000koool00`000?ooooooo`09oooo00<0003oooooool00_ooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002_ooo`800004oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.83996 .24721 L
.85916 .24721 L
.87791 .24721 L
.88735 .24721 L
.88993 .24721 L
.89136 .24721 L
.89206 .24721 L
.89271 .24721 L
s
.89271 .24721 m
.8929 .61803 L
s
0 .4 1 r
.02381 .24721 m
.06244 .24721 L
.08255 .24721 L
.0932 .24721 L
.09905 .24721 L
.10192 .24721 L
.10458 .24721 L
.10587 .24721 L
.10708 .24721 L
.10834 .37082 L
.109 .37082 L
.10972 .37082 L
.11531 .37082 L
.12507 .37082 L
.14415 .37082 L
.18538 .37082 L
.22508 .37082 L
.26328 .37082 L
.30392 .37082 L
.32272 .37082 L
.33261 .37082 L
.33801 .37082 L
.34065 .37082 L
.34305 .37082 L
.34437 .37082 L
.34562 .37102 L
.34694 .3717 L
.34837 .37246 L
.3542 .37556 L
.36446 .38122 L
.38463 .39306 L
.42542 .42031 L
.46468 .45135 L
.48438 .46895 L
.493 .47713 L
.49536 .47942 L
.49789 .4819 L
.49911 .48311 L
.50027 .48372 L
.50131 .48269 L
.50243 .48158 L
.51186 .47248 L
.52178 .46329 L
.54264 .44517 L
.58356 .41391 L
.60391 .40025 L
.62296 .38848 L
.64122 .37805 L
.64648 .37519 L
.64908 .37381 L
Mistroke
.65148 .37254 L
.6526 .37195 L
.65365 .3714 L
.65486 .24721 L
.65596 .24721 L
.66085 .24721 L
.69945 .24721 L
.7405 .24721 L
.78004 .24721 L
.81807 .24721 L
.85854 .24721 L
.89751 .24721 L
.93892 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00?oool00`1Voooo
ooooo`06oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`06oooo00<0I_ooooooool00oooo`030000oooooooo
00coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00Koool00ol0VOoo
ooooo`03oooo00<0003oooooool03?ooo`030000oooooooo01Goool002_oool00`1Vooooooooo`1Q
oooo00<0003oooooool09?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Zoooo000[oooo00<0
I_ooooooool0HOooo`030000oooooooo02Coool00`1Vooooooooo`0joooo00?o09Woooooool0:_oo
o`00:oooo`0306Kooooooooo067oool00`000?ooooooo`0Toooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo02[oool002_oool00`1Vooooooooo`1Qoooo00<0003oooooool09?ooo`0306Kooooooooo
03[oool00ol0VOooooooo`0Zoooo000[oooo00<0I_ooooooool0HOooo`80000Uoooo00<0I_oooooo
ool0>_ooo`03o`2Ioooooooo02[oool002_oool00`1Vooooooooo`1Qoooo00<0003oooooool09?oo
o`0306Kooooooooo03[oool00ol0VOooooooo`0Zoooo000[oooo00<0I_ooooooool0HOooo`030000
oooooooo02Coool00`1Vooooooooo`0joooo00?o09Woooooool0:_ooo`00:oooo`0306Kooooooooo
067oool00`000?ooooooo`0Toooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02[oool002_oool0
0`1Vooooooooo`1Qoooo00<0003oooooool09?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Z
oooo000[oooo00<0I_ooooooool0HOooo`030000oooooooo02Coool00`1Vooooooooo`0joooo00?o
09Woooooool0:_ooo`00:oooo`0306Kooooooooo067oool200009Oooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Zoooo000[oooo00<0I_ooooooool0HOooo`030000oooooooo02Coool00`1Voooo
ooooo`0joooo00?o09Woooooool0:_ooo`00:oooo`0306Kooooooooo067oool00`000?ooooooo`0T
oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02[oool002_oool00`1Vooooooooo`1Qoooo00<0
003oooooool09?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Zoooo000/oooo00<0I_oooooo
ool0H?ooo`030000oooooooo02Coool00`1Vooooooooo`0joooo00?o09Woooooool0:_ooo`00;?oo
o`0306Kooooooooo063oool00`000?ooooooo`0Toooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
02[oool002coool00`1Vooooooooo`1Poooo00<0003oooooool09?ooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Zoooo000/oooo00<0I_ooooooool0H?ooo`80000Uoooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo02[oool002coool00`1Vooooooooo`1Poooo00<0003oooooool09?ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Zoooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo
02Coool00`1Vooooooooo`0joooo00?o09Woooooool0:_ooo`00;?ooo`0306Kooooooooo063oool0
0`000?ooooooo`0Toooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02[oool002coool00`1Voooo
ooooo`1Poooo00<0003oooooool09?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Zoooo000/
oooo00<0I_ooooooool0H?ooo`030000oooooooo02Coool00`1Vooooooooo`0joooo00?o09Wooooo
ool0:_ooo`00;?ooo`0306Kooooooooo063oool200009Oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0Zoooo000/oooo00<0I_ooooooool0H?ooo`030000oooooooo02Coool00`1Vooooooooo`0j
oooo00?o09Woooooool0:_ooo`00;?ooo`0306Kooooooooo063oool00`000?ooooooo`0Toooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo02[oool002coool00`1Vooooooooo`1Poooo00<0003ooooo
ool09?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Zoooo000/oooo00<0I_ooooooool0COoo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo02Coool00`1Vooooooooo`0joooo00?o
09Woooooool0:_ooo`00;?ooo`0306Kooooooooo04coool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0Toooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02[oool0
02cooolm06Ko4_ooo`040000oooooooo00002oooo`030000oooooooo00;oool300009?ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Zoooo001Yoooo0P1Voa3oool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo02;oool206Ko?Oooo`03o`2Ioooooooo02[oool006_oool206Ko3_oo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0Qoooo00<0I_oooooo
ool0?Oooo`03o`2Ioooooooo02[oool006goool00`1Vooooooooo`0<oooo0P0000[oool300001?oo
o`030000oooooooo01ooool206Ko@?ooo`03o`2Ioooooooo02[oool006koool206Ko7oooo`030000
oooooooo01goool206Ko@_ooo`03o`2Ioooooooo02[oool0073oool206Ko7Oooo`030000oooooooo
01coool00`1Vooooooooo`12oooo00?o09Woooooool0:_ooo`00L_ooo`0306Kooooooooo01[oool2
00006oooo`80I_m5oooo00?o09Woooooool0:_ooo`00Loooo`80I_lJoooo00<0003oooooool06?oo
o`80I_m7oooo00?o09Woooooool0:_ooo`00MOooo`0306Kooooooooo01Ooool00`000?ooooooo`0G
oooo00<0I_ooooooool0Aoooo`03o`2Ioooooooo02[oool007Koool00`1Vooooooooo`0Foooo00<0
003oooooool05Oooo`80I_m:oooo00?o09Woooooool0:_ooo`00Moooo`80I_lFoooo00<0003ooooo
ool04oooo`80I_m<oooo00?o09Woooooool0:_ooo`00NOooo`0306Kooooooooo01?oool00`000?oo
ooooo`0Boooo00<0I_ooooooool0C?ooo`03o`2Ioooooooo02[oool007[oool206Ko4oooo`030000
oooooooo017oool00`1Vooooooooo`1=oooo00?o09Woooooool0:_ooo`00O?ooo`0306Kooooooooo
013oool200004?ooo`80I_m@oooo00?o09Woooooool0:_ooo`00OOooo`0306Kooooooooo00ooool0
0`000?ooooooo`0>oooo00<0I_ooooooool0D?ooo`03o`2Ioooooooo02[oool007koool206Ko3ooo
o`030000oooooooo00goool00`1Vooooooooo`1Aoooo00?o09Woooooool0:_ooo`00P?ooo`0306Ko
oooooooo00coool00`000?ooooooo`0<oooo00<0I_ooooooool0D_ooo`03o`2Ioooooooo02[oool0
087oool00`1Vooooooooo`0;oooo00<0003oooooool02_ooo`80I_mEoooo00?o09Woooooool0:_oo
o`00P_ooo`0306Kooooooooo00[oool00`000?ooooooo`09oooo00<0I_ooooooool0EOooo`03o`2I
oooooooo02[oool008?oool206Ko2_ooo`800009oooo00<0I_ooooooool0E_ooo`03o`2Ioooooooo
02[oool008Goool00`1Vooooooooo`07oooo00<0003oooooool01oooo`0306Kooooooooo05Ooool0
0ol0VOooooooo`0Zoooo0026oooo00<0I_ooooooool01_ooo`030000oooooooo00Koool00`1Voooo
ooooo`1Hoooo00?o09Woooooool0:_ooo`00Qoooo`0306Kooooooooo00Goool00`000?ooooooo`04
oooo0P1Voe_oool00ol0VOooooooo`0Zoooo0028oooo0P1Vo`Goool00`000?ooooooo`03oooo00<0
I_ooooooool0Foooo`03o`2Ioooooooo02[oool008[oool00`1Vooooooooo`02oooo00<0003ooooo
ool00_ooo`0306Kooooooooo05coool00ol0VOooooooo`0Zoooo002;oooo00@0I_ooooooooooool2
00000_ooo`0306Kooooooooo05goool00ol0VOooooooo`0Zoooo002<oooo00@0I_ooooooool00002
oooo00<0I_ooooooool0G_ooo`03o`2Ioooooooo02[oool008goool01@1Vooooo`000?ooo`1Vo`1Q
oooo00?o09Woooooool0:_ooo`00S_ooo`0306Ko000006Ko06;oool00ol0VOooooooo`0Zoooo0027
oooo1@0000?oool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00ROooo`030000oooooooo
00?oool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00ROooo`030000oooooooo00?oool3
0000HOooo`03o`2Ioooooooo02[oool008Woool00`000?ooooooo`03oooo00<0003oooooool0HOoo
o`03o`2Ioooooooo02[oool008Woool00`000?ooooooo`03oooo00<0003oooooool0HOooo`03o`2I
oooooooo02[oool008Soool200001Oooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?
oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o
09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo0P00
06;oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool0
08ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool0
0ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool0
0`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`80001Roooo00?o09Woooooool0:_oo
o`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOoo
o`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Sooo
o`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2I
oooooooo02[oool008ooool20000H_ooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Q
oooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?
oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool008ooool00`000?ooooooo`1Qoooo00?o
09Woooooool0:_ooo`00Soooo`030000oooooooo067oool00ol0VOooooooo`0Zoooo002?oooo0P00
06;oool00ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool0
08ooool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00Soooo`030000oooooooo067oool0
0ol0VOooooooo`0Zoooo002?oooo00<0003oooooool0HOooo`03o`2Ioooooooo02[oool007_oool5
00000_ooo`800004oooo0P0000Goool00`000?ooooooo`1Qoooo00?o09Woooooool0:_ooo`00OOoo
o`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1Qoooo00?o09Wooooo
ool0:_ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00067oool00ol0VOoo
ooooo`0Zoooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?oo
o`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool0
07coool00`000?ooooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool0
0`000?ooooooo`0Ioooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?oo
o`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool00`000?ooooooo`1koooo001k
oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0
003oooooool02Oooo`040000oooooooo00000oooo`030000oooooooo07_oool007[oool00`000?oo
ooooo`02oooo00<0003oooooool03_ooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0
003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool02_ooo`050000
oooooooooooo000007goool007_oool01@000?ooooooooooo`00000?oooo00@0003oooooool00008
oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo017oool2
00002_ooo`800003oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.87754 .24721 L
.88797 .24721 L
.89307 .24721 L
.89548 .24721 L
.89654 .24721 L
.89771 .24721 L
s
.89771 .24721 m
.89788 .61803 L
s
0 .4 1 r
.02381 .24721 m
.04262 .24721 L
.06244 .24721 L
.08255 .24721 L
.08806 .24721 L
.09396 .24721 L
.09682 .24721 L
.09822 .24721 L
.09952 .24721 L
.1007 .24721 L
.10195 .37082 L
.1032 .37082 L
.10458 .37082 L
.14487 .37082 L
.18364 .37082 L
.22486 .37082 L
.26457 .37082 L
.30277 .37082 L
.32244 .37082 L
.3281 .37082 L
.33344 .37082 L
.33577 .37082 L
.33704 .37082 L
.33823 .37082 L
.33952 .37094 L
.3402 .37129 L
.34093 .37168 L
.34341 .37298 L
.38477 .39684 L
.42462 .4241 L
.46295 .45499 L
.48233 .47262 L
.48764 .4777 L
.49337 .48331 L
.496 .48594 L
.49744 .48738 L
.49877 .48873 L
.49992 .4899 L
.50114 .48882 L
.50373 .48621 L
.543 .44987 L
.58449 .41746 L
.60529 .40322 L
.62447 .39114 L
.64316 .38028 L
.65258 .37512 L
.65516 .37374 L
.65793 .37227 L
.65928 .37157 L
.66055 .37091 L
Mistroke
.66169 .24721 L
.66294 .24721 L
.70364 .24721 L
.74282 .24721 L
.78445 .24721 L
.82457 .24721 L
.86318 .24721 L
.90423 .24721 L
.94377 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.35) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00;oool00`1Voooo
ooooo`07oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`08oooo00D0I_ooooooooooool000003_ooo`030000
oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool01oooo`03o`2Ioooooooo00;oool0
0`000?ooooooo`0<oooo00<0003oooooool05Oooo`00:_ooo`0306Kooooooooo06;oool00`000?oo
ooooo`0Voooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Woool002[oool00`1Vooooooooo`1R
oooo00<0003oooooool09_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Yoooo000Zoooo00<0
I_ooooooool0H_ooo`030000oooooooo02Koool00`1Vooooooooo`0ioooo00?o09Woooooool0:Ooo
o`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`0Voooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo02Woool002[oool00`1Vooooooooo`1Roooo0P0002Ooool00`1Vooooooooo`0ioooo00?o
09Woooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`0Voooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo02Woool002[oool00`1Vooooooooo`1Roooo00<0003oooooool09_oo
o`0306Kooooooooo03Woool00ol0VOooooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`030000
oooooooo02Koool00`1Vooooooooo`0ioooo00?o09Woooooool0:Oooo`00:_ooo`0306Kooooooooo
06;oool00`000?ooooooo`0Voooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Woool002[oool0
0`1Vooooooooo`1Roooo00<0003oooooool09_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Y
oooo000Zoooo00<0I_ooooooool0H_ooo`80000Woooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02Woool002[oool00`1Vooooooooo`1Roooo00<0003oooooool09_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo02Koool00`1Voooo
ooooo`0ioooo00?o09Woooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`0V
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Woool002[oool00`1Vooooooooo`1Roooo00<0
003oooooool09_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Yoooo000Zoooo00<0I_oooooo
ool0H_ooo`030000oooooooo02Koool00`1Vooooooooo`0ioooo00?o09Woooooool0:Oooo`00:_oo
o`0306Kooooooooo06;oool00`000?ooooooo`0Voooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02Woool002[oool00`1Vooooooooo`1Roooo0P0002Ooool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`0Voooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo02Woool002[oool00`1Vooooooooo`1Roooo00<0003oooooool09_ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo
02Koool00`1Vooooooooo`0ioooo00?o09Woooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool0
0`000?ooooooo`0Voooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Woool002[oool00`1Voooo
ooooo`1Roooo00<0003oooooool09_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Yoooo000Z
oooo00<0I_ooooooool0H_ooo`80000Woooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Woool0
02[oool00`1Vooooooooo`1Roooo00<0003oooooool09_ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0Yoooo000Zoooo00<0I_ooooooool0H_ooo`030000oooooooo02Koool00`1Vooooooooo`0i
oooo00?o09Woooooool0:Oooo`00:_ooo`0306Kooooooooo06;oool00`000?ooooooo`0Voooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo02Woool002[oool00`1Vooooooooo`1?oooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool09_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Y
oooo000Zoooo00<0I_ooooooool0C_ooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo02Koool00`1Vooooooooo`0ioooo00?o09Woooooool0:Oooo`00:_oooch0I_lC
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000Uoooo0P1Voc_oool00ol0VOoo
ooooo`0Yoooo001Woooo00<0I_ooooooool04Oooo`040000oooooooo00002Oooo`800005oooo00<0
003oooooool08oooo`80I_lmoooo00?o09Woooooool0:Oooo`00J?ooo`80I_lAoooo00@0003ooooo
ool00009oooo00<0003oooooool01?ooo`030000oooooooo027oool206Ko?oooo`03o`2Ioooooooo
02Woool006[oool206Ko4?ooo`80000:oooo0`0000Coool00`000?ooooooo`0Poooo00<0I_oooooo
ool0?oooo`03o`2Ioooooooo02Woool006coool206Ko8Oooo`030000oooooooo01koool206Ko@_oo
o`03o`2Ioooooooo02Woool006koool206Ko7oooo`030000oooooooo01goool00`1Vooooooooo`12
oooo00?o09Woooooool0:Oooo`00L?ooo`80I_lMoooo0P0001coool206KoAOooo`03o`2Ioooooooo
02Woool007;oool00`1Vooooooooo`0Joooo00<0003oooooool06Oooo`80I_m7oooo00?o09Wooooo
ool0:Oooo`00Loooo`80I_lJoooo00<0003oooooool06?ooo`0306Kooooooooo04Ooool00ol0VOoo
ooooo`0Yoooo001eoooo00<0I_ooooooool05oooo`030000oooooooo01Koool206KoB_ooo`03o`2I
oooooooo02Woool007Koool00`1Vooooooooo`0Foooo00<0003oooooool05Oooo`0306Kooooooooo
04[oool00ol0VOooooooo`0Yoooo001goooo0P1VoaKoool00`000?ooooooo`0Coooo0P1Vodgoool0
0ol0VOooooooo`0Yoooo001ioooo00<0I_ooooooool04oooo`030000oooooooo01;oool00`1Voooo
ooooo`1=oooo00?o09Woooooool0:Oooo`00N_ooo`80I_lCoooo0P0001;oool00`1Vooooooooo`1>
oooo00?o09Woooooool0:Oooo`00O?ooo`0306Kooooooooo013oool00`000?ooooooo`0?oooo0P1V
oe7oool00ol0VOooooooo`0Yoooo001moooo0P1Voa3oool00`000?ooooooo`0>oooo00<0I_oooooo
ool0DOooo`03o`2Ioooooooo02Woool007ooool00`1Vooooooooo`0=oooo00<0003oooooool03Ooo
o`0306Kooooooooo05;oool00ol0VOooooooo`0Yoooo0020oooo00<0I_ooooooool03?ooo`030000
oooooooo00coool00`1Vooooooooo`1Coooo00?o09Woooooool0:Oooo`00POooo`80I_l<oooo00<0
003oooooool02_ooo`80I_mFoooo00?o09Woooooool0:Oooo`00Poooo`0306Kooooooooo00Woool2
00002_ooo`0306Kooooooooo05Koool00ol0VOooooooo`0Yoooo0024oooo0P1Vo`Woool00`000?oo
ooooo`08oooo00<0I_ooooooool0Eoooo`03o`2Ioooooooo02Woool008Koool00`1Vooooooooo`06
oooo00<0003oooooool01oooo`0306Kooooooooo05Soool00ol0VOooooooo`0Yoooo0027oooo00<0
I_ooooooool01Oooo`030000oooooooo00Koool00`1Vooooooooo`1Ioooo00?o09Woooooool0:Ooo
o`00R?ooo`0306Kooooooooo00Coool00`000?ooooooo`05oooo00<0I_ooooooool0F_ooo`03o`2I
oooooooo02Woool008Soool00`1Vooooooooo`04oooo00<0003oooooool01?ooo`0306Kooooooooo
05_oool00ol0VOooooooo`0Yoooo0029oooo00<0I_ooooooool00oooo`800003oooo0P1Voekoool0
0ol0VOooooooo`0Yoooo002:oooo00<0I_ooooooool00_ooo`050000oooooooooooo06Ko063oool0
0ol0VOooooooo`0Yoooo002;oooo0P1Vo`;oool010000?ooooooo`1Vof7oool00ol0VOooooooo`0Y
oooo002<oooo00H0I_ooooooool0003oool0I_mRoooo00?o09Woooooool0:Oooo`00Qoooo`D00000
1Oooo`1Vo`1Vo`00001Vo`1Soooo00?o09Woooooool0:Oooo`00ROooo`030000oooooooo00;oool0
0`1Vo`000?ooo`1Soooo00?o09Woooooool0:Oooo`00ROooo`030000oooooooo00?oool30000H_oo
o`03o`2Ioooooooo02Woool008Woool00`000?ooooooo`03oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008Woool00`000?ooooooo`03oooo00<0003oooooool0H_ooo`03o`2Ioooooooo
02Woool008Soool200001Oooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0
003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Wooooo
ool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo0P0006?oool0
0ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool0
0`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?oo
ooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`80001Soooo00?o09Woooooool0:Oooo`00Sooo
o`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2I
oooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`030000
oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo
02Woool008ooool20000Hoooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o
09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo00<0
003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool00`000?ooooooo`1Roooo00?o09Wooooo
ool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOooooooo`0Yoooo002?oooo0P0006?oool0
0ol0VOooooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool008ooool0
0`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00Soooo`030000oooooooo06;oool00ol0VOoo
ooooo`0Yoooo002?oooo00<0003oooooool0H_ooo`03o`2Ioooooooo02Woool007_oool500000_oo
o`800004oooo0P0000Goool00`000?ooooooo`1Roooo00?o09Woooooool0:Oooo`00OOooo`030000
oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1Roooo00?o09Woooooool0:Ooo
o`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`0006;oool00ol0VOooooooo`0Y
oooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000
oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool0
0`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000oooooooo00Soool00`000?oo
ooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00Koool400000oooo`800004oooo0P0000Coool200001?ooo`030000oooooooo07Soool0
07Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00Goool0
0`000?ooooooo`09oooo00@0003oooooool00002oooo00@0003oooooool00003oooo00<0003ooooo
ool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool02_oo
o`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000
oooooooo00D0000>oooo00<0003oooooool02_ooo`040000oooooooooooo0P0000Coool00`000?oo
ooooo`1hoooo001hoooo00D0003oooooooooool000003oooo`040000oooooooo00002?ooo`040000
oooooooo00000oooo`030000oooooooo00?oool00`000?ooooooo`1hoooo001ioooo00<0003ooooo
ool04Oooo`80000:oooo0P0000Coool300000_ooo`030000oooooooo07Woool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.87754 .24721 L
.88797 .24721 L
.89307 .24721 L
.89771 .24721 L
.90008 .24721 L
.90133 .24721 L
.90265 .24721 L
.90381 .24721 L
s
.90381 .24721 m
.904 .61803 L
s
0 .4 1 r
.02381 .24721 m
.04262 .24721 L
.06244 .24721 L
.08255 .24721 L
.08806 .24721 L
.09109 .24721 L
.09258 .24721 L
.09324 .24721 L
.09396 .24721 L
.09525 .37082 L
.09596 .37082 L
.09662 .37082 L
.09952 .37082 L
.10458 .37082 L
.14335 .37082 L
.18458 .37082 L
.22428 .37082 L
.26248 .37082 L
.28379 .37082 L
.30312 .37082 L
.3128 .37082 L
.32327 .37082 L
.32808 .37082 L
.33071 .37082 L
.33199 .37082 L
.33316 .37082 L
.33423 .37129 L
.33525 .37182 L
.33749 .373 L
.34225 .37554 L
.38058 .39795 L
.42136 .42612 L
.46063 .45819 L
.48032 .47638 L
.48895 .48484 L
.49383 .48976 L
.49617 .49216 L
.49838 .49444 L
.49953 .49563 L
.50077 .49532 L
.5019 .49415 L
.50294 .49307 L
.50781 .4881 L
.51773 .47827 L
.53858 .45889 L
.57799 .4266 L
.61587 .40021 L
.63695 .38725 L
.65621 .37637 L
.66083 .37389 L
Mistroke
.66336 .37255 L
.6646 .3719 L
.66574 .3713 L
.66641 .37096 L
.6671 .24721 L
.6678 .24721 L
.66857 .24721 L
.67113 .24721 L
.67613 .24721 L
.69504 .24721 L
.73552 .24721 L
.77448 .24721 L
.81589 .24721 L
.85579 .24721 L
.89417 .24721 L
.935 .24721 L
.97432 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`040000oooooooo06Ko2oooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool02Oooo`0406Kooooooooo00003_ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool02?ooo`05o`2Ioooooooooooo000000koool00`000?ooooooo`0E
oooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo02Ooool00`1Vooooooooo`0ioooo00?o
09Woooooool0:?ooo`00:?ooo`0306Kooooooooo06Coool00`000?ooooooo`0Woooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo02Soool002Soool00`1Vooooooooo`1Toooo00<0003oooooool09ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0Xoooo000Xoooo00<0I_ooooooool0I?ooo`030000
oooooooo02Ooool00`1Vooooooooo`0ioooo00?o09Woooooool0:?ooo`00:?ooo`0306Kooooooooo
06Coool20000:?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Xoooo000Xoooo00<0I_oooooo
ool0I?ooo`030000oooooooo02Ooool00`1Vooooooooo`0ioooo00?o09Woooooool0:?ooo`00:?oo
o`0306Kooooooooo06Coool00`000?ooooooo`0Woooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02Soool002Soool00`1Vooooooooo`1Toooo00<0003oooooool09oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Xoooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo02Ooool00`1Voooo
ooooo`0ioooo00?o09Woooooool0:?ooo`00:?ooo`0306Kooooooooo06Coool00`000?ooooooo`0W
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Soool002Soool00`1Vooooooooo`1Toooo0P00
02Soool00`1Vooooooooo`0ioooo00?o09Woooooool0:?ooo`00:?ooo`0306Kooooooooo06Coool0
0`000?ooooooo`0Woooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Soool002Soool00`1Voooo
ooooo`1Toooo00<0003oooooool09oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Xoooo000X
oooo00<0I_ooooooool0I?ooo`030000oooooooo02Ooool00`1Vooooooooo`0ioooo00?o09Wooooo
ool0:?ooo`00:?ooo`0306Kooooooooo06Coool00`000?ooooooo`0Woooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo02Soool002Soool00`1Vooooooooo`1Toooo00<0003oooooool09oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Xoooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo
02Ooool00`1Vooooooooo`0ioooo00?o09Woooooool0:?ooo`00:?ooo`0306Kooooooooo06Coool2
0000:?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Xoooo000Xoooo00<0I_ooooooool0I?oo
o`030000oooooooo02Ooool00`1Vooooooooo`0ioooo00?o09Woooooool0:?ooo`00:?ooo`0306Ko
oooooooo06Coool00`000?ooooooo`0Woooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Soool0
02Soool00`1Vooooooooo`1Toooo00<0003oooooool09oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0Xoooo000Xoooo00<0I_ooooooool0I?ooo`030000oooooooo02Ooool00`1Vooooooooo`0i
oooo00?o09Woooooool0:?ooo`00:?ooo`0306Kooooooooo06Coool00`000?ooooooo`0Woooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo02Soool002Soool00`1Vooooooooo`1Toooo0P0002Soool0
0`1Vooooooooo`0ioooo00?o09Woooooool0:?ooo`00:?ooo`0306Kooooooooo06Coool00`000?oo
ooooo`0Woooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Soool002Soool00`1Vooooooooo`1T
oooo00<0003oooooool09oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Xoooo000Xoooo00<0
I_ooooooool0I?ooo`030000oooooooo02Ooool00`1Vooooooooo`0ioooo00?o09Woooooool0:?oo
o`00:?ooo`0306Kooooooooo057oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0W
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Soool002Soool00`1Vooooooooo`1@oooo00@0
003oooooool00008oooo00@0003oooooool00004oooo00<0003oooooool09oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0Xoooo000Xoooo?P1VoaGoool010000?ooooooo`0000_oool00`000?oo
ooooo`02oooo0`0002Ooool00`1Vooooooooo`0ioooo00?o09Woooooool0:?ooo`00I_ooo`80I_lC
oooo00@0003oooooool00009oooo0P0000Goool00`000?ooooooo`0Uoooo0P1Voccoool00ol0VOoo
ooooo`0Xoooo001Xoooo0P1Voa7oool010000?ooooooo`0000Woool00`000?ooooooo`04oooo00<0
003oooooool08oooo`80I_lnoooo00?o09Woooooool0:?ooo`00J_ooo`80I_l@oooo0P0000[oool3
00001?ooo`030000oooooooo027oool206Ko@?ooo`03o`2Ioooooooo02Soool006coool00`1Voooo
ooooo`0Poooo00<0003oooooool08?ooo`0306Kooooooooo043oool00ol0VOooooooo`0Xoooo001]
oooo0P1Vob3oool00`000?ooooooo`0Noooo0P1Vod?oool00ol0VOooooooo`0Xoooo001_oooo0P1V
oakoool200007_ooo`0306Kooooooooo04?oool00ol0VOooooooo`0Xoooo001aoooo00<0I_oooooo
ool06oooo`030000oooooooo01_oool206KoA_ooo`03o`2Ioooooooo02Soool007;oool206Ko6ooo
o`030000oooooooo01[oool00`1Vooooooooo`16oooo00?o09Woooooool0:?ooo`00M?ooo`0306Ko
oooooooo01Soool00`000?ooooooo`0Hoooo0P1VodWoool00ol0VOooooooo`0Xoooo001eoooo00<0
I_ooooooool05oooo`030000oooooooo01Ooool00`1Vooooooooo`19oooo00?o09Woooooool0:?oo
o`00M_ooo`80I_lGoooo00<0003oooooool05Oooo`80I_m<oooo00?o09Woooooool0:?ooo`00N?oo
o`0306Kooooooooo01Coool00`000?ooooooo`0Doooo00<0I_ooooooool0C?ooo`03o`2Ioooooooo
02Soool007Woool206Ko5?ooo`80000Coooo0P1Vodooool00ol0VOooooooo`0Xoooo001koooo00<0
I_ooooooool04Oooo`030000oooooooo017oool00`1Vooooooooo`1?oooo00?o09Woooooool0:?oo
o`00O?ooo`0306Kooooooooo013oool00`000?ooooooo`0@oooo00<0I_ooooooool0D?ooo`03o`2I
oooooooo02Soool007goool206Ko4?ooo`030000oooooooo00koool206KoDoooo`03o`2Ioooooooo
02Soool007ooool00`1Vooooooooo`0=oooo00<0003oooooool03Oooo`0306Kooooooooo05?oool0
0ol0VOooooooo`0Xoooo0020oooo00<0I_ooooooool03?ooo`030000oooooooo00coool00`1Voooo
ooooo`1Doooo00?o09Woooooool0:?ooo`00POooo`0306Kooooooooo00_oool200003?ooo`0306Ko
oooooooo05Goool00ol0VOooooooo`0Xoooo0022oooo0P1Vo`_oool00`000?ooooooo`09oooo0P1V
oeSoool00ol0VOooooooo`0Xoooo0024oooo00<0I_ooooooool02?ooo`030000oooooooo00Soool0
0`1Vooooooooo`1Hoooo00?o09Woooooool0:?ooo`00QOooo`0306Kooooooooo00Ooool00`000?oo
ooooo`07oooo00<0I_ooooooool0FOooo`03o`2Ioooooooo02Soool008Koool00`1Vooooooooo`06
oooo00<0003oooooool01_ooo`0306Kooooooooo05[oool00ol0VOooooooo`0Xoooo0027oooo00<0
I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`1Koooo00?o09Woooooool0:?oo
o`00R?ooo`0306Kooooooooo00Coool200001?ooo`80I_mNoooo00?o09Woooooool0:?ooo`00ROoo
o`0306Kooooooooo00?oool00`000?ooooooo`02oooo00<0I_ooooooool0G_ooo`03o`2Ioooooooo
02Soool008[oool00`1Vooooooooo`02oooo00D0003oooooooooool0I_l0HOooo`03o`2Ioooooooo
02Soool008_oool01@1Vooooooooooooo`000002oooo00<0I_ooooooool0H?ooo`03o`2Ioooooooo
02Soool008Ooool5000000@0I_ooooooool00002oooo00<0I_ooooooool0H?ooo`03o`2Ioooooooo
02Soool008Woool02@000?ooooooooooo`1Vooooo`000?ooo`1Vo`1Soooo00?o09Woooooool0:?oo
o`00ROooo`030000oooooooo00;oool0101Vo`000000000006?oool00ol0VOooooooo`0Xoooo0029
oooo00<0003oooooool00oooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo0029oooo00<0
003oooooool00oooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo0028oooo0P0000Goool0
0`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOoo
ooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?oo
ooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Sooo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2I
oooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000
oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo
02Soool008ooool20000I?ooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o
09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0
003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Wooooo
ool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo0P0006Coool0
0ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool0
0`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000oooooooo06?oool00ol0VOoo
ooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool008ooool00`000?oo
ooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`80001Toooo00?o09Woooooool0:?ooo`00Sooo
o`030000oooooooo06?oool00ol0VOooooooo`0Xoooo002?oooo00<0003oooooool0Hoooo`03o`2I
oooooooo02Soool008ooool00`000?ooooooo`1Soooo00?o09Woooooool0:?ooo`00Soooo`030000
oooooooo06?oool00ol0VOooooooo`0Xoooo001koooo1@0000;oool200001?ooo`800005oooo00<0
003oooooool0Hoooo`03o`2Ioooooooo02Soool007goool00`000?ooooooo`07oooo00@0003ooooo
ool00004oooo00<0003oooooool0Hoooo`03o`2Ioooooooo02Soool007goool00`000?ooooooo`0:
oooo00<0003oooooool00_ooo`<0001Soooo00?o09Woooooool0:?ooo`00OOooo`030000oooooooo
00Soool20000U_ooo`00OOooo`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P00
00[oool30000UOooo`00ooooob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000
oooooooo07coool007_oool00`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo
07_oool007_oool00`000?ooooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool2
00001Oooo`<00002oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00coool01@000?oooooooooo
o`00001moooo001joooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`08
oooo1@0000?oool00`000?ooooooo`1joooo001koooo00<0003oooooool01@0000koool00`000?oo
ooooo`07oooo00@0003oooooool00003oooo00<0003oooooool0Noooo`00Noooo`050000oooooooo
oooo000000ooool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool0Nooo
o`00O?ooo`030000oooooooo017oool200002oooo`800002oooo00<0003oooooool0O?ooo`00oooo
ob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.87754 .24721 L
.88797 .24721 L
.89771 .24721 L
.90265 .24721 L
.90733 .24721 L
.90859 .24721 L
.90992 .24721 L
.91061 .24721 L
s
.91061 .24721 m
.91073 .61803 L
s
0 .4 1 r
.02381 .24721 m
.04262 .24721 L
.06244 .24721 L
.07216 .24721 L
.08255 .24721 L
.08562 .24721 L
.08713 .24721 L
.08779 .24721 L
.08852 .24721 L
.08979 .37082 L
.09048 .37082 L
.09113 .37082 L
.09396 .37082 L
.10458 .37082 L
.14335 .37082 L
.18458 .37082 L
.22428 .37082 L
.26248 .37082 L
.28379 .37082 L
.30312 .37082 L
.3128 .37082 L
.31789 .37082 L
.32067 .37082 L
.32327 .37082 L
.32555 .37082 L
.32682 .37082 L
.32798 .37113 L
.32926 .3718 L
.33064 .37252 L
.33316 .37386 L
.34225 .37879 L
.38303 .40337 L
.4223 .43137 L
.46005 .46301 L
.48102 .48288 L
.49021 .49215 L
.49507 .49719 L
.49774 .50001 L
.49905 .50141 L
.50025 .50216 L
.50145 .50088 L
.50271 .49954 L
.50537 .49674 L
.51002 .49191 L
.5191 .48275 L
.53894 .46392 L
.57683 .43204 L
.61717 .40324 L
.63574 .39153 L
.65599 .37976 L
Mistroke
.66132 .37683 L
.66698 .37378 L
.66974 .37233 L
.67109 .37162 L
.67233 .37097 L
.67346 .24721 L
.67465 .24721 L
.67717 .24721 L
.69727 .24721 L
.73529 .24721 L
.77577 .24721 L
.81473 .24721 L
.85614 .24721 L
.89604 .24721 L
.93442 .24721 L
.97526 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.45) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooo06Ko00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00_oool00`1Vo`000?ooo`0=oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0:oooo00?o09Woool000003_ooo`030000oooooooo01Goool002Ooool0
0`1Vooooooooo`1Uoooo00<0003oooooool0:Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0V
oooo000Woooo00<0I_ooooooool0IOooo`030000oooooooo02Woool00`1Vooooooooo`0ioooo00?o
09Woooooool09_ooo`009oooo`0306Kooooooooo06Goool00`000?ooooooo`0Yoooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo02Koool002Ooool00`1Vooooooooo`1Uoooo00<0003oooooool0:Ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0Voooo000Woooo00<0I_ooooooool0IOooo`80000Z
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Koool002Ooool00`1Vooooooooo`1Uoooo00<0
003oooooool0:Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Voooo000Woooo00<0I_oooooo
ool0IOooo`030000oooooooo02Woool00`1Vooooooooo`0ioooo00?o09Woooooool09_ooo`009ooo
o`0306Kooooooooo06Goool00`000?ooooooo`0Yoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02Koool002Ooool00`1Vooooooooo`1Uoooo00<0003oooooool0:Oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Voooo000Woooo00<0I_ooooooool0IOooo`030000oooooooo02Woool00`1Voooo
ooooo`0ioooo00?o09Woooooool09_ooo`009oooo`0306Kooooooooo06Goool20000:_ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Voooo000Woooo00<0I_ooooooool0IOooo`030000oooooooo
02Woool00`1Vooooooooo`0ioooo00?o09Woooooool09_ooo`009oooo`0306Kooooooooo06Goool0
0`000?ooooooo`0Yoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Koool002Ooool00`1Voooo
ooooo`1Uoooo00<0003oooooool0:Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Voooo000W
oooo00<0I_ooooooool0IOooo`030000oooooooo02Woool00`1Vooooooooo`0ioooo00?o09Wooooo
ool09_ooo`009oooo`0306Kooooooooo06Goool00`000?ooooooo`0Yoooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo02Koool002Ooool00`1Vooooooooo`1Uoooo00<0003oooooool0:Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Voooo000Woooo00<0I_ooooooool0IOooo`80000Zoooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo02Koool002Ooool00`1Vooooooooo`1Uoooo00<0003ooooo
ool0:Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Voooo000Woooo00<0I_ooooooool0IOoo
o`030000oooooooo02Woool00`1Vooooooooo`0ioooo00?o09Woooooool09_ooo`009oooo`0306Ko
oooooooo06Goool00`000?ooooooo`0Yoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Koool0
02Ooool00`1Vooooooooo`1Uoooo00<0003oooooool0:Oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0Voooo000Woooo00<0I_ooooooool0IOooo`030000oooooooo02Woool00`1Vooooooooo`0i
oooo00?o09Woooooool09_ooo`009oooo`0306Kooooooooo06Goool20000:_ooo`0306Kooooooooo
03Woool00ol0VOooooooo`0Voooo000Woooo00<0I_ooooooool0IOooo`030000oooooooo02Woool0
0`1Vooooooooo`0ioooo00?o09Woooooool09_ooo`009oooo`0306Kooooooooo06Goool00`000?oo
ooooo`0Yoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02Koool002Ooool00`1Vooooooooo`1U
oooo00<0003oooooool0:Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Voooo000Woooo00<0
I_ooooooool0D_ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo02Woool00`1Voooo
ooooo`0ioooo00?o09Woooooool09_ooo`009oooo`0306Kooooooooo057oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0Yoooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo02Koool002Ooooln06Ko5_ooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000:?ooo`80I_lkoooo00?o09Woooooool09_ooo`00I?ooo`80I_lEoooo00@0003oooooool00009
oooo0P0000Goool00`000?ooooooo`0Woooo00<0I_ooooooool0>oooo`03o`2Ioooooooo02Koool0
06Koool206Ko4oooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0U
oooo0P1Vockoool00ol0VOooooooo`0Voooo001Xoooo0P1Voa;oool200002_ooo`<00004oooo00<0
003oooooool08oooo`80I_m0oooo00?o09Woooooool09_ooo`00J_ooo`80I_lSoooo00<0003ooooo
ool08Oooo`80I_m2oooo00?o09Woooooool09_ooo`00K?ooo`0306Kooooooooo023oool00`000?oo
ooooo`0Ooooo0P1VodCoool00ol0VOooooooo`0Voooo001]oooo0P1Vob3oool200007oooo`0306Ko
oooooooo04Coool00ol0VOooooooo`0Voooo001_oooo0P1Voakoool00`000?ooooooo`0Loooo0P1V
odOoool00ol0VOooooooo`0Voooo001aoooo00<0I_ooooooool06oooo`030000oooooooo01_oool0
0`1Vooooooooo`17oooo00?o09Woooooool09_ooo`00L_ooo`80I_lKoooo00<0003oooooool06Ooo
o`80I_m:oooo00?o09Woooooool09_ooo`00M?ooo`0306Kooooooooo01Soool00`000?ooooooo`0H
oooo00<0I_ooooooool0B_ooo`03o`2Ioooooooo02Koool007Goool00`1Vooooooooo`0Goooo00<0
003oooooool05oooo`0306Kooooooooo04_oool00ol0VOooooooo`0Voooo001foooo0P1VoaOoool0
0`000?ooooooo`0Eoooo0P1Vodkoool00ol0VOooooooo`0Voooo001hoooo00<0I_ooooooool05?oo
o`80000Eoooo00<0I_ooooooool0C_ooo`03o`2Ioooooooo02Koool007Woool206Ko5?ooo`030000
oooooooo01?oool00`1Vooooooooo`1?oooo00?o09Woooooool09_ooo`00Noooo`0306Kooooooooo
017oool00`000?ooooooo`0Aoooo0P1Voe;oool00ol0VOooooooo`0Voooo001loooo00<0I_oooooo
ool04?ooo`030000oooooooo013oool00`1Vooooooooo`1Boooo00?o09Woooooool09_ooo`00OOoo
o`80I_l@oooo00<0003oooooool03oooo`0306Kooooooooo05?oool00ol0VOooooooo`0Voooo001o
oooo00<0I_ooooooool03Oooo`030000oooooooo00koool00`1Vooooooooo`1Doooo00?o09Wooooo
ool09_ooo`00P?ooo`0306Kooooooooo00coool200003_ooo`0306Kooooooooo05Goool00ol0VOoo
ooooo`0Voooo0021oooo00<0I_ooooooool02oooo`030000oooooooo00_oool206KoF?ooo`03o`2I
oooooooo02Koool008;oool206Ko2oooo`030000oooooooo00[oool00`1Vooooooooo`1Hoooo00?o
09Woooooool09_ooo`00Q?ooo`0306Kooooooooo00Soool00`000?ooooooo`09oooo00<0I_oooooo
ool0FOooo`03o`2Ioooooooo02Koool008Goool00`1Vooooooooo`07oooo00<0003oooooool02?oo
o`0306Kooooooooo05[oool00ol0VOooooooo`0Voooo0026oooo00<0I_ooooooool01_ooo`030000
oooooooo00Ooool00`1Vooooooooo`1Koooo00?o09Woooooool09_ooo`00Qoooo`0306Kooooooooo
00Goool200001oooo`0306Kooooooooo05coool00ol0VOooooooo`0Voooo0028oooo00<0I_oooooo
ool01?ooo`030000oooooooo00Coool206KoGoooo`03o`2Ioooooooo02Koool008Woool00`1Voooo
ooooo`03oooo00<0003oooooool00oooo`0306Kooooooooo05ooool00ol0VOooooooo`0Voooo002:
oooo00<0I_ooooooool00_ooo`030000oooooooo00;oool00`1Vooooooooo`1Poooo00?o09Wooooo
ool09_ooo`00Qoooo`D00003oooo00D0003oooooooooool0I_l0Hoooo`03o`2Ioooooooo02Koool0
08Woool00`000?ooo`1Vo`03oooo00D0003oooooooooool0I_l0Hoooo`03o`2Ioooooooo02Koool0
08Woool010000?ooooooo`1Vo`;oool3000000<0I_ooooooool0H_ooo`03o`2Ioooooooo02Koool0
08Woool010000?ooooooooooo`80I_l00`00001Vo`1Vo`1Uoooo00?o09Woooooool09_ooo`00ROoo
o`030000oooooooo00;oool00`1Vo`00001Vo`1Voooo00?o09Woooooool09_ooo`00R?ooo`800005
oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o
09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0
003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool20000I_ooo`03o`2Ioooooooo02Koool0
08ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool0
0ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool0
0`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOoo
ooooo`0Voooo002?oooo0P0006Koool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOoo
o`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Sooo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2I
oooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`80001V
oooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?
oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool00`000?ooooooo`1Uoooo00?o
09Woooooool09_ooo`00Soooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo002?oooo00<0
003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool20000I_ooo`03o`2Ioooooooo02Koool0
08ooool00`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Soooo`030000oooooooo06Goool0
0ol0VOooooooo`0Voooo002?oooo00<0003oooooool0IOooo`03o`2Ioooooooo02Koool008ooool0
0`000?ooooooo`1Uoooo00?o09Woooooool09_ooo`00Noooo`D00002oooo0P0000Coool200001Ooo
o`030000oooooooo06Goool00ol0VOooooooo`0Voooo001moooo00<0003oooooool01oooo`040000
oooooooo00001?ooo`030000oooooooo06Goool00ol0VOooooooo`0Voooo001moooo00<0003ooooo
ool02_ooo`030000oooooooo00;oool30000IOooo`03o`2Ioooooooo02Koool007goool00`000?oo
ooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOooo`00O?oo
o`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo02Soool0
0`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool00`000?oo
ooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`@00003
oooo0P0000Goool300000_ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooo
oooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00coool0
10000?ooooooo`0000;oool01@000?ooooooooooo`00001joooo001goooo00<0003oooooool00_oo
o`030000oooooooo00koool00`000?ooooooo`08oooo1@0000Coool00`000?ooooooo`02oooo00<0
003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003oooooool01oooo`040000
oooooooo00000oooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000oooooooooooo0000
00ooool010000?ooooooo`0000Woool00`000?ooo`000003oooo00<0003oooooool00oooo`030000
oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000_oool200000oooo`<00002oooo00<0
003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.87754 .24721 L
.88797 .24721 L
.89771 .24721 L
.90733 .24721 L
.91011 .24721 L
.91273 .24721 L
.91509 .24721 L
.91573 .24721 L
.91642 .24721 L
s
.91642 .24721 m
.9166 .61803 L
s
0 .4 1 r
.02381 .24721 m
.04262 .24721 L
.06244 .24721 L
.07216 .24721 L
.0775 .24721 L
.08013 .24721 L
.08128 .24721 L
.08255 .24721 L
.08327 .24721 L
.08394 .37082 L
.08465 .37082 L
.08542 .37082 L
.08852 .37082 L
.09396 .37082 L
.10458 .37082 L
.1458 .37082 L
.18551 .37082 L
.22371 .37082 L
.26435 .37082 L
.28315 .37082 L
.30348 .37082 L
.3089 .37082 L
.31463 .37082 L
.31699 .37082 L
.31952 .37082 L
.32027 .37082 L
.32098 .37082 L
.32161 .37091 L
.3223 .37127 L
.32489 .37263 L
.34506 .38372 L
.38585 .40922 L
.42511 .43827 L
.46286 .4711 L
.48384 .49171 L
.49302 .50133 L
.49554 .50403 L
.49692 .50552 L
.49822 .50694 L
.49944 .50828 L
.50076 .50806 L
.50196 .50674 L
.50307 .50554 L
.52191 .48588 L
.54175 .4668 L
.58116 .43331 L
.61904 .40593 L
.64012 .39248 L
.65938 .38119 L
.66891 .37594 L
Mistroke
.67152 .37453 L
.6743 .37306 L
.67565 .37234 L
.67692 .37168 L
.67807 .37108 L
.6793 .24721 L
.68048 .24721 L
.68159 .24721 L
.68409 .24721 L
.68915 .24721 L
.69821 .24721 L
.73717 .24721 L
.77858 .24721 L
.81848 .24721 L
.85686 .24721 L
.89769 .24721 L
.93701 .24721 L
.97482 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo01Goool002Goool0
0`1Vooooooooo`1Woooo00<0003oooooool0:_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0T
oooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo02[oool00`1Vooooooooo`0joooo00?o
09Woooooool09?ooo`009Oooo`0306Kooooooooo06Ooool00`000?ooooooo`0Zoooo00<0I_oooooo
ool0>_ooo`03o`2Ioooooooo02Coool002Goool00`1Vooooooooo`1Woooo00<0003oooooool0:_oo
o`0306Kooooooooo03[oool00ol0VOooooooo`0Toooo000Uoooo00<0I_ooooooool0Ioooo`80000[
oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02Coool002Goool00`1Vooooooooo`1Woooo00<0
003oooooool0:_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Toooo000Uoooo00<0I_oooooo
ool0Ioooo`030000oooooooo02[oool00`1Vooooooooo`0joooo00?o09Woooooool09?ooo`009Ooo
o`0306Kooooooooo06Ooool00`000?ooooooo`0Zoooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
02Coool002Goool00`1Vooooooooo`1Woooo00<0003oooooool0:_ooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Toooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo02[oool00`1Voooo
ooooo`0joooo00?o09Woooooool09?ooo`009Oooo`0306Kooooooooo06Ooool20000:oooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Toooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo
02[oool00`1Vooooooooo`0joooo00?o09Woooooool09?ooo`009Oooo`0306Kooooooooo06Ooool0
0`000?ooooooo`0Zoooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02Coool002Goool00`1Voooo
ooooo`1Woooo00<0003oooooool0:_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Toooo000U
oooo00<0I_ooooooool0Ioooo`030000oooooooo02[oool00`1Vooooooooo`0joooo00?o09Wooooo
ool09?ooo`009Oooo`0306Kooooooooo06Ooool00`000?ooooooo`0Zoooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo02Coool002Goool00`1Vooooooooo`1Woooo00<0003oooooool0:_ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Toooo000Uoooo00<0I_ooooooool0Ioooo`80000[oooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo02Coool002Goool00`1Vooooooooo`1Woooo00<0003ooooo
ool0:_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Toooo000Uoooo00<0I_ooooooool0Iooo
o`030000oooooooo02[oool00`1Vooooooooo`0joooo00?o09Woooooool09?ooo`009Oooo`0306Ko
oooooooo06Ooool00`000?ooooooo`0Zoooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02Coool0
02Goool00`1Vooooooooo`1Woooo00<0003oooooool0:_ooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0Toooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo02[oool00`1Vooooooooo`0j
oooo00?o09Woooooool09?ooo`009Oooo`0306Kooooooooo06Ooool20000:oooo`0306Kooooooooo
03[oool00ol0VOooooooo`0Toooo000Uoooo00<0I_ooooooool0Ioooo`030000oooooooo02[oool0
0`1Vooooooooo`0joooo00?o09Woooooool09?ooo`009Oooo`0306Kooooooooo06Ooool00`000?oo
ooooo`0Zoooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo02Coool002Goool00`1Vooooooooo`1W
oooo00<0003oooooool0:_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Toooo000Uoooo00<0
I_ooooooool0E?ooo`800004oooo0P0000Coool200001Oooo`030000oooooooo02[oool00`1Voooo
ooooo`0joooo00?o09Woooooool09?ooo`009Oooo`0306Kooooooooo05?oool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0Zoooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo02Coool002Goooln06Ko6?ooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000:_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Toooo001Soooo0P1VoaKoool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo02Soool206Ko?Oooo`03o`2Ioooooooo02Coool0
06Goool206Ko5?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0V
oooo0P1Vocooool00ol0VOooooooo`0Toooo001Woooo0P1Voa?oool200002_ooo`<00004oooo00<0
003oooooool09Oooo`0306Kooooooooo03ooool00ol0VOooooooo`0Toooo001Yoooo0P1VobCoool0
0`000?ooooooo`0Soooo0P1Vod;oool00ol0VOooooooo`0Toooo001[oooo00<0I_ooooooool08Ooo
o`030000oooooooo027oool206KoA?ooo`03o`2Ioooooooo02Coool006coool00`1Vooooooooo`0P
oooo0P00027oool00`1Vooooooooo`14oooo00?o09Woooooool09?ooo`00KOooo`80I_lPoooo00<0
003oooooool07_ooo`80I_m7oooo00?o09Woooooool09?ooo`00Koooo`0306Kooooooooo01goool0
0`000?ooooooo`0Loooo0P1VodWoool00ol0VOooooooo`0Toooo001`oooo0P1Voagoool00`000?oo
ooooo`0Koooo00<0I_ooooooool0BOooo`03o`2Ioooooooo02Coool007;oool00`1Vooooooooo`0J
oooo00<0003oooooool06_ooo`0306Kooooooooo04[oool00ol0VOooooooo`0Toooo001coooo0P1V
oa[oool00`000?ooooooo`0Hoooo0P1Vodgoool00ol0VOooooooo`0Toooo001eoooo00<0I_oooooo
ool05oooo`030000oooooooo01Ooool00`1Vooooooooo`1=oooo00?o09Woooooool09?ooo`00M_oo
o`0306Kooooooooo01Koool200005oooo`0306Kooooooooo04koool00ol0VOooooooo`0Toooo001g
oooo0P1VoaKoool00`000?ooooooo`0Doooo0P1Voe7oool00ol0VOooooooo`0Toooo001ioooo00<0
I_ooooooool04oooo`030000oooooooo01?oool00`1Vooooooooo`1Aoooo00?o09Woooooool09?oo
o`00N_ooo`80I_lCoooo00<0003oooooool04_ooo`0306Kooooooooo05;oool00ol0VOooooooo`0T
oooo001loooo00<0I_ooooooool04?ooo`030000oooooooo017oool00`1Vooooooooo`1Coooo00?o
09Woooooool09?ooo`00OOooo`0306Kooooooooo00ooool00`000?ooooooo`0?oooo0P1VoeKoool0
0ol0VOooooooo`0Toooo001noooo00<0I_ooooooool03_ooo`80000?oooo00<0I_ooooooool0E_oo
o`03o`2Ioooooooo02Coool007ooool00`1Vooooooooo`0=oooo00<0003oooooool03Oooo`0306Ko
oooooooo05Ooool00ol0VOooooooo`0Toooo0020oooo00<0I_ooooooool03?ooo`030000oooooooo
00coool00`1Vooooooooo`1Hoooo00?o09Woooooool09?ooo`00POooo`80I_l<oooo00<0003ooooo
ool02_ooo`80I_mKoooo00?o09Woooooool09?ooo`00Poooo`0306Kooooooooo00Woool00`000?oo
ooooo`09oooo00<0I_ooooooool0Foooo`03o`2Ioooooooo02Coool008Coool00`1Vooooooooo`08
oooo00<0003oooooool02?ooo`0306Kooooooooo05coool00ol0VOooooooo`0Toooo0025oooo00<0
I_ooooooool01oooo`800008oooo00<0I_ooooooool0GOooo`03o`2Ioooooooo02Coool008Koool0
0`1Vooooooooo`06oooo00<0003oooooool01_ooo`0306Kooooooooo05koool00ol0VOooooooo`0T
oooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool00`1Vooooooooo`1Ooooo00?o
09Woooooool09?ooo`00R?ooo`0306Kooooooooo00Coool00`000?ooooooo`04oooo00<0I_oooooo
ool0H?ooo`03o`2Ioooooooo02Coool008Ooool500000oooo`030000oooooooo00?oool00`1Voooo
ooooo`1Qoooo00?o09Woooooool09?ooo`00ROooo`03000006Kooooo00?oool00`000?ooooooo`02
oooo00<0I_ooooooool0H_ooo`03o`2Ioooooooo02Coool008Woool00`000?ooo`1Vo`03oooo0`00
0003oooo06Kooooo06Coool00ol0VOooooooo`0Toooo0029oooo00@0003oooooool0I_l2oooo00@0
003oooooool0I_mVoooo00?o09Woooooool09?ooo`00ROooo`090000oooooooooooo06Kooooo0000
oooo06Ko06Ooool00ol0VOooooooo`0Toooo0028oooo0P0000Coool00`1Vo`00001Vo`1Xoooo00?o
09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0
003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Wooooo
ool09?ooo`00Soooo`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool0
0ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool0
0`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOoo
ooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool20000J?oo
o`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Sooo
o`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2I
oooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`030000
oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo0P0006Soool00ol0VOooooooo`0Toooo002?
oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o
09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOooooooo`0Toooo002?oooo00<0
003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool00`000?ooooooo`1Woooo00?o09Wooooo
ool09?ooo`00Soooo`80001Xoooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool0
0ol0VOooooooo`0Toooo002?oooo00<0003oooooool0Ioooo`03o`2Ioooooooo02Coool008ooool0
0`000?ooooooo`1Woooo00?o09Woooooool09?ooo`00Soooo`030000oooooooo06Ooool00ol0VOoo
ooooo`0Toooo001koooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0Ioooo`03o`2I
oooooooo02Coool007goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003ooooo
ool0Ioooo`03o`2Ioooooooo02Coool007goool00`000?ooooooo`0:oooo00<0003oooooool00_oo
o`<0001Woooo00?o09Woooooool09?ooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOoo
o`030000oooooooo00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00oooo
ob7oool00?oooolQoooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool0
0`000?ooooooo`08oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo100000?oool200001?ooo`800004oooo00<0
003oooooool0Noooo`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0
003oooooool01Oooo`030000oooooooo00Woool010000?ooooooo`0000?oool00`000?ooooooo`1k
oooo001joooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`0;oooo00<0
003oooooool00_ooo`030000oooooooo07[oool007_oool00`000?ooooooo`0500003_ooo`030000
oooooooo00Soool200001?ooo`030000oooooooo07_oool007_oool01@000?ooooooooooo`00000?
oooo00@0003oooooool00009oooo00<0003oooooool00oooo`030000oooooooo07_oool007coool0
0`000?ooooooo`0Aoooo0P0000[oool300000_ooo`030000oooooooo07coool00?oooolQoooo003o
oooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.90802 .24721 L
.91765 .24721 L
.92014 .24721 L
.92136 .24721 L
.9225 .24721 L
s
.9225 .24721 m
.92269 .61803 L
s
0 .4 1 r
.02381 .24721 m
.04262 .24721 L
.06244 .24721 L
.06747 .24721 L
.07024 .24721 L
.07286 .24721 L
.07529 .24721 L
.07596 .24721 L
.07666 .24721 L
.07793 .37082 L
.07907 .37082 L
.08013 .37082 L
.08255 .37082 L
.10458 .37082 L
.14335 .37082 L
.18458 .37082 L
.22428 .37082 L
.26248 .37082 L
.28379 .37082 L
.30312 .37082 L
.30783 .37082 L
.3128 .37082 L
.31406 .37082 L
.31475 .37082 L
.3154 .37082 L
.31617 .37118 L
.31688 .37155 L
.31825 .37227 L
.32327 .37493 L
.34225 .38553 L
.38058 .40969 L
.42136 .44005 L
.46063 .47462 L
.48032 .49423 L
.48895 .50334 L
.49383 .50866 L
.49617 .51124 L
.49838 .5137 L
.49953 .51498 L
.50077 .51465 L
.5019 .51338 L
.50294 .51222 L
.50781 .50686 L
.51773 .49626 L
.53858 .47537 L
.57799 .44057 L
.61587 .41213 L
.63695 .39816 L
.65621 .38643 L
.66574 .38096 L
Mistroke
.67077 .37817 L
.67613 .37526 L
.67878 .37384 L
.68128 .37252 L
.68237 .37194 L
.68352 .37134 L
.68478 .24721 L
.68594 .24721 L
.69504 .24721 L
.73306 .24721 L
.77354 .24721 L
.8125 .24721 L
.85391 .24721 L
.89381 .24721 L
.93219 .24721 L
.97303 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.55) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool02oooo`0306Ko0000oooo00goool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooo`1Vo`0<oooo00<0003oooooool03?ooo`030000oooooooo
00goool00`000?ooooooo`0<oooo00<0003o09Woool03?ooo`030000oooooooo01Goool002Coool0
0`1Vooooooooo`1Xoooo00<0003oooooool0;?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0S
oooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo02coool00`1Vooooooooo`0ioooo00?o
09Woooooool08oooo`009?ooo`0306Kooooooooo06Soool00`000?ooooooo`0/oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo02?oool002Coool00`1Vooooooooo`1Xoooo00<0003oooooool0;?oo
o`0306Kooooooooo03Woool00ol0VOooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`80000]
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02?oool002Coool00`1Vooooooooo`1Xoooo00<0
003oooooool0;?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Soooo000Toooo00<0I_oooooo
ool0J?ooo`030000oooooooo02coool00`1Vooooooooo`0ioooo00?o09Woooooool08oooo`009?oo
o`0306Kooooooooo06Soool00`000?ooooooo`0/oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
02?oool002Coool00`1Vooooooooo`1Xoooo00<0003oooooool0;?ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo02coool00`1Voooo
ooooo`0ioooo00?o09Woooooool08oooo`009?ooo`0306Kooooooooo06Soool20000;Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo
02coool00`1Vooooooooo`0ioooo00?o09Woooooool08oooo`009?ooo`0306Kooooooooo06Soool0
0`000?ooooooo`0/oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02?oool002Coool00`1Voooo
ooooo`1Xoooo00<0003oooooool0;?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Soooo000T
oooo00<0I_ooooooool0J?ooo`030000oooooooo02coool00`1Vooooooooo`0ioooo00?o09Wooooo
ool08oooo`009?ooo`0306Kooooooooo06Soool00`000?ooooooo`0/oooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo02?oool002Coool00`1Vooooooooo`1Xoooo00<0003oooooool0;?ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`80000]oooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo02?oool002Coool00`1Vooooooooo`1Xoooo00<0003ooooo
ool0;?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Soooo000Toooo00<0I_ooooooool0J?oo
o`030000oooooooo02coool00`1Vooooooooo`0ioooo00?o09Woooooool08oooo`009?ooo`0306Ko
oooooooo06Soool00`000?ooooooo`0/oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02?oool0
02Coool00`1Vooooooooo`1Xoooo00<0003oooooool0;?ooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo02coool00`1Vooooooooo`0i
oooo00?o09Woooooool08oooo`009?ooo`0306Kooooooooo06Soool20000;Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0Soooo000Toooo00<0I_ooooooool0J?ooo`030000oooooooo02coool0
0`1Vooooooooo`0ioooo00?o09Woooooool08oooo`009?ooo`0306Kooooooooo06Soool00`000?oo
ooooo`0/oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo02?oool002Coool00`1Vooooooooo`1X
oooo00<0003oooooool0;?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Soooo000Toooo00<0
I_ooooooool0EOooo`800004oooo0P0000Coool200001Oooo`030000oooooooo02coool00`1Voooo
ooooo`0ioooo00?o09Woooooool08oooo`009?ooo`0306Kooooooooo05Coool010000?ooooooo`00
00Soool010000?ooooooo`0000Coool00`000?ooooooo`0/oooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo02?oool002Coooln06Ko6Oooo`040000oooooooo00002oooo`030000oooooooo00;oool3
0000:oooo`80I_lkoooo00?o09Woooooool08oooo`00H_ooo`0306Kooooooooo01Koool010000?oo
ooooo`0000Woool200001Oooo`030000oooooooo02[oool206Ko??ooo`03o`2Ioooooooo02?oool0
06?oool206Ko5_ooo`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0X
oooo0P1Vockoool00ol0VOooooooo`0Soooo001Uoooo0P1VoaGoool200002_ooo`<00004oooo00<0
003oooooool09oooo`0306Kooooooooo03koool00ol0VOooooooo`0Soooo001Woooo00<0I_oooooo
ool09Oooo`030000oooooooo02Goool206Ko@Oooo`03o`2Ioooooooo02?oool006Soool206Ko9Ooo
o`030000oooooooo02?oool206Ko@oooo`03o`2Ioooooooo02?oool006[oool206Ko8oooo`80000R
oooo0P1VodGoool00ol0VOooooooo`0Soooo001/oooo00<0I_ooooooool08?ooo`030000oooooooo
023oool00`1Vooooooooo`15oooo00?o09Woooooool08oooo`00KOooo`80I_lPoooo00<0003ooooo
ool07_ooo`80I_m8oooo00?o09Woooooool08oooo`00Koooo`80I_lNoooo00<0003oooooool07Ooo
o`0306Kooooooooo04Soool00ol0VOooooooo`0Soooo001aoooo00<0I_ooooooool06oooo`030000
oooooooo01_oool206KoBoooo`03o`2Ioooooooo02?oool007;oool00`1Vooooooooo`0Joooo00<0
003oooooool06_ooo`0306Kooooooooo04_oool00ol0VOooooooo`0Soooo001coooo0P1Voa[oool0
0`000?ooooooo`0Ioooo00<0I_ooooooool0C?ooo`03o`2Ioooooooo02?oool007Goool00`1Voooo
ooooo`0Goooo0P0001Soool206KoCoooo`03o`2Ioooooooo02?oool007Koool00`1Vooooooooo`0F
oooo00<0003oooooool05_ooo`0306Kooooooooo04ooool00ol0VOooooooo`0Soooo001goooo00<0
I_ooooooool05Oooo`030000oooooooo01Goool00`1Vooooooooo`1@oooo00?o09Woooooool08ooo
o`00N?ooo`80I_lEoooo00<0003oooooool04oooo`80I_mCoooo00?o09Woooooool08oooo`00N_oo
o`0306Kooooooooo01;oool00`000?ooooooo`0Boooo00<0I_ooooooool0Doooo`03o`2Ioooooooo
02?oool007_oool00`1Vooooooooo`0Aoooo00<0003oooooool04Oooo`0306Kooooooooo05Coool0
0ol0VOooooooo`0Soooo001loooo00<0I_ooooooool04?ooo`80000Aoooo00<0I_ooooooool0EOoo
o`03o`2Ioooooooo02?oool007goool206Ko4?ooo`030000oooooooo00ooool00`1Vooooooooo`1F
oooo00?o09Woooooool08oooo`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0>oooo00<0
I_ooooooool0Eoooo`03o`2Ioooooooo02?oool0083oool00`1Vooooooooo`0<oooo00<0003ooooo
ool03Oooo`0306Kooooooooo05Soool00ol0VOooooooo`0Soooo0021oooo00<0I_ooooooool02ooo
o`030000oooooooo00_oool206KoFoooo`03o`2Ioooooooo02?oool008;oool206Ko2oooo`030000
oooooooo00[oool00`1Vooooooooo`1Koooo00?o09Woooooool08oooo`00Q?ooo`0306Kooooooooo
00Soool200002_ooo`0306Kooooooooo05coool00ol0VOooooooo`0Soooo0025oooo00<0I_oooooo
ool01oooo`030000oooooooo00Soool00`1Vooooooooo`1Moooo00?o09Woooooool08oooo`00Q_oo
o`0306Kooooooooo00Koool00`000?ooooooo`07oooo00<0I_ooooooool0G_ooo`03o`2Ioooooooo
02?oool008Ooool00`1Vooooooooo`05oooo00<0003oooooool01_ooo`0306Kooooooooo05ooool0
0ol0VOooooooo`0Soooo0027oooo1@0000?oool00`000?ooooooo`05oooo00<0I_ooooooool0H?oo
o`03o`2Ioooooooo02?oool008Woool00`000?ooooooo`03oooo00<0003oooooool00oooo`80I_mS
oooo00?o09Woooooool08oooo`00ROooo`03000006Kooooo00?oool300000_ooo`0306Kooooooooo
06?oool00ol0VOooooooo`0Soooo0029oooo00<0003oool0I_l00oooo`050000oooooooooooo06Ko
06Koool00ol0VOooooooo`0Soooo0029oooo00<0003oool0I_l00oooo`040000oooooooo06KoIooo
o`03o`2Ioooooooo02?oool008Soool200000_ooo`0406Kooooooooo00000_ooo`0306Kooooooooo
06Goool00ol0VOooooooo`0Soooo002=oooo00D0I_ooool0003oool0I_l0J?ooo`03o`2Ioooooooo
02?oool008koool00`1Vo`00001Vo`1Yoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo
06Soool00ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?oooo00<0
003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Wooooo
ool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08ooo
o`00Soooo`80001Yoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOoo
ooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?oo
ooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0S
oooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool20000JOooo`03o`2I
oooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000
oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0003oooooool0J?ooo`03o`2Ioooooooo
02?oool008ooool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00Soooo`030000oooooooo
06Soool00ol0VOooooooo`0Soooo002?oooo0P0006Woool00ol0VOooooooo`0Soooo002?oooo00<0
003oooooool0J?ooo`03o`2Ioooooooo02?oool008ooool00`000?ooooooo`1Xoooo00?o09Wooooo
ool08oooo`00Soooo`030000oooooooo06Soool00ol0VOooooooo`0Soooo002?oooo00<0003ooooo
ool0J?ooo`03o`2Ioooooooo02?oool007_oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`1Xoooo00?o09Woooooool08oooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`1Xoooo00?o09Woooooool08oooo`00OOooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`0006Soool00ol0VOooooooo`0Soooo001moooo00<0003oooooool02?oo
o`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003ooooo
ool0NOooo`00N?ooo`030000oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?oo
o`00N?ooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004
oooo0P0000Coool200001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002
oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003ooooo
ool00002oooo00@0003oooooool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo
00;oool00`000?ooooooo`0>oooo00<0003oooooool02oooo`030000oooooooo00?oool00`000?oo
ooooo`02oooo00<0003oooooool0Moooo`00N?ooo`030000oooooooo00D0000>oooo00<0003ooooo
ool02?ooo`800004oooo0P0000Coool00`000?ooooooo`1hoooo001hoooo00D0003oooooooooool0
00003oooo`040000oooooooo00002Oooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0
003oooooool0N?ooo`00NOooo`030000oooooooo017oool200002_ooo`<00003oooo0`0000;oool0
0`000?ooooooo`1ioooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.91765 .24721 L
.9225 .24721 L
.92516 .24721 L
.92648 .24721 L
.92769 .24721 L
.92838 .24721 L
s
.92838 .24721 m
.9285 .61803 L
s
0 .4 1 r
.02381 .24721 m
.04262 .24721 L
.0522 .24721 L
.06244 .24721 L
.06525 .24721 L
.0679 .24721 L
.06905 .24721 L
.07027 .24721 L
.07091 .24721 L
.07162 .37082 L
.07286 .37082 L
.08255 .37082 L
.10458 .37082 L
.14487 .37082 L
.18364 .37082 L
.22486 .37082 L
.26457 .37082 L
.2846 .37082 L
.29333 .37082 L
.30277 .37082 L
.30533 .37082 L
.30673 .37082 L
.30804 .37082 L
.30916 .37082 L
.31036 .37125 L
.31104 .37161 L
.31168 .37195 L
.3129 .37258 L
.32244 .37771 L
.34341 .38973 L
.38174 .41462 L
.42252 .44589 L
.46179 .48152 L
.48148 .50172 L
.49011 .51111 L
.49499 .51658 L
.49733 .51924 L
.49848 .52056 L
.49954 .52177 L
.50068 .52152 L
.50193 .52009 L
.5041 .51761 L
.50896 .51214 L
.51889 .50133 L
.53974 .48002 L
.57915 .44451 L
.61703 .41548 L
.63811 .40123 L
.65737 .38926 L
.6669 .38369 L
Mistroke
.67729 .37786 L
.68204 .37528 L
.68465 .37388 L
.6871 .37259 L
.68822 .372 L
.68939 .37138 L
.69069 .24721 L
.69187 .24721 L
.6962 .24721 L
.73422 .24721 L
.7747 .24721 L
.81366 .24721 L
.85507 .24721 L
.89497 .24721 L
.93335 .24721 L
.97418 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool02Oooo`0406Kooooooooo00003_ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`040000oooooooo06Ko2oooo`030000oooooooo00coool00`000?oo
ooooo`0=oooo00<0003oooooool03?ooo`040000ooooooooo`2I2oooo`030000oooooooo01Goool0
02;oool00`1Vooooooooo`1Zoooo00<0003oooooool0;Oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0Qoooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo02goool00`1Vooooooooo`0j
oooo00?o09Woooooool08Oooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`0]oooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo027oool002;oool00`1Vooooooooo`1Zoooo00<0003ooooo
ool0;Oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Qoooo000Roooo00<0I_ooooooool0J_oo
o`80000^oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo027oool002;oool00`1Vooooooooo`1Z
oooo00<0003oooooool0;Oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Qoooo000Roooo00<0
I_ooooooool0J_ooo`030000oooooooo02goool00`1Vooooooooo`0joooo00?o09Woooooool08Ooo
o`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`0]oooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo027oool002;oool00`1Vooooooooo`1Zoooo00<0003oooooool0;Oooo`0306Kooooooooo
03[oool00ol0VOooooooo`0Qoooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo02goool0
0`1Vooooooooo`0joooo00?o09Woooooool08Oooo`008_ooo`0306Kooooooooo06[oool20000;_oo
o`0306Kooooooooo03[oool00ol0VOooooooo`0Qoooo000Roooo00<0I_ooooooool0J_ooo`030000
oooooooo02goool00`1Vooooooooo`0joooo00?o09Woooooool08Oooo`008_ooo`0306Kooooooooo
06[oool00`000?ooooooo`0]oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo027oool002;oool0
0`1Vooooooooo`1Zoooo00<0003oooooool0;Oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Q
oooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo02goool00`1Vooooooooo`0joooo00?o
09Woooooool08Oooo`008_ooo`0306Kooooooooo06[oool00`000?ooooooo`0]oooo00<0I_oooooo
ool0>_ooo`03o`2Ioooooooo027oool002;oool00`1Vooooooooo`1Zoooo00<0003oooooool0;Ooo
o`0306Kooooooooo03[oool00ol0VOooooooo`0Qoooo000Roooo00<0I_ooooooool0J_ooo`80000^
oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo027oool002;oool00`1Vooooooooo`1Zoooo00<0
003oooooool0;Oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Qoooo000Roooo00<0I_oooooo
ool0J_ooo`030000oooooooo02goool00`1Vooooooooo`0joooo00?o09Woooooool08Oooo`008_oo
o`0306Kooooooooo06[oool00`000?ooooooo`0]oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
027oool002;oool00`1Vooooooooo`1Zoooo00<0003oooooool0;Oooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Qoooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo02goool00`1Voooo
ooooo`0joooo00?o09Woooooool08Oooo`008_ooo`0306Kooooooooo06[oool20000;_ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Qoooo000Roooo00<0I_ooooooool0J_ooo`030000oooooooo
02goool00`1Vooooooooo`0joooo00?o09Woooooool08Oooo`008_ooo`0306Kooooooooo06[oool0
0`000?ooooooo`0]oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo027oool002;oool00`1Voooo
ooooo`1Zoooo00<0003oooooool0;Oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Qoooo000R
oooo00<0I_ooooooool0Eoooo`800004oooo0P0000Coool200001Oooo`030000oooooooo02goool0
0`1Vooooooooo`0joooo00?o09Woooooool08Oooo`008_ooo`0306Kooooooooo05Koool010000?oo
ooooo`0000Soool010000?ooooooo`0000Coool00`000?ooooooo`0]oooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo027oool002;oooln06Ko6oooo`040000oooooooo00002oooo`030000oooooooo
00;oool30000;Oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Qoooo001Poooo00<0I_oooooo
ool06?ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0:oooo`80I_lmoooo00?o
09Woooooool08Oooo`00HOooo`80I_lHoooo00@0003oooooool00009oooo00<0003oooooool01?oo
o`030000oooooooo02Woool206Ko?oooo`03o`2Ioooooooo027oool006?oool206Ko5oooo`80000:
oooo0`0000Coool00`000?ooooooo`0Woooo0P1Vod7oool00ol0VOooooooo`0Qoooo001Uoooo0P1V
obSoool00`000?ooooooo`0Voooo00<0I_ooooooool0@Oooo`03o`2Ioooooooo027oool006Ooool0
0`1Vooooooooo`0Uoooo00<0003oooooool09Oooo`0306Kooooooooo04;oool00ol0VOooooooo`0Q
oooo001Xoooo0P1VobGoool200009?ooo`80I_m5oooo00?o09Woooooool08Oooo`00J_ooo`80I_lS
oooo00<0003oooooool08Oooo`80I_m7oooo00?o09Woooooool08Oooo`00K?ooo`0306Kooooooooo
023oool00`000?ooooooo`0Poooo00<0I_ooooooool0Aoooo`03o`2Ioooooooo027oool006goool2
06Ko8?ooo`030000oooooooo01koool206KoB_ooo`03o`2Ioooooooo027oool006ooool206Ko7_oo
o`030000oooooooo01coool206KoC?ooo`03o`2Ioooooooo027oool0077oool00`1Vooooooooo`0K
oooo00<0003oooooool06oooo`0306Kooooooooo04coool00ol0VOooooooo`0Qoooo001boooo00<0
I_ooooooool06_ooo`030000oooooooo01[oool00`1Vooooooooo`1=oooo00?o09Woooooool08Ooo
o`00Loooo`80I_lJoooo0P0001Woool206KoD?ooo`03o`2Ioooooooo027oool007Goool00`1Voooo
ooooo`0Goooo00<0003oooooool05oooo`0306Kooooooooo053oool00ol0VOooooooo`0Qoooo001f
oooo00<0I_ooooooool05_ooo`030000oooooooo01Koool00`1Vooooooooo`1Aoooo00?o09Wooooo
ool08Oooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Eoooo00<0I_ooooooool0D_oo
o`03o`2Ioooooooo027oool007Soool206Ko5Oooo`030000oooooooo01?oool206KoEOooo`03o`2I
oooooooo027oool007[oool00`1Vooooooooo`0Boooo00<0003oooooool04_ooo`0306Kooooooooo
05Goool00ol0VOooooooo`0Qoooo001koooo00<0I_ooooooool04Oooo`80000Boooo00<0I_oooooo
ool0E_ooo`03o`2Ioooooooo027oool007coool00`1Vooooooooo`0@oooo00<0003oooooool04?oo
o`0306Kooooooooo05Ooool00ol0VOooooooo`0Qoooo001moooo00<0I_ooooooool03oooo`030000
oooooooo00ooool00`1Vooooooooo`1Hoooo00?o09Woooooool08Oooo`00O_ooo`0306Kooooooooo
00koool00`000?ooooooo`0>oooo00<0I_ooooooool0FOooo`03o`2Ioooooooo027oool007ooool0
0`1Vooooooooo`0=oooo00<0003oooooool03Oooo`0306Kooooooooo05[oool00ol0VOooooooo`0Q
oooo0020oooo0P1Vo`goool00`000?ooooooo`0;oooo0P1Voegoool00ol0VOooooooo`0Qoooo0022
oooo00<0I_ooooooool02_ooo`80000;oooo00<0I_ooooooool0GOooo`03o`2Ioooooooo027oool0
08?oool00`1Vooooooooo`09oooo00<0003oooooool02Oooo`0306Kooooooooo05koool00ol0VOoo
ooooo`0Qoooo0024oooo00<0I_ooooooool02?ooo`030000oooooooo00Soool00`1Vooooooooo`1O
oooo00?o09Woooooool08Oooo`00QOooo`0306Kooooooooo00Ooool00`000?ooooooo`07oooo00<0
I_ooooooool0H?ooo`03o`2Ioooooooo027oool008Koool00`1Vo`000000000300000oooo`030000
oooooooo00Koool00`1Vooooooooo`1Qoooo00?o09Woooooool08Oooo`00Qoooo`0306Kooooo0000
00Goool00`000?ooooooo`05oooo00<0I_ooooooool0H_ooo`03o`2Ioooooooo027oool008Soool0
0`1Vo`000?ooo`04oooo0`0000Coool00`1Vooooooooo`1Soooo00?o09Woooooool08Oooo`00ROoo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0I_ooooooool0I?ooo`03o`2Ioooooooo
027oool008Woool00`00001Vooooo`03oooo00<0003oooooool00_ooo`0306Kooooooooo06Goool0
0ol0VOooooooo`0Qoooo0028oooo0P000003oooo06Kooooo00;oool01@000?ooooooooooo`1Vo`1X
oooo00?o09Woooooool08Oooo`00Roooo`0506Kooooooooooooo000000;oool00`1Vooooooooo`1W
oooo00?o09Woooooool08Oooo`00S?ooo`0606Kooooooooo0000oooo06KoJ_ooo`03o`2Ioooooooo
027oool008goool206Ko00<00000I_ooool0J_ooo`03o`2Ioooooooo027oool008koool00`1Vo`00
0000001[oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Q
oooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?
oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool20000Joooo`03o`2Ioooooooo
027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo
06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool0
08ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool0
0ol0VOooooooo`0Qoooo002?oooo0P0006_oool00ol0VOooooooo`0Qoooo002?oooo00<0003ooooo
ool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Ooo
o`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo002?oooo00<0003oooooool0J_oo
o`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Zoooo00?o09Woooooool08Oooo`00Sooo
o`80001[oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Q
oooo002?oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool008ooool00`000?ooooooo`1Z
oooo00?o09Woooooool08Oooo`00Soooo`030000oooooooo06[oool00ol0VOooooooo`0Qoooo001k
oooo1@0000;oool200001?ooo`800005oooo00<0003oooooool0J_ooo`03o`2Ioooooooo027oool0
07goool00`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0J_ooo`03o`2I
oooooooo027oool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0001Zoooo00?o
09Woooooool08Oooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo
00Soool00`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQ
oooo001loooo00<0003oooooool08_ooo`030000oooooooo07coool007_oool00`000?ooooooo`08
oooo00<0003oooooool06Oooo`030000oooooooo07_oool007_oool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`06oooo100000?oool200000oooo`<00004oooo00<0003oooooool0Nooo
o`00Noooo`050000oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`030000oooooooo00Woool010000?ooooooo`0000?oool00`000?ooooooo`1koooo001joooo00<0
003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`08oooo00@0003oooooool00004
oooo00<0003oooooool0N_ooo`00Noooo`030000oooooooo00D0000>oooo00<0003oooooool01ooo
o`<00004oooo00<0003oooooool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?oo
ooooo`0000Woool00`000?ooooooo`03oooo00<0003oooooool0Noooo`00O?ooo`030000oooooooo
017oool200002_ooo`<00002oooo00<0003oooooool0O?ooo`00ooooob7oool00?oooolQoooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.91765 .24721 L
.92769 .24721 L
.93044 .24721 L
.93196 .24721 L
.9327 .24721 L
.93339 .24721 L
.93404 .24721 L
s
.93404 .24721 m
.93414 .61803 L
s
0 .4 1 r
.02381 .24721 m
.04262 .24721 L
.0522 .24721 L
.05746 .24721 L
.06244 .24721 L
.06371 .24721 L
.06441 .24721 L
.06506 .24721 L
.06576 .37082 L
.06653 .37082 L
.0679 .37082 L
.07286 .37082 L
.08255 .37082 L
.10458 .37082 L
.14335 .37082 L
.18458 .37082 L
.22428 .37082 L
.26248 .37082 L
.28379 .37082 L
.29386 .37082 L
.29828 .37082 L
.30078 .37082 L
.30201 .37082 L
.30312 .37082 L
.30429 .37119 L
.30539 .37177 L
.30783 .37305 L
.3128 .37571 L
.32327 .38148 L
.34225 .39262 L
.38058 .41802 L
.42136 .44994 L
.46063 .48628 L
.48032 .5069 L
.48895 .51648 L
.49383 .52206 L
.49617 .52477 L
.49838 .52736 L
.49953 .52871 L
.50077 .52836 L
.5019 .52703 L
.50294 .52581 L
.50781 .52017 L
.51773 .50903 L
.53858 .48707 L
.57799 .45049 L
.61587 .42058 L
.65621 .39356 L
.67479 .38258 L
.6846 .37712 L
Mistroke
.68998 .37422 L
.69261 .37282 L
.69504 .37154 L
.69574 .37118 L
.69639 .37084 L
.69707 .24721 L
.69781 .24721 L
.7008 .24721 L
.70603 .24721 L
.71621 .24721 L
.73632 .24721 L
.77528 .24721 L
.81669 .24721 L
.85659 .24721 L
.89497 .24721 L
.9358 .24721 L
.97512 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.65) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool02?ooo`0506Kooooooooooooo000000koool0
0`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003ooooo
ool03?ooo`030000oooooooo00coool00`000?ooooooo`02oooo00<0I_ooooooool01oooo`030000
oooooooo00coool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`050000ooooooooooooo`2I
00[oool00`000?ooooooo`0Eoooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo02ooool0
0`1Vooooooooo`0ioooo00?o09Woooooool08?ooo`008Oooo`0306Kooooooooo06_oool00`000?oo
ooooo`0_oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo023oool0027oool00`1Vooooooooo`1[
oooo00<0003oooooool0;oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Poooo000Qoooo00<0
I_ooooooool0Joooo`030000oooooooo02ooool00`1Vooooooooo`0ioooo00?o09Woooooool08?oo
o`008Oooo`0306Kooooooooo06_oool20000<?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0P
oooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo02ooool00`1Vooooooooo`0ioooo00?o
09Woooooool08?ooo`008Oooo`0306Kooooooooo06_oool00`000?ooooooo`0_oooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo023oool0027oool00`1Vooooooooo`1[oooo00<0003oooooool0;ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0Poooo000Qoooo00<0I_ooooooool0Joooo`030000
oooooooo02ooool00`1Vooooooooo`0ioooo00?o09Woooooool08?ooo`008Oooo`0306Kooooooooo
06_oool00`000?ooooooo`0_oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo023oool0027oool0
0`1Vooooooooo`1[oooo0P00033oool00`1Vooooooooo`0ioooo00?o09Woooooool08?ooo`008Ooo
o`0306Kooooooooo06_oool00`000?ooooooo`0_oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
023oool0027oool00`1Vooooooooo`1[oooo00<0003oooooool0;oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Poooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo02ooool00`1Voooo
ooooo`0ioooo00?o09Woooooool08?ooo`008Oooo`0306Kooooooooo06_oool00`000?ooooooo`0_
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo023oool0027oool00`1Vooooooooo`1[oooo00<0
003oooooool0;oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Poooo000Qoooo00<0I_oooooo
ool0Joooo`030000oooooooo02ooool00`1Vooooooooo`0ioooo00?o09Woooooool08?ooo`008Ooo
o`0306Kooooooooo06_oool20000<?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Poooo000Q
oooo00<0I_ooooooool0Joooo`030000oooooooo02ooool00`1Vooooooooo`0ioooo00?o09Wooooo
ool08?ooo`008Oooo`0306Kooooooooo06_oool00`000?ooooooo`0_oooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo023oool0027oool00`1Vooooooooo`1[oooo00<0003oooooool0;oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Poooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo
02ooool00`1Vooooooooo`0ioooo00?o09Woooooool08?ooo`008Oooo`0306Kooooooooo06_oool0
0`000?ooooooo`0_oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo023oool0027oool00`1Voooo
ooooo`1[oooo0P00033oool00`1Vooooooooo`0ioooo00?o09Woooooool08?ooo`008Oooo`0306Ko
oooooooo06_oool00`000?ooooooo`0_oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo023oool0
027oool00`1Vooooooooo`1[oooo00<0003oooooool0;oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0Poooo000Qoooo00<0I_ooooooool0Joooo`030000oooooooo02ooool00`1Vooooooooo`0i
oooo00?o09Woooooool08?ooo`008Oooo`0306Kooooooooo05Soool200001?ooo`800004oooo0P00
00Goool00`000?ooooooo`0_oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo023oool0027oool0
0`1Vooooooooo`1Goooo00@0003oooooool00008oooo00@0003oooooool00004oooo00<0003ooooo
ool0;oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Poooo000Qoooo?P1Voacoool010000?oo
ooooo`0000_oool00`000?ooooooo`02oooo0`0002koool206Ko>oooo`03o`2Ioooooooo023oool0
05koool306Ko6_ooo`040000oooooooo00002Oooo`800005oooo00<0003oooooool0;Oooo`80I_ll
oooo00?o09Woooooool08?ooo`00HOooo`0306Kooooooooo01Ooool010000?ooooooo`0000Woool0
0`000?ooooooo`04oooo00<0003oooooool0:oooo`80I_lnoooo00?o09Woooooool08?ooo`00H_oo
o`0306Kooooooooo01Ooool200002_ooo`<00004oooo00<0003oooooool0:Oooo`80I_m0oooo00?o
09Woooooool08?ooo`00Hoooo`80I_lZoooo00<0003oooooool0:?ooo`0306Kooooooooo043oool0
0ol0VOooooooo`0Poooo001Uoooo0P1VobSoool00`000?ooooooo`0Voooo0P1Vod?oool00ol0VOoo
ooooo`0Poooo001Woooo00<0I_ooooooool09Oooo`80000Voooo00<0I_ooooooool0@oooo`03o`2I
oooooooo023oool006Soool206Ko9Oooo`030000oooooooo02?oool206KoA_ooo`03o`2Ioooooooo
023oool006[oool206Ko8oooo`030000oooooooo02;oool00`1Vooooooooo`16oooo00?o09Wooooo
ool08?ooo`00K?ooo`0306Kooooooooo023oool00`000?ooooooo`0Poooo0P1VodWoool00ol0VOoo
ooooo`0Poooo001]oooo0P1Vob3oool00`000?ooooooo`0Noooo0P1Vod_oool00ol0VOooooooo`0P
oooo001_oooo0P1Voakoool00`000?ooooooo`0Moooo00<0I_ooooooool0Boooo`03o`2Ioooooooo
023oool0077oool00`1Vooooooooo`0Koooo00<0003oooooool06oooo`80I_m>oooo00?o09Wooooo
ool08?ooo`00L_ooo`0306Kooooooooo01[oool200006oooo`0306Kooooooooo04koool00ol0VOoo
ooooo`0Poooo001coooo0P1Voa[oool00`000?ooooooo`0Ioooo00<0I_ooooooool0Coooo`03o`2I
oooooooo023oool007Goool00`1Vooooooooo`0Goooo00<0003oooooool05oooo`80I_mBoooo00?o
09Woooooool08?ooo`00M_ooo`0306Kooooooooo01Koool00`000?ooooooo`0Foooo00<0I_oooooo
ool0D_ooo`03o`2Ioooooooo023oool007Ooool00`1Vooooooooo`0Eoooo00<0003oooooool05Ooo
o`0306Kooooooooo05?oool00ol0VOooooooo`0Poooo001hoooo0P1VoaGoool00`000?ooooooo`0C
oooo0P1VoeKoool00ol0VOooooooo`0Poooo001joooo00<0I_ooooooool04_ooo`80000Coooo00<0
I_ooooooool0E_ooo`03o`2Ioooooooo023oool007_oool00`1Vooooooooo`0Aoooo00<0003ooooo
ool04Oooo`0306Kooooooooo05Ooool00ol0VOooooooo`0Poooo001loooo00<0I_ooooooool04?oo
o`030000oooooooo013oool00`1Vooooooooo`1Hoooo00?o09Woooooool08?ooo`00OOooo`0306Ko
oooooooo00ooool00`000?ooooooo`0?oooo00<0I_ooooooool0FOooo`03o`2Ioooooooo023oool0
07koool00`1Vooooooooo`0>oooo00<0003oooooool03_ooo`0306Kooooooooo05[oool00ol0VOoo
ooooo`0Poooo001ooooo00<0I_ooooooool03Oooo`030000oooooooo00goool00`1Vooooooooo`1K
oooo00?o09Woooooool08?ooo`00P?ooo`80I_l=oooo0P0000goool00`1Vooooooooo`1Loooo00?o
09Woooooool08?ooo`00P_ooo`0306Kooooooooo00[oool00`000?ooooooo`0;oooo00<0I_oooooo
ool0GOooo`03o`2Ioooooooo023oool008?oool00`1Vooooooooo`09oooo00<0003oooooool02_oo
o`0306Kooooooooo05koool00ol0VOooooooo`0Poooo0024oooo00<0I_ooooooool02?ooo`030000
oooooooo00Woool00`1Vooooooooo`1Ooooo00?o09Woooooool08?ooo`00QOooo`0306Kooooo0000
00@00003oooo00<0003oooooool02?ooo`0306Kooooooooo063oool00ol0VOooooooo`0Poooo0026
oooo00@0I_ooooooool00005oooo00<0003oooooool01oooo`0306Kooooooooo067oool00ol0VOoo
ooooo`0Poooo0027oooo00<0I_ooool000001Oooo`<00006oooo00<0I_ooooooool0H_ooo`03o`2I
oooooooo023oool008Ooool00`1Vooooo`000005oooo00<0003oooooool01Oooo`0306Kooooooooo
06?oool00ol0VOooooooo`0Poooo0028oooo00<0I_l0003oool01?ooo`030000oooooooo00?oool2
06KoI_ooo`03o`2Ioooooooo023oool008Soool200001Oooo`030000oooooooo00;oool00`1Voooo
ooooo`1Voooo00?o09Woooooool08?ooo`00R_ooo`0306Kooooooooo00;oool01@000?oooooooooo
o`1Vo`1Yoooo00?o09Woooooool08?ooo`00Roooo`0506Kooooooooooooo000000;oool00`1Voooo
ooooo`1Xoooo00?o09Woooooool08?ooo`00S?ooo`0406Kooooooooo00000_ooo`0306Kooooooooo
06Soool00ol0VOooooooo`0Poooo002=oooo00D0I_ooool000000000I_l0Joooo`03o`2Ioooooooo
023oool008koool00`1Vo`00001Vo`1/oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo
06_oool00ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool0
08ooool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool0
0ol0VOooooooo`0Poooo002?oooo0P0006coool00ol0VOooooooo`0Poooo002?oooo00<0003ooooo
ool0Joooo`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[oooo00?o09Woooooool08?oo
o`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Jooo
o`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Sooo
o`80001/oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0P
oooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool008ooool00`000?ooooooo`1[
oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo002?
oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool008ooool20000K?ooo`03o`2Ioooooooo
023oool008ooool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Soooo`030000oooooooo
06_oool00ol0VOooooooo`0Poooo002?oooo00<0003oooooool0Joooo`03o`2Ioooooooo023oool0
08ooool00`000?ooooooo`1[oooo00?o09Woooooool08?ooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo001moooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo06_oool00ol0VOooooooo`0Poooo001moooo00<0
003oooooool02_ooo`030000oooooooo00;oool30000Joooo`03o`2Ioooooooo023oool007goool0
0`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00NOooo`030000oooooooo
02Soool00`000?ooooooo`1ioooo001hoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`1hoooo001hoooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`@00003oooo0P0000?oool300001?ooo`800004oooo00<0003oooooool0N?ooo`00N?ooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00Woool010000?ooooooo`0000;oool010000?ooooooo`0000?oool00`000?ooooooo`1hoooo001g
oooo00<0003oooooool00_ooo`030000oooooooo00koool00`000?ooooooo`08oooo00@0003ooooo
ool00005oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool00`000?ooooooo`05
00003_ooo`030000oooooooo00Ooool300001?ooo`800004oooo00<0003oooooool0N?ooo`00N?oo
o`050000oooooooooooo000000ooool010000?ooooooo`0000Woool00`000?ooooooo`03oooo00<0
003oooooool00oooo`030000oooooooo07Soool007Woool00`000?ooooooo`0Aoooo0P0000[oool3
00000oooo`<00002oooo00<0003oooooool0NOooo`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.91726 .24721 L
.92761 .24721 L
.93331 .24721 L
.93612 .24721 L
.93735 .24721 L
.93871 .24721 L
.93993 .24721 L
s
.93993 .24721 m
.9401 .61803 L
s
0 .4 1 r
.02381 .24721 m
.03279 .24721 L
.04262 .24721 L
.04758 .24721 L
.05288 .24721 L
.05546 .24721 L
.05672 .24721 L
.05789 .24721 L
.05895 .24721 L
.06007 .37082 L
.0612 .37082 L
.06244 .37082 L
.10458 .37082 L
.14487 .37082 L
.18364 .37082 L
.22486 .37082 L
.24546 .37082 L
.26457 .37082 L
.28306 .37082 L
.28838 .37082 L
.29099 .37082 L
.29339 .37082 L
.29558 .37082 L
.29669 .37082 L
.2979 .37096 L
.29911 .3716 L
.30041 .37228 L
.30277 .37352 L
.34413 .39748 L
.38397 .42486 L
.4223 .45589 L
.46308 .49487 L
.48334 .51686 L
.48817 .52239 L
.49326 .52833 L
.4976 .53351 L
.49879 .53494 L
.50006 .53634 L
.50126 .53488 L
.50235 .53357 L
.52052 .51253 L
.5401 .49158 L
.58008 .45381 L
.61855 .42299 L
.65947 .39523 L
.67982 .3831 L
.68978 .37754 L
.6945 .37498 L
.69887 .37266 L
.70104 .37152 L
Mistroke
.70225 .37089 L
.70335 .24721 L
.70456 .24721 L
.70587 .24721 L
.70824 .24721 L
.71714 .24721 L
.73676 .24721 L
.77781 .24721 L
.81735 .24721 L
.85538 .24721 L
.89585 .24721 L
.93481 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.7) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool01_ooo`0306Kooooooooo00?oool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool01?ooo`0306Kooooooooo
00Goool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`03oooo00?o09Woooooool01_ooo`030000oooooooo01Goool001ooool00`1Vooooooooo`1]
oooo00<0003oooooool0<Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Noooo000Ooooo00<0
I_ooooooool0KOooo`030000oooooooo037oool00`1Vooooooooo`0ioooo00?o09Woooooool07_oo
o`007oooo`0306Kooooooooo06goool00`000?ooooooo`0aoooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo01koool001ooool00`1Vooooooooo`1]oooo00<0003oooooool0<Oooo`0306Kooooooooo
03Woool00ol0VOooooooo`0Noooo000Ooooo00<0I_ooooooool0KOooo`80000boooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo01koool001ooool00`1Vooooooooo`1]oooo00<0003oooooool0<Ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0Noooo000Ooooo00<0I_ooooooool0KOooo`030000
oooooooo037oool00`1Vooooooooo`0ioooo00?o09Woooooool07_ooo`007oooo`0306Kooooooooo
06goool00`000?ooooooo`0aoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01koool001ooool0
0`1Vooooooooo`1]oooo00<0003oooooool0<Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0N
oooo000Ooooo00<0I_ooooooool0KOooo`030000oooooooo037oool00`1Vooooooooo`0ioooo00?o
09Woooooool07_ooo`007oooo`0306Kooooooooo06goool20000<_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Noooo000Ooooo00<0I_ooooooool0KOooo`030000oooooooo037oool00`1Voooo
ooooo`0ioooo00?o09Woooooool07_ooo`007oooo`0306Kooooooooo06goool00`000?ooooooo`0a
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01koool001ooool00`1Vooooooooo`1]oooo00<0
003oooooool0<Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Noooo000Ooooo00<0I_oooooo
ool0KOooo`030000oooooooo033oool00`1Vooooooooo`0joooo00?o09Woooooool07_ooo`007ooo
o`0306Kooooooooo06goool00`000?ooooooo`0`oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
01koool001ooool00`1Vooooooooo`1]oooo00<0003oooooool0<?ooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Noooo000Ooooo00<0I_ooooooool0KOooo`80000aoooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo01koool001ooool00`1Vooooooooo`1]oooo00<0003oooooool0<?ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Noooo000Ooooo00<0I_ooooooool0KOooo`030000oooooooo
033oool00`1Vooooooooo`0joooo00?o09Woooooool07_ooo`007oooo`0306Kooooooooo06goool0
0`000?ooooooo`0`oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo01koool001ooool00`1Voooo
ooooo`1]oooo00<0003oooooool0<?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Noooo000O
oooo00<0I_ooooooool0KOooo`030000oooooooo033oool00`1Vooooooooo`0joooo00?o09Wooooo
ool07_ooo`007oooo`0306Kooooooooo06goool20000<Oooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0Noooo000Ooooo00<0I_ooooooool0KOooo`030000oooooooo033oool00`1Vooooooooo`0j
oooo00?o09Woooooool07_ooo`007oooo`0306Kooooooooo06goool00`000?ooooooo`0`oooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo01koool001ooool00`1Vooooooooo`1]oooo00<0003ooooo
ool0<?ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Noooo000Ooooo00<0I_ooooooool0F_oo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo033oool00`1Vooooooooo`0joooo00?o
09Woooooool07_ooo`007oooo`0306Kooooooooo05Woool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0`oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo01koool0
01ooooln06Ko7_ooo`040000oooooooo00002oooo`030000oooooooo00;oool30000<?ooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Noooo001Moooo00<0I_ooooooool06oooo`040000oooooooo
00002Oooo`800005oooo00<0003oooooool0;_ooo`80I_lmoooo00?o09Woooooool07_ooo`00G_oo
o`80I_lKoooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo02goool0
0`1Vooooooooo`0moooo00?o09Woooooool07_ooo`00H?ooo`80I_lJoooo0P0000[oool300001?oo
o`030000oooooooo02_oool206Ko@?ooo`03o`2Ioooooooo01koool006;oool00`1Vooooooooo`0Z
oooo00<0003oooooool0:Oooo`80I_m2oooo00?o09Woooooool07_ooo`00Hoooo`80I_lZoooo00<0
003oooooool09oooo`80I_m4oooo00?o09Woooooool07_ooo`00IOooo`80I_lXoooo0P0002Koool2
06KoA_ooo`03o`2Ioooooooo01koool006Ooool00`1Vooooooooo`0Uoooo00<0003oooooool08ooo
o`80I_m8oooo00?o09Woooooool07_ooo`00J?ooo`80I_lUoooo00<0003oooooool08_ooo`0306Ko
oooooooo04Soool00ol0VOooooooo`0Noooo001Zoooo00<0I_ooooooool08_ooo`030000oooooooo
027oool00`1Vooooooooo`19oooo00?o09Woooooool07_ooo`00Joooo`80I_lRoooo00<0003ooooo
ool07oooo`80I_m<oooo00?o09Woooooool07_ooo`00KOooo`80I_lPoooo00<0003oooooool07_oo
o`0306Kooooooooo04coool00ol0VOooooooo`0Noooo001_oooo00<0I_ooooooool07Oooo`030000
oooooooo01coool206KoCoooo`03o`2Ioooooooo01koool0073oool206Ko7Oooo`80000Loooo00<0
I_ooooooool0Coooo`03o`2Ioooooooo01koool007;oool00`1Vooooooooo`0Joooo00<0003ooooo
ool06_ooo`0306Kooooooooo053oool00ol0VOooooooo`0Noooo001coooo00<0I_ooooooool06Ooo
o`030000oooooooo01Soool206KoDoooo`03o`2Ioooooooo01koool007Coool00`1Vooooooooo`0H
oooo00<0003oooooool05oooo`0306Kooooooooo05?oool00ol0VOooooooo`0Noooo001eoooo00<0
I_ooooooool05oooo`030000oooooooo01Koool00`1Vooooooooo`1Doooo00?o09Woooooool07_oo
o`00M_ooo`80I_lGoooo00<0003oooooool05Oooo`0306Kooooooooo05Goool00ol0VOooooooo`0N
oooo001hoooo00<0I_ooooooool05?ooo`80000Doooo0P1VoeSoool00ol0VOooooooo`0Noooo001i
oooo00<0I_ooooooool04oooo`030000oooooooo01;oool00`1Vooooooooo`1Hoooo00?o09Wooooo
ool07_ooo`00N_ooo`0306Kooooooooo01;oool00`000?ooooooo`0Aoooo00<0I_ooooooool0FOoo
o`03o`2Ioooooooo01koool007_oool00`1Vooooooooo`0Aoooo00<0003oooooool04?ooo`0306Ko
oooooooo05[oool00ol0VOooooooo`0Noooo001loooo00<0I_ooooooool04?ooo`030000oooooooo
00ooool00`1Vooooooooo`1Koooo00?o09Woooooool07_ooo`00OOooo`0306Kooooooooo00ooool0
0`000?ooooooo`0>oooo00<0I_ooooooool0G?ooo`03o`2Ioooooooo01koool007koool00`1Voooo
ooooo`0>oooo0P0000koool00`1Vooooooooo`1Moooo00?o09Woooooool07_ooo`00Ooooo`0306Ko
oooooooo00goool00`000?ooooooo`0<oooo00<0I_ooooooool0G_ooo`03o`2Ioooooooo01koool0
083oool206Ko3Oooo`030000oooooooo00_oool00`1Vooooooooo`1Ooooo00?o09Woooooool07_oo
o`00P_ooo`0306Kooooooooo00[oool00`000?ooooooo`0:oooo00<0I_ooooooool0H?ooo`03o`2I
oooooooo01koool008?oool0101Vooooooooooooo`D00003oooo00<0003oooooool02Oooo`0306Ko
oooooooo067oool00ol0VOooooooo`0Noooo0024oooo00<0I_ooooooool00_ooo`030000oooooooo
00?oool00`000?ooooooo`08oooo00<0I_ooooooool0H_ooo`03o`2Ioooooooo01koool008Goool0
1@1Vooooooooooooo`000005oooo0`0000Ooool00`1Vooooooooo`1Soooo00?o09Woooooool07_oo
o`00Q_ooo`0406Kooooooooo00001Oooo`030000oooooooo00Koool00`1Vooooooooo`1Toooo00?o
09Woooooool07_ooo`00Qoooo`0306Kooooo000000Goool00`000?ooooooo`05oooo00<0I_oooooo
ool0IOooo`03o`2Ioooooooo01koool008Soool200001Oooo`030000oooooooo00Coool00`1Voooo
ooooo`1Voooo00?o09Woooooool07_ooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03
oooo00<0I_ooooooool0Ioooo`03o`2Ioooooooo01koool008[oool00`1Vooooooooo`02oooo00<0
003oooooool00_ooo`0306Kooooooooo06Soool00ol0VOooooooo`0Noooo002;oooo00D0I_oooooo
ooooool000000oooo`0306Kooooooooo06Woool00ol0VOooooooo`0Noooo002;oooo00@0I_oooooo
ooooool2000000?oool0I_ooool0Joooo`03o`2Ioooooooo01koool008coool0101Vooooooooo`00
00;oool00`1Vooooooooo`1Zoooo00?o09Woooooool07_ooo`00SOooo`0506Kooooo0000oooo06Ko
06goool00ol0VOooooooo`0Noooo002>oooo00<0I_l00000I_l0K_ooo`03o`2Ioooooooo01koool0
08ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool0
0ol0VOooooooo`0Noooo002?oooo0P0006koool00ol0VOooooooo`0Noooo002?oooo00<0003ooooo
ool0KOooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_oo
o`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOoo
o`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Sooo
o`80001^oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0N
oooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool00`000?ooooooo`1]
oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo06goool00ol0VOooooooo`0Noooo002?
oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool008ooool20000K_ooo`03o`2Ioooooooo
01koool008ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Soooo`030000oooooooo
06goool00ol0VOooooooo`0Noooo002?oooo00<0003oooooool0KOooo`03o`2Ioooooooo01koool0
08ooool00`000?ooooooo`1]oooo00?o09Woooooool07_ooo`00Noooo`D00002oooo0P0000Coool2
00001Oooo`030000oooooooo06goool00ol0VOooooooo`0Noooo001moooo00<0003oooooool01ooo
o`040000oooooooo00001?ooo`030000oooooooo06goool00ol0VOooooooo`0Noooo001moooo00<0
003oooooool02_ooo`030000oooooooo00;oool30000KOooo`03o`2Ioooooooo01koool007goool0
0`000?ooooooo`08oooo0P0009Koool007goool00`000?ooooooo`08oooo00<0003oooooool0UOoo
o`00O?ooo`80000:oooo0`0009Goool00?oooolQoooo003ooooo8Oooo`00O?ooo`030000oooooooo
02;oool00`000?ooooooo`1loooo001koooo00<0003oooooool02?ooo`030000oooooooo01Woool0
0`000?ooooooo`1koooo001koooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_oo
o`@00003oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00Noooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo
00_oool00`000?ooooooo`02oooo00<0003oooooool0Noooo`00N_ooo`030000oooooooo00;oool0
0`000?ooooooo`0>oooo00<0003oooooool02_ooo`030000oooooooo00?oool00`000?ooooooo`1j
oooo001koooo00<0003oooooool01@0000koool00`000?ooooooo`0:oooo00D0003oooooooooool0
0000OOooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`800009oooo1000
00;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.91726 .24721 L
.92761 .24721 L
.93331 .24721 L
.93871 .24721 L
.94357 .24721 L
.9449 .24721 L
.94563 .24721 L
.94631 .24721 L
s
.94631 .24721 m
.9465 .61803 L
s
0 .4 1 r
.02381 .24721 m
.03279 .24721 L
.04262 .24721 L
.04758 .24721 L
.0503 .24721 L
.05164 .24721 L
.05288 .24721 L
.05405 .37082 L
.05528 .37082 L
.05789 .37082 L
.06244 .37082 L
.10458 .37082 L
.14241 .37082 L
.1827 .37082 L
.22147 .37082 L
.24118 .37082 L
.2627 .37082 L
.27267 .37082 L
.27814 .37082 L
.28329 .37082 L
.28811 .37082 L
.28943 .37082 L
.29015 .37082 L
.29082 .37082 L
.29201 .371 L
.29332 .37168 L
.30241 .37652 L
.34132 .39948 L
.38268 .42837 L
.42252 .46137 L
.46085 .49877 L
.48024 .52011 L
.49053 .53217 L
.49594 .53872 L
.49866 .54207 L
.4994 .54299 L
.5002 .54348 L
.50095 .54255 L
.50163 .5417 L
.5122 .52892 L
.52189 .51769 L
.5409 .49693 L
.58088 .45833 L
.61935 .42683 L
.66027 .39847 L
.68062 .38608 L
.69058 .38039 L
.69967 .3754 L
.70415 .37301 L
.70538 .37236 L
Mistroke
.70669 .37168 L
.70792 .37103 L
.70904 .24721 L
.71019 .24721 L
.71124 .24721 L
.71362 .24721 L
.71794 .24721 L
.73756 .24721 L
.7771 .24721 L
.81512 .24721 L
.8556 .24721 L
.89456 .24721 L
.93597 .24721 L
.97587 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool01Oooo`0306Kooooooooo00Coool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool01Oooo`0306Kooooooooo
00Coool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`04oooo00?o09Woooooool01Oooo`030000oooooooo01Goool001koool00`1Vooooooooo`1^
oooo00<0003oooooool0<_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Moooo000Noooo00<0
I_ooooooool0K_ooo`030000oooooooo03;oool00`1Vooooooooo`0ioooo00?o09Woooooool07Ooo
o`007_ooo`0306Kooooooooo06koool00`000?ooooooo`0boooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo01goool001koool00`1Vooooooooo`1^oooo00<0003oooooool0<_ooo`0306Kooooooooo
03Woool00ol0VOooooooo`0Moooo000Noooo00<0I_ooooooool0K_ooo`80000coooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo01goool001koool00`1Vooooooooo`1^oooo00<0003oooooool0<_oo
o`0306Kooooooooo03Woool00ol0VOooooooo`0Moooo000Noooo00<0I_ooooooool0K_ooo`030000
oooooooo03;oool00`1Vooooooooo`0ioooo00?o09Woooooool07Oooo`007_ooo`0306Kooooooooo
06koool00`000?ooooooo`0boooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01goool001koool0
0`1Vooooooooo`1^oooo00<0003oooooool0<_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0M
oooo000Noooo00<0I_ooooooool0K_ooo`030000oooooooo03;oool00`1Vooooooooo`0ioooo00?o
09Woooooool07Oooo`007_ooo`0306Kooooooooo06koool20000<oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Moooo000Noooo00<0I_ooooooool0K_ooo`030000oooooooo03;oool00`1Voooo
ooooo`0ioooo00?o09Woooooool07Oooo`007_ooo`0306Kooooooooo06koool00`000?ooooooo`0b
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01goool001koool00`1Vooooooooo`1^oooo00<0
003oooooool0<_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Moooo000Noooo00<0I_oooooo
ool0K_ooo`030000oooooooo03;oool00`1Vooooooooo`0ioooo00?o09Woooooool07Oooo`007_oo
o`0306Kooooooooo06koool00`000?ooooooo`0boooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
01goool001koool00`1Vooooooooo`1^oooo00<0003oooooool0<_ooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Moooo000Noooo00<0I_ooooooool0K_ooo`80000coooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo01goool001koool00`1Vooooooooo`1^oooo00<0003oooooool0<_ooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Moooo000Noooo00<0I_ooooooool0K_ooo`030000oooooooo
03;oool00`1Vooooooooo`0ioooo00?o09Woooooool07Oooo`007_ooo`0306Kooooooooo06koool0
0`000?ooooooo`0boooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01goool001koool00`1Voooo
ooooo`1^oooo00<0003oooooool0<_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Moooo000N
oooo00<0I_ooooooool0K_ooo`030000oooooooo03;oool00`1Vooooooooo`0ioooo00?o09Wooooo
ool07Oooo`007_ooo`0306Kooooooooo06koool20000<oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0Moooo000Noooo00<0I_ooooooool0K_ooo`030000oooooooo03;oool00`1Vooooooooo`0i
oooo00?o09Woooooool07Oooo`007_ooo`0306Kooooooooo06koool00`000?ooooooo`0boooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo01goool001koool00`1Vooooooooo`1^oooo00<0003ooooo
ool0<_ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Moooo000Noooo00<0I_ooooooool0Fooo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo03;oool00`1Vooooooooo`0ioooo00?o
09Woooooool07Oooo`007_ooo`0306Kooooooooo05[oool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0boooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01goool0
01koooln06Ko7oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000<Oooo`80I_lk
oooo00?o09Woooooool07Oooo`00G?ooo`0306Kooooooooo01coool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo033oool206Ko??ooo`03o`2Ioooooooo01goool005goool00`1Voooo
ooooo`0Koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000oooooooo02koool2
06Ko?_ooo`03o`2Ioooooooo01goool005koool206Ko7?ooo`80000:oooo0`0000Coool00`000?oo
ooooo`0]oooo00<0I_ooooooool0?_ooo`03o`2Ioooooooo01goool0063oool206Ko;Oooo`030000
oooooooo02_oool206Ko@Oooo`03o`2Ioooooooo01goool006;oool206Ko:oooo`030000oooooooo
02Woool206Ko@oooo`03o`2Ioooooooo01goool006Coool206Ko:Oooo`80000Xoooo0P1VodGoool0
0ol0VOooooooo`0Moooo001Voooo0P1VobOoool00`000?ooooooo`0Voooo00<0I_ooooooool0AOoo
o`03o`2Ioooooooo01goool006Soool00`1Vooooooooo`0Toooo00<0003oooooool09?ooo`80I_m8
oooo00?o09Woooooool07Oooo`00JOooo`80I_lToooo00<0003oooooool08oooo`0306Kooooooooo
04Soool00ol0VOooooooo`0Moooo001[oooo00<0I_ooooooool08Oooo`030000oooooooo027oool2
06KoBoooo`03o`2Ioooooooo01goool006coool00`1Vooooooooo`0Poooo00<0003oooooool07ooo
o`80I_m=oooo00?o09Woooooool07Oooo`00KOooo`0306Kooooooooo01ooool00`000?ooooooo`0N
oooo00<0I_ooooooool0COooo`03o`2Ioooooooo01goool006koool206Ko7oooo`80000Moooo0P1V
oe3oool00ol0VOooooooo`0Moooo001`oooo00<0I_ooooooool07?ooo`030000oooooooo01_oool0
0`1Vooooooooo`1@oooo00?o09Woooooool07Oooo`00LOooo`0306Kooooooooo01_oool00`000?oo
ooooo`0Joooo00<0I_ooooooool0DOooo`03o`2Ioooooooo01goool007;oool00`1Vooooooooo`0J
oooo00<0003oooooool06?ooo`80I_mDoooo00?o09Woooooool07Oooo`00Loooo`80I_lJoooo00<0
003oooooool05oooo`0306Kooooooooo05Coool00ol0VOooooooo`0Moooo001eoooo00<0I_oooooo
ool05oooo`030000oooooooo01Koool00`1Vooooooooo`1Eoooo00?o09Woooooool07Oooo`00M_oo
o`0306Kooooooooo01Koool200005_ooo`0306Kooooooooo05Koool00ol0VOooooooo`0Moooo001g
oooo00<0I_ooooooool05Oooo`030000oooooooo01?oool206KoFOooo`03o`2Ioooooooo01goool0
07Soool206Ko5Oooo`030000oooooooo01;oool00`1Vooooooooo`1Ioooo00?o09Woooooool07Ooo
o`00N_ooo`0306Kooooooooo01;oool00`000?ooooooo`0Aoooo00<0I_ooooooool0F_ooo`03o`2I
oooooooo01goool007_oool00`1Vooooooooo`0Aoooo00<0003oooooool04?ooo`0306Kooooooooo
05_oool00ol0VOooooooo`0Moooo001loooo00<0I_ooooooool04?ooo`030000oooooooo00ooool0
0`1Vooooooooo`1Loooo00?o09Woooooool07Oooo`00OOooo`0306Kooooooooo00ooool200003ooo
o`0306Kooooooooo05goool00ol0VOooooooo`0Moooo001noooo00<0I_ooooooool03_ooo`030000
oooooooo00goool00`1Vooooooooo`1Noooo00?o09Woooooool07Oooo`00Ooooo`0306Kooooooooo
00goool00`000?ooooooo`0<oooo00<0I_ooooooool0Goooo`03o`2Ioooooooo01goool0083oool0
0`1Vooooooooo`0<oooo00<0003oooooool02oooo`0306Kooooooooo063oool00ol0VOooooooo`0M
oooo0021oooo00<0I_ooooooool00oooo`D00003oooo00<0003oooooool02_ooo`0306Kooooooooo
067oool00ol0VOooooooo`0Moooo0022oooo00<0I_ooooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`09oooo00<0I_ooooooool0H_ooo`03o`2Ioooooooo01goool008?oool00`1Voooo
ooooo`03oooo00<0003oooooool00oooo`<00008oooo00<0I_ooooooool0Hoooo`03o`2Ioooooooo
01goool008Coool00`1Vooooooooo`02oooo00<0003oooooool00oooo`030000oooooooo00Ooool0
0`1Vooooooooo`1Toooo00?o09Woooooool07Oooo`00QOooo`0506Kooooooooooooo000000Goool0
0`000?ooooooo`06oooo00<0I_ooooooool0IOooo`03o`2Ioooooooo01goool008Koool0101Voooo
o`00000000Goool00`000?ooooooo`05oooo00<0I_ooooooool0I_ooo`03o`2Ioooooooo01goool0
08Ooool00`1Vooooooooo`05oooo00<0003oooooool01Oooo`0306Kooooooooo06Koool00ol0VOoo
ooooo`0Moooo0028oooo00<0I_ooooooool01?ooo`030000oooooooo00Coool00`1Vooooooooo`1W
oooo00?o09Woooooool07Oooo`00ROooo`0306Kooooooooo00?oool00`000?ooooooo`03oooo00<0
I_ooooooool0J?ooo`03o`2Ioooooooo01goool008[oool00`1Vooooooooo`02oooo0P0000?oool0
0`1Vooooooooo`1Yoooo00?o09Woooooool07Oooo`00Roooo`0506Kooooooooooooo000000?oool0
0`1Vooooooooo`1Zoooo00?o09Woooooool07Oooo`00S?ooo`0406Kooooooooo00000_ooo`0306Ko
oooooooo06_oool00ol0VOooooooo`0Moooo002=oooo00D0I_ooool0003oool0I_l0K_ooo`03o`2I
oooooooo01goool008goool0101Vooooo`00001Vofooool00ol0VOooooooo`0Moooo002>oooo00<0
I_l0003oool0Koooo`03o`2Ioooooooo01goool008ooool20000Koooo`03o`2Ioooooooo01goool0
08ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo06koool0
0ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool008ooool0
0`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo06koool00ol0VOoo
ooooo`0Moooo002?oooo0P0006ooool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_oo
o`03o`2Ioooooooo01goool008ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Sooo
o`030000oooooooo06koool00ol0VOooooooo`0Moooo002?oooo00<0003oooooool0K_ooo`03o`2I
oooooooo01goool008ooool00`000?ooooooo`1^oooo00?o09Woooooool07Oooo`00Soooo`80001_
oooo00?o09Woooooool07Oooo`00Soooo`030000oooooooo06koool00ol0VOooooooo`0Moooo002?
oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool008ooool00`000?ooooooo`1^oooo00?o
09Woooooool07Oooo`00Soooo`030000oooooooo06koool00ol0VOooooooo`0Moooo001koooo1@00
00;oool200001?ooo`800005oooo00<0003oooooool0K_ooo`03o`2Ioooooooo01goool007goool0
0`000?ooooooo`07oooo00@0003oooooool00004oooo00<0003oooooool0K_ooo`03o`2Ioooooooo
01goool007goool00`000?ooooooo`0:oooo00<0003oooooool00_ooo`<0001^oooo00?o09Wooooo
ool07Oooo`00OOooo`030000oooooooo00Soool20000U_ooo`00OOooo`030000oooooooo00Soool0
0`000?ooooooo`2Eoooo001loooo0P0000[oool30000UOooo`00ooooob7oool00?oooolQoooo001i
oooo00<0003oooooool0:?ooo`030000oooooooo07Woool007Soool00`000?ooooooo`08oooo00<0
003oooooool07oooo`030000oooooooo07Soool007Soool00`000?ooooooo`02oooo0P0000Coool0
0`000?ooooooo`06oooo100000?oool200001Oooo`030000oooooooo00;oool200001?ooo`030000
oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000
oooooooo00Goool00`000?ooooooo`0;oooo00D0003oooooooooool000000_ooo`050000oooooooo
oooo000007[oool007Ooool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000oooooooo
00[oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo07Ooool007Soool0
0`000?ooooooo`0500003_ooo`030000oooooooo00[oool010000?ooooooooooo`800004oooo00<0
003oooooool0N?ooo`00N?ooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool0
10000?ooooooo`0000?oool00`000?ooooooo`03oooo00<0003oooooool0N?ooo`00NOooo`030000
oooooooo017oool200002Oooo`@00003oooo0`0000;oool00`000?ooooooo`1ioooo003ooooo8Ooo
o`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.91726 .24721 L
.92761 .24721 L
.93871 .24721 L
.94392 .24721 L
.94648 .24721 L
.94885 .24721 L
.951 .24721 L
.95208 .24721 L
s
.95208 .24721 m
.95226 .61803 L
s
0 .4 1 r
.02381 .24721 m
.03279 .24721 L
.04262 .24721 L
.04517 .24721 L
.04642 .24721 L
.04758 .24721 L
.04822 .37082 L
.04891 .37082 L
.05035 .37082 L
.05288 .37082 L
.06244 .37082 L
.10458 .37082 L
.14241 .37082 L
.1827 .37082 L
.22147 .37082 L
.24118 .37082 L
.2627 .37082 L
.27267 .37082 L
.27814 .37082 L
.28082 .37082 L
.28329 .37082 L
.2845 .37082 L
.28563 .37082 L
.28681 .37139 L
.28811 .37207 L
.29332 .37483 L
.30241 .3798 L
.34132 .40333 L
.38268 .43295 L
.42252 .46679 L
.46085 .50514 L
.48024 .52702 L
.49053 .53939 L
.49594 .5461 L
.49866 .54953 L
.4994 .55048 L
.5002 .55098 L
.50095 .55002 L
.50163 .54916 L
.5122 .53605 L
.52189 .52454 L
.5409 .50325 L
.58088 .46367 L
.61935 .43138 L
.66027 .4023 L
.68062 .38959 L
.69058 .38376 L
.69967 .37865 L
.70415 .37619 L
.70904 .37357 L
Mistroke
.71128 .37239 L
.7125 .37175 L
.71366 .37115 L
.71474 .24721 L
.7159 .24721 L
.71794 .24721 L
.73756 .24721 L
.77861 .24721 L
.81815 .24721 L
.85618 .24721 L
.89665 .24721 L
.93561 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool00oooo`0306Kooooooooo00Koool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool01_ooo`0306Kooooooooo
00?oool00`000?ooooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?oo
ooooo`06oooo00?o09Woooooool00oooo`030000oooooooo01Goool001coool00`1Vooooooooo`1`
oooo00<0003oooooool0<oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Koooo000Loooo00<0
I_ooooooool0L?ooo`030000oooooooo03?oool00`1Vooooooooo`0joooo00?o09Woooooool06ooo
o`007?ooo`0306Kooooooooo073oool00`000?ooooooo`0coooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo01_oool001coool00`1Vooooooooo`1`oooo00<0003oooooool0<oooo`0306Kooooooooo
03[oool00ol0VOooooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`80000doooo00<0I_oooooo
ool0>_ooo`03o`2Ioooooooo01_oool001coool00`1Vooooooooo`1`oooo00<0003oooooool0<ooo
o`0306Kooooooooo03[oool00ol0VOooooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`030000
oooooooo03?oool00`1Vooooooooo`0joooo00?o09Woooooool06oooo`007?ooo`0306Kooooooooo
073oool00`000?ooooooo`0coooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo01_oool001coool0
0`1Vooooooooo`1`oooo00<0003oooooool0<oooo`0306Kooooooooo03[oool00ol0VOooooooo`0K
oooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo03?oool00`1Vooooooooo`0joooo00?o
09Woooooool06oooo`007?ooo`0306Kooooooooo073oool20000=?ooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo03?oool00`1Voooo
ooooo`0joooo00?o09Woooooool06oooo`007?ooo`0306Kooooooooo073oool00`000?ooooooo`0c
oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo01_oool001coool00`1Vooooooooo`1`oooo00<0
003oooooool0<oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Koooo000Loooo00<0I_oooooo
ool0L?ooo`030000oooooooo03?oool00`1Vooooooooo`0joooo00?o09Woooooool06oooo`007?oo
o`0306Kooooooooo073oool00`000?ooooooo`0coooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo
01_oool001coool00`1Vooooooooo`1`oooo00<0003oooooool0<oooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`80000doooo00<0I_ooooooool0>_oo
o`03o`2Ioooooooo01_oool001coool00`1Vooooooooo`1`oooo00<0003oooooool0<oooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo
03?oool00`1Vooooooooo`0joooo00?o09Woooooool06oooo`007?ooo`0306Kooooooooo073oool0
0`000?ooooooo`0coooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo01_oool001coool00`1Voooo
ooooo`1`oooo00<0003oooooool0<oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Koooo000L
oooo00<0I_ooooooool0L?ooo`030000oooooooo03?oool00`1Vooooooooo`0joooo00?o09Wooooo
ool06oooo`007?ooo`0306Kooooooooo073oool20000=?ooo`0306Kooooooooo03[oool00ol0VOoo
ooooo`0Koooo000Loooo00<0I_ooooooool0L?ooo`030000oooooooo03?oool00`1Vooooooooo`0j
oooo00?o09Woooooool06oooo`007?ooo`0306Kooooooooo073oool00`000?ooooooo`0coooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo01_oool001coool00`1Vooooooooo`1`oooo00<0003ooooo
ool0<oooo`0306Kooooooooo03[oool00ol0VOooooooo`0Koooo000Loooo00<0I_ooooooool0GOoo
o`800004oooo0P0000Coool200001Oooo`030000oooooooo03?oool00`1Vooooooooo`0joooo00?o
09Woooooool06oooo`007?ooo`0306Kooooooooo05coool010000?ooooooo`0000Soool010000?oo
ooooo`0000Coool00`000?ooooooo`0coooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo01_oool0
01coooln06Ko8Oooo`040000oooooooo00002oooo`030000oooooooo00;oool30000<oooo`0306Ko
oooooooo03[oool00ol0VOooooooo`0Koooo001Joooo0P1Voaooool010000?ooooooo`0000Woool2
00001Oooo`030000oooooooo037oool206Ko?Oooo`03o`2Ioooooooo01_oool005coool206Ko7Ooo
o`040000oooooooo00002Oooo`030000oooooooo00Coool00`000?ooooooo`0_oooo0P1Vocooool0
0ol0VOooooooo`0Koooo001Noooo0P1Voacoool200002_ooo`<00004oooo00<0003oooooool0;Ooo
o`80I_m1oooo00?o09Woooooool06oooo`00H?ooo`80I_l]oooo00<0003oooooool0;?ooo`0306Ko
oooooooo047oool00ol0VOooooooo`0Koooo001Roooo00<0I_ooooooool0:_ooo`030000oooooooo
02_oool00`1Vooooooooo`12oooo00?o09Woooooool06oooo`00Hoooo`80I_lZoooo0P0002[oool2
06KoAOooo`03o`2Ioooooooo01_oool006Goool206Ko:?ooo`030000oooooooo02Ooool206KoAooo
o`03o`2Ioooooooo01_oool006Ooool00`1Vooooooooo`0Uoooo00<0003oooooool09_ooo`0306Ko
oooooooo04Ooool00ol0VOooooooo`0Koooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo
02Coool206KoB_ooo`03o`2Ioooooooo01_oool006Woool206Ko9?ooo`030000oooooooo02?oool0
0`1Vooooooooo`1:oooo00?o09Woooooool06oooo`00Joooo`0306Kooooooooo027oool00`000?oo
ooooo`0Qoooo0P1Vodgoool00ol0VOooooooo`0Koooo001/oooo00<0I_ooooooool08?ooo`030000
oooooooo01ooool206KoCoooo`03o`2Ioooooooo01_oool006goool00`1Vooooooooo`0Ooooo0P00
01ooool00`1Vooooooooo`1?oooo00?o09Woooooool06oooo`00K_ooo`80I_lOoooo00<0003ooooo
ool07?ooo`80I_mBoooo00?o09Woooooool06oooo`00L?ooo`0306Kooooooooo01coool00`000?oo
ooooo`0Koooo00<0I_ooooooool0D_ooo`03o`2Ioooooooo01_oool0077oool00`1Vooooooooo`0K
oooo00<0003oooooool06_ooo`0306Kooooooooo05?oool00ol0VOooooooo`0Koooo001boooo00<0
I_ooooooool06_ooo`030000oooooooo01Woool00`1Vooooooooo`1Doooo00?o09Woooooool06ooo
o`00Loooo`80I_lJoooo00<0003oooooool06?ooo`0306Kooooooooo05Goool00ol0VOooooooo`0K
oooo001eoooo00<0I_ooooooool05oooo`80000Hoooo00<0I_ooooooool0E_ooo`03o`2Ioooooooo
01_oool007Koool00`1Vooooooooo`0Foooo00<0003oooooool05Oooo`80I_mIoooo00?o09Wooooo
ool06oooo`00Moooo`0306Kooooooooo01Goool00`000?ooooooo`0Doooo00<0I_ooooooool0FOoo
o`03o`2Ioooooooo01_oool007Soool206Ko5Oooo`030000oooooooo01?oool00`1Vooooooooo`1J
oooo00?o09Woooooool06oooo`00N_ooo`0306Kooooooooo01;oool00`000?ooooooo`0Boooo00<0
I_ooooooool0Foooo`03o`2Ioooooooo01_oool007_oool00`1Vooooooooo`0Aoooo00<0003ooooo
ool04Oooo`0306Kooooooooo05coool00ol0VOooooooo`0Koooo001loooo00<0I_ooooooool04?oo
o`80000Aoooo00<0I_ooooooool0GOooo`03o`2Ioooooooo01_oool007goool00`1Vooooooooo`0?
oooo00<0003oooooool03oooo`0306Kooooooooo05koool00ol0VOooooooo`0Koooo001noooo00<0
I_ooooooool03_ooo`030000oooooooo00koool00`1Vooooooooo`1Ooooo00?o09Woooooool06ooo
o`00Ooooo`0306Kooooooooo00goool00`000?ooooooo`0=oooo00<0I_ooooooool0H?ooo`03o`2I
oooooooo01_oool0083oool00`1Vooooooooo`04oooo1@0000?oool00`000?ooooooo`0<oooo00<0
I_ooooooool0HOooo`03o`2Ioooooooo01_oool0087oool00`1Vooooooooo`05oooo00<0003ooooo
ool00oooo`030000oooooooo00_oool00`1Vooooooooo`1Roooo00?o09Woooooool06oooo`00P_oo
o`0306Kooooooooo00Coool00`000?ooooooo`03oooo0`0000[oool00`1Vooooooooo`1Soooo00?o
09Woooooool06oooo`00Poooo`0306Kooooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool02Oooo`0306Kooooooooo06Coool00ol0VOooooooo`0Koooo0024oooo00<0I_ooooooool00_oo
o`030000oooooooo00?oool00`000?ooooooo`08oooo00<0I_ooooooool0IOooo`03o`2Ioooooooo
01_oool008Goool00`1Vooooooooo`0200001Oooo`030000oooooooo00Ooool00`1Vooooooooo`1V
oooo00?o09Woooooool06oooo`00Q_ooo`0306Kooooooooo00Koool00`000?ooooooo`06oooo00<0
I_ooooooool0Ioooo`03o`2Ioooooooo01_oool008Ooool00`1Vooooooooo`05oooo00<0003ooooo
ool01Oooo`0306Kooooooooo06Soool00ol0VOooooooo`0Koooo0027oooo00<0I_ooooooool01Ooo
o`030000oooooooo00Goool00`1Vooooooooo`1Xoooo00?o09Woooooool06oooo`00R?ooo`0306Ko
oooooooo00Coool200001Oooo`0306Kooooooooo06Woool00ol0VOooooooo`0Koooo0029oooo00<0
I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`1Zoooo00?o09Woooooool06ooo
o`00R_ooo`0306Kooooooooo00;oool00`000?ooooooo`02oooo00<0I_ooooooool0Joooo`03o`2I
oooooooo01_oool008_oool01@1Vooooooooooooo`000003oooo00<0I_ooooooool0K?ooo`03o`2I
oooooooo01_oool008coool0101Vooooooooo`0000;oool00`1Vooooooooo`1]oooo00?o09Wooooo
ool06oooo`00SOooo`0506Kooooo0000oooo06Ko073oool00ol0VOooooooo`0Koooo002=oooo00@0
I_ooool00000001aoooo00?o09Woooooool06oooo`00S_ooo`0306Ko0000oooo077oool00ol0VOoo
ooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?oo
ooooo`1`oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0K
oooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool20000LOooo`03o`2I
oooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`030000
oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003oooooool0L?ooo`03o`2Ioooooooo
01_oool008ooool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00Soooo`030000oooooooo
073oool00ol0VOooooooo`0Koooo002?oooo0P00077oool00ol0VOooooooo`0Koooo002?oooo00<0
003oooooool0L?ooo`03o`2Ioooooooo01_oool008ooool00`000?ooooooo`1`oooo00?o09Wooooo
ool06oooo`00Soooo`030000oooooooo073oool00ol0VOooooooo`0Koooo002?oooo00<0003ooooo
ool0L?ooo`03o`2Ioooooooo01_oool007_oool500000_ooo`800004oooo0P0000Goool00`000?oo
ooooo`1`oooo00?o09Woooooool06oooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`00
00Coool00`000?ooooooo`1`oooo00?o09Woooooool06oooo`00OOooo`030000oooooooo00[oool0
0`000?ooooooo`02oooo0`00073oool00ol0VOooooooo`0Koooo001moooo00<0003oooooool02?oo
o`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo09Goool007coool200002_oo
o`<0002Eoooo003ooooo8Oooo`00ooooob7oool007coool00`000?ooooooo`0Roooo00<0003ooooo
ool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0Ioooo00<0003oooooool0Nooo
o`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004
oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02Oooo`040000oooooooo00000ooo
o`030000oooooooo07_oool007[oool00`000?ooooooo`02oooo00<0003oooooool03_ooo`030000
oooooooo00Soool010000?ooooooo`0000Coool00`000?ooooooo`1joooo001koooo00<0003ooooo
ool01@0000koool00`000?ooooooo`08oooo0P0000Coool00`000?ooooooo`1koooo001koooo00D0
003oooooooooool000003oooo`040000oooooooo00002?ooo`040000oooooooo00000oooo`030000
oooooooo07_oool007coool00`000?ooooooo`0Aoooo0P0000[oool200000oooo`030000oooooooo
07coool00?oooolQoooo003ooooo8Oooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.91726 .24721 L
.93871 .24721 L
.94807 .24721 L
.95322 .24721 L
.95575 .24721 L
.95687 .24721 L
.9581 .24721 L
s
.9581 .24721 m
.95827 .61803 L
s
0 .4 1 r
.02381 .24721 m
.02846 .24721 L
.03279 .24721 L
.03754 .24721 L
.0389 .24721 L
.0402 .24721 L
.04136 .24721 L
.04262 .37082 L
.04385 .37082 L
.045 .37082 L
.04762 .37082 L
.05293 .37082 L
.06244 .37082 L
.10458 .37082 L
.14335 .37082 L
.18458 .37082 L
.22428 .37082 L
.24432 .37082 L
.26248 .37082 L
.26734 .37082 L
.27261 .37082 L
.27502 .37082 L
.27758 .37082 L
.27863 .37082 L
.27976 .37082 L
.281 .37146 L
.28215 .37207 L
.30312 .38356 L
.34448 .40943 L
.38433 .43898 L
.42266 .47248 L
.46344 .51456 L
.48369 .5383 L
.48853 .54427 L
.49361 .55068 L
.49571 .55337 L
.49796 .55627 L
.49925 .55795 L
.50042 .55839 L
.5016 .55685 L
.50271 .55541 L
.52087 .53277 L
.54046 .51022 L
.57892 .47098 L
.61984 .43565 L
.65925 .40691 L
.69713 .38342 L
.70711 .37783 L
.71202 .37516 L
.71658 .37273 L
Mistroke
.71788 .37205 L
.71911 .37141 L
.71979 .37105 L
.72052 .24721 L
.7218 .24721 L
.7275 .24721 L
.73747 .24721 L
.77853 .24721 L
.81807 .24721 L
.85609 .24721 L
.89657 .24721 L
.93553 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -27.7813 0 ]
[.5 .63053 27.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -88.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.85) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
108.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00<0003oooooool00_ooo`0306Kooooooooo00Ooool00`000?oo
ooooo`0<oooo00<0003oooooool03Oooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0
003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool03?oo
o`030000oooooooo00coool00`000?ooooooo`0<oooo00<0003oooooool02?ooo`0506Kooooooooo
oooo000000koool00`000?ooooooo`0=oooo00<0003oooooool03?ooo`030000oooooooo00Ooool0
0ol0VOooooooo`02oooo00<0003oooooool05Oooo`006oooo`0306Kooooooooo077oool00`000?oo
ooooo`0eoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01[oool001_oool00`1Vooooooooo`1a
oooo00<0003oooooool0=Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Joooo000Koooo00<0
I_ooooooool0LOooo`030000oooooooo03Goool00`1Vooooooooo`0ioooo00?o09Woooooool06_oo
o`006oooo`0306Kooooooooo077oool00`000?ooooooo`0eoooo00<0I_ooooooool0>Oooo`03o`2I
oooooooo01[oool001_oool00`1Vooooooooo`1aoooo0P0003Koool00`1Vooooooooo`0ioooo00?o
09Woooooool06_ooo`006oooo`0306Kooooooooo077oool00`000?ooooooo`0eoooo00<0I_oooooo
ool0>Oooo`03o`2Ioooooooo01[oool001_oool00`1Vooooooooo`1aoooo00<0003oooooool0=Ooo
o`0306Kooooooooo03Woool00ol0VOooooooo`0Joooo000Koooo00<0I_ooooooool0LOooo`030000
oooooooo03Goool00`1Vooooooooo`0ioooo00?o09Woooooool06_ooo`006oooo`0306Kooooooooo
077oool00`000?ooooooo`0eoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01[oool001_oool0
0`1Vooooooooo`1aoooo00<0003oooooool0=Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0J
oooo000Koooo00<0I_ooooooool0LOooo`80000foooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
01[oool001_oool00`1Vooooooooo`1aoooo00<0003oooooool0=Oooo`0306Kooooooooo03Woool0
0ol0VOooooooo`0Joooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo03Goool00`1Voooo
ooooo`0ioooo00?o09Woooooool06_ooo`006oooo`0306Kooooooooo077oool00`000?ooooooo`0e
oooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01[oool001_oool00`1Vooooooooo`1aoooo00<0
003oooooool0=Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Joooo000Koooo00<0I_oooooo
ool0LOooo`030000oooooooo03Goool00`1Vooooooooo`0ioooo00?o09Woooooool06_ooo`006ooo
o`0306Kooooooooo077oool00`000?ooooooo`0eoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo
01[oool001_oool00`1Vooooooooo`1aoooo0P0003Koool00`1Vooooooooo`0ioooo00?o09Wooooo
ool06_ooo`006oooo`0306Kooooooooo077oool00`000?ooooooo`0eoooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo01[oool001_oool00`1Vooooooooo`1aoooo00<0003oooooool0=Oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Joooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo
03Goool00`1Vooooooooo`0ioooo00?o09Woooooool06_ooo`006oooo`0306Kooooooooo077oool0
0`000?ooooooo`0eoooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01[oool001_oool00`1Voooo
ooooo`1aoooo00<0003oooooool0=Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Joooo000K
oooo00<0I_ooooooool0LOooo`80000foooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01[oool0
01_oool00`1Vooooooooo`1aoooo00<0003oooooool0=Oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0Joooo000Koooo00<0I_ooooooool0LOooo`030000oooooooo03Goool00`1Vooooooooo`0i
oooo00?o09Woooooool06_ooo`006oooo`0306Kooooooooo077oool00`000?ooooooo`0eoooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo01[oool001_oool00`1Vooooooooo`1Noooo0P0000Coool2
00001?ooo`800005oooo00<0003oooooool0=Oooo`0306Kooooooooo03Woool00ol0VOooooooo`0J
oooo000Koooo00<0I_ooooooool0GOooo`040000oooooooo00002?ooo`040000oooooooo00001?oo
o`030000oooooooo03Goool00`1Vooooooooo`0ioooo00?o09Woooooool06_ooo`006ooooch0I_lR
oooo00@0003oooooool0000;oooo00<0003oooooool00_ooo`<0000doooo0P1Voc_oool00ol0VOoo
ooooo`0Joooo001Ioooo0P1Vob3oool010000?ooooooo`0000Woool200001Oooo`030000oooooooo
03?oool206Ko??ooo`03o`2Ioooooooo01[oool005_oool206Ko7_ooo`040000oooooooo00002Ooo
o`030000oooooooo00Coool00`000?ooooooo`0aoooo0P1Vockoool00ol0VOooooooo`0Joooo001M
oooo00<0I_ooooooool07?ooo`80000:oooo0`0000Coool00`000?ooooooo`0_oooo0P1Vod3oool0
0ol0VOooooooo`0Joooo001Noooo0P1Vobooool00`000?ooooooo`0]oooo0P1Vod;oool00ol0VOoo
ooooo`0Joooo001Poooo00<0I_ooooooool0;?ooo`030000oooooooo02_oool206KoA?ooo`03o`2I
oooooooo01[oool0067oool206Ko;?ooo`80000[oooo00<0I_ooooooool0A?ooo`03o`2Ioooooooo
01[oool006?oool206Ko:_ooo`030000oooooooo02Soool206KoAoooo`03o`2Ioooooooo01[oool0
06Goool00`1Vooooooooo`0Woooo00<0003oooooool09_ooo`80I_m9oooo00?o09Woooooool06_oo
o`00I_ooo`80I_lWoooo00<0003oooooool09Oooo`0306Kooooooooo04Woool00ol0VOooooooo`0J
oooo001Xoooo00<0I_ooooooool09?ooo`030000oooooooo02Coool00`1Vooooooooo`1:oooo00?o
09Woooooool06_ooo`00JOooo`80I_lToooo00<0003oooooool08_ooo`80I_m=oooo00?o09Wooooo
ool06_ooo`00Joooo`0306Kooooooooo027oool00`000?ooooooo`0Qoooo00<0I_ooooooool0COoo
o`03o`2Ioooooooo01[oool006coool00`1Vooooooooo`0Poooo0P00027oool00`1Vooooooooo`1>
oooo00?o09Woooooool06_ooo`00KOooo`80I_lPoooo00<0003oooooool07oooo`0306Kooooooooo
04ooool00ol0VOooooooo`0Joooo001_oooo00<0I_ooooooool07Oooo`030000oooooooo01goool2
06KoD_ooo`03o`2Ioooooooo01[oool0073oool206Ko7Oooo`030000oooooooo01coool00`1Voooo
ooooo`1Boooo00?o09Woooooool06_ooo`00L_ooo`0306Kooooooooo01[oool00`000?ooooooo`0K
oooo00<0I_ooooooool0Doooo`03o`2Ioooooooo01[oool007?oool00`1Vooooooooo`0Ioooo00<0
003oooooool06_ooo`0306Kooooooooo05Coool00ol0VOooooooo`0Joooo001doooo00<0I_oooooo
ool06?ooo`80000Ioooo0P1VoeOoool00ol0VOooooooo`0Joooo001eoooo00<0I_ooooooool05ooo
o`030000oooooooo01Ooool00`1Vooooooooo`1Goooo00?o09Woooooool06_ooo`00M_ooo`0306Ko
oooooooo01Koool00`000?ooooooo`0Foooo00<0I_ooooooool0F?ooo`03o`2Ioooooooo01[oool0
07Ooool00`1Vooooooooo`0Eoooo00<0003oooooool05Oooo`0306Kooooooooo05Woool00ol0VOoo
ooooo`0Joooo001hoooo00<0I_ooooooool05?ooo`030000oooooooo01?oool206KoG?ooo`03o`2I
oooooooo01[oool007Woool00`1Vooooooooo`0Coooo00<0003oooooool04_ooo`0306Kooooooooo
05coool00ol0VOooooooo`0Joooo001joooo00<0I_ooooooool04_ooo`80000Boooo00<0I_oooooo
ool0GOooo`03o`2Ioooooooo01[oool007_oool00`1Vooooooooo`0Aoooo00<0003oooooool04?oo
o`0306Kooooooooo05koool00ol0VOooooooo`0Joooo001loooo00<0I_ooooooool04?ooo`030000
oooooooo00ooool00`1Vooooooooo`1Ooooo00?o09Woooooool06_ooo`00OOooo`0306Kooooooooo
00ooool00`000?ooooooo`0>oooo00<0I_ooooooool0H?ooo`03o`2Ioooooooo01[oool007koool0
0`1Vooooooooo`06oooo1@0000?oool00`000?ooooooo`0=oooo00<0I_ooooooool0HOooo`03o`2I
oooooooo01[oool007ooool00`1Vooooooooo`07oooo00<0003oooooool00oooo`030000oooooooo
00coool00`1Vooooooooo`1Roooo00?o09Woooooool06_ooo`00P?ooo`0306Kooooooooo00Koool0
0`000?ooooooo`03oooo0`0000_oool00`1Vooooooooo`1Soooo00?o09Woooooool06_ooo`00POoo
o`0306Kooooooooo00Goool00`000?ooooooo`03oooo00<0003oooooool02_ooo`0306Kooooooooo
06Coool00ol0VOooooooo`0Joooo0022oooo00<0I_ooooooool01?ooo`030000oooooooo00?oool0
0`000?ooooooo`09oooo00<0I_ooooooool0IOooo`03o`2Ioooooooo01[oool008?oool00`1Voooo
ooooo`02oooo0P0000Goool00`000?ooooooo`08oooo00<0I_ooooooool0I_ooo`03o`2Ioooooooo
01[oool008Coool00`1Vooooooooo`08oooo00<0003oooooool01oooo`0306Kooooooooo06Ooool0
0ol0VOooooooo`0Joooo0025oooo00<0I_ooooooool01oooo`030000oooooooo00Koool00`1Voooo
ooooo`1Xoooo00?o09Woooooool06_ooo`00Q_ooo`0306Kooooooooo00Koool00`000?ooooooo`05
oooo00<0I_ooooooool0JOooo`03o`2Ioooooooo01[oool008Ooool00`1Vooooooooo`05oooo0P00
00Goool00`1Vooooooooo`1Zoooo00?o09Woooooool06_ooo`00R?ooo`0306Kooooooooo00Coool0
0`000?ooooooo`04oooo00<0I_ooooooool0J_ooo`03o`2Ioooooooo01[oool008Soool00`1Voooo
ooooo`04oooo00<0003oooooool00oooo`0306Kooooooooo06_oool00ol0VOooooooo`0Joooo0029
oooo00<0I_ooooooool00oooo`030000oooooooo00;oool00`1Vooooooooo`1/oooo00?o09Wooooo
ool06_ooo`00R_ooo`0306Kooooooooo00;oool01@000?ooooooooooo`1Vo`1_oooo00?o09Wooooo
ool06_ooo`00Roooo`0506Kooooooooooooo000000?oool00`1Vooooooooo`1]oooo00?o09Wooooo
ool06_ooo`00S?ooo`0306Kooooooooo008000000oooo`1Vooooo`1_oooo00?o09Woooooool06_oo
o`00S?ooo`0606Kooooooooo0000oooo06KoLOooo`03o`2Ioooooooo01[oool008goool206Ko00<0
003oool0I_l0LOooo`03o`2Ioooooooo01[oool008koool00`1Vo`00001Vo`1boooo00?o09Wooooo
ool06_ooo`00Soooo`030000oooooooo077oool00ol0VOooooooo`0Joooo002?oooo00<0003ooooo
ool0LOooo`03o`2Ioooooooo01[oool008ooool20000L_ooo`03o`2Ioooooooo01[oool008ooool0
0`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000oooooooo077oool00ol0VOoo
ooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo01[oool008ooool00`000?oo
ooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000oooooooo077oool00ol0VOooooooo`0J
oooo002?oooo0P0007;oool00ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2I
oooooooo01[oool008ooool00`000?ooooooo`1aoooo00?o09Woooooool06_ooo`00Soooo`030000
oooooooo077oool00ol0VOooooooo`0Joooo002?oooo00<0003oooooool0LOooo`03o`2Ioooooooo
01[oool007_oool500000_ooo`800004oooo0P0000Goool00`000?ooooooo`1aoooo00?o09Wooooo
ool06_ooo`00OOooo`030000oooooooo00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1a
oooo00?o09Woooooool06_ooo`00OOooo`030000oooooooo00[oool00`000?ooooooo`02oooo0`00
077oool00ol0VOooooooo`0Joooo001moooo00<0003oooooool02?ooo`80002Foooo001moooo00<0
003oooooool02?ooo`030000oooooooo09Goool007coool200002_ooo`<0002Eoooo003ooooo8Ooo
o`00ooooob7oool007Woool00`000?ooooooo`0Xoooo00<0003oooooool0NOooo`00N?ooo`030000
oooooooo00Soool00`000?ooooooo`0Ooooo00<0003oooooool0N?ooo`00N?ooo`030000oooooooo
00;oool200001?ooo`030000oooooooo00Koool400000oooo`800004oooo0P0000Coool200001?oo
o`030000oooooooo07Soool007Soool01@000?ooooooooooo`000002oooo00<0003oooooool00_oo
o`030000oooooooo00Goool00`000?ooooooo`09oooo00@0003oooooool00002oooo00@0003ooooo
ool00003oooo00<0003oooooool0N?ooo`00Moooo`030000oooooooo00;oool00`000?ooooooo`0>
oooo00<0003oooooool02?ooo`040000oooooooo00001Oooo`030000oooooooo00;oool00`000?oo
ooooo`1goooo001hoooo00<0003oooooool01@0000koool00`000?ooooooo`08oooo0P0000Coool2
00001?ooo`030000oooooooo07Soool007Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00008oooo00@0003oooooool00003oooo00<0003oooooool00oooo`030000oooooooo07Soool0
07Woool00`000?ooooooo`0Aoooo0P0000[oool200001?ooo`<00002oooo00<0003oooooool0NOoo
o`00ooooob7oool00?oooolQoooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
.2 1 0 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
.97619 .24721 L
.02381 .24721 L
F
0 g
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.93871 .24721 L
.97619 .24721 L
s
1 0 .6 r
.02381 .24721 m
.06244 .24721 L
.10458 .24721 L
.14415 .24721 L
.18221 .24721 L
.22272 .24721 L
.26171 .24721 L
.30316 .24721 L
.34309 .24721 L
.3815 .24721 L
.42237 .24721 L
.46172 .24721 L
.49955 .24721 L
.53984 .24721 L
.57861 .24721 L
.61984 .24721 L
.65954 .24721 L
.69774 .24721 L
.73838 .24721 L
.77751 .24721 L
.81909 .24721 L
.85916 .24721 L
.89771 .24721 L
.91726 .24721 L
.93871 .24721 L
.94807 .24721 L
.95322 .24721 L
.9581 .24721 L
.96029 .24721 L
.96263 .24721 L
.96385 .24721 L
s
.96385 .24721 m
.96395 .61803 L
s
0 .4 1 r
.02381 .24721 m
.02846 .24721 L
.03279 .24721 L
.03406 .24721 L
.03527 .24721 L
.03636 .37082 L
.03754 .37082 L
.04262 .37082 L
.06244 .37082 L
.10458 .37082 L
.14545 .37082 L
.1848 .37082 L
.22263 .37082 L
.24367 .37082 L
.26292 .37082 L
.26752 .37082 L
.27004 .37082 L
.27242 .37082 L
.27308 .37082 L
.27378 .37082 L
.27454 .3712 L
.27524 .37157 L
.2778 .37291 L
.2828 .37558 L
.30169 .38618 L
.33966 .4102 L
.38009 .44036 L
.419 .47465 L
.46036 .5178 L
.48105 .54238 L
.49016 .55388 L
.49499 .56017 L
.49753 .56353 L
.4982 .56442 L
.49891 .56537 L
.5002 .56655 L
.50145 .56488 L
.50259 .56337 L
.5052 .55992 L
.50979 .55395 L
.51879 .54257 L
.53853 .51907 L
.57851 .47704 L
.61698 .44276 L
.6579 .41188 L
.67826 .39839 L
.6973 .38677 L
.71557 .37646 L
.72083 .37364 L
.72342 .37227 L
Mistroke
.72468 .37161 L
.72582 .37101 L
.72694 .24721 L
.72799 .24721 L
.7303 .24721 L
.73519 .24721 L
.77379 .24721 L
.81485 .24721 L
.85439 .24721 L
.89241 .24721 L
.93289 .24721 L
.97185 .24721 L
.97619 .24721 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 0.618034 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.247214 0.247214 [
[.02381 .23471 -6 -9 ]
[.02381 .23471 6 0 ]
[.2619 .23471 -6 -9 ]
[.2619 .23471 6 0 ]
[.7381 .23471 -3 -9 ]
[.7381 .23471 3 0 ]
[.97619 .23471 -3 -9 ]
[.97619 .23471 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .12361 -24 -4.5 ]
[.4875 .12361 0 4.5 ]
[.4875 .37082 -18 -4.5 ]
[.4875 .37082 0 4.5 ]
[.4875 .49443 -6 -4.5 ]
[.4875 .49443 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -24.7813 0 ]
[.5 .63053 24.7813 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24721 m
.02381 .25346 L
s
[(-4)] .02381 .23471 0 1 Mshowa
.2619 .24721 m
.2619 .25346 L
s
[(-2)] .2619 .23471 0 1 Mshowa
.7381 .24721 m
.7381 .25346 L
s
[(2)] .7381 .23471 0 1 Mshowa
.97619 .24721 m
.97619 .25346 L
s
[(4)] .97619 .23471 0 1 Mshowa
.125 Mabswid
.08333 .24721 m
.08333 .25096 L
s
.14286 .24721 m
.14286 .25096 L
s
.20238 .24721 m
.20238 .25096 L
s
.32143 .24721 m
.32143 .25096 L
s
.38095 .24721 m
.38095 .25096 L
s
.44048 .24721 m
.44048 .25096 L
s
.55952 .24721 m
.55952 .25096 L
s
.61905 .24721 m
.61905 .25096 L
s
.67857 .24721 m
.67857 .25096 L
s
.79762 .24721 m
.79762 .25096 L
s
.85714 .24721 m
.85714 .25096 L
s
.91667 .24721 m
.91667 .25096 L
s
.25 Mabswid
0 .24721 m
1 .24721 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .12361 m
.50625 .12361 L
s
[(-0.5)] .4875 .12361 1 0 Mshowa
.5 .37082 m
.50625 .37082 L
s
[(0.5)] .4875 .37082 1 0 Mshowa
.5 .49443 m
.50625 .49443 L
s
[(1)] .4875 .49443 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .02472 m
.50375 .02472 L
s
.5 .04944 m
.50375 .04944 L
s
.5 .07416 m
.50375 .07416 L
s
.5 .09889 m
.50375 .09889 L
s
.5 .14833 m
.50375 .14833 L
s
.5 .17305 m
.50375 .17305 L
s
.5 .19777 m
.50375 .19777 L
s
.5 .22249 m
.50375 .22249 L
s
.5 .27193 m
.50375 .27193 L
s
.5 .29666 m
.50375 .29666 L
s
.5 .32138 m
.50375 .32138 L
s
.5 .3461 m
.50375 .3461 L
s
.5 .39554 m
.50375 .39554 L
s
.5 .42026 m
.50375 .42026 L
s
.5 .44498 m
.50375 .44498 L
s
.5 .46971 m
.50375 .46971 L
s
.5 .51915 m
.50375 .51915 L
s
.5 .54387 m
.50375 .54387 L
s
.5 .56859 m
.50375 .56859 L
s
.5 .59331 m
.50375 .59331 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -85.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.813 moveto
(8) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 12.813 moveto
(,) show
84.563 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
102.563 12.813 moveto
(<) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
0?oooolQoooo0027oooo1@0009Coool008Woool00`000?ooooooo`2Doooo0029oooo00<0003ooooo
ool00oooo`<0002>oooo0021oooo100000Coool00`000?ooooooo`03oooo00<0003oooooool0S_oo
o`00ROooo`030000oooooooo00?oool00`000?ooooooo`2>oooo0028oooo0P0000Goool00`000?oo
ooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool2
0000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0
003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`80002?oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`00Soooo`030000oooooooo08koool008ooool20000Soooo`00Soooo`030000oooooooo08koool0
08ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo
08koool008ooool00`000?ooooooo`2>oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool007coool200001?oo
o`800004oooo0P0000Goool00`000?ooooooo`2>oooo001koooo00@0003oooooool00008oooo00@0
003oooooool00004oooo00<0003oooooool0S_ooo`00Noooo`040000oooooooo00002oooo`030000
oooooooo00;oool30000S_ooo`00MOooo`@00002oooo00@0003oooooool00009oooo0P0000Goool0
0`000?ooooooo`2>oooo001koooo00@0003oooooool00009oooo00<0003oooooool01?ooo`030000
oooooooo08koool007coool200002_ooo`<00004oooo00<0003oooooool0S_ooo`00Soooo`030000
oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`80002?oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool0
0`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool0
08ooool20000Soooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?
oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool008ooool00`000?ooooooo`2>
oooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>oooo000Ioooo0`0003Soool40000=ooo
o`030000oooooooo03Ooool40000>oooo`<0000Eoooo000Joooo00<0003oooooool0=oooo`030000
oooooooo03Soool00`000?ooooooo`0goooo00<0003oooooool0?Oooo`030000oooooooo01Coool0
01Ooool50000>Oooo`030000oooooooo03Ooool00`000?ooooooo`0hoooo00<0003oooooool0>Ooo
o`D0000Eoooo000Aoooo100000;oool010000?ooooooo`0003?oool400001?ooo`030000oooooooo
03Koool00`000?ooooooo`0ioooo00<0003oooooool0>?ooo`040000oooooooo00005_ooo`006?oo
o`030000oooo000003Woool010000?ooooooo`0003Ooool20000>?ooo`040000oooooooo0000>_oo
o`030000oooo000001Koool001Woool20000>_ooo`80000hoooo00<0003oooooool0>?ooo`80000l
oooo0P0001Koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_ooo`00Sooo
o`030000oooooooo08koool008ooool00`000?ooooooo`2>oooo002?oooo00<0003oooooool0S_oo
o`004?ooool0000Aoooo000Foooo00@0003oooooool0I_l;oooo00<0003oooooool03?ooo`030000
oooooooo00goool00`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool0
0`000?ooooooo`0<oooo00<0003oooooool03?ooo`030000oooooooo00coool00`000?ooooooo`0<
oooo00<0003oooooool03?ooo`030000oooooooo00[oool00`1Vooooo`00000>oooo00<0003ooooo
ool03Oooo`030000oooooooo00coool00`000?ooooooo`09oooo00Co09Woooooool0000Goooo000I
oooo00<0I_ooooooool0Loooo`030000oooooooo03Ooool00`1Vooooooooo`0ioooo00?o09Wooooo
ool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`0goooo00<0I_ooooooool0>Ooo
o`03o`2Ioooooooo01Soool001Woool00`1Vooooooooo`1coooo00<0003oooooool0=oooo`0306Ko
oooooooo03Woool00ol0VOooooooo`0Hoooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo
03Ooool00`1Vooooooooo`0ioooo00?o09Woooooool06?ooo`006Oooo`0306Kooooooooo07?oool2
0000>?ooo`0306Kooooooooo03Woool00ol0VOooooooo`0Hoooo000Ioooo00<0I_ooooooool0Looo
o`030000oooooooo03Ooool00`1Vooooooooo`0ioooo00?o09Woooooool06?ooo`006Oooo`0306Ko
oooooooo07?oool00`000?ooooooo`0goooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01Soool0
01Woool00`1Vooooooooo`1coooo00<0003oooooool0=oooo`0306Kooooooooo03Woool00ol0VOoo
ooooo`0Hoooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo03Ooool00`1Vooooooooo`0i
oooo00?o09Woooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`0goooo00<0
I_ooooooool0>Oooo`03o`2Ioooooooo01Soool001Woool00`1Vooooooooo`1coooo0P0003Soool0
0`1Vooooooooo`0ioooo00?o09Woooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?oo
ooooo`0goooo00<0I_ooooooool0>Oooo`03o`2Ioooooooo01Soool001Woool00`1Vooooooooo`1c
oooo00<0003oooooool0=oooo`0306Kooooooooo03Woool00ol0VOooooooo`0Hoooo000Ioooo00<0
I_ooooooool0Loooo`030000oooooooo03Ooool00`1Vooooooooo`0ioooo00?o09Woooooool06?oo
o`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`0foooo00<0I_ooooooool0>_ooo`03o`2I
oooooooo01Soool001Woool00`1Vooooooooo`1coooo00<0003oooooool0=_ooo`0306Kooooooooo
03[oool00ol0VOooooooo`0Hoooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo03Koool0
0`1Vooooooooo`0joooo00?o09Woooooool06?ooo`006Oooo`0306Kooooooooo07?oool20000=ooo
o`0306Kooooooooo03[oool00ol0VOooooooo`0Hoooo000Ioooo00<0I_ooooooool0Loooo`030000
oooooooo03Koool00`1Vooooooooo`0joooo00?o09Woooooool06?ooo`006Oooo`0306Kooooooooo
07?oool00`000?ooooooo`0foooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo01Soool001Woool0
0`1Vooooooooo`1coooo00<0003oooooool0=_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0H
oooo000Ioooo00<0I_ooooooool0Loooo`030000oooooooo03Koool00`1Vooooooooo`0joooo00?o
09Woooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`0foooo00<0I_oooooo
ool0>_ooo`03o`2Ioooooooo01Soool001Woool00`1Vooooooooo`1coooo0P0003Ooool00`1Voooo
ooooo`0joooo00?o09Woooooool06?ooo`006Oooo`0306Kooooooooo07?oool00`000?ooooooo`0f
oooo00<0I_ooooooool0>_ooo`03o`2Ioooooooo01Soool001Woool00`1Vooooooooo`1coooo00<0
003oooooool0=_ooo`0306Kooooooooo03[oool00ol0VOooooooo`0Hoooo000Ioooo00<0I_oooooo
ool0Loooo`030000oooooooo03Koool00`1Vooooooooo`0joooo00?o09Woooooool06?ooo`006Ooo
o`0306Kooooooooo063oool200001?ooo`800004oooo0P0000Goool00`000?ooooooo`0foooo00<0
I_ooooooool0>_ooo`03o`2Ioooooooo01Soool001Woool00`1Vooooooooo`1Ooooo00@0003ooooo
ool00008oooo00@0003oooooool00004oooo00<0003oooooool0=_ooo`0306Kooooooooo03[oool0
0ol0VOooooooo`0Hoooo000Ioooo?P1VobCoool010000?ooooooo`0000_oool00`000?ooooooo`02
oooo0`0003Koool00`1Vooooooooo`0joooo00?o09Woooooool06?ooo`00Eoooo`80I_lRoooo00@0
003oooooool00009oooo0P0000Goool00`000?ooooooo`0eoooo00<0I_ooooooool0>oooo`03o`2I
oooooooo01Soool005Woool206Ko8?ooo`040000oooooooo00002Oooo`030000oooooooo00Coool0
0`000?ooooooo`0coooo0P1Vockoool00ol0VOooooooo`0Hoooo001Koooo0P1Voaooool200002_oo
o`<00004oooo00<0003oooooool0<Oooo`80I_m0oooo00?o09Woooooool06?ooo`00GOooo`0306Ko
oooooooo02ooool00`000?ooooooo`0_oooo0P1Vod;oool00ol0VOooooooo`0Hoooo001Noooo0P1V
obooool00`000?ooooooo`0]oooo0P1VodCoool00ol0VOooooooo`0Hoooo001Poooo00<0I_oooooo
ool0;?ooo`80000/oooo0P1VodKoool00ol0VOooooooo`0Hoooo001Qoooo0P1Vobcoool00`000?oo
ooooo`0Zoooo00<0I_ooooooool0A_ooo`03o`2Ioooooooo01Soool006?oool00`1Vooooooooo`0Y
oooo00<0003oooooool0:?ooo`80I_m9oooo00?o09Woooooool06?ooo`00I?ooo`80I_lYoooo00<0
003oooooool09_ooo`80I_m;oooo00?o09Woooooool06?ooo`00I_ooo`0306Kooooooooo02Koool0
0`000?ooooooo`0Uoooo00<0I_ooooooool0Boooo`03o`2Ioooooooo01Soool006Ooool206Ko9_oo
o`030000oooooooo02Coool00`1Vooooooooo`1<oooo00?o09Woooooool06?ooo`00JOooo`0306Ko
oooooooo02?oool00`000?ooooooo`0Roooo0P1Vodooool00ol0VOooooooo`0Hoooo001Zoooo00<0
I_ooooooool08_ooo`80000Roooo00<0I_ooooooool0Coooo`03o`2Ioooooooo01Soool006_oool2
06Ko8_ooo`030000oooooooo023oool00`1Vooooooooo`1@oooo00?o09Woooooool06?ooo`00KOoo
o`0306Kooooooooo01ooool00`000?ooooooo`0Ooooo00<0I_ooooooool0DOooo`03o`2Ioooooooo
01Soool006koool00`1Vooooooooo`0Noooo00<0003oooooool07Oooo`80I_mDoooo00?o09Wooooo
ool06?ooo`00Koooo`80I_lNoooo00<0003oooooool07?ooo`0306Kooooooooo05Coool00ol0VOoo
ooooo`0Hoooo001aoooo00<0I_ooooooool06oooo`030000oooooooo01_oool00`1Vooooooooo`1E
oooo00?o09Woooooool06?ooo`00L_ooo`0306Kooooooooo01[oool200006oooo`0306Kooooooooo
05Koool00ol0VOooooooo`0Hoooo001coooo00<0I_ooooooool06Oooo`030000oooooooo01Woool0
0`1Vooooooooo`1Goooo00?o09Woooooool06?ooo`00M?ooo`0306Kooooooooo01Soool00`000?oo
ooooo`0Hoooo00<0I_ooooooool0F?ooo`03o`2Ioooooooo01Soool007Goool206Ko6?ooo`030000
oooooooo01Ooool00`1Vooooooooo`1Ioooo00?o09Woooooool06?ooo`00Moooo`0306Kooooooooo
01Goool00`000?ooooooo`0Eoooo0P1Voecoool00ol0VOooooooo`0Hoooo001hoooo00<0I_oooooo
ool05?ooo`030000oooooooo01Coool00`1Vooooooooo`1Loooo00?o09Woooooool06?ooo`00NOoo
o`0306Kooooooooo01?oool200005?ooo`0306Kooooooooo05goool00ol0VOooooooo`0Hoooo001j
oooo00<0I_ooooooool04_ooo`030000oooooooo01;oool00`1Vooooooooo`1Noooo00?o09Wooooo
ool06?ooo`00Noooo`0306Kooooooooo017oool00`000?ooooooo`0Aoooo00<0I_ooooooool0Gooo
o`03o`2Ioooooooo01Soool007coool00`1Vooooooooo`0@oooo00<0003oooooool04?ooo`0306Ko
oooooooo063oool00ol0VOooooooo`0Hoooo001moooo00<0I_ooooooool01oooo`D00003oooo00<0
003oooooool03oooo`0306Kooooooooo067oool00ol0VOooooooo`0Hoooo001noooo00<0I_oooooo
ool02?ooo`030000oooooooo00?oool00`000?ooooooo`0>oooo00<0I_ooooooool0H_ooo`03o`2I
oooooooo01Soool007ooool00`1Vooooooooo`07oooo00<0003oooooool00oooo`<0000=oooo00<0
I_ooooooool0Hoooo`03o`2Ioooooooo01Soool0083oool00`1Vooooooooo`06oooo00<0003ooooo
ool00oooo`030000oooooooo00coool00`1Vooooooooo`1Toooo00?o09Woooooool06?ooo`00POoo
o`0306Kooooooooo00Goool00`000?ooooooo`03oooo00<0003oooooool03?ooo`0306Kooooooooo
06Coool00ol0VOooooooo`0Hoooo0022oooo00<0I_ooooooool00oooo`800005oooo00<0003ooooo
ool02oooo`0306Kooooooooo06Goool00ol0VOooooooo`0Hoooo0023oooo00<0I_ooooooool02Ooo
o`030000oooooooo00[oool00`1Vooooooooo`1Voooo00?o09Woooooool06?ooo`00Q?ooo`0306Ko
oooooooo00Soool00`000?ooooooo`09oooo00<0I_ooooooool0Ioooo`03o`2Ioooooooo01Soool0
08Goool00`1Vooooooooo`07oooo00<0003oooooool02?ooo`0306Kooooooooo06Soool00ol0VOoo
ooooo`0Hoooo0026oooo00<0I_ooooooool01_ooo`800008oooo00<0I_ooooooool0JOooo`03o`2I
oooooooo01Soool008Koool00`1Vooooooooo`06oooo00<0003oooooool01_ooo`0306Kooooooooo
06[oool00ol0VOooooooo`0Hoooo0027oooo00<0I_ooooooool01Oooo`030000oooooooo00Goool0
0`1Vooooooooo`1[oooo00?o09Woooooool06?ooo`00R?ooo`0306Kooooooooo00Coool00`000?oo
ooooo`04oooo00<0I_ooooooool0K?ooo`03o`2Ioooooooo01Soool008Woool00`1Vooooooooo`03
oooo00<0003oooooool01?ooo`0306Kooooooooo06coool00ol0VOooooooo`0Hoooo0029oooo00<0
I_ooooooool00oooo`030000oooooooo00?oool00`1Vooooooooo`1]oooo00?o09Woooooool06?oo
o`00R_ooo`0306Kooooooooo00;oool200000oooo`0306Kooooooooo06koool00ol0VOooooooo`0H
oooo002;oooo00D0I_ooooooooooool000000oooo`0306Kooooooooo06ooool00ol0VOooooooo`0H
oooo002<oooo00@0I_ooooooool00002oooo00<0I_ooooooool0L?ooo`03o`2Ioooooooo01Soool0
08goool01@1Vooooo`000?ooo`1Vo`1coooo00?o09Woooooool06?ooo`00S_ooo`0306Ko000006Ko
07Coool00ol0VOooooooo`0Hoooo002>oooo00<0I_l00000I_l0M?ooo`03o`2Ioooooooo01Soool0
08ooool20000M?ooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Wooooo
ool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo00<0003ooooo
ool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?ooooooo`1coooo00?o09Woooooool06?oo
o`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0Hoooo002?oooo0P0007Coool00ol0VOoo
ooooo`0Hoooo002?oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool008ooool00`000?oo
ooooo`1coooo00?o09Woooooool06?ooo`00Soooo`030000oooooooo07?oool00ol0VOooooooo`0H
oooo002?oooo00<0003oooooool0Loooo`03o`2Ioooooooo01Soool007_oool500000_ooo`800004
oooo0P0000Goool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00OOooo`030000oooooooo
00Ooool010000?ooooooo`0000Coool00`000?ooooooo`1coooo00?o09Woooooool06?ooo`00OOoo
o`030000oooooooo00[oool00`000?ooooooo`02oooo0`0007?oool00ol0VOooooooo`0Hoooo001m
oooo00<0003oooooool02?ooo`80002Foooo001moooo00<0003oooooool02?ooo`030000oooooooo
09Goool007coool200002_ooo`<0002Eoooo003ooooo8Oooo`00ooooob7oool007coool00`000?oo
ooooo`0Roooo00<0003oooooool0O?ooo`00Noooo`030000oooooooo00Soool00`000?ooooooo`0I
oooo00<0003oooooool0Noooo`00Noooo`030000oooooooo00;oool200001?ooo`030000oooooooo
00Koool400000oooo`800003oooo0`0000Coool00`000?ooooooo`1koooo001koooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00;oool00`000?ooooooo`05oooo00<0003oooooool02ooo
o`030000oooooooo00;oool00`000?ooooooo`1koooo001joooo00<0003oooooool00_ooo`030000
oooooooo00koool00`000?ooooooo`09oooo0`0000Coool00`000?ooooooo`1joooo001koooo00<0
003oooooool01@0000koool00`000?ooooooo`07oooo00@0003oooooool00003oooo00<0003ooooo
ool0Noooo`00Noooo`050000oooooooooooo000000ooool010000?ooooooo`0000Soool010000?oo
ooooo`0000?oool00`000?ooooooo`1koooo001loooo00<0003oooooool04Oooo`80000:oooo0`00
00;oool00`000?ooooooo`1loooo003ooooo8Oooo`00ooooob7oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00124022, -5.00002*^-06, \
0.00349296, 0.00565173}, {{0.3125, 286.625}, {176.938, 0}} -> {-4.75297, \
-1.0718, 0.0331289, 0.0159535}, {{0.3125, 286.625}, {176.938, 0}} -> \
{-4.75297, -1.0718, 0.0331289, 0.0159535}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
ScreenStyleEnvironment->"Working",
WindowSize->{757, 792},
WindowMargins->{{Automatic, 127}, {Automatic, -10}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 212, 6, 96, "Title"],
Cell[1942, 60, 1013, 25, 258, "Text"],
Cell[2958, 87, 120, 4, 49, "Text"],
Cell[3081, 93, 344, 6, 19, "Input",
  CellOpen->False],
Cell[3428, 101, 185, 5, 68, "Text"],
Cell[3616, 108, 91, 1, 30, "Input"],
Cell[3710, 111, 108, 1, 49, "Text"],
Cell[3821, 114, 557, 12, 19, "Input",
  CellOpen->False],
Cell[4381, 128, 74, 2, 19, "Input",
  CellOpen->False],
Cell[4458, 132, 75, 2, 19, "Input",
  CellOpen->False],
Cell[4536, 136, 373, 12, 49, "Text"],

Cell[CellGroupData[{
Cell[4934, 152, 657, 11, 110, "Input"],

Cell[CellGroupData[{
Cell[5616, 167, 21637, 820, 186, 10866, 683, "GraphicsData", "PostScript", \
"Graphics"],
Cell[27256, 989, 21870, 826, 186, 10920, 686, "GraphicsData", "PostScript", \
"Graphics"],
Cell[49129, 1817, 21810, 826, 186, 10950, 688, "GraphicsData", "PostScript", \
"Graphics"],
Cell[70942, 2645, 21878, 826, 186, 10924, 686, "GraphicsData", "PostScript", \
"Graphics"],
Cell[92823, 3473, 21794, 824, 186, 10901, 685, "GraphicsData", "PostScript", \
"Graphics"],
Cell[114620, 4299, 21912, 828, 186, 10954, 688, "GraphicsData", "PostScript", \
"Graphics"],
Cell[136535, 5129, 21653, 823, 186, 10922, 686, "GraphicsData", "PostScript", \
"Graphics"],
Cell[158191, 5954, 21675, 823, 186, 10920, 686, "GraphicsData", "PostScript", \
"Graphics"],
Cell[179869, 6779, 21521, 821, 186, 10920, 686, "GraphicsData", "PostScript", \
"Graphics"],
Cell[201393, 7602, 21695, 825, 186, 10952, 688, "GraphicsData", "PostScript", \
"Graphics"],
Cell[223091, 8429, 21657, 824, 186, 10934, 687, "GraphicsData", "PostScript", \
"Graphics"],
Cell[244751, 9255, 21866, 828, 186, 10969, 689, "GraphicsData", "PostScript", \
"Graphics"],
Cell[266620, 10085, 21784, 827, 186, 10968, 689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[288407, 10914, 21844, 825, 186, 10927, 686, "GraphicsData", \
"PostScript", "Graphics"],
Cell[310254, 11741, 21586, 823, 186, 10936, 687, "GraphicsData", \
"PostScript", "Graphics"],
Cell[331843, 12566, 21674, 826, 186, 10988, 690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[353520, 13394, 21464, 823, 186, 10968, 689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[374987, 14219, 21408, 821, 186, 10940, 687, "GraphicsData", \
"PostScript", "Graphics"],
Cell[396398, 15042, 19668, 799, 186, 10938, 687, "GraphicsData", \
"PostScript", "Graphics"],
Cell[416069, 15843, 19395, 797, 186, 10956, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[435467, 16642, 18902, 789, 186, 10917, 686, "GraphicsData", \
"PostScript", "Graphics"],
Cell[454372, 17433, 19269, 795, 186, 10956, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[473644, 18230, 19614, 799, 186, 10953, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[493261, 19031, 21271, 821, 186, 10982, 690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[514535, 19854, 21744, 826, 186, 10965, 689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[536282, 20682, 21917, 829, 186, 10967, 689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[558202, 21513, 21900, 832, 186, 11031, 693, "GraphicsData", \
"PostScript", "Graphics"],
Cell[580105, 22347, 21947, 829, 186, 10969, 689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[602055, 23178, 21816, 826, 186, 10939, 687, "GraphicsData", \
"PostScript", "Graphics"],
Cell[623874, 24006, 21944, 829, 186, 10970, 689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[645821, 24837, 21844, 829, 186, 11000, 691, "GraphicsData", \
"PostScript", "Graphics"],
Cell[667668, 25668, 21941, 832, 186, 11036, 693, "GraphicsData", \
"PostScript", "Graphics"],
Cell[689612, 26502, 21841, 832, 186, 11049, 694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[711456, 27336, 21933, 830, 186, 11000, 691, "GraphicsData", \
"PostScript", "Graphics"],
Cell[733392, 28168, 21871, 830, 186, 11015, 692, "GraphicsData", \
"PostScript", "Graphics"],
Cell[755266, 29000, 22018, 833, 186, 11036, 693, "GraphicsData", \
"PostScript", "Graphics"],
Cell[777287, 29835, 21924, 832, 186, 11035, 693, "GraphicsData", \
"PostScript", "Graphics"],
Cell[799214, 30669, 21930, 829, 186, 10972, 689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[821147, 31500, 21831, 827, 186, 10954, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[842981, 32329, 21456, 823, 186, 10968, 689, "GraphicsData", \
"PostScript", "Graphics"],
Cell[864440, 33154, 19729, 779, 186, 10318, 658, "GraphicsData", \
"PostScript", "Graphics"],
Cell[884172, 33935, 21040, 809, 186, 10609, 676, "GraphicsData", \
"PostScript", "Graphics"],
Cell[905215, 34746, 21387, 812, 186, 10575, 674, "GraphicsData", \
"PostScript", "Graphics"],
Cell[926605, 35560, 21564, 816, 186, 10623, 677, "GraphicsData", \
"PostScript", "Graphics"],
Cell[948172, 36378, 21544, 819, 186, 10688, 681, "GraphicsData", \
"PostScript", "Graphics"],
Cell[969719, 37199, 21639, 821, 186, 10689, 681, "GraphicsData", \
"PostScript", "Graphics"],
Cell[991361, 38022, 21496, 819, 186, 10684, 681, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1012860, 38843, 21508, 816, 186, 10623, 677, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1034371, 39661, 21410, 818, 186, 10687, 681, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1055784, 40481, 21534, 820, 186, 10706, 682, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1077321, 41303, 21409, 816, 186, 10654, 679, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1098733, 42121, 21521, 818, 186, 10656, 679, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1120257, 42941, 21410, 815, 186, 10639, 678, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1141670, 43758, 21601, 819, 186, 10668, 680, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1163274, 44579, 21556, 822, 186, 10732, 684, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1184833, 45403, 21555, 817, 186, 10638, 678, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1206391, 46222, 21478, 819, 186, 10682, 681, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1227872, 47043, 21525, 817, 186, 10640, 678, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1249400, 47862, 20930, 809, 186, 10641, 678, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1270333, 48673, 20947, 810, 186, 10658, 679, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1291283, 49485, 20681, 807, 186, 10647, 679, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1311967, 50294, 21086, 819, 186, 10801, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1333056, 51115, 21199, 826, 186, 10889, 694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1354258, 51943, 21703, 833, 186, 10928, 696, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1375964, 52778, 21862, 839, 186, 10989, 700, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1397829, 53619, 21999, 840, 186, 10993, 700, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1419831, 54461, 21907, 841, 186, 11018, 702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1441741, 55304, 21966, 838, 186, 10960, 698, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1463710, 56144, 21846, 837, 186, 10953, 698, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1485559, 56983, 22051, 841, 186, 10988, 700, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1507613, 57826, 21953, 841, 186, 10995, 701, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1529569, 58669, 22174, 847, 186, 11062, 705, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1551746, 59518, 21982, 839, 186, 10968, 699, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1573731, 60359, 22324, 851, 186, 11111, 708, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1596058, 61212, 22149, 844, 186, 11013, 702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1618210, 62058, 22380, 851, 186, 11098, 707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1640593, 62911, 22227, 846, 186, 11026, 703, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1662823, 63759, 22403, 848, 186, 11040, 703, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1685229, 64609, 22349, 849, 186, 11063, 705, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1707581, 65460, 22472, 852, 186, 11093, 707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1730056, 66314, 22258, 844, 186, 10997, 701, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1752317, 67160, 22618, 854, 186, 11101, 707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1774938, 68016, 22532, 851, 186, 11068, 705, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1797473, 68869, 22729, 855, 186, 11099, 707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1820205, 69726, 22676, 852, 186, 11046, 704, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1842884, 70580, 22876, 857, 186, 11100, 707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1865763, 71439, 22794, 853, 186, 11047, 704, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1888560, 72294, 22819, 850, 186, 10970, 699, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1911382, 73146, 22904, 859, 186, 11124, 709, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1934289, 74007, 23006, 859, 186, 11121, 708, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1957298, 74868, 23011, 862, 186, 11162, 711, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1980312, 75732, 23056, 858, 186, 11086, 706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2003371, 76592, 23093, 860, 186, 11094, 707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2026467, 77454, 23284, 863, 186, 11132, 709, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2049754, 78319, 23271, 859, 186, 11050, 704, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2073028, 79180, 23518, 865, 186, 11094, 707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2096549, 80047, 23501, 863, 186, 11061, 705, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2120053, 80912, 23647, 864, 186, 11049, 704, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2143703, 81778, 23605, 864, 186, 11060, 705, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

